{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "LSE Data Science Institute | ME204 (2023/24) | Week 01 Day 03\n",
    "\n",
    "# 💻 Week 01 – Day 03: Dataviz Practice \n",
    "\n",
    "<span style=\"color:#E69F25;font-weight: 500 !important\">(AFTERNOON NOTEBOOK)</span>\n",
    "\n",
    "**DATE:** 10 July 2024\n",
    "\n",
    "**AUTHOR:** [Alexander Soldatkin](https://www.area-studies.ox.ac.uk/people/alexander-soldatkin) (edited by Dr [Jon Cardoso-Silva](https://jonjoncardoso.github.io))\n",
    "\n",
    "-----"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## ⚙️ Setup\n",
    "\n",
    "- Ensure the Python kernel has the necessary libraries: `pandas`, `matplotlib` and `lets-plot`, `numerize`\n",
    "- Ensure the `bakery.csv` file is in the `data` folder."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Imports**\n",
    "\n",
    "(It is a good practice to import ALL the libraries you will be using at the start of your notebook)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "            <div id=\"EpFCoh\"></div>\n",
       "            <script type=\"text/javascript\" data-lets-plot-script=\"library\">\n",
       "                if(!window.letsPlotCallQueue) {\n",
       "                    window.letsPlotCallQueue = [];\n",
       "                }; \n",
       "                window.letsPlotCall = function(f) {\n",
       "                    window.letsPlotCallQueue.push(f);\n",
       "                };\n",
       "                (function() {\n",
       "                    var script = document.createElement(\"script\");\n",
       "                    script.type = \"text/javascript\";\n",
       "                    script.src = \"https://cdn.jsdelivr.net/gh/JetBrains/lets-plot@v4.3.3/js-package/distr/lets-plot.min.js\";\n",
       "                    script.onload = function() {\n",
       "                        window.letsPlotCall = function(f) {f();};\n",
       "                        window.letsPlotCallQueue.forEach(function(f) {f();});\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        \n",
       "                    };\n",
       "                    script.onerror = function(event) {\n",
       "                        window.letsPlotCall = function(f) {};    // noop\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        var div = document.createElement(\"div\");\n",
       "                        div.style.color = 'darkred';\n",
       "                        div.textContent = 'Error loading Lets-Plot JS';\n",
       "                        document.getElementById(\"EpFCoh\").appendChild(div);\n",
       "                    };\n",
       "                    var e = document.getElementById(\"EpFCoh\");\n",
       "                    e.appendChild(script);\n",
       "                })()\n",
       "            </script>\n",
       "            "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import numpy as np\n",
    "import pandas as pd\n",
    "\n",
    "from numerize import numerize as nz\n",
    "\n",
    "from lets_plot import * # This imports all of ggplot2's functions\n",
    "LetsPlot.setup_html()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "⬇️ **Downloading and reading the Data**\n",
    "\n",
    "In today's lab, we will use a different dataset called Gapminder. It has data on life expectancy, GDP per capita, and population by country and year, among other variables.\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Note that `pd.read_csv()` can also take in a URL as an argument. \n",
    "gapminder = pd.read_csv('https://raw.githubusercontent.com/kirenz/datasets/master/gapminder.csv')\n",
    "\n",
    "# We need to convert the year column to a date object\n",
    "gapminder.year = pd.to_datetime(gapminder.year, format='%Y')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# 1. Intro to Grammar of Graphics: Gapminder Data\n",
    "\n",
    "In the morning session, you had a brief introduction to `lets-plot` and the layered grammar of graphics approach to building visualizations. Now, let's get a bit more formal into the concepts."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<iframe width=\"560\" height=\"315\" src=\"https://www.youtube.com/embed/hVimVzgtD6w?si=Mq7_Gnr8T07o_qIM&amp;start=210\" title=\"YouTube video player\" frameborder=\"0\" allow=\"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share\" referrerpolicy=\"strict-origin-when-cross-origin\" allowfullscreen></iframe>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "<iframe width=\"560\" height=\"315\" src=\"https://www.youtube.com/embed/aJQmVZSAqlc?si=kKNQNwEs_DYcyJRd&amp;start=16\" title=\"YouTube video player\" frameborder=\"0\" allow=\"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share\" referrerpolicy=\"strict-origin-when-cross-origin\" allowfullscreen></iframe>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Let's start layering "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Observe what changes in the code below when we add layers to the plot. If you just define the data and the aesthetics, you get `No layers in plot`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"6j3khl\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"6j3khl\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x2a1fded4df0>"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             )    \n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Add the first layer: `geom_point()`"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now let's add a `geom_point()` layer to the plot, which is a simple scatter plot. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 75,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"fqOWv9\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,30.332,31.997,34.02,36.088,38.438,39.854,40.822,41.674,41.763,42.129,43.828,55.23,59.28,64.82,66.22,67.69,68.93,70.42,72.0,71.581,72.95,75.651,76.423,43.077,45.685,48.303,51.407,54.518,58.014,61.368,65.799,67.744,69.152,70.994,72.301,30.015,31.999,34.0,35.985,37.928,39.483,39.942,39.906,40.647,40.963,41.003,42.731,62.485,64.399,65.142,65.634,67.065,68.481,69.942,70.774,71.868,73.275,74.34,75.32,69.12,70.33,70.93,71.1,71.93,73.49,74.74,76.32,77.56,78.83,80.37,81.235,66.8,67.48,69.54,70.14,70.63,72.17,73.18,74.94,76.04,77.51,78.98,79.829,50.939,53.832,56.923,59.923,63.3,65.593,69.052,70.75,72.601,73.925,74.795,75.635,37.484,39.348,41.216,43.453,45.252,46.923,50.009,52.819,56.018,59.412,62.013,64.062,68.0,69.24,70.25,70.94,71.44,72.8,73.93,75.35,76.46,77.53,78.32,79.441,38.223,40.358,42.618,44.885,47.014,49.19,50.904,52.337,53.919,54.777,54.406,56.728,40.414,41.89,43.428,45.032,46.714,50.023,53.859,57.251,59.957,62.05,63.883,65.554,53.82,58.45,61.93,64.79,67.45,69.86,70.69,71.14,72.178,73.244,74.09,74.852,47.622,49.618,51.52,53.298,56.024,59.319,61.484,63.622,62.745,52.556,46.634,50.728,50.917,53.285,55.665,57.632,59.504,61.489,63.336,65.205,67.057,69.388,71.006,72.39,59.6,66.61,69.51,70.42,70.9,70.81,71.08,71.34,71.19,70.32,72.14,73.005,31.975,34.906,37.814,40.697,43.591,46.137,48.122,49.557,50.26,50.324,50.65,52.295,39.031,40.533,42.045,43.548,44.057,45.91,47.471,48.211,44.736,45.326,47.36,49.58,39.417,41.366,43.415,45.415,40.317,31.22,50.957,53.914,55.803,56.534,56.752,59.723,38.523,40.428,42.643,44.799,47.049,49.355,52.961,54.985,54.314,52.199,49.856,50.43,68.75,69.96,71.3,72.13,72.88,74.21,75.76,76.86,77.95,78.61,79.77,80.653,35.463,37.464,39.475,41.478,43.457,46.775,48.295,50.485,49.396,46.066,43.308,44.741,38.092,39.881,41.716,43.601,45.569,47.383,49.517,51.051,51.724,51.573,50.525,50.651,54.745,56.074,57.924,60.523,63.441,67.052,70.565,72.492,74.126,75.816,77.86,78.553,44.0,50.54896,44.50136,58.38112,63.11888,63.96736,65.525,67.274,68.69,70.426,72.028,72.961,50.643,55.118,57.863,59.963,61.623,63.837,66.653,67.768,68.421,70.313,71.682,72.889,40.715,42.46,44.467,46.472,48.944,50.939,52.933,54.926,57.939,60.66,62.974,65.152,39.143,40.652,42.122,44.056,45.989,47.804,47.784,47.412,45.548,42.587,44.966,46.462,42.111,45.053,48.435,52.04,54.907,55.625,56.695,57.47,56.433,52.962,52.97,55.322,57.206,60.026,62.842,65.424,67.849,70.75,73.45,74.752,75.713,77.26,78.123,78.782,40.477,42.469,44.93,47.35,49.801,52.374,53.983,54.655,52.044,47.991,46.832,48.328,61.21,64.77,67.13,68.5,69.61,70.64,70.46,71.52,72.527,73.68,74.876,75.748,59.421,62.325,65.246,68.29,70.723,72.649,73.717,74.174,74.414,76.151,77.158,78.273,66.87,69.03,69.9,70.38,70.29,70.71,70.96,71.58,72.4,74.01,75.51,76.486,70.78,71.81,72.35,72.96,73.47,74.69,74.63,74.8,75.33,76.11,77.18,78.332,34.812,37.328,39.693,42.074,44.366,46.519,48.812,50.04,51.604,53.157,53.373,54.791,45.928,49.828,53.459,56.751,59.631,61.788,63.727,66.046,68.457,69.957,70.847,72.235,48.357,51.356,54.64,56.678,58.796,61.31,64.342,67.231,69.613,72.312,74.173,74.994,41.893,44.444,46.992,49.293,51.137,53.319,56.006,59.797,63.674,67.217,69.806,71.338,45.262,48.57,52.307,55.855,58.207,56.696,56.604,63.154,66.798,69.535,70.734,71.878,34.482,35.983,37.485,38.987,40.516,42.024,43.662,45.664,47.545,48.245,49.348,51.579,35.928,38.047,40.158,42.189,44.142,44.535,43.89,46.453,49.991,53.378,55.24,58.04,34.078,36.667,40.059,42.115,43.515,44.51,44.916,46.684,48.091,49.402,50.725,52.947,66.55,67.49,68.75,69.83,70.87,72.52,74.55,74.83,75.7,77.13,78.37,79.313,67.41,68.93,70.51,71.55,72.38,73.83,74.89,76.34,77.46,78.64,79.59,80.657,37.003,38.999,40.489,44.598,48.69,52.79,56.564,60.19,61.366,60.461,56.761,56.735,30.0,32.065,33.896,35.857,38.308,41.842,45.58,49.265,52.644,55.861,58.041,59.448,67.5,69.1,70.3,70.8,71.0,72.5,73.8,74.847,76.07,77.34,78.67,79.406,43.149,44.779,46.452,48.072,49.875,51.756,53.744,55.729,57.501,58.556,58.453,60.022,65.86,67.86,69.51,71.0,72.34,73.68,75.24,76.67,77.03,77.869,78.256,79.483,42.023,44.142,46.954,50.016,53.738,56.029,58.137,60.782,63.373,66.322,68.978,70.259,33.609,34.558,35.753,37.197,38.842,40.762,42.891,45.552,48.576,51.455,53.676,56.007,32.5,33.489,34.488,35.492,36.486,37.465,39.327,41.245,43.266,44.873,45.504,46.388,37.579,40.696,43.59,46.243,48.042,49.923,51.461,53.636,55.089,56.671,58.137,60.916,41.912,44.665,48.041,50.924,53.884,57.402,60.909,64.492,66.399,67.659,68.565,70.198,60.96,64.75,67.65,70.0,72.0,73.6,75.45,76.2,77.601,80.0,81.495,82.208,64.03,66.41,67.96,69.5,69.76,69.95,69.39,69.58,69.17,71.04,72.59,73.338,72.49,73.47,73.68,73.73,74.46,76.11,76.99,77.23,78.77,78.95,80.5,81.757,37.373,40.249,43.605,47.193,50.651,54.208,56.596,58.553,60.223,61.765,62.879,64.698,37.468,39.918,42.518,45.964,49.203,52.702,56.159,60.137,62.681,66.041,68.588,70.65,44.869,47.181,49.325,52.469,55.234,57.702,59.62,63.04,65.742,68.042,69.451,70.964,45.32,48.437,51.457,54.459,56.95,60.413,62.038,65.044,59.461,58.811,57.046,59.545,66.91,68.9,70.29,71.08,71.28,72.03,73.1,74.36,75.467,76.122,77.783,78.885,65.39,67.84,69.39,70.75,71.63,73.06,74.45,75.6,76.93,78.269,79.696,80.745,65.94,67.81,69.24,71.06,72.19,73.48,74.98,76.42,77.44,78.82,80.24,80.546,58.53,62.61,65.61,67.51,69.0,70.11,71.21,71.77,71.766,72.262,72.047,72.567,63.03,65.5,68.73,71.43,73.42,75.38,77.11,78.67,79.36,80.69,82.0,82.603,43.158,45.669,48.126,51.629,56.528,61.134,63.739,65.869,68.015,69.772,71.263,72.535,42.27,44.686,47.949,50.654,53.559,56.155,58.766,59.339,59.285,54.407,50.992,54.11,50.056,54.081,56.656,59.942,63.983,67.159,69.1,70.647,69.978,67.727,66.662,67.297,47.453,52.681,55.292,57.716,62.612,64.766,67.123,69.81,72.244,74.647,77.045,78.623,55.565,58.033,60.47,64.624,67.712,69.343,71.309,74.174,75.19,76.156,76.904,77.588,55.928,59.489,62.094,63.87,65.421,66.099,66.983,67.926,69.292,70.265,71.028,71.993,42.138,45.047,47.747,48.492,49.767,52.208,55.078,57.18,59.685,55.558,44.593,42.592,38.48,39.486,40.502,41.536,42.614,43.764,44.852,46.027,40.802,42.221,43.753,45.678,42.723,45.289,47.808,50.227,52.773,57.442,62.155,66.234,68.755,71.555,72.737,73.952,36.681,38.865,40.848,42.881,44.851,46.881,48.969,49.35,52.214,54.978,57.286,59.443,36.256,37.207,38.41,39.487,41.766,43.767,45.642,47.457,49.42,47.495,45.009,48.303,48.463,52.102,55.737,59.371,63.01,65.256,68.0,69.5,70.693,71.938,73.044,74.241,33.685,35.307,36.936,38.487,39.977,41.714,43.916,46.364,48.388,49.903,51.818,54.467,40.543,42.338,44.248,46.289,48.437,50.852,53.599,56.145,58.333,60.43,62.247,64.164,50.986,58.089,60.246,61.557,62.944,64.93,66.711,68.74,69.745,70.736,71.954,72.801,50.789,55.19,58.299,60.11,62.361,65.032,67.405,69.498,71.455,73.67,74.902,76.195,42.244,45.248,48.251,51.253,53.754,55.491,57.489,60.222,61.271,63.625,65.033,66.803,59.164,61.448,63.728,67.178,70.636,73.066,74.101,74.865,75.435,75.445,73.981,74.543,42.873,45.423,47.924,50.335,52.862,55.73,59.65,62.677,65.393,67.66,69.615,71.164,31.286,33.779,36.161,38.113,40.328,42.495,42.795,42.861,44.284,46.344,44.026,42.082,36.319,41.905,45.108,49.379,53.07,56.059,58.056,58.339,59.32,60.328,59.908,62.069,41.725,45.226,48.386,51.159,53.867,56.437,58.968,60.835,61.999,58.909,51.479,52.906,36.157,37.686,39.393,41.472,43.971,46.748,49.594,52.537,55.727,59.426,61.34,63.785,72.13,72.99,73.23,73.82,73.75,75.24,76.05,76.83,77.42,78.03,78.53,79.762,69.39,70.26,71.24,71.52,71.89,72.22,73.84,74.32,76.33,77.55,79.11,80.204,42.314,45.432,48.632,51.884,55.151,57.47,59.298,62.008,65.843,68.426,70.836,72.899,37.444,38.598,39.487,40.118,40.546,41.291,42.598,44.555,47.391,51.313,54.496,56.867,36.324,37.802,39.36,41.04,42.821,44.514,45.826,46.886,47.472,47.464,46.608,46.859,72.67,73.44,73.47,74.08,74.34,75.37,75.97,75.89,77.32,78.32,79.05,80.196,37.578,40.08,43.165,46.988,52.143,57.367,62.728,67.734,71.197,72.499,74.193,75.64,43.436,45.557,47.67,49.8,51.929,54.043,56.158,58.245,60.838,61.818,63.61,65.483,55.191,59.201,61.817,64.071,66.216,68.681,70.472,71.523,72.462,73.738,74.712,75.537,62.649,63.196,64.361,64.951,65.815,66.353,66.874,67.378,68.225,69.4,70.755,71.752,43.902,46.263,49.096,51.445,55.448,58.447,61.406,64.134,66.458,68.386,69.906,71.421,47.752,51.334,54.757,56.393,58.065,60.06,62.082,64.151,66.458,68.564,70.303,71.688,61.31,65.77,67.64,69.61,70.85,70.67,71.32,70.98,70.99,72.75,74.67,75.563,59.82,61.51,64.39,66.6,69.26,70.41,72.77,74.06,74.86,75.97,77.29,78.098,64.28,68.54,69.62,71.1,72.16,73.44,73.75,74.63,73.911,74.917,77.778,78.746,52.724,55.09,57.666,60.542,64.274,67.064,69.885,71.913,73.615,74.772,75.744,76.442,61.05,64.1,66.8,66.8,69.21,69.46,69.66,69.53,69.36,69.72,71.322,72.476,40.0,41.5,43.0,44.1,44.6,45.0,46.218,44.02,23.599,36.087,43.413,46.242,46.471,48.945,51.893,54.425,56.48,58.55,60.351,61.728,62.742,63.306,64.337,65.528,39.875,42.868,45.914,49.901,53.886,58.69,63.012,66.295,68.768,70.533,71.626,72.777,37.278,39.329,41.454,43.563,45.815,48.879,52.379,55.769,58.196,60.187,61.6,63.062,57.996,61.685,64.531,66.914,68.7,70.3,70.162,71.218,71.659,72.232,73.213,74.002,30.331,31.57,32.767,34.113,35.4,36.788,38.445,40.006,38.333,39.897,41.012,42.568,60.396,63.179,65.798,67.946,69.521,70.795,71.76,73.56,75.788,77.158,78.77,79.972,64.36,67.45,70.33,70.98,70.35,70.45,70.8,71.08,71.38,72.71,73.8,74.663,65.57,67.85,69.15,69.18,69.82,70.97,71.063,72.25,73.64,75.13,76.66,77.926,32.978,34.977,36.981,38.977,40.973,41.974,42.955,44.501,39.658,43.795,45.936,48.159,45.009,47.985,49.951,51.927,53.696,55.527,58.161,60.834,61.888,60.236,53.365,49.339,64.94,66.66,69.69,71.44,73.06,74.39,76.3,76.9,77.57,78.77,79.78,80.941,57.593,61.456,62.192,64.266,65.042,65.949,68.757,69.011,70.379,70.457,70.815,72.396,38.635,39.624,40.87,42.858,45.083,47.8,50.338,51.744,53.556,55.373,56.369,58.556,41.407,43.424,44.992,46.633,49.552,52.537,55.561,57.678,58.474,54.289,43.869,39.613,71.86,72.49,73.37,74.16,74.72,75.44,76.42,77.19,78.16,79.39,80.04,80.884,69.62,70.56,71.32,72.77,73.78,75.39,76.21,77.41,78.03,79.37,80.62,81.701,45.883,48.284,50.305,53.655,57.296,61.195,64.59,66.974,69.249,71.527,73.053,74.143,58.5,62.4,65.2,67.5,69.39,70.59,72.16,73.4,74.26,75.25,76.99,78.4,41.215,42.974,44.246,45.757,47.62,49.919,50.608,51.535,50.44,48.466,49.651,52.517,50.848,53.63,56.061,58.285,60.405,62.494,64.597,66.084,67.298,67.521,68.564,70.616,38.596,41.208,43.922,46.769,49.759,52.887,55.471,56.941,58.061,58.39,57.561,58.42,59.1,61.8,64.9,65.4,65.9,68.3,68.832,69.582,69.862,69.465,68.976,69.819,44.6,47.1,49.579,52.053,55.602,59.837,64.048,66.894,70.001,71.973,73.042,73.923,43.585,48.079,52.098,54.336,57.005,59.507,61.036,63.108,66.146,68.835,70.845,71.777,39.978,42.571,45.344,48.051,51.016,50.35,49.849,51.509,48.825,44.578,47.813,51.542,69.18,70.42,70.76,71.36,72.01,72.76,74.04,75.007,76.42,77.218,78.471,79.425,68.44,69.49,70.21,70.76,71.34,73.38,74.65,75.02,76.09,76.81,77.31,78.242,66.071,67.044,68.253,68.468,68.673,69.481,70.805,71.918,72.752,74.223,75.307,76.384,55.088,57.907,60.77,63.479,65.712,67.456,68.557,70.19,71.15,72.146,72.766,73.747,40.412,42.887,45.363,47.838,50.254,55.764,58.816,62.82,67.662,70.672,73.017,74.249,43.16,45.671,48.127,51.631,56.532,60.765,64.406,67.046,69.718,71.096,72.37,73.422,32.548,33.97,35.18,36.984,39.848,44.175,49.113,52.922,55.599,58.02,60.308,62.698,42.038,44.077,46.023,47.768,50.107,51.386,51.821,50.821,46.1,40.238,39.193,42.384,48.451,50.469,52.358,53.995,55.635,57.674,60.363,62.351,60.377,46.809,39.989,43.487],\n",
       "\"pop\":[8425333.0,9240934.0,1.0267083E7,1.1537966E7,1.307946E7,1.4880372E7,1.2881816E7,1.3867957E7,1.6317921E7,2.2227415E7,2.5268405E7,3.1889923E7,1282697.0,1476505.0,1728137.0,1984060.0,2263554.0,2509048.0,2780097.0,3075321.0,3326498.0,3428038.0,3508512.0,3600523.0,9279525.0,1.0270856E7,1.1000948E7,1.2760499E7,1.4760787E7,1.7152804E7,2.0033753E7,2.3254956E7,2.6298373E7,2.9072015E7,3.1287142E7,3.3333216E7,4232095.0,4561361.0,4826015.0,5247469.0,5894858.0,6162675.0,7016384.0,7874230.0,8735988.0,9875024.0,1.0866106E7,1.2420476E7,1.7876956E7,1.9610538E7,2.1283783E7,2.2934225E7,2.4779799E7,2.6983828E7,2.9341374E7,3.1620918E7,3.3958947E7,3.6203463E7,3.8331121E7,4.0301927E7,8691212.0,9712569.0,1.0794968E7,1.1872264E7,1.3177E7,1.40741E7,1.51842E7,1.6257249E7,1.7481977E7,1.8565243E7,1.9546792E7,2.0434176E7,6927772.0,6965860.0,7129864.0,7376998.0,7544201.0,7568430.0,7574613.0,7578903.0,7914969.0,8069876.0,8148312.0,8199783.0,120447.0,138655.0,171863.0,202182.0,230800.0,297410.0,377967.0,454612.0,529491.0,598561.0,656397.0,708573.0,4.6886859E7,5.1365468E7,5.6839289E7,6.2821884E7,7.0759295E7,8.0428306E7,9.3074406E7,1.03764241E8,1.13704579E8,1.23315288E8,1.3565679E8,1.50448339E8,8730405.0,8989111.0,9218400.0,9556500.0,9709100.0,9821800.0,9856303.0,9870200.0,1.0045622E7,1.0199787E7,1.031197E7,1.0392226E7,1738315.0,1925173.0,2151895.0,2427334.0,2761407.0,3168267.0,3641603.0,4243788.0,4981671.0,6066080.0,7026113.0,8078314.0,2883315.0,3211738.0,3593918.0,4040665.0,4565872.0,5079716.0,5642224.0,6156369.0,6893451.0,7693188.0,8445134.0,9119152.0,2791000.0,3076000.0,3349000.0,3585000.0,3819000.0,4086000.0,4172693.0,4338977.0,4256013.0,3607000.0,4165416.0,4552198.0,442308.0,474639.0,512764.0,553541.0,619351.0,781472.0,970347.0,1151184.0,1342614.0,1536536.0,1630347.0,1639131.0,5.660256E7,6.5551171E7,7.603939E7,8.8049823E7,1.00840058E8,1.14313951E8,1.28962939E8,1.42938076E8,1.55975974E8,1.68546719E8,1.79914212E8,1.90010647E8,7274900.0,7651254.0,8012946.0,8310226.0,8576200.0,8797022.0,8892098.0,8971958.0,8658506.0,8066057.0,7661799.0,7322858.0,4469979.0,4713416.0,4919632.0,5127935.0,5433886.0,5889574.0,6634596.0,7586551.0,8878303.0,1.0352843E7,1.2251209E7,1.4326203E7,2445618.0,2667518.0,2961915.0,3330989.0,3529983.0,3834415.0,4580410.0,5126023.0,5809236.0,6121610.0,7021078.0,8390505.0,4693836.0,5322536.0,6083619.0,6960067.0,7450606.0,6978607.0,7272485.0,8371791.0,1.0150094E7,1.1782962E7,1.2926707E7,1.4131858E7,5009067.0,5359923.0,5793633.0,6335506.0,7021028.0,7959865.0,9250831.0,1.0780667E7,1.2467171E7,1.4195809E7,1.5929988E7,1.7696293E7,1.4785584E7,1.7010154E7,1.8985849E7,2.0819767E7,2.22845E7,2.37964E7,2.52019E7,2.65497E7,2.8523502E7,3.0305843E7,3.1902268E7,3.3390141E7,1291695.0,1392284.0,1523478.0,1733638.0,1927260.0,2167533.0,2476971.0,2840009.0,3265124.0,3696513.0,4048013.0,4369038.0,2682462.0,2894855.0,3150417.0,3495967.0,3899068.0,4388260.0,4875118.0,5498955.0,6429417.0,7562011.0,8835739.0,1.0238807E7,6377619.0,7048426.0,7961258.0,8858908.0,9717524.0,1.0599793E7,1.1487112E7,1.2463354E7,1.3572994E7,1.4599929E7,1.5497046E7,1.6284741E7,5.56263527E8,6.37408E8,6.6577E8,7.5455E8,8.6203E8,9.43455E8,1.000281E9,1.084035E9,1.16497E9,1.230075E9,1.2804E9,1.318683096E9,1.2350771E7,1.4485993E7,1.7009885E7,1.9764027E7,2.254289E7,2.5094412E7,2.7764644E7,3.0964245E7,3.4202721E7,3.765783E7,4.1008227E7,4.422755E7,153936.0,170928.0,191689.0,217378.0,250027.0,304739.0,348643.0,395114.0,454429.0,527982.0,614382.0,710960.0,1.4100005E7,1.5577932E7,1.7486434E7,1.9941073E7,2.3007669E7,2.648087E7,3.0646495E7,3.5481645E7,4.1672143E7,4.7798986E7,5.5379852E7,6.4606759E7,854885.0,940458.0,1047924.0,1179760.0,1340458.0,1536769.0,1774735.0,2064095.0,2409073.0,2800947.0,3328795.0,3800610.0,926317.0,1112300.0,1345187.0,1588717.0,1834796.0,2108457.0,2424367.0,2799811.0,3173216.0,3518107.0,3834934.0,4133884.0,2977019.0,3300000.0,3832408.0,4744870.0,6071696.0,7459574.0,9025951.0,1.0761098E7,1.2772596E7,1.4625967E7,1.6252726E7,1.8013409E7,3882229.0,3991242.0,4076557.0,4174366.0,4225310.0,4318673.0,4413368.0,4484310.0,4494013.0,4444595.0,4481020.0,4493312.0,6007797.0,6640752.0,7254373.0,8139332.0,8831348.0,9537988.0,9789224.0,1.0239839E7,1.072326E7,1.0983007E7,1.1226999E7,1.1416987E7,9125183.0,9513758.0,9620282.0,9835109.0,9862158.0,1.0161915E7,1.0303704E7,1.0311597E7,1.0315702E7,1.0300707E7,1.0256295E7,1.0228744E7,4334000.0,4487831.0,4646899.0,4838800.0,4991596.0,5088419.0,5117810.0,5127024.0,5171393.0,5283663.0,5374693.0,5468120.0,63149.0,71851.0,89898.0,127617.0,178848.0,228694.0,305991.0,311025.0,384156.0,417908.0,447416.0,496374.0,2491346.0,2923186.0,3453434.0,4049146.0,4671329.0,5302800.0,5968349.0,6655297.0,7351181.0,7992357.0,8650322.0,9319622.0,3548753.0,4058385.0,4681707.0,5432424.0,6298651.0,7278866.0,8365850.0,9545158.0,1.0748394E7,1.1911819E7,1.2921234E7,1.375568E7,2.2223309E7,2.5009741E7,2.8173309E7,3.1681188E7,3.4807417E7,3.8783863E7,4.5681811E7,5.2799062E7,5.9402198E7,6.6134291E7,7.3312559E7,8.0264543E7,2042865.0,2355805.0,2747687.0,3232927.0,3790903.0,4282586.0,4474873.0,4842194.0,5274649.0,5783439.0,6353681.0,6939688.0,216964.0,232922.0,249220.0,259864.0,277603.0,192675.0,285483.0,341244.0,387838.0,439971.0,495627.0,551201.0,1438760.0,1542611.0,1666618.0,1820319.0,2260187.0,2512642.0,2637297.0,2915959.0,3668440.0,4058319.0,4414865.0,4906585.0,2.0860941E7,2.2815614E7,2.5145372E7,2.7860297E7,3.0770372E7,3.4617799E7,3.8111756E7,4.299953E7,5.2088559E7,5.9861301E7,6.7946797E7,7.6511887E7,4090500.0,4324000.0,4491443.0,4605744.0,4639657.0,4738902.0,4826933.0,4931729.0,5041039.0,5134406.0,5193039.0,5238460.0,4.2459667E7,4.4310863E7,4.7124E7,4.9569E7,5.1732E7,5.3165019E7,5.4433565E7,5.56301E7,5.7374179E7,5.8623428E7,5.9925035E7,6.1083916E7,420702.0,434904.0,455661.0,489004.0,537977.0,706367.0,753874.0,880397.0,985739.0,1126189.0,1299304.0,1454867.0,284320.0,323150.0,374020.0,439593.0,517101.0,608274.0,715523.0,848406.0,1025384.0,1235767.0,1457766.0,1688359.0,6.9145952E7,7.1019069E7,7.3739117E7,7.6368453E7,7.8717088E7,7.8160773E7,7.8335266E7,7.7718298E7,8.0597764E7,8.2011073E7,8.2350671E7,8.2400996E7,5581001.0,6391288.0,7355248.0,8490213.0,9354120.0,1.0538093E7,1.1400338E7,1.4168101E7,1.6278738E7,1.8418288E7,2.0550751E7,2.2873338E7,7733250.0,8096218.0,8448233.0,8716441.0,8888628.0,9308479.0,9786480.0,9974490.0,1.0325429E7,1.0502372E7,1.0603863E7,1.070629E7,3146381.0,3640876.0,4208858.0,4690773.0,5149581.0,5703430.0,6395630.0,7326406.0,8486949.0,9803875.0,1.117865E7,1.2572928E7,2664249.0,2876726.0,3140003.0,3451418.0,3811387.0,4227026.0,4710497.0,5650262.0,6990574.0,8048834.0,8807818.0,9947814.0,580653.0,601095.0,627820.0,601287.0,625361.0,745228.0,825987.0,927524.0,1050938.0,1193708.0,1332459.0,1472041.0,3201488.0,3507701.0,3880130.0,4318137.0,4698301.0,4908554.0,5198399.0,5756203.0,6326682.0,6913545.0,7607651.0,8502814.0,1517453.0,1770390.0,2090162.0,2500689.0,2965146.0,3055235.0,3669448.0,4372203.0,5077347.0,5867957.0,6677328.0,7483763.0,2125900.0,2736300.0,3305200.0,3722800.0,4115700.0,4583700.0,5264500.0,5584510.0,5829696.0,6495918.0,6762476.0,6980412.0,9504000.0,9839000.0,1.0063E7,1.0223422E7,1.0394091E7,1.0637171E7,1.0705535E7,1.061274E7,1.0348684E7,1.0244684E7,1.0083313E7,9956108.0,147962.0,165110.0,182053.0,198676.0,209275.0,221823.0,233997.0,244676.0,259012.0,271192.0,288030.0,301931.0,3.72E8,4.09E8,4.54E8,5.06E8,5.67E8,6.34E8,7.08E8,7.88E8,8.72E8,9.59E8,1.034172547E9,1.110396331E9,8.2052E7,9.0124E7,9.9028E7,1.09343E8,1.21282E8,1.36725E8,1.53343E8,1.69276E8,1.84816E8,1.99278E8,2.1106E8,2.23547E8,1.7272E7,1.9792E7,2.2874E7,2.6538E7,3.0614E7,3.5480679E7,4.3072751E7,5.1889696E7,6.0397973E7,6.3327987E7,6.6907826E7,6.945357E7,5441766.0,6248643.0,7240260.0,8519282.0,1.0061506E7,1.1882916E7,1.4173318E7,1.6543189E7,1.7861905E7,2.0775703E7,2.4001816E7,2.7499638E7,2952156.0,2878220.0,2830000.0,2900100.0,3024400.0,3271900.0,3480000.0,3539900.0,3557761.0,3667233.0,3879155.0,4109086.0,1620914.0,1944401.0,2310904.0,2693585.0,3095893.0,3495918.0,3858421.0,4203148.0,4936550.0,5531387.0,6029529.0,6426679.0,4.7666E7,4.9182E7,5.08432E7,5.26671E7,5.4365564E7,5.6059245E7,5.6535636E7,5.6729703E7,5.6840847E7,5.7479469E7,5.7926999E7,5.8147733E7,1426095.0,1535090.0,1665128.0,1861096.0,1997616.0,2156814.0,2298309.0,2326606.0,2378618.0,2531311.0,2664659.0,2780132.0,8.6459025E7,9.1563009E7,9.5831757E7,1.00825279E8,1.07188273E8,1.13872473E8,1.18454974E8,1.22091325E8,1.24329269E8,1.25956499E8,1.27065841E8,1.27467972E8,607914.0,746559.0,933559.0,1255058.0,1613551.0,1937652.0,2347031.0,2820042.0,3867409.0,4526235.0,5307470.0,6053193.0,6464046.0,7454779.0,8678557.0,1.0191512E7,1.2044785E7,1.4500404E7,1.7661452E7,2.1198082E7,2.5020539E7,2.8263827E7,3.1386842E7,3.5610177E7,8865488.0,9411381.0,1.0917494E7,1.2617009E7,1.4781241E7,1.632532E7,1.7647518E7,1.9067554E7,2.0711375E7,2.1585105E7,2.2215365E7,2.3301725E7,2.0947571E7,2.2611552E7,2.6420307E7,3.0131E7,3.3505E7,3.6436E7,3.9326E7,4.1622E7,4.380545E7,4.6173816E7,4.796915E7,4.904479E7,160000.0,212846.0,358266.0,575003.0,841934.0,1140357.0,1497494.0,1891487.0,1418095.0,1765345.0,2111561.0,2505559.0,1439529.0,1647412.0,1886848.0,2186894.0,2680018.0,3115787.0,3086876.0,3089353.0,3219994.0,3430388.0,3677780.0,3921278.0,748747.0,813338.0,893143.0,996380.0,1116779.0,1251524.0,1411807.0,1599200.0,1803195.0,1982823.0,2046772.0,2012649.0,863308.0,975950.0,1112796.0,1279406.0,1482628.0,1703617.0,1956875.0,2269414.0,1912974.0,2200725.0,2814651.0,3193942.0,1019729.0,1201578.0,1441863.0,1759224.0,2183877.0,2721783.0,3344074.0,3799845.0,4364501.0,4759670.0,5368585.0,6036914.0,4762912.0,5181679.0,5703324.0,6334556.0,7082430.0,8007166.0,9171477.0,1.0568642E7,1.2210395E7,1.4165114E7,1.6473477E7,1.9167654E7,2917802.0,3221238.0,3628608.0,4147252.0,4730997.0,5637246.0,6502825.0,7824747.0,1.0014249E7,1.0419991E7,1.1824495E7,1.3327079E7,6748378.0,7739235.0,8906385.0,1.0154878E7,1.1441462E7,1.2845381E7,1.4441916E7,1.6331785E7,1.8319502E7,2.0476091E7,2.2662365E7,2.4821286E7,3838168.0,4241884.0,4690372.0,5212416.0,5828158.0,6491649.0,6998256.0,7634008.0,8416215.0,9384984.0,1.0580176E7,1.2031795E7,1022556.0,1076852.0,1146757.0,1230542.0,1332786.0,1456688.0,1622136.0,1841240.0,2119465.0,2444741.0,2828858.0,3270065.0,516556.0,609816.0,701016.0,789309.0,851334.0,913025.0,992040.0,1042663.0,1096202.0,1149818.0,1200206.0,1250882.0,3.0144317E7,3.5015548E7,4.1121485E7,4.7995559E7,5.5984294E7,6.3759976E7,7.1640904E7,8.0122492E7,8.811103E7,9.5895146E7,1.02479927E8,1.08700891E8,800663.0,882134.0,1010280.0,1149500.0,1320500.0,1528000.0,1756032.0,2015133.0,2312802.0,2494803.0,2674234.0,2874127.0,413834.0,442829.0,474528.0,501035.0,527678.0,560073.0,562548.0,569473.0,621621.0,692651.0,720230.0,684736.0,9939217.0,1.140635E7,1.3056604E7,1.4770296E7,1.666067E7,1.8396941E7,2.019873E7,2.2987397E7,2.5798239E7,2.8529501E7,3.1167783E7,3.3757175E7,6446316.0,7038035.0,7788944.0,8680909.0,9809596.0,1.1127868E7,1.2587223E7,1.2891952E7,1.3160731E7,1.6603334E7,1.847378E7,1.9951656E7,2.0092996E7,2.1731844E7,2.3634436E7,2.5870271E7,2.846639E7,3.1528087E7,3.4680442E7,3.8028578E7,4.0546538E7,4.3247867E7,4.5598081E7,4.776198E7,485831.0,548080.0,621392.0,706640.0,821782.0,977026.0,1099010.0,1278184.0,1554253.0,1774766.0,1972153.0,2055080.0,9182536.0,9682338.0,1.0332057E7,1.126169E7,1.2412593E7,1.3933198E7,1.5796314E7,1.791718E7,2.0326209E7,2.3001113E7,2.5873917E7,2.890179E7,1.0381988E7,1.1026383E7,1.1805689E7,1.2596822E7,1.3329874E7,1.3852989E7,1.4310401E7,1.4665278E7,1.5174244E7,1.5604464E7,1.612283E7,1.6570613E7,1994794.0,2229407.0,2488550.0,2728150.0,2929100.0,3164900.0,3210650.0,3317166.0,3437674.0,3676187.0,3908037.0,4115771.0,1165790.0,1358828.0,1590597.0,1865490.0,2182908.0,2554598.0,2979423.0,3344353.0,4017939.0,4609572.0,5146848.0,5675356.0,3379468.0,3692184.0,4076008.0,4534062.0,5060262.0,5682086.0,6437188.0,7332638.0,8392818.0,9666252.0,1.1140655E7,1.2894865E7,3.3119096E7,3.717334E7,4.1871351E7,4.7287752E7,5.3740085E7,6.2209173E7,7.3039376E7,8.155152E7,9.3364244E7,1.06207839E8,1.19901274E8,1.35031164E8,3327728.0,3491938.0,3638919.0,3786019.0,3933004.0,4043205.0,4114787.0,4186147.0,4286357.0,4405672.0,4535591.0,4627926.0,507833.0,561977.0,628164.0,714775.0,829050.0,1004533.0,1301048.0,1593882.0,1915208.0,2283635.0,2713462.0,3204897.0,4.134656E7,4.6679944E7,5.3100671E7,6.0641899E7,6.9325921E7,7.8152686E7,9.1462088E7,1.05186881E8,1.20065004E8,1.35564834E8,1.53403524E8,1.69270617E8,940080.0,1063506.0,1215725.0,1405486.0,1616384.0,1839782.0,2036305.0,2253639.0,2484997.0,2734531.0,2990875.0,3242173.0,1555876.0,1770902.0,2009813.0,2287985.0,2614104.0,2984494.0,3366439.0,3886512.0,4483945.0,5154123.0,5884491.0,6667147.0,8025700.0,9146100.0,1.05165E7,1.21322E7,1.39547E7,1.5990099E7,1.8125129E7,2.0195924E7,2.2430449E7,2.4748122E7,2.6769436E7,2.8674757E7,2.2438691E7,2.6072194E7,3.0325264E7,3.53566E7,4.0850141E7,4.6850962E7,5.3456774E7,6.0017788E7,6.7185766E7,7.5012988E7,8.2995088E7,9.1077287E7,2.5730551E7,2.8235346E7,3.0329617E7,3.1785378E7,3.3039545E7,3.4621254E7,3.6227381E7,3.774071E7,3.8370697E7,3.8654957E7,3.8625976E7,3.8518241E7,8526050.0,8817650.0,9019800.0,9103000.0,8970450.0,9662600.0,9859650.0,9915289.0,9927680.0,1.0156415E7,1.0433867E7,1.0642836E7,2227000.0,2260000.0,2448046.0,2648961.0,2847132.0,3080828.0,3279001.0,3444468.0,3585176.0,3759430.0,3859606.0,3942491.0,257700.0,308700.0,358900.0,414024.0,461633.0,492095.0,517810.0,562035.0,622191.0,684810.0,743981.0,798094.0,1.663E7,1.7829327E7,1.8680721E7,1.9284814E7,2.0662648E7,2.1658597E7,2.2356726E7,2.2686371E7,2.2797027E7,2.2562458E7,2.2404337E7,2.2276056E7,2534927.0,2822082.0,3051242.0,3451079.0,3992121.0,4657072.0,5507565.0,6349365.0,7290203.0,7212583.0,7852401.0,8860588.0,60011.0,61325.0,65345.0,70787.0,76595.0,86796.0,98593.0,110812.0,125911.0,145608.0,170372.0,199579.0,4005677.0,4419650.0,4943029.0,5618198.0,6472756.0,8128505.0,1.1254672E7,1.4619745E7,1.6945857E7,2.1229759E7,2.450153E7,2.7601038E7,2755589.0,3054547.0,3430243.0,3965841.0,4588696.0,5260855.0,6147783.0,7171347.0,8307920.0,9535314.0,1.0870037E7,1.2267493E7,6860147.0,7271135.0,7616060.0,7971222.0,8313288.0,8686367.0,9032824.0,9230783.0,9826397.0,1.0336594E7,1.0111559E7,1.0150265E7,2143249.0,2295678.0,2467895.0,2662190.0,2879013.0,3140897.0,3464522.0,3868905.0,4260884.0,4578212.0,5359092.0,6144562.0,1127000.0,1445929.0,1750200.0,1977600.0,2152400.0,2325300.0,2651869.0,2794552.0,3235865.0,3802309.0,4197776.0,4553009.0,3558137.0,3844277.0,4237384.0,4442238.0,4593433.0,4827803.0,5048043.0,5199318.0,5302888.0,5383010.0,5410052.0,5447502.0,1489518.0,1533070.0,1582962.0,1646912.0,1694510.0,1746919.0,1861252.0,1945870.0,1999210.0,2011612.0,2011497.0,2009245.0,2526994.0,2780415.0,3080153.0,3428839.0,3840161.0,4353666.0,5828892.0,6921858.0,6099799.0,6633514.0,7753310.0,9118773.0,1.4264935E7,1.6151549E7,1.8356657E7,2.0997321E7,2.393581E7,2.7129932E7,3.1140029E7,3.5933379E7,3.9964159E7,4.2835005E7,4.4433622E7,4.3997828E7,2.854987E7,2.9841614E7,3.1158061E7,3.2850275E7,3.4513161E7,3.6439E7,3.798331E7,3.8880702E7,3.9549438E7,3.9855442E7,4.0152517E7,4.0448191E7,7982342.0,9128546.0,1.0421936E7,1.1737396E7,1.3016733E7,1.4116836E7,1.5410151E7,1.6495304E7,1.758706E7,1.8698655E7,1.9576783E7,2.0378239E7,8504667.0,9753392.0,1.1183227E7,1.2716129E7,1.4597019E7,1.7104986E7,2.0367053E7,2.472596E7,2.8227588E7,3.2160729E7,3.7090298E7,4.2292929E7,290243.0,326741.0,370006.0,420690.0,480105.0,551425.0,649901.0,779348.0,962344.0,1054486.0,1130269.0,1133066.0,7124673.0,7363802.0,7561588.0,7867931.0,8122293.0,8251648.0,8325260.0,8421403.0,8718867.0,8897619.0,8954175.0,9031088.0,4815000.0,5126000.0,5666000.0,6063000.0,6401400.0,6316424.0,6468126.0,6649942.0,6995447.0,7193761.0,7361757.0,7554661.0,3661549.0,4149908.0,4834621.0,5680812.0,6701172.0,7932503.0,9410494.0,1.1242847E7,1.3219062E7,1.5081016E7,1.7155814E7,1.9314747E7,8550362.0,1.0164215E7,1.1918938E7,1.3648692E7,1.5226039E7,1.6785196E7,1.850139E7,1.9757799E7,2.0686918E7,2.1628605E7,2.2454239E7,2.3174294E7,8322925.0,9452826.0,1.0863958E7,1.2607312E7,1.4706593E7,1.7129565E7,1.9844382E7,2.304063E7,2.6605473E7,3.0686889E7,3.4593779E7,3.813964E7,2.1289402E7,2.5041917E7,2.9263397E7,3.4024249E7,3.9276153E7,4.4148285E7,4.882716E7,5.2910342E7,5.6667095E7,6.0216677E7,6.2806748E7,6.5068149E7,1219113.0,1357445.0,1528098.0,1735550.0,2056351.0,2308582.0,2644765.0,3154264.0,3747553.0,4320890.0,4977378.0,5701579.0,662850.0,764900.0,887498.0,960155.0,975199.0,1039009.0,1116479.0,1191336.0,1183669.0,1138101.0,1101832.0,1056608.0,3647735.0,3950849.0,4286552.0,4786986.0,5303507.0,6005061.0,6734098.0,7724976.0,8523077.0,9231669.0,9770575.0,1.0276158E7,2.2235677E7,2.5670939E7,2.9788695E7,3.3411317E7,3.7492953E7,4.2404033E7,4.7328791E7,5.2881328E7,5.8179144E7,6.3047647E7,6.7308928E7,7.1158647E7,5824797.0,6675501.0,7688797.0,8900294.0,1.0190285E7,1.1457758E7,1.29394E7,1.528305E7,1.825219E7,2.1210254E7,2.4739869E7,2.9170398E7,5.043E7,5.143E7,5.3292E7,5.4959E7,5.6079E7,5.6179E7,5.6339704E7,5.698162E7,5.7866349E7,5.8808266E7,5.9912431E7,6.0776238E7,1.57553E8,1.71984E8,1.86538E8,1.98712E8,2.09896E8,2.20239E8,2.32187835E8,2.42803533E8,2.56894189E8,2.7291176E8,2.87675526E8,3.01139947E8,2252965.0,2424959.0,2598466.0,2748579.0,2829526.0,2873520.0,2953997.0,3045153.0,3149262.0,3262838.0,3363085.0,3447496.0,5439568.0,6702668.0,8143375.0,9709552.0,1.1515649E7,1.3503563E7,1.5620766E7,1.7910182E7,2.0265563E7,2.2374398E7,2.428767E7,2.6084662E7,2.6246839E7,2.8998543E7,3.379614E7,3.946391E7,4.4655014E7,5.0533506E7,5.6142181E7,6.2826491E7,6.9940728E7,7.6048996E7,8.0908147E7,8.5262356E7,1030585.0,1070439.0,1133134.0,1142636.0,1089572.0,1261091.0,1425876.0,1691210.0,2104779.0,2826046.0,3389578.0,4018332.0,4963829.0,5498090.0,6120081.0,6740785.0,7407075.0,8403990.0,9657618.0,1.121934E7,1.3367997E7,1.5826497E7,1.8701257E7,2.2211743E7,2672000.0,3016000.0,3421000.0,3900000.0,4506497.0,5216550.0,6100407.0,7272406.0,8381163.0,9417789.0,1.0595811E7,1.1746035E7,3080907.0,3646340.0,4277736.0,4995432.0,5861135.0,6642107.0,7636524.0,9216418.0,1.070434E7,1.1404948E7,1.1926563E7,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,820.8530296,853.10071,836.1971382,739.9811058,786.11336,978.0114388,852.3959448,649.3413952,635.341351,726.7340548,974.5803384,1601.056136,1942.284244,2312.888958,2760.196931,3313.422188,3533.00391,3630.880722,3738.932735,2497.437901,3193.054604,4604.211737,5937.029526,2449.008185,3013.976023,2550.81688,3246.991771,4182.663766,4910.416756,5745.160213,5681.358539,5023.216647,4797.295051,5288.040382,6223.367465,3520.610273,3827.940465,4269.276742,5522.776375,5473.288005,3008.647355,2756.953672,2430.208311,2627.845685,2277.140884,2773.287312,4797.231267,5911.315053,6856.856212,7133.166023,8052.953021,9443.038526,10079.02674,8997.897412,9139.671389,9308.41871,10967.28195,8797.640716,12779.37964,10039.59564,10949.64959,12217.22686,14526.12465,16788.62948,18334.19751,19477.00928,21888.88903,23424.76683,26997.93657,30687.75473,34435.36744,6137.076492,8842.59803,10750.72111,12834.6024,16661.6256,19749.4223,21597.08362,23687.82607,27042.01868,29095.92066,32417.60769,36126.4927,9867.084765,11635.79945,12753.27514,14804.6727,18268.65839,19340.10196,19211.14731,18524.02406,19035.57917,20292.01679,23403.55927,29796.04834,684.2441716,661.6374577,686.3415538,721.1860862,630.2336265,659.8772322,676.9818656,751.9794035,837.8101643,972.7700352,1136.39043,1391.253792,8343.105127,9714.960623,10991.20676,13149.04119,16672.14356,19117.97448,20979.84589,22525.56308,25575.57069,27561.19663,30485.88375,33692.60508,1062.7522,959.6010805,949.4990641,1035.831411,1085.796879,1029.161251,1277.897616,1225.85601,1191.207681,1232.975292,1372.877931,1441.284873,2677.326347,2127.686326,2180.972546,2586.886053,2980.331339,3548.097832,3156.510452,2753.69149,2961.699694,3326.143191,3413.26269,3822.137084,973.5331948,1353.989176,1709.683679,2172.352423,2860.16975,3528.481305,4126.613157,4314.114757,2546.781445,4766.355904,6018.975239,7446.298803,851.2411407,918.2325349,983.6539764,1214.709294,2263.611114,3214.857818,4551.14215,6205.88385,7954.111645,8647.142313,11003.60508,12569.85177,2108.944355,2487.365989,3336.585802,3429.864357,4985.711467,6660.118654,7030.835878,7807.095818,6950.283021,7957.980824,8131.212843,9065.800825,2444.286648,3008.670727,4254.337839,5577.0028,6597.494398,7612.240438,8224.191647,8239.854824,6302.623438,5970.38876,7696.777725,10680.79282,543.2552413,617.1834648,722.5120206,794.8265597,854.7359763,743.3870368,807.1985855,912.0631417,931.7527731,946.2949618,1037.645221,1217.032994,339.2964587,379.5646281,355.2032273,412.9775136,464.0995039,556.1032651,559.603231,621.8188189,631.6998778,463.1151478,446.4035126,430.0706916,368.4692856,434.0383364,496.9136476,523.4323142,421.6240257,524.9721832,624.4754784,683.8955732,682.3031755,734.28517,896.2260153,1713.778686,1172.667655,1313.048099,1399.607441,1508.453148,1684.146528,1783.432873,2367.983282,2602.664206,1793.163278,1694.337469,1934.011449,2042.09524,11367.16112,12489.95006,13462.48555,16076.58803,18970.57086,22090.88306,22898.79214,26626.51503,26342.88426,28954.92589,33328.96507,36319.23501,1071.310713,1190.844328,1193.068753,1136.056615,1070.013275,1109.374338,956.7529907,844.8763504,747.9055252,740.5063317,738.6906068,706.016537,1178.665927,1308.495577,1389.817618,1196.810565,1104.103987,1133.98495,797.9081006,952.386129,1058.0643,1004.961353,1156.18186,1704.063724,3939.978789,4315.622723,4519.094331,5106.654313,5494.024437,4756.763836,5095.665738,5547.063754,7596.125964,10118.05318,10778.78385,13171.63885,400.448611,575.9870009,487.6740183,612.7056934,676.9000921,741.2374699,962.4213805,1378.904018,1655.784158,2289.234136,3119.280896,4959.114854,2144.115096,2323.805581,2492.351109,2678.729839,3264.660041,3815.80787,4397.575659,4903.2191,5444.648617,6117.361746,5755.259962,7006.580419,1102.990936,1211.148548,1406.648278,1876.029643,1937.577675,1172.603047,1267.100083,1315.980812,1246.90737,1173.618235,1075.811558,986.1478792,780.5423257,905.8602303,896.3146335,861.5932424,904.8960685,795.757282,673.7478181,672.774812,457.7191807,312.188423,241.1658765,277.5518587,2125.621418,2315.056572,2464.783157,2677.939642,3213.152683,3259.178978,4879.507522,4201.194937,4016.239529,3484.164376,3484.06197,3632.557798,2627.009471,2990.010802,3460.937025,4161.727834,5118.146939,5926.876967,5262.734751,5629.915318,6160.416317,6677.045314,7723.447195,9645.06142,1388.594732,1500.895925,1728.869428,2052.050473,2378.201111,2517.736547,2602.710169,2156.956069,1648.073791,1786.265407,1648.800823,1544.750112,3119.23652,4338.231617,5477.890018,6960.297861,9164.090127,11305.38517,13221.82184,13822.58394,8447.794873,9875.604515,11628.38895,14619.22272,5586.53878,6092.174359,5180.75591,5690.268015,5305.445256,6380.494966,7316.918107,7532.924763,5592.843963,5431.990415,6340.646683,8948.102923,6876.14025,8256.343918,10136.86713,11399.44489,13108.4536,14800.16062,15377.22855,16310.4434,14297.02122,16048.51424,17596.21022,22833.30851,9692.385245,11099.65935,13583.31351,15937.21123,18866.20721,20422.9015,21688.04048,25116.17581,26406.73985,29804.34567,32166.50006,35278.41874,2669.529475,2864.969076,3020.989263,3020.050513,3694.212352,3081.761022,2879.468067,2880.102568,2377.156192,1895.016984,1908.260867,2082.481567,1397.717137,1544.402995,1662.137359,1653.723003,2189.874499,2681.9889,2861.092386,2899.842175,3044.214214,3614.101285,4563.808154,6025.374752,3522.110717,3780.546651,4086.114078,4579.074215,5280.99471,6679.62326,7213.791267,6481.776993,7103.702595,7429.455877,5773.044512,6873.262326,1418.822445,1458.915272,1693.335853,1814.880728,2024.008147,2785.493582,3503.729636,3885.46071,3794.755195,4173.181797,4754.604414,5581.180998,3048.3029,3421.523218,3776.803627,4358.595393,4520.246008,5138.922374,4098.344175,4140.442097,4444.2317,5154.825496,5351.568666,5728.353514,375.6431231,426.0964081,582.8419714,915.5960025,672.4122571,958.5668124,927.8253427,966.8968149,1132.055034,2814.480755,7703.4959,12154.08975,328.9405571,344.1618859,380.9958433,468.7949699,514.3242082,505.7538077,524.8758493,521.1341333,582.8585102,913.47079,765.3500015,641.3695236,362.1462796,378.9041632,419.4564161,516.1186438,566.2439442,556.8083834,577.8607471,573.7413142,421.3534653,515.8894013,530.0535319,690.8055759,6424.519071,7545.415386,9371.842561,10921.63626,14358.8759,15605.42283,18533.15761,21141.01223,20647.16499,23723.9502,28204.59057,33207.0844,7029.809327,8662.834898,10560.48553,12999.91766,16107.19171,18292.63514,20293.89746,22066.44214,24703.79615,25889.78487,28926.03234,30470.0167,4293.476475,4976.198099,6631.459222,8358.761987,11401.94841,21745.57328,15113.36194,11864.40844,13522.15752,14722.84188,12521.71392,13206.48452,485.2306591,520.9267111,599.650276,734.7829124,756.0868363,884.7552507,835.8096108,611.6588611,665.6244126,653.7301704,660.5855997,752.7497265,7144.114393,10187.82665,12902.46291,14745.62561,18016.18027,20512.92123,22031.53274,24639.18566,26505.30317,27788.88416,30035.80198,32170.37442,911.2989371,1043.561537,1190.041118,1125.69716,1178.223708,993.2239571,876.032569,847.0061135,925.060154,1005.245812,1111.984578,1327.60891,3530.690067,4916.299889,6017.190733,8513.097016,12724.82957,14195.52428,15268.42089,16120.52839,17541.49634,18747.69814,22514.2548,27538.41188,2428.237769,2617.155967,2750.364446,3242.531147,4031.408271,4879.992748,4820.49479,4246.485974,4439.45084,4684.313807,4858.347495,5186.050003,510.1964923,576.2670245,686.3736739,708.7595409,741.6662307,874.6858643,857.2503577,805.5724718,794.3484384,869.4497668,945.5835837,942.6542111,299.850319,431.7904566,522.0343725,715.5806402,820.2245876,764.7259628,838.1239671,736.4153921,745.5398706,796.6644681,575.7047176,579.231743,1840.366939,1726.887882,1796.589032,1452.057666,1654.456946,1874.298931,2011.159549,1823.015995,1456.309517,1341.726931,1270.364932,1201.637154,2194.926204,2220.487682,2291.156835,2538.269358,2529.842345,3203.208066,3121.760794,3023.096699,3081.694603,3160.454906,3099.72866,3548.330846,3054.421209,3629.076457,4692.648272,6197.962814,8315.928145,11186.14125,14560.53051,20038.47269,24757.60301,28377.63219,30209.01516,39724.97867,5263.673816,6040.180011,7550.359877,9326.64467,10168.65611,11674.83737,12545.99066,12986.47998,10535.62855,11712.7768,14843.93556,18008.94444,7267.688428,9244.001412,10350.15906,13319.89568,15798.06362,19654.96247,23269.6075,26923.20628,25144.39201,28061.09966,31163.20196,36180.78919,546.5657493,590.061996,658.3471509,700.7706107,724.032527,813.337323,855.7235377,976.5126756,1164.406809,1458.817442,1746.769454,2452.210407,749.6816546,858.9002707,849.2897701,762.4317721,1111.107907,1382.702056,1516.872988,1748.356961,2383.140898,3119.335603,2873.91287,3540.651564,3035.326002,3290.257643,4187.329802,5906.731805,9613.818607,11888.59508,7608.334602,6642.881371,7235.653188,8263.590301,9240.761975,11605.71449,4129.766056,6229.333562,8341.737815,8931.459811,9576.037596,14688.23507,14517.90711,11643.57268,3745.640687,3076.239795,4390.717312,4471.061906,5210.280328,5599.077872,6631.597314,7655.568963,9530.772896,11150.98113,12618.32141,13872.86652,17558.81555,24521.94713,34077.04939,40675.99635,4086.522128,5385.278451,7105.630706,8393.741404,12786.93223,13306.61921,15367.0292,17122.47986,18051.52254,20896.60924,21905.59514,25523.2771,4931.404155,6248.656232,8243.58234,10022.40131,12269.27378,14255.98475,16537.4835,19207.23482,22013.64486,24675.02446,27968.09817,28569.7197,2898.530881,4756.525781,5246.107524,6124.703451,7433.889293,6650.195573,6068.05135,6351.237495,7404.923685,7121.924704,6994.774861,7320.880262,3216.956347,4317.694365,6576.649461,9847.788607,14778.78636,16610.37701,19384.10571,22375.94189,26824.89511,28816.58499,28604.5919,31656.06806,1546.907807,1886.080591,2348.009158,2741.796252,2110.856309,2852.351568,4161.415959,4448.679912,3431.593647,3645.379572,3844.917194,4519.461171,853.540919,944.4383152,896.9663732,1056.736457,1222.359968,1267.613204,1348.225791,1361.936856,1341.921721,1360.485021,1287.514732,1463.249282,1088.277758,1571.134655,1621.693598,2143.540609,3701.621503,4106.301249,4106.525293,4106.492315,3726.063507,1690.756814,1646.758151,1593.06548,1030.592226,1487.593537,1536.344387,2029.228142,3030.87665,4657.22102,5622.942464,8533.088805,12104.27872,15993.52796,19233.98818,23348.13973,108382.3529,113523.1329,95458.11176,80894.88326,109347.867,59265.47714,31354.03573,28118.42998,34932.91959,40300.61996,35110.10566,47306.98978,4834.804067,6089.786934,5714.560611,6006.983042,7486.384341,8659.696836,7640.519521,5377.091329,6890.806854,8754.96385,9313.93883,10461.05868,298.8462121,335.9971151,411.8006266,498.6390265,496.5815922,745.3695408,797.2631074,773.9932141,977.4862725,1186.147994,1275.184575,1569.331442,575.5729961,620.9699901,634.1951625,713.6036483,803.0054535,640.3224383,572.1995694,506.1138573,636.6229191,609.1739508,531.4823679,414.5073415,2387.54806,3448.284395,6757.030816,18772.75169,21011.49721,21951.21176,17364.27538,11770.5898,9640.138501,9467.446056,9534.677467,12057.49928,1443.011715,1589.20275,1643.38711,1634.047282,1748.562982,1544.228586,1302.878658,1155.441948,1040.67619,986.2958956,894.6370822,1044.770126,369.1650802,416.3698064,427.9010856,495.5147806,584.6219709,663.2236766,632.8039209,635.5173634,563.2000145,692.2758103,665.4231186,759.3499101,1831.132894,1810.066992,2036.884944,2277.742396,2849.09478,3827.921571,4920.355951,5249.802653,7277.912802,10132.90964,10206.97794,12451.6558,452.3369807,490.3821867,496.1743428,545.0098873,581.3688761,686.3952693,618.0140641,684.1715576,739.014375,790.2579846,951.4097518,1042.581557,743.1159097,846.1202613,1055.896036,1421.145193,1586.851781,1497.492223,1481.150189,1421.603576,1361.369784,1483.136136,1579.019543,1803.151496,1967.955707,2034.037981,2529.067487,2475.387562,2575.484158,3710.982963,3688.037739,4783.586903,6058.253846,7425.705295,9021.815894,10956.99112,3478.125529,4131.546641,4581.609385,5754.733883,6809.40669,7674.929108,9611.147541,8688.156003,9472.384295,9767.29753,10742.44053,11977.57496,786.5668575,912.6626085,1056.353958,1226.04113,1421.741975,1647.511665,2000.603139,2338.008304,1785.402016,1902.2521,2140.739323,3095.772271,2647.585601,3682.259903,4649.593785,5907.850937,7778.414017,9595.929905,11222.58762,11732.51017,7003.339037,6465.613349,6557.194282,9253.896111,1688.20357,1642.002314,1566.353493,1711.04477,1930.194975,2370.619976,2702.620356,2755.046991,2948.047252,2982.101858,3258.495584,3820.17523,468.5260381,495.5868333,556.6863539,566.6691539,724.9178037,502.3197334,462.2114149,389.8761846,410.8968239,472.3460771,633.6179466,823.6856205,331.0,350.0,388.0,349.0,357.0,371.0,424.0,385.0,347.0,415.0,611.0,944.0,2423.780443,2621.448058,3173.215595,3793.694753,3746.080948,3876.485958,4191.100511,3693.731337,3804.537999,3899.52426,4072.324751,4811.060429,545.8657229,597.9363558,652.3968593,676.4422254,674.7881296,694.1124398,718.3730947,775.6324501,897.7403604,1010.892138,1057.206311,1091.359778,8941.571858,11276.19344,12790.84956,15363.25136,18794.74567,21209.0592,21399.46046,23651.32361,26790.94961,30246.13063,33724.75778,36797.93332,10556.57566,12247.39532,13175.678,14463.91893,16046.03728,16233.7177,17632.4104,19007.19129,18363.32494,21050.41377,23189.80135,25185.00911,3112.363948,3457.415947,3634.364406,4643.393534,4688.593267,5486.371089,3470.338156,2955.984375,2170.151724,2253.023004,2474.548819,2749.320965,761.879376,835.5234025,997.7661127,1054.384891,954.2092363,808.8970728,909.7221354,668.3000228,581.182725,580.3052092,601.0745012,619.6768924,1077.281856,1100.592563,1150.927478,1014.514104,1698.388838,1981.951806,1576.97375,1385.029563,1619.848217,1624.941275,1615.286395,2013.977305,10095.42172,11653.97304,13450.40151,16361.87647,18965.05551,23311.34939,26298.63531,31540.9748,33965.66115,41283.16433,44683.97525,49357.19017,1828.230307,2242.746551,2924.638113,4720.942687,10618.03855,11848.34392,12954.79101,18115.22313,18616.70691,19702.05581,19774.83687,22316.19287,684.5971438,747.0835292,803.3427418,942.4082588,1049.938981,1175.921193,1443.429832,1704.686583,1971.829464,2049.350521,2092.712441,2605.94758,2480.380334,2961.800905,3536.540301,4421.009084,5364.249663,5351.912144,7009.601598,7034.779161,6618.74305,7113.692252,7356.031934,9809.185636,1952.308701,2046.154706,2148.027146,2299.376311,2523.337977,3248.373311,4258.503604,3998.875695,4196.411078,4247.400261,3783.674243,4172.838464,3758.523437,4245.256698,4957.037982,5788.09333,5937.827283,6281.290855,6434.501797,6360.943444,4446.380924,5838.347657,5909.020073,7408.905561,1272.880995,1547.944844,1649.552153,1814.12743,1989.37407,2373.204287,2603.273765,2189.634995,2279.324017,2536.534925,2650.921068,3190.481016,4029.329699,4734.253019,5338.752143,6557.152776,8006.506993,9508.141454,8451.531004,9082.351172,7738.881247,10159.58368,12002.23908,15389.92468,3068.319867,3774.571743,4727.954889,6361.517993,9022.247417,10172.48572,11753.84291,13039.30876,16207.26663,17641.03156,19970.90787,20509.64777,3081.959785,3907.156189,5108.34463,6929.277714,9123.041742,9770.524921,10330.98915,12281.34191,14641.58711,16999.4333,18855.60618,19328.70901,2718.885295,2769.451844,3173.72334,4021.175739,5047.658563,4319.804067,5267.219353,5303.377488,6101.255823,6071.941411,6316.1652,7670.122558,3144.613186,3943.370225,4734.997586,6470.866545,8011.414402,9356.39724,9605.314053,9696.273295,6598.409903,7346.547557,7885.360081,10808.47561,493.3238752,540.2893983,597.4730727,510.9637142,590.5806638,670.0806011,881.5706467,847.991217,737.0685949,589.9445051,785.6537648,863.0884639,879.5835855,860.7369026,1071.551119,1384.840593,1532.985254,1737.561657,1890.218117,1516.525457,1428.777814,1339.076036,1353.09239,1598.435089,6459.554823,8157.591248,11626.41975,16903.04886,24837.42865,34167.7626,33693.17525,21198.26136,24841.61777,20586.69019,19014.54118,21654.83194,1450.356983,1567.653006,1654.988723,1612.404632,1597.712056,1561.769116,1518.479984,1441.72072,1367.899369,1392.368347,1519.635262,1712.472136,3581.459448,4981.090891,6289.629157,7991.707066,10522.06749,12980.66956,15181.0927,15870.87851,9325.068238,7914.320304,7236.075251,9786.534714,879.7877358,1004.484437,1116.639877,1206.043465,1353.759762,1348.285159,1465.010784,1294.447788,1068.696278,574.6481576,699.489713,862.5407561,2315.138227,2843.104409,3674.735572,4977.41854,8597.756202,11210.08948,15169.16112,18861.53081,24769.8912,33519.4766,36023.1054,47143.17964,5074.659104,6093.26298,7481.107598,8412.902397,9674.167626,10922.66404,11348.54585,12037.26758,9498.467723,12126.23065,13638.77837,18678.31435,4215.041741,5862.276629,7402.303395,9405.489397,12383.4862,15277.03017,17866.72175,18678.53492,14214.71681,17161.10735,20660.01936,25768.25759,1135.749842,1258.147413,1369.488336,1284.73318,1254.576127,1450.992513,1176.807031,1093.244963,926.9602964,930.5964284,882.0818218,926.1410683,4725.295531,5487.104219,5768.729717,7114.477971,7765.962636,8028.651439,8568.266228,7825.823398,7225.069258,7479.188244,7710.946444,9269.657808,3834.034742,4564.80241,5693.843879,7993.512294,10638.75131,13236.92117,13926.16997,15764.98313,18603.06452,20445.29896,24835.47166,28821.0637,1083.53203,1072.546602,1074.47196,1135.514326,1213.39553,1348.775651,1648.079789,1876.766827,2153.739222,2664.477257,3015.378833,3970.095407,1615.991129,1770.337074,1959.593767,1687.997641,1659.652775,2202.988423,1895.544073,1507.819159,1492.197043,1632.210764,1993.398314,2602.394995,1148.376626,1244.708364,1856.182125,2613.101665,3364.836625,3781.410618,3895.384018,3984.839812,3553.0224,3876.76846,4128.116943,4513.480643,8527.844662,9911.878226,12329.44192,15258.29697,17832.02464,18855.72521,20667.38125,23586.92927,23880.01683,25266.59499,29341.63093,33859.74835,14734.23275,17909.48973,20431.0927,22966.14432,27195.11304,26982.29052,28397.71512,30281.70459,31871.5303,32135.32301,34480.95771,37506.41907,1643.485354,2117.234893,2193.037133,1881.923632,2571.423014,3195.484582,3761.837715,3116.774285,3340.542768,4014.238972,4090.925331,4184.548089,1206.947913,1507.86129,1822.879028,2643.858681,4062.523897,5596.519826,7426.354774,11054.56175,15215.6579,20206.82098,23235.42329,28718.27684,716.6500721,698.5356073,722.0038073,848.2186575,915.9850592,962.4922932,874.2426069,831.8220794,825.682454,789.1862231,899.0742111,1107.482182,757.7974177,793.5774148,1002.199172,1295.46066,1524.358936,1961.224635,2393.219781,2982.653773,4616.896545,5852.625497,5913.187529,7458.396327,859.8086567,925.9083202,1067.53481,1477.59676,1649.660188,1532.776998,1344.577953,1202.201361,1034.298904,982.2869243,886.2205765,882.9699438,3023.271928,4100.3934,4997.523971,5621.368472,6619.551419,7899.554209,9119.528607,7388.597823,7370.990932,8792.573126,11460.60023,18008.50924,1468.475631,1395.232468,1660.30321,1932.360167,2753.285994,3120.876811,3560.233174,3810.419296,4332.720164,4876.798614,5722.895655,7092.923025,1969.10098,2218.754257,2322.869908,2826.356387,3450.69638,4269.122326,4241.356344,5089.043686,5678.348271,6601.429915,6508.085718,8458.276384,734.753484,774.3710692,767.2717398,908.9185217,950.735869,843.7331372,682.2662268,617.7244065,644.1707969,816.559081,927.7210018,1056.380121,9979.508487,11283.17795,12477.17707,14142.85089,15895.11641,17428.74846,18232.42452,21664.78767,22705.09254,26074.53136,29478.99919,33203.26128,13990.48208,14847.12712,16173.14586,19530.36557,21806.03594,24072.63213,25009.55914,29884.35041,32003.93224,35767.43303,39097.09955,42951.65309,5716.766744,6150.772969,5603.357717,5444.61962,5703.408898,6504.339663,6920.223051,7452.398969,8137.004775,9230.240708,7727.002004,10611.46299,7689.799761,9802.466526,8422.974165,9541.474188,10505.25966,13143.95095,11152.41011,9883.584648,10733.92631,10165.49518,8605.047831,11415.80569,605.0664917,676.2854478,772.0491602,637.1232887,699.5016441,713.5371196,707.2357863,820.7994449,989.0231487,1385.896769,1764.456677,2441.576404,1515.592329,1827.067742,2198.956312,2649.715007,3133.409277,3682.831494,4336.032082,5107.197384,6017.654756,7110.667619,4515.487575,3025.349798,781.7175761,804.8304547,825.6232006,862.4421463,1265.047031,1829.765177,1977.55701,1971.741538,1879.496673,2117.484526,2234.820827,2280.769906,1147.388831,1311.956766,1452.725766,1777.077318,1773.498265,1588.688299,1408.678565,1213.315116,1210.884633,1071.353818,1071.613938,1271.211593,406.8841148,518.7642681,527.2721818,569.7950712,799.3621758,685.5876821,788.8550411,706.1573059,693.4207856,792.4499603,672.0386227,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"fqOWv9\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x14436c390>"
      ]
     },
     "execution_count": 75,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             ) +\n",
    "        geom_point(alpha=0.5)        \n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Change the scales"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "That's better! But it looks like the scale is a bit off due to vast differences in output across different countries. Let's add a `scale_x_log10()` layer to the plot to make it more readable."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 76,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"FVnwBb\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,30.332,31.997,34.02,36.088,38.438,39.854,40.822,41.674,41.763,42.129,43.828,55.23,59.28,64.82,66.22,67.69,68.93,70.42,72.0,71.581,72.95,75.651,76.423,43.077,45.685,48.303,51.407,54.518,58.014,61.368,65.799,67.744,69.152,70.994,72.301,30.015,31.999,34.0,35.985,37.928,39.483,39.942,39.906,40.647,40.963,41.003,42.731,62.485,64.399,65.142,65.634,67.065,68.481,69.942,70.774,71.868,73.275,74.34,75.32,69.12,70.33,70.93,71.1,71.93,73.49,74.74,76.32,77.56,78.83,80.37,81.235,66.8,67.48,69.54,70.14,70.63,72.17,73.18,74.94,76.04,77.51,78.98,79.829,50.939,53.832,56.923,59.923,63.3,65.593,69.052,70.75,72.601,73.925,74.795,75.635,37.484,39.348,41.216,43.453,45.252,46.923,50.009,52.819,56.018,59.412,62.013,64.062,68.0,69.24,70.25,70.94,71.44,72.8,73.93,75.35,76.46,77.53,78.32,79.441,38.223,40.358,42.618,44.885,47.014,49.19,50.904,52.337,53.919,54.777,54.406,56.728,40.414,41.89,43.428,45.032,46.714,50.023,53.859,57.251,59.957,62.05,63.883,65.554,53.82,58.45,61.93,64.79,67.45,69.86,70.69,71.14,72.178,73.244,74.09,74.852,47.622,49.618,51.52,53.298,56.024,59.319,61.484,63.622,62.745,52.556,46.634,50.728,50.917,53.285,55.665,57.632,59.504,61.489,63.336,65.205,67.057,69.388,71.006,72.39,59.6,66.61,69.51,70.42,70.9,70.81,71.08,71.34,71.19,70.32,72.14,73.005,31.975,34.906,37.814,40.697,43.591,46.137,48.122,49.557,50.26,50.324,50.65,52.295,39.031,40.533,42.045,43.548,44.057,45.91,47.471,48.211,44.736,45.326,47.36,49.58,39.417,41.366,43.415,45.415,40.317,31.22,50.957,53.914,55.803,56.534,56.752,59.723,38.523,40.428,42.643,44.799,47.049,49.355,52.961,54.985,54.314,52.199,49.856,50.43,68.75,69.96,71.3,72.13,72.88,74.21,75.76,76.86,77.95,78.61,79.77,80.653,35.463,37.464,39.475,41.478,43.457,46.775,48.295,50.485,49.396,46.066,43.308,44.741,38.092,39.881,41.716,43.601,45.569,47.383,49.517,51.051,51.724,51.573,50.525,50.651,54.745,56.074,57.924,60.523,63.441,67.052,70.565,72.492,74.126,75.816,77.86,78.553,44.0,50.54896,44.50136,58.38112,63.11888,63.96736,65.525,67.274,68.69,70.426,72.028,72.961,50.643,55.118,57.863,59.963,61.623,63.837,66.653,67.768,68.421,70.313,71.682,72.889,40.715,42.46,44.467,46.472,48.944,50.939,52.933,54.926,57.939,60.66,62.974,65.152,39.143,40.652,42.122,44.056,45.989,47.804,47.784,47.412,45.548,42.587,44.966,46.462,42.111,45.053,48.435,52.04,54.907,55.625,56.695,57.47,56.433,52.962,52.97,55.322,57.206,60.026,62.842,65.424,67.849,70.75,73.45,74.752,75.713,77.26,78.123,78.782,40.477,42.469,44.93,47.35,49.801,52.374,53.983,54.655,52.044,47.991,46.832,48.328,61.21,64.77,67.13,68.5,69.61,70.64,70.46,71.52,72.527,73.68,74.876,75.748,59.421,62.325,65.246,68.29,70.723,72.649,73.717,74.174,74.414,76.151,77.158,78.273,66.87,69.03,69.9,70.38,70.29,70.71,70.96,71.58,72.4,74.01,75.51,76.486,70.78,71.81,72.35,72.96,73.47,74.69,74.63,74.8,75.33,76.11,77.18,78.332,34.812,37.328,39.693,42.074,44.366,46.519,48.812,50.04,51.604,53.157,53.373,54.791,45.928,49.828,53.459,56.751,59.631,61.788,63.727,66.046,68.457,69.957,70.847,72.235,48.357,51.356,54.64,56.678,58.796,61.31,64.342,67.231,69.613,72.312,74.173,74.994,41.893,44.444,46.992,49.293,51.137,53.319,56.006,59.797,63.674,67.217,69.806,71.338,45.262,48.57,52.307,55.855,58.207,56.696,56.604,63.154,66.798,69.535,70.734,71.878,34.482,35.983,37.485,38.987,40.516,42.024,43.662,45.664,47.545,48.245,49.348,51.579,35.928,38.047,40.158,42.189,44.142,44.535,43.89,46.453,49.991,53.378,55.24,58.04,34.078,36.667,40.059,42.115,43.515,44.51,44.916,46.684,48.091,49.402,50.725,52.947,66.55,67.49,68.75,69.83,70.87,72.52,74.55,74.83,75.7,77.13,78.37,79.313,67.41,68.93,70.51,71.55,72.38,73.83,74.89,76.34,77.46,78.64,79.59,80.657,37.003,38.999,40.489,44.598,48.69,52.79,56.564,60.19,61.366,60.461,56.761,56.735,30.0,32.065,33.896,35.857,38.308,41.842,45.58,49.265,52.644,55.861,58.041,59.448,67.5,69.1,70.3,70.8,71.0,72.5,73.8,74.847,76.07,77.34,78.67,79.406,43.149,44.779,46.452,48.072,49.875,51.756,53.744,55.729,57.501,58.556,58.453,60.022,65.86,67.86,69.51,71.0,72.34,73.68,75.24,76.67,77.03,77.869,78.256,79.483,42.023,44.142,46.954,50.016,53.738,56.029,58.137,60.782,63.373,66.322,68.978,70.259,33.609,34.558,35.753,37.197,38.842,40.762,42.891,45.552,48.576,51.455,53.676,56.007,32.5,33.489,34.488,35.492,36.486,37.465,39.327,41.245,43.266,44.873,45.504,46.388,37.579,40.696,43.59,46.243,48.042,49.923,51.461,53.636,55.089,56.671,58.137,60.916,41.912,44.665,48.041,50.924,53.884,57.402,60.909,64.492,66.399,67.659,68.565,70.198,60.96,64.75,67.65,70.0,72.0,73.6,75.45,76.2,77.601,80.0,81.495,82.208,64.03,66.41,67.96,69.5,69.76,69.95,69.39,69.58,69.17,71.04,72.59,73.338,72.49,73.47,73.68,73.73,74.46,76.11,76.99,77.23,78.77,78.95,80.5,81.757,37.373,40.249,43.605,47.193,50.651,54.208,56.596,58.553,60.223,61.765,62.879,64.698,37.468,39.918,42.518,45.964,49.203,52.702,56.159,60.137,62.681,66.041,68.588,70.65,44.869,47.181,49.325,52.469,55.234,57.702,59.62,63.04,65.742,68.042,69.451,70.964,45.32,48.437,51.457,54.459,56.95,60.413,62.038,65.044,59.461,58.811,57.046,59.545,66.91,68.9,70.29,71.08,71.28,72.03,73.1,74.36,75.467,76.122,77.783,78.885,65.39,67.84,69.39,70.75,71.63,73.06,74.45,75.6,76.93,78.269,79.696,80.745,65.94,67.81,69.24,71.06,72.19,73.48,74.98,76.42,77.44,78.82,80.24,80.546,58.53,62.61,65.61,67.51,69.0,70.11,71.21,71.77,71.766,72.262,72.047,72.567,63.03,65.5,68.73,71.43,73.42,75.38,77.11,78.67,79.36,80.69,82.0,82.603,43.158,45.669,48.126,51.629,56.528,61.134,63.739,65.869,68.015,69.772,71.263,72.535,42.27,44.686,47.949,50.654,53.559,56.155,58.766,59.339,59.285,54.407,50.992,54.11,50.056,54.081,56.656,59.942,63.983,67.159,69.1,70.647,69.978,67.727,66.662,67.297,47.453,52.681,55.292,57.716,62.612,64.766,67.123,69.81,72.244,74.647,77.045,78.623,55.565,58.033,60.47,64.624,67.712,69.343,71.309,74.174,75.19,76.156,76.904,77.588,55.928,59.489,62.094,63.87,65.421,66.099,66.983,67.926,69.292,70.265,71.028,71.993,42.138,45.047,47.747,48.492,49.767,52.208,55.078,57.18,59.685,55.558,44.593,42.592,38.48,39.486,40.502,41.536,42.614,43.764,44.852,46.027,40.802,42.221,43.753,45.678,42.723,45.289,47.808,50.227,52.773,57.442,62.155,66.234,68.755,71.555,72.737,73.952,36.681,38.865,40.848,42.881,44.851,46.881,48.969,49.35,52.214,54.978,57.286,59.443,36.256,37.207,38.41,39.487,41.766,43.767,45.642,47.457,49.42,47.495,45.009,48.303,48.463,52.102,55.737,59.371,63.01,65.256,68.0,69.5,70.693,71.938,73.044,74.241,33.685,35.307,36.936,38.487,39.977,41.714,43.916,46.364,48.388,49.903,51.818,54.467,40.543,42.338,44.248,46.289,48.437,50.852,53.599,56.145,58.333,60.43,62.247,64.164,50.986,58.089,60.246,61.557,62.944,64.93,66.711,68.74,69.745,70.736,71.954,72.801,50.789,55.19,58.299,60.11,62.361,65.032,67.405,69.498,71.455,73.67,74.902,76.195,42.244,45.248,48.251,51.253,53.754,55.491,57.489,60.222,61.271,63.625,65.033,66.803,59.164,61.448,63.728,67.178,70.636,73.066,74.101,74.865,75.435,75.445,73.981,74.543,42.873,45.423,47.924,50.335,52.862,55.73,59.65,62.677,65.393,67.66,69.615,71.164,31.286,33.779,36.161,38.113,40.328,42.495,42.795,42.861,44.284,46.344,44.026,42.082,36.319,41.905,45.108,49.379,53.07,56.059,58.056,58.339,59.32,60.328,59.908,62.069,41.725,45.226,48.386,51.159,53.867,56.437,58.968,60.835,61.999,58.909,51.479,52.906,36.157,37.686,39.393,41.472,43.971,46.748,49.594,52.537,55.727,59.426,61.34,63.785,72.13,72.99,73.23,73.82,73.75,75.24,76.05,76.83,77.42,78.03,78.53,79.762,69.39,70.26,71.24,71.52,71.89,72.22,73.84,74.32,76.33,77.55,79.11,80.204,42.314,45.432,48.632,51.884,55.151,57.47,59.298,62.008,65.843,68.426,70.836,72.899,37.444,38.598,39.487,40.118,40.546,41.291,42.598,44.555,47.391,51.313,54.496,56.867,36.324,37.802,39.36,41.04,42.821,44.514,45.826,46.886,47.472,47.464,46.608,46.859,72.67,73.44,73.47,74.08,74.34,75.37,75.97,75.89,77.32,78.32,79.05,80.196,37.578,40.08,43.165,46.988,52.143,57.367,62.728,67.734,71.197,72.499,74.193,75.64,43.436,45.557,47.67,49.8,51.929,54.043,56.158,58.245,60.838,61.818,63.61,65.483,55.191,59.201,61.817,64.071,66.216,68.681,70.472,71.523,72.462,73.738,74.712,75.537,62.649,63.196,64.361,64.951,65.815,66.353,66.874,67.378,68.225,69.4,70.755,71.752,43.902,46.263,49.096,51.445,55.448,58.447,61.406,64.134,66.458,68.386,69.906,71.421,47.752,51.334,54.757,56.393,58.065,60.06,62.082,64.151,66.458,68.564,70.303,71.688,61.31,65.77,67.64,69.61,70.85,70.67,71.32,70.98,70.99,72.75,74.67,75.563,59.82,61.51,64.39,66.6,69.26,70.41,72.77,74.06,74.86,75.97,77.29,78.098,64.28,68.54,69.62,71.1,72.16,73.44,73.75,74.63,73.911,74.917,77.778,78.746,52.724,55.09,57.666,60.542,64.274,67.064,69.885,71.913,73.615,74.772,75.744,76.442,61.05,64.1,66.8,66.8,69.21,69.46,69.66,69.53,69.36,69.72,71.322,72.476,40.0,41.5,43.0,44.1,44.6,45.0,46.218,44.02,23.599,36.087,43.413,46.242,46.471,48.945,51.893,54.425,56.48,58.55,60.351,61.728,62.742,63.306,64.337,65.528,39.875,42.868,45.914,49.901,53.886,58.69,63.012,66.295,68.768,70.533,71.626,72.777,37.278,39.329,41.454,43.563,45.815,48.879,52.379,55.769,58.196,60.187,61.6,63.062,57.996,61.685,64.531,66.914,68.7,70.3,70.162,71.218,71.659,72.232,73.213,74.002,30.331,31.57,32.767,34.113,35.4,36.788,38.445,40.006,38.333,39.897,41.012,42.568,60.396,63.179,65.798,67.946,69.521,70.795,71.76,73.56,75.788,77.158,78.77,79.972,64.36,67.45,70.33,70.98,70.35,70.45,70.8,71.08,71.38,72.71,73.8,74.663,65.57,67.85,69.15,69.18,69.82,70.97,71.063,72.25,73.64,75.13,76.66,77.926,32.978,34.977,36.981,38.977,40.973,41.974,42.955,44.501,39.658,43.795,45.936,48.159,45.009,47.985,49.951,51.927,53.696,55.527,58.161,60.834,61.888,60.236,53.365,49.339,64.94,66.66,69.69,71.44,73.06,74.39,76.3,76.9,77.57,78.77,79.78,80.941,57.593,61.456,62.192,64.266,65.042,65.949,68.757,69.011,70.379,70.457,70.815,72.396,38.635,39.624,40.87,42.858,45.083,47.8,50.338,51.744,53.556,55.373,56.369,58.556,41.407,43.424,44.992,46.633,49.552,52.537,55.561,57.678,58.474,54.289,43.869,39.613,71.86,72.49,73.37,74.16,74.72,75.44,76.42,77.19,78.16,79.39,80.04,80.884,69.62,70.56,71.32,72.77,73.78,75.39,76.21,77.41,78.03,79.37,80.62,81.701,45.883,48.284,50.305,53.655,57.296,61.195,64.59,66.974,69.249,71.527,73.053,74.143,58.5,62.4,65.2,67.5,69.39,70.59,72.16,73.4,74.26,75.25,76.99,78.4,41.215,42.974,44.246,45.757,47.62,49.919,50.608,51.535,50.44,48.466,49.651,52.517,50.848,53.63,56.061,58.285,60.405,62.494,64.597,66.084,67.298,67.521,68.564,70.616,38.596,41.208,43.922,46.769,49.759,52.887,55.471,56.941,58.061,58.39,57.561,58.42,59.1,61.8,64.9,65.4,65.9,68.3,68.832,69.582,69.862,69.465,68.976,69.819,44.6,47.1,49.579,52.053,55.602,59.837,64.048,66.894,70.001,71.973,73.042,73.923,43.585,48.079,52.098,54.336,57.005,59.507,61.036,63.108,66.146,68.835,70.845,71.777,39.978,42.571,45.344,48.051,51.016,50.35,49.849,51.509,48.825,44.578,47.813,51.542,69.18,70.42,70.76,71.36,72.01,72.76,74.04,75.007,76.42,77.218,78.471,79.425,68.44,69.49,70.21,70.76,71.34,73.38,74.65,75.02,76.09,76.81,77.31,78.242,66.071,67.044,68.253,68.468,68.673,69.481,70.805,71.918,72.752,74.223,75.307,76.384,55.088,57.907,60.77,63.479,65.712,67.456,68.557,70.19,71.15,72.146,72.766,73.747,40.412,42.887,45.363,47.838,50.254,55.764,58.816,62.82,67.662,70.672,73.017,74.249,43.16,45.671,48.127,51.631,56.532,60.765,64.406,67.046,69.718,71.096,72.37,73.422,32.548,33.97,35.18,36.984,39.848,44.175,49.113,52.922,55.599,58.02,60.308,62.698,42.038,44.077,46.023,47.768,50.107,51.386,51.821,50.821,46.1,40.238,39.193,42.384,48.451,50.469,52.358,53.995,55.635,57.674,60.363,62.351,60.377,46.809,39.989,43.487],\n",
       "\"pop\":[8425333.0,9240934.0,1.0267083E7,1.1537966E7,1.307946E7,1.4880372E7,1.2881816E7,1.3867957E7,1.6317921E7,2.2227415E7,2.5268405E7,3.1889923E7,1282697.0,1476505.0,1728137.0,1984060.0,2263554.0,2509048.0,2780097.0,3075321.0,3326498.0,3428038.0,3508512.0,3600523.0,9279525.0,1.0270856E7,1.1000948E7,1.2760499E7,1.4760787E7,1.7152804E7,2.0033753E7,2.3254956E7,2.6298373E7,2.9072015E7,3.1287142E7,3.3333216E7,4232095.0,4561361.0,4826015.0,5247469.0,5894858.0,6162675.0,7016384.0,7874230.0,8735988.0,9875024.0,1.0866106E7,1.2420476E7,1.7876956E7,1.9610538E7,2.1283783E7,2.2934225E7,2.4779799E7,2.6983828E7,2.9341374E7,3.1620918E7,3.3958947E7,3.6203463E7,3.8331121E7,4.0301927E7,8691212.0,9712569.0,1.0794968E7,1.1872264E7,1.3177E7,1.40741E7,1.51842E7,1.6257249E7,1.7481977E7,1.8565243E7,1.9546792E7,2.0434176E7,6927772.0,6965860.0,7129864.0,7376998.0,7544201.0,7568430.0,7574613.0,7578903.0,7914969.0,8069876.0,8148312.0,8199783.0,120447.0,138655.0,171863.0,202182.0,230800.0,297410.0,377967.0,454612.0,529491.0,598561.0,656397.0,708573.0,4.6886859E7,5.1365468E7,5.6839289E7,6.2821884E7,7.0759295E7,8.0428306E7,9.3074406E7,1.03764241E8,1.13704579E8,1.23315288E8,1.3565679E8,1.50448339E8,8730405.0,8989111.0,9218400.0,9556500.0,9709100.0,9821800.0,9856303.0,9870200.0,1.0045622E7,1.0199787E7,1.031197E7,1.0392226E7,1738315.0,1925173.0,2151895.0,2427334.0,2761407.0,3168267.0,3641603.0,4243788.0,4981671.0,6066080.0,7026113.0,8078314.0,2883315.0,3211738.0,3593918.0,4040665.0,4565872.0,5079716.0,5642224.0,6156369.0,6893451.0,7693188.0,8445134.0,9119152.0,2791000.0,3076000.0,3349000.0,3585000.0,3819000.0,4086000.0,4172693.0,4338977.0,4256013.0,3607000.0,4165416.0,4552198.0,442308.0,474639.0,512764.0,553541.0,619351.0,781472.0,970347.0,1151184.0,1342614.0,1536536.0,1630347.0,1639131.0,5.660256E7,6.5551171E7,7.603939E7,8.8049823E7,1.00840058E8,1.14313951E8,1.28962939E8,1.42938076E8,1.55975974E8,1.68546719E8,1.79914212E8,1.90010647E8,7274900.0,7651254.0,8012946.0,8310226.0,8576200.0,8797022.0,8892098.0,8971958.0,8658506.0,8066057.0,7661799.0,7322858.0,4469979.0,4713416.0,4919632.0,5127935.0,5433886.0,5889574.0,6634596.0,7586551.0,8878303.0,1.0352843E7,1.2251209E7,1.4326203E7,2445618.0,2667518.0,2961915.0,3330989.0,3529983.0,3834415.0,4580410.0,5126023.0,5809236.0,6121610.0,7021078.0,8390505.0,4693836.0,5322536.0,6083619.0,6960067.0,7450606.0,6978607.0,7272485.0,8371791.0,1.0150094E7,1.1782962E7,1.2926707E7,1.4131858E7,5009067.0,5359923.0,5793633.0,6335506.0,7021028.0,7959865.0,9250831.0,1.0780667E7,1.2467171E7,1.4195809E7,1.5929988E7,1.7696293E7,1.4785584E7,1.7010154E7,1.8985849E7,2.0819767E7,2.22845E7,2.37964E7,2.52019E7,2.65497E7,2.8523502E7,3.0305843E7,3.1902268E7,3.3390141E7,1291695.0,1392284.0,1523478.0,1733638.0,1927260.0,2167533.0,2476971.0,2840009.0,3265124.0,3696513.0,4048013.0,4369038.0,2682462.0,2894855.0,3150417.0,3495967.0,3899068.0,4388260.0,4875118.0,5498955.0,6429417.0,7562011.0,8835739.0,1.0238807E7,6377619.0,7048426.0,7961258.0,8858908.0,9717524.0,1.0599793E7,1.1487112E7,1.2463354E7,1.3572994E7,1.4599929E7,1.5497046E7,1.6284741E7,5.56263527E8,6.37408E8,6.6577E8,7.5455E8,8.6203E8,9.43455E8,1.000281E9,1.084035E9,1.16497E9,1.230075E9,1.2804E9,1.318683096E9,1.2350771E7,1.4485993E7,1.7009885E7,1.9764027E7,2.254289E7,2.5094412E7,2.7764644E7,3.0964245E7,3.4202721E7,3.765783E7,4.1008227E7,4.422755E7,153936.0,170928.0,191689.0,217378.0,250027.0,304739.0,348643.0,395114.0,454429.0,527982.0,614382.0,710960.0,1.4100005E7,1.5577932E7,1.7486434E7,1.9941073E7,2.3007669E7,2.648087E7,3.0646495E7,3.5481645E7,4.1672143E7,4.7798986E7,5.5379852E7,6.4606759E7,854885.0,940458.0,1047924.0,1179760.0,1340458.0,1536769.0,1774735.0,2064095.0,2409073.0,2800947.0,3328795.0,3800610.0,926317.0,1112300.0,1345187.0,1588717.0,1834796.0,2108457.0,2424367.0,2799811.0,3173216.0,3518107.0,3834934.0,4133884.0,2977019.0,3300000.0,3832408.0,4744870.0,6071696.0,7459574.0,9025951.0,1.0761098E7,1.2772596E7,1.4625967E7,1.6252726E7,1.8013409E7,3882229.0,3991242.0,4076557.0,4174366.0,4225310.0,4318673.0,4413368.0,4484310.0,4494013.0,4444595.0,4481020.0,4493312.0,6007797.0,6640752.0,7254373.0,8139332.0,8831348.0,9537988.0,9789224.0,1.0239839E7,1.072326E7,1.0983007E7,1.1226999E7,1.1416987E7,9125183.0,9513758.0,9620282.0,9835109.0,9862158.0,1.0161915E7,1.0303704E7,1.0311597E7,1.0315702E7,1.0300707E7,1.0256295E7,1.0228744E7,4334000.0,4487831.0,4646899.0,4838800.0,4991596.0,5088419.0,5117810.0,5127024.0,5171393.0,5283663.0,5374693.0,5468120.0,63149.0,71851.0,89898.0,127617.0,178848.0,228694.0,305991.0,311025.0,384156.0,417908.0,447416.0,496374.0,2491346.0,2923186.0,3453434.0,4049146.0,4671329.0,5302800.0,5968349.0,6655297.0,7351181.0,7992357.0,8650322.0,9319622.0,3548753.0,4058385.0,4681707.0,5432424.0,6298651.0,7278866.0,8365850.0,9545158.0,1.0748394E7,1.1911819E7,1.2921234E7,1.375568E7,2.2223309E7,2.5009741E7,2.8173309E7,3.1681188E7,3.4807417E7,3.8783863E7,4.5681811E7,5.2799062E7,5.9402198E7,6.6134291E7,7.3312559E7,8.0264543E7,2042865.0,2355805.0,2747687.0,3232927.0,3790903.0,4282586.0,4474873.0,4842194.0,5274649.0,5783439.0,6353681.0,6939688.0,216964.0,232922.0,249220.0,259864.0,277603.0,192675.0,285483.0,341244.0,387838.0,439971.0,495627.0,551201.0,1438760.0,1542611.0,1666618.0,1820319.0,2260187.0,2512642.0,2637297.0,2915959.0,3668440.0,4058319.0,4414865.0,4906585.0,2.0860941E7,2.2815614E7,2.5145372E7,2.7860297E7,3.0770372E7,3.4617799E7,3.8111756E7,4.299953E7,5.2088559E7,5.9861301E7,6.7946797E7,7.6511887E7,4090500.0,4324000.0,4491443.0,4605744.0,4639657.0,4738902.0,4826933.0,4931729.0,5041039.0,5134406.0,5193039.0,5238460.0,4.2459667E7,4.4310863E7,4.7124E7,4.9569E7,5.1732E7,5.3165019E7,5.4433565E7,5.56301E7,5.7374179E7,5.8623428E7,5.9925035E7,6.1083916E7,420702.0,434904.0,455661.0,489004.0,537977.0,706367.0,753874.0,880397.0,985739.0,1126189.0,1299304.0,1454867.0,284320.0,323150.0,374020.0,439593.0,517101.0,608274.0,715523.0,848406.0,1025384.0,1235767.0,1457766.0,1688359.0,6.9145952E7,7.1019069E7,7.3739117E7,7.6368453E7,7.8717088E7,7.8160773E7,7.8335266E7,7.7718298E7,8.0597764E7,8.2011073E7,8.2350671E7,8.2400996E7,5581001.0,6391288.0,7355248.0,8490213.0,9354120.0,1.0538093E7,1.1400338E7,1.4168101E7,1.6278738E7,1.8418288E7,2.0550751E7,2.2873338E7,7733250.0,8096218.0,8448233.0,8716441.0,8888628.0,9308479.0,9786480.0,9974490.0,1.0325429E7,1.0502372E7,1.0603863E7,1.070629E7,3146381.0,3640876.0,4208858.0,4690773.0,5149581.0,5703430.0,6395630.0,7326406.0,8486949.0,9803875.0,1.117865E7,1.2572928E7,2664249.0,2876726.0,3140003.0,3451418.0,3811387.0,4227026.0,4710497.0,5650262.0,6990574.0,8048834.0,8807818.0,9947814.0,580653.0,601095.0,627820.0,601287.0,625361.0,745228.0,825987.0,927524.0,1050938.0,1193708.0,1332459.0,1472041.0,3201488.0,3507701.0,3880130.0,4318137.0,4698301.0,4908554.0,5198399.0,5756203.0,6326682.0,6913545.0,7607651.0,8502814.0,1517453.0,1770390.0,2090162.0,2500689.0,2965146.0,3055235.0,3669448.0,4372203.0,5077347.0,5867957.0,6677328.0,7483763.0,2125900.0,2736300.0,3305200.0,3722800.0,4115700.0,4583700.0,5264500.0,5584510.0,5829696.0,6495918.0,6762476.0,6980412.0,9504000.0,9839000.0,1.0063E7,1.0223422E7,1.0394091E7,1.0637171E7,1.0705535E7,1.061274E7,1.0348684E7,1.0244684E7,1.0083313E7,9956108.0,147962.0,165110.0,182053.0,198676.0,209275.0,221823.0,233997.0,244676.0,259012.0,271192.0,288030.0,301931.0,3.72E8,4.09E8,4.54E8,5.06E8,5.67E8,6.34E8,7.08E8,7.88E8,8.72E8,9.59E8,1.034172547E9,1.110396331E9,8.2052E7,9.0124E7,9.9028E7,1.09343E8,1.21282E8,1.36725E8,1.53343E8,1.69276E8,1.84816E8,1.99278E8,2.1106E8,2.23547E8,1.7272E7,1.9792E7,2.2874E7,2.6538E7,3.0614E7,3.5480679E7,4.3072751E7,5.1889696E7,6.0397973E7,6.3327987E7,6.6907826E7,6.945357E7,5441766.0,6248643.0,7240260.0,8519282.0,1.0061506E7,1.1882916E7,1.4173318E7,1.6543189E7,1.7861905E7,2.0775703E7,2.4001816E7,2.7499638E7,2952156.0,2878220.0,2830000.0,2900100.0,3024400.0,3271900.0,3480000.0,3539900.0,3557761.0,3667233.0,3879155.0,4109086.0,1620914.0,1944401.0,2310904.0,2693585.0,3095893.0,3495918.0,3858421.0,4203148.0,4936550.0,5531387.0,6029529.0,6426679.0,4.7666E7,4.9182E7,5.08432E7,5.26671E7,5.4365564E7,5.6059245E7,5.6535636E7,5.6729703E7,5.6840847E7,5.7479469E7,5.7926999E7,5.8147733E7,1426095.0,1535090.0,1665128.0,1861096.0,1997616.0,2156814.0,2298309.0,2326606.0,2378618.0,2531311.0,2664659.0,2780132.0,8.6459025E7,9.1563009E7,9.5831757E7,1.00825279E8,1.07188273E8,1.13872473E8,1.18454974E8,1.22091325E8,1.24329269E8,1.25956499E8,1.27065841E8,1.27467972E8,607914.0,746559.0,933559.0,1255058.0,1613551.0,1937652.0,2347031.0,2820042.0,3867409.0,4526235.0,5307470.0,6053193.0,6464046.0,7454779.0,8678557.0,1.0191512E7,1.2044785E7,1.4500404E7,1.7661452E7,2.1198082E7,2.5020539E7,2.8263827E7,3.1386842E7,3.5610177E7,8865488.0,9411381.0,1.0917494E7,1.2617009E7,1.4781241E7,1.632532E7,1.7647518E7,1.9067554E7,2.0711375E7,2.1585105E7,2.2215365E7,2.3301725E7,2.0947571E7,2.2611552E7,2.6420307E7,3.0131E7,3.3505E7,3.6436E7,3.9326E7,4.1622E7,4.380545E7,4.6173816E7,4.796915E7,4.904479E7,160000.0,212846.0,358266.0,575003.0,841934.0,1140357.0,1497494.0,1891487.0,1418095.0,1765345.0,2111561.0,2505559.0,1439529.0,1647412.0,1886848.0,2186894.0,2680018.0,3115787.0,3086876.0,3089353.0,3219994.0,3430388.0,3677780.0,3921278.0,748747.0,813338.0,893143.0,996380.0,1116779.0,1251524.0,1411807.0,1599200.0,1803195.0,1982823.0,2046772.0,2012649.0,863308.0,975950.0,1112796.0,1279406.0,1482628.0,1703617.0,1956875.0,2269414.0,1912974.0,2200725.0,2814651.0,3193942.0,1019729.0,1201578.0,1441863.0,1759224.0,2183877.0,2721783.0,3344074.0,3799845.0,4364501.0,4759670.0,5368585.0,6036914.0,4762912.0,5181679.0,5703324.0,6334556.0,7082430.0,8007166.0,9171477.0,1.0568642E7,1.2210395E7,1.4165114E7,1.6473477E7,1.9167654E7,2917802.0,3221238.0,3628608.0,4147252.0,4730997.0,5637246.0,6502825.0,7824747.0,1.0014249E7,1.0419991E7,1.1824495E7,1.3327079E7,6748378.0,7739235.0,8906385.0,1.0154878E7,1.1441462E7,1.2845381E7,1.4441916E7,1.6331785E7,1.8319502E7,2.0476091E7,2.2662365E7,2.4821286E7,3838168.0,4241884.0,4690372.0,5212416.0,5828158.0,6491649.0,6998256.0,7634008.0,8416215.0,9384984.0,1.0580176E7,1.2031795E7,1022556.0,1076852.0,1146757.0,1230542.0,1332786.0,1456688.0,1622136.0,1841240.0,2119465.0,2444741.0,2828858.0,3270065.0,516556.0,609816.0,701016.0,789309.0,851334.0,913025.0,992040.0,1042663.0,1096202.0,1149818.0,1200206.0,1250882.0,3.0144317E7,3.5015548E7,4.1121485E7,4.7995559E7,5.5984294E7,6.3759976E7,7.1640904E7,8.0122492E7,8.811103E7,9.5895146E7,1.02479927E8,1.08700891E8,800663.0,882134.0,1010280.0,1149500.0,1320500.0,1528000.0,1756032.0,2015133.0,2312802.0,2494803.0,2674234.0,2874127.0,413834.0,442829.0,474528.0,501035.0,527678.0,560073.0,562548.0,569473.0,621621.0,692651.0,720230.0,684736.0,9939217.0,1.140635E7,1.3056604E7,1.4770296E7,1.666067E7,1.8396941E7,2.019873E7,2.2987397E7,2.5798239E7,2.8529501E7,3.1167783E7,3.3757175E7,6446316.0,7038035.0,7788944.0,8680909.0,9809596.0,1.1127868E7,1.2587223E7,1.2891952E7,1.3160731E7,1.6603334E7,1.847378E7,1.9951656E7,2.0092996E7,2.1731844E7,2.3634436E7,2.5870271E7,2.846639E7,3.1528087E7,3.4680442E7,3.8028578E7,4.0546538E7,4.3247867E7,4.5598081E7,4.776198E7,485831.0,548080.0,621392.0,706640.0,821782.0,977026.0,1099010.0,1278184.0,1554253.0,1774766.0,1972153.0,2055080.0,9182536.0,9682338.0,1.0332057E7,1.126169E7,1.2412593E7,1.3933198E7,1.5796314E7,1.791718E7,2.0326209E7,2.3001113E7,2.5873917E7,2.890179E7,1.0381988E7,1.1026383E7,1.1805689E7,1.2596822E7,1.3329874E7,1.3852989E7,1.4310401E7,1.4665278E7,1.5174244E7,1.5604464E7,1.612283E7,1.6570613E7,1994794.0,2229407.0,2488550.0,2728150.0,2929100.0,3164900.0,3210650.0,3317166.0,3437674.0,3676187.0,3908037.0,4115771.0,1165790.0,1358828.0,1590597.0,1865490.0,2182908.0,2554598.0,2979423.0,3344353.0,4017939.0,4609572.0,5146848.0,5675356.0,3379468.0,3692184.0,4076008.0,4534062.0,5060262.0,5682086.0,6437188.0,7332638.0,8392818.0,9666252.0,1.1140655E7,1.2894865E7,3.3119096E7,3.717334E7,4.1871351E7,4.7287752E7,5.3740085E7,6.2209173E7,7.3039376E7,8.155152E7,9.3364244E7,1.06207839E8,1.19901274E8,1.35031164E8,3327728.0,3491938.0,3638919.0,3786019.0,3933004.0,4043205.0,4114787.0,4186147.0,4286357.0,4405672.0,4535591.0,4627926.0,507833.0,561977.0,628164.0,714775.0,829050.0,1004533.0,1301048.0,1593882.0,1915208.0,2283635.0,2713462.0,3204897.0,4.134656E7,4.6679944E7,5.3100671E7,6.0641899E7,6.9325921E7,7.8152686E7,9.1462088E7,1.05186881E8,1.20065004E8,1.35564834E8,1.53403524E8,1.69270617E8,940080.0,1063506.0,1215725.0,1405486.0,1616384.0,1839782.0,2036305.0,2253639.0,2484997.0,2734531.0,2990875.0,3242173.0,1555876.0,1770902.0,2009813.0,2287985.0,2614104.0,2984494.0,3366439.0,3886512.0,4483945.0,5154123.0,5884491.0,6667147.0,8025700.0,9146100.0,1.05165E7,1.21322E7,1.39547E7,1.5990099E7,1.8125129E7,2.0195924E7,2.2430449E7,2.4748122E7,2.6769436E7,2.8674757E7,2.2438691E7,2.6072194E7,3.0325264E7,3.53566E7,4.0850141E7,4.6850962E7,5.3456774E7,6.0017788E7,6.7185766E7,7.5012988E7,8.2995088E7,9.1077287E7,2.5730551E7,2.8235346E7,3.0329617E7,3.1785378E7,3.3039545E7,3.4621254E7,3.6227381E7,3.774071E7,3.8370697E7,3.8654957E7,3.8625976E7,3.8518241E7,8526050.0,8817650.0,9019800.0,9103000.0,8970450.0,9662600.0,9859650.0,9915289.0,9927680.0,1.0156415E7,1.0433867E7,1.0642836E7,2227000.0,2260000.0,2448046.0,2648961.0,2847132.0,3080828.0,3279001.0,3444468.0,3585176.0,3759430.0,3859606.0,3942491.0,257700.0,308700.0,358900.0,414024.0,461633.0,492095.0,517810.0,562035.0,622191.0,684810.0,743981.0,798094.0,1.663E7,1.7829327E7,1.8680721E7,1.9284814E7,2.0662648E7,2.1658597E7,2.2356726E7,2.2686371E7,2.2797027E7,2.2562458E7,2.2404337E7,2.2276056E7,2534927.0,2822082.0,3051242.0,3451079.0,3992121.0,4657072.0,5507565.0,6349365.0,7290203.0,7212583.0,7852401.0,8860588.0,60011.0,61325.0,65345.0,70787.0,76595.0,86796.0,98593.0,110812.0,125911.0,145608.0,170372.0,199579.0,4005677.0,4419650.0,4943029.0,5618198.0,6472756.0,8128505.0,1.1254672E7,1.4619745E7,1.6945857E7,2.1229759E7,2.450153E7,2.7601038E7,2755589.0,3054547.0,3430243.0,3965841.0,4588696.0,5260855.0,6147783.0,7171347.0,8307920.0,9535314.0,1.0870037E7,1.2267493E7,6860147.0,7271135.0,7616060.0,7971222.0,8313288.0,8686367.0,9032824.0,9230783.0,9826397.0,1.0336594E7,1.0111559E7,1.0150265E7,2143249.0,2295678.0,2467895.0,2662190.0,2879013.0,3140897.0,3464522.0,3868905.0,4260884.0,4578212.0,5359092.0,6144562.0,1127000.0,1445929.0,1750200.0,1977600.0,2152400.0,2325300.0,2651869.0,2794552.0,3235865.0,3802309.0,4197776.0,4553009.0,3558137.0,3844277.0,4237384.0,4442238.0,4593433.0,4827803.0,5048043.0,5199318.0,5302888.0,5383010.0,5410052.0,5447502.0,1489518.0,1533070.0,1582962.0,1646912.0,1694510.0,1746919.0,1861252.0,1945870.0,1999210.0,2011612.0,2011497.0,2009245.0,2526994.0,2780415.0,3080153.0,3428839.0,3840161.0,4353666.0,5828892.0,6921858.0,6099799.0,6633514.0,7753310.0,9118773.0,1.4264935E7,1.6151549E7,1.8356657E7,2.0997321E7,2.393581E7,2.7129932E7,3.1140029E7,3.5933379E7,3.9964159E7,4.2835005E7,4.4433622E7,4.3997828E7,2.854987E7,2.9841614E7,3.1158061E7,3.2850275E7,3.4513161E7,3.6439E7,3.798331E7,3.8880702E7,3.9549438E7,3.9855442E7,4.0152517E7,4.0448191E7,7982342.0,9128546.0,1.0421936E7,1.1737396E7,1.3016733E7,1.4116836E7,1.5410151E7,1.6495304E7,1.758706E7,1.8698655E7,1.9576783E7,2.0378239E7,8504667.0,9753392.0,1.1183227E7,1.2716129E7,1.4597019E7,1.7104986E7,2.0367053E7,2.472596E7,2.8227588E7,3.2160729E7,3.7090298E7,4.2292929E7,290243.0,326741.0,370006.0,420690.0,480105.0,551425.0,649901.0,779348.0,962344.0,1054486.0,1130269.0,1133066.0,7124673.0,7363802.0,7561588.0,7867931.0,8122293.0,8251648.0,8325260.0,8421403.0,8718867.0,8897619.0,8954175.0,9031088.0,4815000.0,5126000.0,5666000.0,6063000.0,6401400.0,6316424.0,6468126.0,6649942.0,6995447.0,7193761.0,7361757.0,7554661.0,3661549.0,4149908.0,4834621.0,5680812.0,6701172.0,7932503.0,9410494.0,1.1242847E7,1.3219062E7,1.5081016E7,1.7155814E7,1.9314747E7,8550362.0,1.0164215E7,1.1918938E7,1.3648692E7,1.5226039E7,1.6785196E7,1.850139E7,1.9757799E7,2.0686918E7,2.1628605E7,2.2454239E7,2.3174294E7,8322925.0,9452826.0,1.0863958E7,1.2607312E7,1.4706593E7,1.7129565E7,1.9844382E7,2.304063E7,2.6605473E7,3.0686889E7,3.4593779E7,3.813964E7,2.1289402E7,2.5041917E7,2.9263397E7,3.4024249E7,3.9276153E7,4.4148285E7,4.882716E7,5.2910342E7,5.6667095E7,6.0216677E7,6.2806748E7,6.5068149E7,1219113.0,1357445.0,1528098.0,1735550.0,2056351.0,2308582.0,2644765.0,3154264.0,3747553.0,4320890.0,4977378.0,5701579.0,662850.0,764900.0,887498.0,960155.0,975199.0,1039009.0,1116479.0,1191336.0,1183669.0,1138101.0,1101832.0,1056608.0,3647735.0,3950849.0,4286552.0,4786986.0,5303507.0,6005061.0,6734098.0,7724976.0,8523077.0,9231669.0,9770575.0,1.0276158E7,2.2235677E7,2.5670939E7,2.9788695E7,3.3411317E7,3.7492953E7,4.2404033E7,4.7328791E7,5.2881328E7,5.8179144E7,6.3047647E7,6.7308928E7,7.1158647E7,5824797.0,6675501.0,7688797.0,8900294.0,1.0190285E7,1.1457758E7,1.29394E7,1.528305E7,1.825219E7,2.1210254E7,2.4739869E7,2.9170398E7,5.043E7,5.143E7,5.3292E7,5.4959E7,5.6079E7,5.6179E7,5.6339704E7,5.698162E7,5.7866349E7,5.8808266E7,5.9912431E7,6.0776238E7,1.57553E8,1.71984E8,1.86538E8,1.98712E8,2.09896E8,2.20239E8,2.32187835E8,2.42803533E8,2.56894189E8,2.7291176E8,2.87675526E8,3.01139947E8,2252965.0,2424959.0,2598466.0,2748579.0,2829526.0,2873520.0,2953997.0,3045153.0,3149262.0,3262838.0,3363085.0,3447496.0,5439568.0,6702668.0,8143375.0,9709552.0,1.1515649E7,1.3503563E7,1.5620766E7,1.7910182E7,2.0265563E7,2.2374398E7,2.428767E7,2.6084662E7,2.6246839E7,2.8998543E7,3.379614E7,3.946391E7,4.4655014E7,5.0533506E7,5.6142181E7,6.2826491E7,6.9940728E7,7.6048996E7,8.0908147E7,8.5262356E7,1030585.0,1070439.0,1133134.0,1142636.0,1089572.0,1261091.0,1425876.0,1691210.0,2104779.0,2826046.0,3389578.0,4018332.0,4963829.0,5498090.0,6120081.0,6740785.0,7407075.0,8403990.0,9657618.0,1.121934E7,1.3367997E7,1.5826497E7,1.8701257E7,2.2211743E7,2672000.0,3016000.0,3421000.0,3900000.0,4506497.0,5216550.0,6100407.0,7272406.0,8381163.0,9417789.0,1.0595811E7,1.1746035E7,3080907.0,3646340.0,4277736.0,4995432.0,5861135.0,6642107.0,7636524.0,9216418.0,1.070434E7,1.1404948E7,1.1926563E7,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,820.8530296,853.10071,836.1971382,739.9811058,786.11336,978.0114388,852.3959448,649.3413952,635.341351,726.7340548,974.5803384,1601.056136,1942.284244,2312.888958,2760.196931,3313.422188,3533.00391,3630.880722,3738.932735,2497.437901,3193.054604,4604.211737,5937.029526,2449.008185,3013.976023,2550.81688,3246.991771,4182.663766,4910.416756,5745.160213,5681.358539,5023.216647,4797.295051,5288.040382,6223.367465,3520.610273,3827.940465,4269.276742,5522.776375,5473.288005,3008.647355,2756.953672,2430.208311,2627.845685,2277.140884,2773.287312,4797.231267,5911.315053,6856.856212,7133.166023,8052.953021,9443.038526,10079.02674,8997.897412,9139.671389,9308.41871,10967.28195,8797.640716,12779.37964,10039.59564,10949.64959,12217.22686,14526.12465,16788.62948,18334.19751,19477.00928,21888.88903,23424.76683,26997.93657,30687.75473,34435.36744,6137.076492,8842.59803,10750.72111,12834.6024,16661.6256,19749.4223,21597.08362,23687.82607,27042.01868,29095.92066,32417.60769,36126.4927,9867.084765,11635.79945,12753.27514,14804.6727,18268.65839,19340.10196,19211.14731,18524.02406,19035.57917,20292.01679,23403.55927,29796.04834,684.2441716,661.6374577,686.3415538,721.1860862,630.2336265,659.8772322,676.9818656,751.9794035,837.8101643,972.7700352,1136.39043,1391.253792,8343.105127,9714.960623,10991.20676,13149.04119,16672.14356,19117.97448,20979.84589,22525.56308,25575.57069,27561.19663,30485.88375,33692.60508,1062.7522,959.6010805,949.4990641,1035.831411,1085.796879,1029.161251,1277.897616,1225.85601,1191.207681,1232.975292,1372.877931,1441.284873,2677.326347,2127.686326,2180.972546,2586.886053,2980.331339,3548.097832,3156.510452,2753.69149,2961.699694,3326.143191,3413.26269,3822.137084,973.5331948,1353.989176,1709.683679,2172.352423,2860.16975,3528.481305,4126.613157,4314.114757,2546.781445,4766.355904,6018.975239,7446.298803,851.2411407,918.2325349,983.6539764,1214.709294,2263.611114,3214.857818,4551.14215,6205.88385,7954.111645,8647.142313,11003.60508,12569.85177,2108.944355,2487.365989,3336.585802,3429.864357,4985.711467,6660.118654,7030.835878,7807.095818,6950.283021,7957.980824,8131.212843,9065.800825,2444.286648,3008.670727,4254.337839,5577.0028,6597.494398,7612.240438,8224.191647,8239.854824,6302.623438,5970.38876,7696.777725,10680.79282,543.2552413,617.1834648,722.5120206,794.8265597,854.7359763,743.3870368,807.1985855,912.0631417,931.7527731,946.2949618,1037.645221,1217.032994,339.2964587,379.5646281,355.2032273,412.9775136,464.0995039,556.1032651,559.603231,621.8188189,631.6998778,463.1151478,446.4035126,430.0706916,368.4692856,434.0383364,496.9136476,523.4323142,421.6240257,524.9721832,624.4754784,683.8955732,682.3031755,734.28517,896.2260153,1713.778686,1172.667655,1313.048099,1399.607441,1508.453148,1684.146528,1783.432873,2367.983282,2602.664206,1793.163278,1694.337469,1934.011449,2042.09524,11367.16112,12489.95006,13462.48555,16076.58803,18970.57086,22090.88306,22898.79214,26626.51503,26342.88426,28954.92589,33328.96507,36319.23501,1071.310713,1190.844328,1193.068753,1136.056615,1070.013275,1109.374338,956.7529907,844.8763504,747.9055252,740.5063317,738.6906068,706.016537,1178.665927,1308.495577,1389.817618,1196.810565,1104.103987,1133.98495,797.9081006,952.386129,1058.0643,1004.961353,1156.18186,1704.063724,3939.978789,4315.622723,4519.094331,5106.654313,5494.024437,4756.763836,5095.665738,5547.063754,7596.125964,10118.05318,10778.78385,13171.63885,400.448611,575.9870009,487.6740183,612.7056934,676.9000921,741.2374699,962.4213805,1378.904018,1655.784158,2289.234136,3119.280896,4959.114854,2144.115096,2323.805581,2492.351109,2678.729839,3264.660041,3815.80787,4397.575659,4903.2191,5444.648617,6117.361746,5755.259962,7006.580419,1102.990936,1211.148548,1406.648278,1876.029643,1937.577675,1172.603047,1267.100083,1315.980812,1246.90737,1173.618235,1075.811558,986.1478792,780.5423257,905.8602303,896.3146335,861.5932424,904.8960685,795.757282,673.7478181,672.774812,457.7191807,312.188423,241.1658765,277.5518587,2125.621418,2315.056572,2464.783157,2677.939642,3213.152683,3259.178978,4879.507522,4201.194937,4016.239529,3484.164376,3484.06197,3632.557798,2627.009471,2990.010802,3460.937025,4161.727834,5118.146939,5926.876967,5262.734751,5629.915318,6160.416317,6677.045314,7723.447195,9645.06142,1388.594732,1500.895925,1728.869428,2052.050473,2378.201111,2517.736547,2602.710169,2156.956069,1648.073791,1786.265407,1648.800823,1544.750112,3119.23652,4338.231617,5477.890018,6960.297861,9164.090127,11305.38517,13221.82184,13822.58394,8447.794873,9875.604515,11628.38895,14619.22272,5586.53878,6092.174359,5180.75591,5690.268015,5305.445256,6380.494966,7316.918107,7532.924763,5592.843963,5431.990415,6340.646683,8948.102923,6876.14025,8256.343918,10136.86713,11399.44489,13108.4536,14800.16062,15377.22855,16310.4434,14297.02122,16048.51424,17596.21022,22833.30851,9692.385245,11099.65935,13583.31351,15937.21123,18866.20721,20422.9015,21688.04048,25116.17581,26406.73985,29804.34567,32166.50006,35278.41874,2669.529475,2864.969076,3020.989263,3020.050513,3694.212352,3081.761022,2879.468067,2880.102568,2377.156192,1895.016984,1908.260867,2082.481567,1397.717137,1544.402995,1662.137359,1653.723003,2189.874499,2681.9889,2861.092386,2899.842175,3044.214214,3614.101285,4563.808154,6025.374752,3522.110717,3780.546651,4086.114078,4579.074215,5280.99471,6679.62326,7213.791267,6481.776993,7103.702595,7429.455877,5773.044512,6873.262326,1418.822445,1458.915272,1693.335853,1814.880728,2024.008147,2785.493582,3503.729636,3885.46071,3794.755195,4173.181797,4754.604414,5581.180998,3048.3029,3421.523218,3776.803627,4358.595393,4520.246008,5138.922374,4098.344175,4140.442097,4444.2317,5154.825496,5351.568666,5728.353514,375.6431231,426.0964081,582.8419714,915.5960025,672.4122571,958.5668124,927.8253427,966.8968149,1132.055034,2814.480755,7703.4959,12154.08975,328.9405571,344.1618859,380.9958433,468.7949699,514.3242082,505.7538077,524.8758493,521.1341333,582.8585102,913.47079,765.3500015,641.3695236,362.1462796,378.9041632,419.4564161,516.1186438,566.2439442,556.8083834,577.8607471,573.7413142,421.3534653,515.8894013,530.0535319,690.8055759,6424.519071,7545.415386,9371.842561,10921.63626,14358.8759,15605.42283,18533.15761,21141.01223,20647.16499,23723.9502,28204.59057,33207.0844,7029.809327,8662.834898,10560.48553,12999.91766,16107.19171,18292.63514,20293.89746,22066.44214,24703.79615,25889.78487,28926.03234,30470.0167,4293.476475,4976.198099,6631.459222,8358.761987,11401.94841,21745.57328,15113.36194,11864.40844,13522.15752,14722.84188,12521.71392,13206.48452,485.2306591,520.9267111,599.650276,734.7829124,756.0868363,884.7552507,835.8096108,611.6588611,665.6244126,653.7301704,660.5855997,752.7497265,7144.114393,10187.82665,12902.46291,14745.62561,18016.18027,20512.92123,22031.53274,24639.18566,26505.30317,27788.88416,30035.80198,32170.37442,911.2989371,1043.561537,1190.041118,1125.69716,1178.223708,993.2239571,876.032569,847.0061135,925.060154,1005.245812,1111.984578,1327.60891,3530.690067,4916.299889,6017.190733,8513.097016,12724.82957,14195.52428,15268.42089,16120.52839,17541.49634,18747.69814,22514.2548,27538.41188,2428.237769,2617.155967,2750.364446,3242.531147,4031.408271,4879.992748,4820.49479,4246.485974,4439.45084,4684.313807,4858.347495,5186.050003,510.1964923,576.2670245,686.3736739,708.7595409,741.6662307,874.6858643,857.2503577,805.5724718,794.3484384,869.4497668,945.5835837,942.6542111,299.850319,431.7904566,522.0343725,715.5806402,820.2245876,764.7259628,838.1239671,736.4153921,745.5398706,796.6644681,575.7047176,579.231743,1840.366939,1726.887882,1796.589032,1452.057666,1654.456946,1874.298931,2011.159549,1823.015995,1456.309517,1341.726931,1270.364932,1201.637154,2194.926204,2220.487682,2291.156835,2538.269358,2529.842345,3203.208066,3121.760794,3023.096699,3081.694603,3160.454906,3099.72866,3548.330846,3054.421209,3629.076457,4692.648272,6197.962814,8315.928145,11186.14125,14560.53051,20038.47269,24757.60301,28377.63219,30209.01516,39724.97867,5263.673816,6040.180011,7550.359877,9326.64467,10168.65611,11674.83737,12545.99066,12986.47998,10535.62855,11712.7768,14843.93556,18008.94444,7267.688428,9244.001412,10350.15906,13319.89568,15798.06362,19654.96247,23269.6075,26923.20628,25144.39201,28061.09966,31163.20196,36180.78919,546.5657493,590.061996,658.3471509,700.7706107,724.032527,813.337323,855.7235377,976.5126756,1164.406809,1458.817442,1746.769454,2452.210407,749.6816546,858.9002707,849.2897701,762.4317721,1111.107907,1382.702056,1516.872988,1748.356961,2383.140898,3119.335603,2873.91287,3540.651564,3035.326002,3290.257643,4187.329802,5906.731805,9613.818607,11888.59508,7608.334602,6642.881371,7235.653188,8263.590301,9240.761975,11605.71449,4129.766056,6229.333562,8341.737815,8931.459811,9576.037596,14688.23507,14517.90711,11643.57268,3745.640687,3076.239795,4390.717312,4471.061906,5210.280328,5599.077872,6631.597314,7655.568963,9530.772896,11150.98113,12618.32141,13872.86652,17558.81555,24521.94713,34077.04939,40675.99635,4086.522128,5385.278451,7105.630706,8393.741404,12786.93223,13306.61921,15367.0292,17122.47986,18051.52254,20896.60924,21905.59514,25523.2771,4931.404155,6248.656232,8243.58234,10022.40131,12269.27378,14255.98475,16537.4835,19207.23482,22013.64486,24675.02446,27968.09817,28569.7197,2898.530881,4756.525781,5246.107524,6124.703451,7433.889293,6650.195573,6068.05135,6351.237495,7404.923685,7121.924704,6994.774861,7320.880262,3216.956347,4317.694365,6576.649461,9847.788607,14778.78636,16610.37701,19384.10571,22375.94189,26824.89511,28816.58499,28604.5919,31656.06806,1546.907807,1886.080591,2348.009158,2741.796252,2110.856309,2852.351568,4161.415959,4448.679912,3431.593647,3645.379572,3844.917194,4519.461171,853.540919,944.4383152,896.9663732,1056.736457,1222.359968,1267.613204,1348.225791,1361.936856,1341.921721,1360.485021,1287.514732,1463.249282,1088.277758,1571.134655,1621.693598,2143.540609,3701.621503,4106.301249,4106.525293,4106.492315,3726.063507,1690.756814,1646.758151,1593.06548,1030.592226,1487.593537,1536.344387,2029.228142,3030.87665,4657.22102,5622.942464,8533.088805,12104.27872,15993.52796,19233.98818,23348.13973,108382.3529,113523.1329,95458.11176,80894.88326,109347.867,59265.47714,31354.03573,28118.42998,34932.91959,40300.61996,35110.10566,47306.98978,4834.804067,6089.786934,5714.560611,6006.983042,7486.384341,8659.696836,7640.519521,5377.091329,6890.806854,8754.96385,9313.93883,10461.05868,298.8462121,335.9971151,411.8006266,498.6390265,496.5815922,745.3695408,797.2631074,773.9932141,977.4862725,1186.147994,1275.184575,1569.331442,575.5729961,620.9699901,634.1951625,713.6036483,803.0054535,640.3224383,572.1995694,506.1138573,636.6229191,609.1739508,531.4823679,414.5073415,2387.54806,3448.284395,6757.030816,18772.75169,21011.49721,21951.21176,17364.27538,11770.5898,9640.138501,9467.446056,9534.677467,12057.49928,1443.011715,1589.20275,1643.38711,1634.047282,1748.562982,1544.228586,1302.878658,1155.441948,1040.67619,986.2958956,894.6370822,1044.770126,369.1650802,416.3698064,427.9010856,495.5147806,584.6219709,663.2236766,632.8039209,635.5173634,563.2000145,692.2758103,665.4231186,759.3499101,1831.132894,1810.066992,2036.884944,2277.742396,2849.09478,3827.921571,4920.355951,5249.802653,7277.912802,10132.90964,10206.97794,12451.6558,452.3369807,490.3821867,496.1743428,545.0098873,581.3688761,686.3952693,618.0140641,684.1715576,739.014375,790.2579846,951.4097518,1042.581557,743.1159097,846.1202613,1055.896036,1421.145193,1586.851781,1497.492223,1481.150189,1421.603576,1361.369784,1483.136136,1579.019543,1803.151496,1967.955707,2034.037981,2529.067487,2475.387562,2575.484158,3710.982963,3688.037739,4783.586903,6058.253846,7425.705295,9021.815894,10956.99112,3478.125529,4131.546641,4581.609385,5754.733883,6809.40669,7674.929108,9611.147541,8688.156003,9472.384295,9767.29753,10742.44053,11977.57496,786.5668575,912.6626085,1056.353958,1226.04113,1421.741975,1647.511665,2000.603139,2338.008304,1785.402016,1902.2521,2140.739323,3095.772271,2647.585601,3682.259903,4649.593785,5907.850937,7778.414017,9595.929905,11222.58762,11732.51017,7003.339037,6465.613349,6557.194282,9253.896111,1688.20357,1642.002314,1566.353493,1711.04477,1930.194975,2370.619976,2702.620356,2755.046991,2948.047252,2982.101858,3258.495584,3820.17523,468.5260381,495.5868333,556.6863539,566.6691539,724.9178037,502.3197334,462.2114149,389.8761846,410.8968239,472.3460771,633.6179466,823.6856205,331.0,350.0,388.0,349.0,357.0,371.0,424.0,385.0,347.0,415.0,611.0,944.0,2423.780443,2621.448058,3173.215595,3793.694753,3746.080948,3876.485958,4191.100511,3693.731337,3804.537999,3899.52426,4072.324751,4811.060429,545.8657229,597.9363558,652.3968593,676.4422254,674.7881296,694.1124398,718.3730947,775.6324501,897.7403604,1010.892138,1057.206311,1091.359778,8941.571858,11276.19344,12790.84956,15363.25136,18794.74567,21209.0592,21399.46046,23651.32361,26790.94961,30246.13063,33724.75778,36797.93332,10556.57566,12247.39532,13175.678,14463.91893,16046.03728,16233.7177,17632.4104,19007.19129,18363.32494,21050.41377,23189.80135,25185.00911,3112.363948,3457.415947,3634.364406,4643.393534,4688.593267,5486.371089,3470.338156,2955.984375,2170.151724,2253.023004,2474.548819,2749.320965,761.879376,835.5234025,997.7661127,1054.384891,954.2092363,808.8970728,909.7221354,668.3000228,581.182725,580.3052092,601.0745012,619.6768924,1077.281856,1100.592563,1150.927478,1014.514104,1698.388838,1981.951806,1576.97375,1385.029563,1619.848217,1624.941275,1615.286395,2013.977305,10095.42172,11653.97304,13450.40151,16361.87647,18965.05551,23311.34939,26298.63531,31540.9748,33965.66115,41283.16433,44683.97525,49357.19017,1828.230307,2242.746551,2924.638113,4720.942687,10618.03855,11848.34392,12954.79101,18115.22313,18616.70691,19702.05581,19774.83687,22316.19287,684.5971438,747.0835292,803.3427418,942.4082588,1049.938981,1175.921193,1443.429832,1704.686583,1971.829464,2049.350521,2092.712441,2605.94758,2480.380334,2961.800905,3536.540301,4421.009084,5364.249663,5351.912144,7009.601598,7034.779161,6618.74305,7113.692252,7356.031934,9809.185636,1952.308701,2046.154706,2148.027146,2299.376311,2523.337977,3248.373311,4258.503604,3998.875695,4196.411078,4247.400261,3783.674243,4172.838464,3758.523437,4245.256698,4957.037982,5788.09333,5937.827283,6281.290855,6434.501797,6360.943444,4446.380924,5838.347657,5909.020073,7408.905561,1272.880995,1547.944844,1649.552153,1814.12743,1989.37407,2373.204287,2603.273765,2189.634995,2279.324017,2536.534925,2650.921068,3190.481016,4029.329699,4734.253019,5338.752143,6557.152776,8006.506993,9508.141454,8451.531004,9082.351172,7738.881247,10159.58368,12002.23908,15389.92468,3068.319867,3774.571743,4727.954889,6361.517993,9022.247417,10172.48572,11753.84291,13039.30876,16207.26663,17641.03156,19970.90787,20509.64777,3081.959785,3907.156189,5108.34463,6929.277714,9123.041742,9770.524921,10330.98915,12281.34191,14641.58711,16999.4333,18855.60618,19328.70901,2718.885295,2769.451844,3173.72334,4021.175739,5047.658563,4319.804067,5267.219353,5303.377488,6101.255823,6071.941411,6316.1652,7670.122558,3144.613186,3943.370225,4734.997586,6470.866545,8011.414402,9356.39724,9605.314053,9696.273295,6598.409903,7346.547557,7885.360081,10808.47561,493.3238752,540.2893983,597.4730727,510.9637142,590.5806638,670.0806011,881.5706467,847.991217,737.0685949,589.9445051,785.6537648,863.0884639,879.5835855,860.7369026,1071.551119,1384.840593,1532.985254,1737.561657,1890.218117,1516.525457,1428.777814,1339.076036,1353.09239,1598.435089,6459.554823,8157.591248,11626.41975,16903.04886,24837.42865,34167.7626,33693.17525,21198.26136,24841.61777,20586.69019,19014.54118,21654.83194,1450.356983,1567.653006,1654.988723,1612.404632,1597.712056,1561.769116,1518.479984,1441.72072,1367.899369,1392.368347,1519.635262,1712.472136,3581.459448,4981.090891,6289.629157,7991.707066,10522.06749,12980.66956,15181.0927,15870.87851,9325.068238,7914.320304,7236.075251,9786.534714,879.7877358,1004.484437,1116.639877,1206.043465,1353.759762,1348.285159,1465.010784,1294.447788,1068.696278,574.6481576,699.489713,862.5407561,2315.138227,2843.104409,3674.735572,4977.41854,8597.756202,11210.08948,15169.16112,18861.53081,24769.8912,33519.4766,36023.1054,47143.17964,5074.659104,6093.26298,7481.107598,8412.902397,9674.167626,10922.66404,11348.54585,12037.26758,9498.467723,12126.23065,13638.77837,18678.31435,4215.041741,5862.276629,7402.303395,9405.489397,12383.4862,15277.03017,17866.72175,18678.53492,14214.71681,17161.10735,20660.01936,25768.25759,1135.749842,1258.147413,1369.488336,1284.73318,1254.576127,1450.992513,1176.807031,1093.244963,926.9602964,930.5964284,882.0818218,926.1410683,4725.295531,5487.104219,5768.729717,7114.477971,7765.962636,8028.651439,8568.266228,7825.823398,7225.069258,7479.188244,7710.946444,9269.657808,3834.034742,4564.80241,5693.843879,7993.512294,10638.75131,13236.92117,13926.16997,15764.98313,18603.06452,20445.29896,24835.47166,28821.0637,1083.53203,1072.546602,1074.47196,1135.514326,1213.39553,1348.775651,1648.079789,1876.766827,2153.739222,2664.477257,3015.378833,3970.095407,1615.991129,1770.337074,1959.593767,1687.997641,1659.652775,2202.988423,1895.544073,1507.819159,1492.197043,1632.210764,1993.398314,2602.394995,1148.376626,1244.708364,1856.182125,2613.101665,3364.836625,3781.410618,3895.384018,3984.839812,3553.0224,3876.76846,4128.116943,4513.480643,8527.844662,9911.878226,12329.44192,15258.29697,17832.02464,18855.72521,20667.38125,23586.92927,23880.01683,25266.59499,29341.63093,33859.74835,14734.23275,17909.48973,20431.0927,22966.14432,27195.11304,26982.29052,28397.71512,30281.70459,31871.5303,32135.32301,34480.95771,37506.41907,1643.485354,2117.234893,2193.037133,1881.923632,2571.423014,3195.484582,3761.837715,3116.774285,3340.542768,4014.238972,4090.925331,4184.548089,1206.947913,1507.86129,1822.879028,2643.858681,4062.523897,5596.519826,7426.354774,11054.56175,15215.6579,20206.82098,23235.42329,28718.27684,716.6500721,698.5356073,722.0038073,848.2186575,915.9850592,962.4922932,874.2426069,831.8220794,825.682454,789.1862231,899.0742111,1107.482182,757.7974177,793.5774148,1002.199172,1295.46066,1524.358936,1961.224635,2393.219781,2982.653773,4616.896545,5852.625497,5913.187529,7458.396327,859.8086567,925.9083202,1067.53481,1477.59676,1649.660188,1532.776998,1344.577953,1202.201361,1034.298904,982.2869243,886.2205765,882.9699438,3023.271928,4100.3934,4997.523971,5621.368472,6619.551419,7899.554209,9119.528607,7388.597823,7370.990932,8792.573126,11460.60023,18008.50924,1468.475631,1395.232468,1660.30321,1932.360167,2753.285994,3120.876811,3560.233174,3810.419296,4332.720164,4876.798614,5722.895655,7092.923025,1969.10098,2218.754257,2322.869908,2826.356387,3450.69638,4269.122326,4241.356344,5089.043686,5678.348271,6601.429915,6508.085718,8458.276384,734.753484,774.3710692,767.2717398,908.9185217,950.735869,843.7331372,682.2662268,617.7244065,644.1707969,816.559081,927.7210018,1056.380121,9979.508487,11283.17795,12477.17707,14142.85089,15895.11641,17428.74846,18232.42452,21664.78767,22705.09254,26074.53136,29478.99919,33203.26128,13990.48208,14847.12712,16173.14586,19530.36557,21806.03594,24072.63213,25009.55914,29884.35041,32003.93224,35767.43303,39097.09955,42951.65309,5716.766744,6150.772969,5603.357717,5444.61962,5703.408898,6504.339663,6920.223051,7452.398969,8137.004775,9230.240708,7727.002004,10611.46299,7689.799761,9802.466526,8422.974165,9541.474188,10505.25966,13143.95095,11152.41011,9883.584648,10733.92631,10165.49518,8605.047831,11415.80569,605.0664917,676.2854478,772.0491602,637.1232887,699.5016441,713.5371196,707.2357863,820.7994449,989.0231487,1385.896769,1764.456677,2441.576404,1515.592329,1827.067742,2198.956312,2649.715007,3133.409277,3682.831494,4336.032082,5107.197384,6017.654756,7110.667619,4515.487575,3025.349798,781.7175761,804.8304547,825.6232006,862.4421463,1265.047031,1829.765177,1977.55701,1971.741538,1879.496673,2117.484526,2234.820827,2280.769906,1147.388831,1311.956766,1452.725766,1777.077318,1773.498265,1588.688299,1408.678565,1213.315116,1210.884633,1071.353818,1071.613938,1271.211593,406.8841148,518.7642681,527.2721818,569.7950712,799.3621758,685.5876821,788.8550411,706.1573059,693.4207856,792.4499603,672.0386227,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"trans\":\"log10\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"FVnwBb\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x143a181d0>"
      ]
     },
     "execution_count": 76,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             ) +\n",
    "        geom_point(alpha=0.5) +\n",
    "        scale_x_log10() \n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Add some break points"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Better yet. But it looks like the scale could be better explained with some break points. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 77,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"FYnR0a\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,30.332,31.997,34.02,36.088,38.438,39.854,40.822,41.674,41.763,42.129,43.828,55.23,59.28,64.82,66.22,67.69,68.93,70.42,72.0,71.581,72.95,75.651,76.423,43.077,45.685,48.303,51.407,54.518,58.014,61.368,65.799,67.744,69.152,70.994,72.301,30.015,31.999,34.0,35.985,37.928,39.483,39.942,39.906,40.647,40.963,41.003,42.731,62.485,64.399,65.142,65.634,67.065,68.481,69.942,70.774,71.868,73.275,74.34,75.32,69.12,70.33,70.93,71.1,71.93,73.49,74.74,76.32,77.56,78.83,80.37,81.235,66.8,67.48,69.54,70.14,70.63,72.17,73.18,74.94,76.04,77.51,78.98,79.829,50.939,53.832,56.923,59.923,63.3,65.593,69.052,70.75,72.601,73.925,74.795,75.635,37.484,39.348,41.216,43.453,45.252,46.923,50.009,52.819,56.018,59.412,62.013,64.062,68.0,69.24,70.25,70.94,71.44,72.8,73.93,75.35,76.46,77.53,78.32,79.441,38.223,40.358,42.618,44.885,47.014,49.19,50.904,52.337,53.919,54.777,54.406,56.728,40.414,41.89,43.428,45.032,46.714,50.023,53.859,57.251,59.957,62.05,63.883,65.554,53.82,58.45,61.93,64.79,67.45,69.86,70.69,71.14,72.178,73.244,74.09,74.852,47.622,49.618,51.52,53.298,56.024,59.319,61.484,63.622,62.745,52.556,46.634,50.728,50.917,53.285,55.665,57.632,59.504,61.489,63.336,65.205,67.057,69.388,71.006,72.39,59.6,66.61,69.51,70.42,70.9,70.81,71.08,71.34,71.19,70.32,72.14,73.005,31.975,34.906,37.814,40.697,43.591,46.137,48.122,49.557,50.26,50.324,50.65,52.295,39.031,40.533,42.045,43.548,44.057,45.91,47.471,48.211,44.736,45.326,47.36,49.58,39.417,41.366,43.415,45.415,40.317,31.22,50.957,53.914,55.803,56.534,56.752,59.723,38.523,40.428,42.643,44.799,47.049,49.355,52.961,54.985,54.314,52.199,49.856,50.43,68.75,69.96,71.3,72.13,72.88,74.21,75.76,76.86,77.95,78.61,79.77,80.653,35.463,37.464,39.475,41.478,43.457,46.775,48.295,50.485,49.396,46.066,43.308,44.741,38.092,39.881,41.716,43.601,45.569,47.383,49.517,51.051,51.724,51.573,50.525,50.651,54.745,56.074,57.924,60.523,63.441,67.052,70.565,72.492,74.126,75.816,77.86,78.553,44.0,50.54896,44.50136,58.38112,63.11888,63.96736,65.525,67.274,68.69,70.426,72.028,72.961,50.643,55.118,57.863,59.963,61.623,63.837,66.653,67.768,68.421,70.313,71.682,72.889,40.715,42.46,44.467,46.472,48.944,50.939,52.933,54.926,57.939,60.66,62.974,65.152,39.143,40.652,42.122,44.056,45.989,47.804,47.784,47.412,45.548,42.587,44.966,46.462,42.111,45.053,48.435,52.04,54.907,55.625,56.695,57.47,56.433,52.962,52.97,55.322,57.206,60.026,62.842,65.424,67.849,70.75,73.45,74.752,75.713,77.26,78.123,78.782,40.477,42.469,44.93,47.35,49.801,52.374,53.983,54.655,52.044,47.991,46.832,48.328,61.21,64.77,67.13,68.5,69.61,70.64,70.46,71.52,72.527,73.68,74.876,75.748,59.421,62.325,65.246,68.29,70.723,72.649,73.717,74.174,74.414,76.151,77.158,78.273,66.87,69.03,69.9,70.38,70.29,70.71,70.96,71.58,72.4,74.01,75.51,76.486,70.78,71.81,72.35,72.96,73.47,74.69,74.63,74.8,75.33,76.11,77.18,78.332,34.812,37.328,39.693,42.074,44.366,46.519,48.812,50.04,51.604,53.157,53.373,54.791,45.928,49.828,53.459,56.751,59.631,61.788,63.727,66.046,68.457,69.957,70.847,72.235,48.357,51.356,54.64,56.678,58.796,61.31,64.342,67.231,69.613,72.312,74.173,74.994,41.893,44.444,46.992,49.293,51.137,53.319,56.006,59.797,63.674,67.217,69.806,71.338,45.262,48.57,52.307,55.855,58.207,56.696,56.604,63.154,66.798,69.535,70.734,71.878,34.482,35.983,37.485,38.987,40.516,42.024,43.662,45.664,47.545,48.245,49.348,51.579,35.928,38.047,40.158,42.189,44.142,44.535,43.89,46.453,49.991,53.378,55.24,58.04,34.078,36.667,40.059,42.115,43.515,44.51,44.916,46.684,48.091,49.402,50.725,52.947,66.55,67.49,68.75,69.83,70.87,72.52,74.55,74.83,75.7,77.13,78.37,79.313,67.41,68.93,70.51,71.55,72.38,73.83,74.89,76.34,77.46,78.64,79.59,80.657,37.003,38.999,40.489,44.598,48.69,52.79,56.564,60.19,61.366,60.461,56.761,56.735,30.0,32.065,33.896,35.857,38.308,41.842,45.58,49.265,52.644,55.861,58.041,59.448,67.5,69.1,70.3,70.8,71.0,72.5,73.8,74.847,76.07,77.34,78.67,79.406,43.149,44.779,46.452,48.072,49.875,51.756,53.744,55.729,57.501,58.556,58.453,60.022,65.86,67.86,69.51,71.0,72.34,73.68,75.24,76.67,77.03,77.869,78.256,79.483,42.023,44.142,46.954,50.016,53.738,56.029,58.137,60.782,63.373,66.322,68.978,70.259,33.609,34.558,35.753,37.197,38.842,40.762,42.891,45.552,48.576,51.455,53.676,56.007,32.5,33.489,34.488,35.492,36.486,37.465,39.327,41.245,43.266,44.873,45.504,46.388,37.579,40.696,43.59,46.243,48.042,49.923,51.461,53.636,55.089,56.671,58.137,60.916,41.912,44.665,48.041,50.924,53.884,57.402,60.909,64.492,66.399,67.659,68.565,70.198,60.96,64.75,67.65,70.0,72.0,73.6,75.45,76.2,77.601,80.0,81.495,82.208,64.03,66.41,67.96,69.5,69.76,69.95,69.39,69.58,69.17,71.04,72.59,73.338,72.49,73.47,73.68,73.73,74.46,76.11,76.99,77.23,78.77,78.95,80.5,81.757,37.373,40.249,43.605,47.193,50.651,54.208,56.596,58.553,60.223,61.765,62.879,64.698,37.468,39.918,42.518,45.964,49.203,52.702,56.159,60.137,62.681,66.041,68.588,70.65,44.869,47.181,49.325,52.469,55.234,57.702,59.62,63.04,65.742,68.042,69.451,70.964,45.32,48.437,51.457,54.459,56.95,60.413,62.038,65.044,59.461,58.811,57.046,59.545,66.91,68.9,70.29,71.08,71.28,72.03,73.1,74.36,75.467,76.122,77.783,78.885,65.39,67.84,69.39,70.75,71.63,73.06,74.45,75.6,76.93,78.269,79.696,80.745,65.94,67.81,69.24,71.06,72.19,73.48,74.98,76.42,77.44,78.82,80.24,80.546,58.53,62.61,65.61,67.51,69.0,70.11,71.21,71.77,71.766,72.262,72.047,72.567,63.03,65.5,68.73,71.43,73.42,75.38,77.11,78.67,79.36,80.69,82.0,82.603,43.158,45.669,48.126,51.629,56.528,61.134,63.739,65.869,68.015,69.772,71.263,72.535,42.27,44.686,47.949,50.654,53.559,56.155,58.766,59.339,59.285,54.407,50.992,54.11,50.056,54.081,56.656,59.942,63.983,67.159,69.1,70.647,69.978,67.727,66.662,67.297,47.453,52.681,55.292,57.716,62.612,64.766,67.123,69.81,72.244,74.647,77.045,78.623,55.565,58.033,60.47,64.624,67.712,69.343,71.309,74.174,75.19,76.156,76.904,77.588,55.928,59.489,62.094,63.87,65.421,66.099,66.983,67.926,69.292,70.265,71.028,71.993,42.138,45.047,47.747,48.492,49.767,52.208,55.078,57.18,59.685,55.558,44.593,42.592,38.48,39.486,40.502,41.536,42.614,43.764,44.852,46.027,40.802,42.221,43.753,45.678,42.723,45.289,47.808,50.227,52.773,57.442,62.155,66.234,68.755,71.555,72.737,73.952,36.681,38.865,40.848,42.881,44.851,46.881,48.969,49.35,52.214,54.978,57.286,59.443,36.256,37.207,38.41,39.487,41.766,43.767,45.642,47.457,49.42,47.495,45.009,48.303,48.463,52.102,55.737,59.371,63.01,65.256,68.0,69.5,70.693,71.938,73.044,74.241,33.685,35.307,36.936,38.487,39.977,41.714,43.916,46.364,48.388,49.903,51.818,54.467,40.543,42.338,44.248,46.289,48.437,50.852,53.599,56.145,58.333,60.43,62.247,64.164,50.986,58.089,60.246,61.557,62.944,64.93,66.711,68.74,69.745,70.736,71.954,72.801,50.789,55.19,58.299,60.11,62.361,65.032,67.405,69.498,71.455,73.67,74.902,76.195,42.244,45.248,48.251,51.253,53.754,55.491,57.489,60.222,61.271,63.625,65.033,66.803,59.164,61.448,63.728,67.178,70.636,73.066,74.101,74.865,75.435,75.445,73.981,74.543,42.873,45.423,47.924,50.335,52.862,55.73,59.65,62.677,65.393,67.66,69.615,71.164,31.286,33.779,36.161,38.113,40.328,42.495,42.795,42.861,44.284,46.344,44.026,42.082,36.319,41.905,45.108,49.379,53.07,56.059,58.056,58.339,59.32,60.328,59.908,62.069,41.725,45.226,48.386,51.159,53.867,56.437,58.968,60.835,61.999,58.909,51.479,52.906,36.157,37.686,39.393,41.472,43.971,46.748,49.594,52.537,55.727,59.426,61.34,63.785,72.13,72.99,73.23,73.82,73.75,75.24,76.05,76.83,77.42,78.03,78.53,79.762,69.39,70.26,71.24,71.52,71.89,72.22,73.84,74.32,76.33,77.55,79.11,80.204,42.314,45.432,48.632,51.884,55.151,57.47,59.298,62.008,65.843,68.426,70.836,72.899,37.444,38.598,39.487,40.118,40.546,41.291,42.598,44.555,47.391,51.313,54.496,56.867,36.324,37.802,39.36,41.04,42.821,44.514,45.826,46.886,47.472,47.464,46.608,46.859,72.67,73.44,73.47,74.08,74.34,75.37,75.97,75.89,77.32,78.32,79.05,80.196,37.578,40.08,43.165,46.988,52.143,57.367,62.728,67.734,71.197,72.499,74.193,75.64,43.436,45.557,47.67,49.8,51.929,54.043,56.158,58.245,60.838,61.818,63.61,65.483,55.191,59.201,61.817,64.071,66.216,68.681,70.472,71.523,72.462,73.738,74.712,75.537,62.649,63.196,64.361,64.951,65.815,66.353,66.874,67.378,68.225,69.4,70.755,71.752,43.902,46.263,49.096,51.445,55.448,58.447,61.406,64.134,66.458,68.386,69.906,71.421,47.752,51.334,54.757,56.393,58.065,60.06,62.082,64.151,66.458,68.564,70.303,71.688,61.31,65.77,67.64,69.61,70.85,70.67,71.32,70.98,70.99,72.75,74.67,75.563,59.82,61.51,64.39,66.6,69.26,70.41,72.77,74.06,74.86,75.97,77.29,78.098,64.28,68.54,69.62,71.1,72.16,73.44,73.75,74.63,73.911,74.917,77.778,78.746,52.724,55.09,57.666,60.542,64.274,67.064,69.885,71.913,73.615,74.772,75.744,76.442,61.05,64.1,66.8,66.8,69.21,69.46,69.66,69.53,69.36,69.72,71.322,72.476,40.0,41.5,43.0,44.1,44.6,45.0,46.218,44.02,23.599,36.087,43.413,46.242,46.471,48.945,51.893,54.425,56.48,58.55,60.351,61.728,62.742,63.306,64.337,65.528,39.875,42.868,45.914,49.901,53.886,58.69,63.012,66.295,68.768,70.533,71.626,72.777,37.278,39.329,41.454,43.563,45.815,48.879,52.379,55.769,58.196,60.187,61.6,63.062,57.996,61.685,64.531,66.914,68.7,70.3,70.162,71.218,71.659,72.232,73.213,74.002,30.331,31.57,32.767,34.113,35.4,36.788,38.445,40.006,38.333,39.897,41.012,42.568,60.396,63.179,65.798,67.946,69.521,70.795,71.76,73.56,75.788,77.158,78.77,79.972,64.36,67.45,70.33,70.98,70.35,70.45,70.8,71.08,71.38,72.71,73.8,74.663,65.57,67.85,69.15,69.18,69.82,70.97,71.063,72.25,73.64,75.13,76.66,77.926,32.978,34.977,36.981,38.977,40.973,41.974,42.955,44.501,39.658,43.795,45.936,48.159,45.009,47.985,49.951,51.927,53.696,55.527,58.161,60.834,61.888,60.236,53.365,49.339,64.94,66.66,69.69,71.44,73.06,74.39,76.3,76.9,77.57,78.77,79.78,80.941,57.593,61.456,62.192,64.266,65.042,65.949,68.757,69.011,70.379,70.457,70.815,72.396,38.635,39.624,40.87,42.858,45.083,47.8,50.338,51.744,53.556,55.373,56.369,58.556,41.407,43.424,44.992,46.633,49.552,52.537,55.561,57.678,58.474,54.289,43.869,39.613,71.86,72.49,73.37,74.16,74.72,75.44,76.42,77.19,78.16,79.39,80.04,80.884,69.62,70.56,71.32,72.77,73.78,75.39,76.21,77.41,78.03,79.37,80.62,81.701,45.883,48.284,50.305,53.655,57.296,61.195,64.59,66.974,69.249,71.527,73.053,74.143,58.5,62.4,65.2,67.5,69.39,70.59,72.16,73.4,74.26,75.25,76.99,78.4,41.215,42.974,44.246,45.757,47.62,49.919,50.608,51.535,50.44,48.466,49.651,52.517,50.848,53.63,56.061,58.285,60.405,62.494,64.597,66.084,67.298,67.521,68.564,70.616,38.596,41.208,43.922,46.769,49.759,52.887,55.471,56.941,58.061,58.39,57.561,58.42,59.1,61.8,64.9,65.4,65.9,68.3,68.832,69.582,69.862,69.465,68.976,69.819,44.6,47.1,49.579,52.053,55.602,59.837,64.048,66.894,70.001,71.973,73.042,73.923,43.585,48.079,52.098,54.336,57.005,59.507,61.036,63.108,66.146,68.835,70.845,71.777,39.978,42.571,45.344,48.051,51.016,50.35,49.849,51.509,48.825,44.578,47.813,51.542,69.18,70.42,70.76,71.36,72.01,72.76,74.04,75.007,76.42,77.218,78.471,79.425,68.44,69.49,70.21,70.76,71.34,73.38,74.65,75.02,76.09,76.81,77.31,78.242,66.071,67.044,68.253,68.468,68.673,69.481,70.805,71.918,72.752,74.223,75.307,76.384,55.088,57.907,60.77,63.479,65.712,67.456,68.557,70.19,71.15,72.146,72.766,73.747,40.412,42.887,45.363,47.838,50.254,55.764,58.816,62.82,67.662,70.672,73.017,74.249,43.16,45.671,48.127,51.631,56.532,60.765,64.406,67.046,69.718,71.096,72.37,73.422,32.548,33.97,35.18,36.984,39.848,44.175,49.113,52.922,55.599,58.02,60.308,62.698,42.038,44.077,46.023,47.768,50.107,51.386,51.821,50.821,46.1,40.238,39.193,42.384,48.451,50.469,52.358,53.995,55.635,57.674,60.363,62.351,60.377,46.809,39.989,43.487],\n",
       "\"pop\":[8425333.0,9240934.0,1.0267083E7,1.1537966E7,1.307946E7,1.4880372E7,1.2881816E7,1.3867957E7,1.6317921E7,2.2227415E7,2.5268405E7,3.1889923E7,1282697.0,1476505.0,1728137.0,1984060.0,2263554.0,2509048.0,2780097.0,3075321.0,3326498.0,3428038.0,3508512.0,3600523.0,9279525.0,1.0270856E7,1.1000948E7,1.2760499E7,1.4760787E7,1.7152804E7,2.0033753E7,2.3254956E7,2.6298373E7,2.9072015E7,3.1287142E7,3.3333216E7,4232095.0,4561361.0,4826015.0,5247469.0,5894858.0,6162675.0,7016384.0,7874230.0,8735988.0,9875024.0,1.0866106E7,1.2420476E7,1.7876956E7,1.9610538E7,2.1283783E7,2.2934225E7,2.4779799E7,2.6983828E7,2.9341374E7,3.1620918E7,3.3958947E7,3.6203463E7,3.8331121E7,4.0301927E7,8691212.0,9712569.0,1.0794968E7,1.1872264E7,1.3177E7,1.40741E7,1.51842E7,1.6257249E7,1.7481977E7,1.8565243E7,1.9546792E7,2.0434176E7,6927772.0,6965860.0,7129864.0,7376998.0,7544201.0,7568430.0,7574613.0,7578903.0,7914969.0,8069876.0,8148312.0,8199783.0,120447.0,138655.0,171863.0,202182.0,230800.0,297410.0,377967.0,454612.0,529491.0,598561.0,656397.0,708573.0,4.6886859E7,5.1365468E7,5.6839289E7,6.2821884E7,7.0759295E7,8.0428306E7,9.3074406E7,1.03764241E8,1.13704579E8,1.23315288E8,1.3565679E8,1.50448339E8,8730405.0,8989111.0,9218400.0,9556500.0,9709100.0,9821800.0,9856303.0,9870200.0,1.0045622E7,1.0199787E7,1.031197E7,1.0392226E7,1738315.0,1925173.0,2151895.0,2427334.0,2761407.0,3168267.0,3641603.0,4243788.0,4981671.0,6066080.0,7026113.0,8078314.0,2883315.0,3211738.0,3593918.0,4040665.0,4565872.0,5079716.0,5642224.0,6156369.0,6893451.0,7693188.0,8445134.0,9119152.0,2791000.0,3076000.0,3349000.0,3585000.0,3819000.0,4086000.0,4172693.0,4338977.0,4256013.0,3607000.0,4165416.0,4552198.0,442308.0,474639.0,512764.0,553541.0,619351.0,781472.0,970347.0,1151184.0,1342614.0,1536536.0,1630347.0,1639131.0,5.660256E7,6.5551171E7,7.603939E7,8.8049823E7,1.00840058E8,1.14313951E8,1.28962939E8,1.42938076E8,1.55975974E8,1.68546719E8,1.79914212E8,1.90010647E8,7274900.0,7651254.0,8012946.0,8310226.0,8576200.0,8797022.0,8892098.0,8971958.0,8658506.0,8066057.0,7661799.0,7322858.0,4469979.0,4713416.0,4919632.0,5127935.0,5433886.0,5889574.0,6634596.0,7586551.0,8878303.0,1.0352843E7,1.2251209E7,1.4326203E7,2445618.0,2667518.0,2961915.0,3330989.0,3529983.0,3834415.0,4580410.0,5126023.0,5809236.0,6121610.0,7021078.0,8390505.0,4693836.0,5322536.0,6083619.0,6960067.0,7450606.0,6978607.0,7272485.0,8371791.0,1.0150094E7,1.1782962E7,1.2926707E7,1.4131858E7,5009067.0,5359923.0,5793633.0,6335506.0,7021028.0,7959865.0,9250831.0,1.0780667E7,1.2467171E7,1.4195809E7,1.5929988E7,1.7696293E7,1.4785584E7,1.7010154E7,1.8985849E7,2.0819767E7,2.22845E7,2.37964E7,2.52019E7,2.65497E7,2.8523502E7,3.0305843E7,3.1902268E7,3.3390141E7,1291695.0,1392284.0,1523478.0,1733638.0,1927260.0,2167533.0,2476971.0,2840009.0,3265124.0,3696513.0,4048013.0,4369038.0,2682462.0,2894855.0,3150417.0,3495967.0,3899068.0,4388260.0,4875118.0,5498955.0,6429417.0,7562011.0,8835739.0,1.0238807E7,6377619.0,7048426.0,7961258.0,8858908.0,9717524.0,1.0599793E7,1.1487112E7,1.2463354E7,1.3572994E7,1.4599929E7,1.5497046E7,1.6284741E7,5.56263527E8,6.37408E8,6.6577E8,7.5455E8,8.6203E8,9.43455E8,1.000281E9,1.084035E9,1.16497E9,1.230075E9,1.2804E9,1.318683096E9,1.2350771E7,1.4485993E7,1.7009885E7,1.9764027E7,2.254289E7,2.5094412E7,2.7764644E7,3.0964245E7,3.4202721E7,3.765783E7,4.1008227E7,4.422755E7,153936.0,170928.0,191689.0,217378.0,250027.0,304739.0,348643.0,395114.0,454429.0,527982.0,614382.0,710960.0,1.4100005E7,1.5577932E7,1.7486434E7,1.9941073E7,2.3007669E7,2.648087E7,3.0646495E7,3.5481645E7,4.1672143E7,4.7798986E7,5.5379852E7,6.4606759E7,854885.0,940458.0,1047924.0,1179760.0,1340458.0,1536769.0,1774735.0,2064095.0,2409073.0,2800947.0,3328795.0,3800610.0,926317.0,1112300.0,1345187.0,1588717.0,1834796.0,2108457.0,2424367.0,2799811.0,3173216.0,3518107.0,3834934.0,4133884.0,2977019.0,3300000.0,3832408.0,4744870.0,6071696.0,7459574.0,9025951.0,1.0761098E7,1.2772596E7,1.4625967E7,1.6252726E7,1.8013409E7,3882229.0,3991242.0,4076557.0,4174366.0,4225310.0,4318673.0,4413368.0,4484310.0,4494013.0,4444595.0,4481020.0,4493312.0,6007797.0,6640752.0,7254373.0,8139332.0,8831348.0,9537988.0,9789224.0,1.0239839E7,1.072326E7,1.0983007E7,1.1226999E7,1.1416987E7,9125183.0,9513758.0,9620282.0,9835109.0,9862158.0,1.0161915E7,1.0303704E7,1.0311597E7,1.0315702E7,1.0300707E7,1.0256295E7,1.0228744E7,4334000.0,4487831.0,4646899.0,4838800.0,4991596.0,5088419.0,5117810.0,5127024.0,5171393.0,5283663.0,5374693.0,5468120.0,63149.0,71851.0,89898.0,127617.0,178848.0,228694.0,305991.0,311025.0,384156.0,417908.0,447416.0,496374.0,2491346.0,2923186.0,3453434.0,4049146.0,4671329.0,5302800.0,5968349.0,6655297.0,7351181.0,7992357.0,8650322.0,9319622.0,3548753.0,4058385.0,4681707.0,5432424.0,6298651.0,7278866.0,8365850.0,9545158.0,1.0748394E7,1.1911819E7,1.2921234E7,1.375568E7,2.2223309E7,2.5009741E7,2.8173309E7,3.1681188E7,3.4807417E7,3.8783863E7,4.5681811E7,5.2799062E7,5.9402198E7,6.6134291E7,7.3312559E7,8.0264543E7,2042865.0,2355805.0,2747687.0,3232927.0,3790903.0,4282586.0,4474873.0,4842194.0,5274649.0,5783439.0,6353681.0,6939688.0,216964.0,232922.0,249220.0,259864.0,277603.0,192675.0,285483.0,341244.0,387838.0,439971.0,495627.0,551201.0,1438760.0,1542611.0,1666618.0,1820319.0,2260187.0,2512642.0,2637297.0,2915959.0,3668440.0,4058319.0,4414865.0,4906585.0,2.0860941E7,2.2815614E7,2.5145372E7,2.7860297E7,3.0770372E7,3.4617799E7,3.8111756E7,4.299953E7,5.2088559E7,5.9861301E7,6.7946797E7,7.6511887E7,4090500.0,4324000.0,4491443.0,4605744.0,4639657.0,4738902.0,4826933.0,4931729.0,5041039.0,5134406.0,5193039.0,5238460.0,4.2459667E7,4.4310863E7,4.7124E7,4.9569E7,5.1732E7,5.3165019E7,5.4433565E7,5.56301E7,5.7374179E7,5.8623428E7,5.9925035E7,6.1083916E7,420702.0,434904.0,455661.0,489004.0,537977.0,706367.0,753874.0,880397.0,985739.0,1126189.0,1299304.0,1454867.0,284320.0,323150.0,374020.0,439593.0,517101.0,608274.0,715523.0,848406.0,1025384.0,1235767.0,1457766.0,1688359.0,6.9145952E7,7.1019069E7,7.3739117E7,7.6368453E7,7.8717088E7,7.8160773E7,7.8335266E7,7.7718298E7,8.0597764E7,8.2011073E7,8.2350671E7,8.2400996E7,5581001.0,6391288.0,7355248.0,8490213.0,9354120.0,1.0538093E7,1.1400338E7,1.4168101E7,1.6278738E7,1.8418288E7,2.0550751E7,2.2873338E7,7733250.0,8096218.0,8448233.0,8716441.0,8888628.0,9308479.0,9786480.0,9974490.0,1.0325429E7,1.0502372E7,1.0603863E7,1.070629E7,3146381.0,3640876.0,4208858.0,4690773.0,5149581.0,5703430.0,6395630.0,7326406.0,8486949.0,9803875.0,1.117865E7,1.2572928E7,2664249.0,2876726.0,3140003.0,3451418.0,3811387.0,4227026.0,4710497.0,5650262.0,6990574.0,8048834.0,8807818.0,9947814.0,580653.0,601095.0,627820.0,601287.0,625361.0,745228.0,825987.0,927524.0,1050938.0,1193708.0,1332459.0,1472041.0,3201488.0,3507701.0,3880130.0,4318137.0,4698301.0,4908554.0,5198399.0,5756203.0,6326682.0,6913545.0,7607651.0,8502814.0,1517453.0,1770390.0,2090162.0,2500689.0,2965146.0,3055235.0,3669448.0,4372203.0,5077347.0,5867957.0,6677328.0,7483763.0,2125900.0,2736300.0,3305200.0,3722800.0,4115700.0,4583700.0,5264500.0,5584510.0,5829696.0,6495918.0,6762476.0,6980412.0,9504000.0,9839000.0,1.0063E7,1.0223422E7,1.0394091E7,1.0637171E7,1.0705535E7,1.061274E7,1.0348684E7,1.0244684E7,1.0083313E7,9956108.0,147962.0,165110.0,182053.0,198676.0,209275.0,221823.0,233997.0,244676.0,259012.0,271192.0,288030.0,301931.0,3.72E8,4.09E8,4.54E8,5.06E8,5.67E8,6.34E8,7.08E8,7.88E8,8.72E8,9.59E8,1.034172547E9,1.110396331E9,8.2052E7,9.0124E7,9.9028E7,1.09343E8,1.21282E8,1.36725E8,1.53343E8,1.69276E8,1.84816E8,1.99278E8,2.1106E8,2.23547E8,1.7272E7,1.9792E7,2.2874E7,2.6538E7,3.0614E7,3.5480679E7,4.3072751E7,5.1889696E7,6.0397973E7,6.3327987E7,6.6907826E7,6.945357E7,5441766.0,6248643.0,7240260.0,8519282.0,1.0061506E7,1.1882916E7,1.4173318E7,1.6543189E7,1.7861905E7,2.0775703E7,2.4001816E7,2.7499638E7,2952156.0,2878220.0,2830000.0,2900100.0,3024400.0,3271900.0,3480000.0,3539900.0,3557761.0,3667233.0,3879155.0,4109086.0,1620914.0,1944401.0,2310904.0,2693585.0,3095893.0,3495918.0,3858421.0,4203148.0,4936550.0,5531387.0,6029529.0,6426679.0,4.7666E7,4.9182E7,5.08432E7,5.26671E7,5.4365564E7,5.6059245E7,5.6535636E7,5.6729703E7,5.6840847E7,5.7479469E7,5.7926999E7,5.8147733E7,1426095.0,1535090.0,1665128.0,1861096.0,1997616.0,2156814.0,2298309.0,2326606.0,2378618.0,2531311.0,2664659.0,2780132.0,8.6459025E7,9.1563009E7,9.5831757E7,1.00825279E8,1.07188273E8,1.13872473E8,1.18454974E8,1.22091325E8,1.24329269E8,1.25956499E8,1.27065841E8,1.27467972E8,607914.0,746559.0,933559.0,1255058.0,1613551.0,1937652.0,2347031.0,2820042.0,3867409.0,4526235.0,5307470.0,6053193.0,6464046.0,7454779.0,8678557.0,1.0191512E7,1.2044785E7,1.4500404E7,1.7661452E7,2.1198082E7,2.5020539E7,2.8263827E7,3.1386842E7,3.5610177E7,8865488.0,9411381.0,1.0917494E7,1.2617009E7,1.4781241E7,1.632532E7,1.7647518E7,1.9067554E7,2.0711375E7,2.1585105E7,2.2215365E7,2.3301725E7,2.0947571E7,2.2611552E7,2.6420307E7,3.0131E7,3.3505E7,3.6436E7,3.9326E7,4.1622E7,4.380545E7,4.6173816E7,4.796915E7,4.904479E7,160000.0,212846.0,358266.0,575003.0,841934.0,1140357.0,1497494.0,1891487.0,1418095.0,1765345.0,2111561.0,2505559.0,1439529.0,1647412.0,1886848.0,2186894.0,2680018.0,3115787.0,3086876.0,3089353.0,3219994.0,3430388.0,3677780.0,3921278.0,748747.0,813338.0,893143.0,996380.0,1116779.0,1251524.0,1411807.0,1599200.0,1803195.0,1982823.0,2046772.0,2012649.0,863308.0,975950.0,1112796.0,1279406.0,1482628.0,1703617.0,1956875.0,2269414.0,1912974.0,2200725.0,2814651.0,3193942.0,1019729.0,1201578.0,1441863.0,1759224.0,2183877.0,2721783.0,3344074.0,3799845.0,4364501.0,4759670.0,5368585.0,6036914.0,4762912.0,5181679.0,5703324.0,6334556.0,7082430.0,8007166.0,9171477.0,1.0568642E7,1.2210395E7,1.4165114E7,1.6473477E7,1.9167654E7,2917802.0,3221238.0,3628608.0,4147252.0,4730997.0,5637246.0,6502825.0,7824747.0,1.0014249E7,1.0419991E7,1.1824495E7,1.3327079E7,6748378.0,7739235.0,8906385.0,1.0154878E7,1.1441462E7,1.2845381E7,1.4441916E7,1.6331785E7,1.8319502E7,2.0476091E7,2.2662365E7,2.4821286E7,3838168.0,4241884.0,4690372.0,5212416.0,5828158.0,6491649.0,6998256.0,7634008.0,8416215.0,9384984.0,1.0580176E7,1.2031795E7,1022556.0,1076852.0,1146757.0,1230542.0,1332786.0,1456688.0,1622136.0,1841240.0,2119465.0,2444741.0,2828858.0,3270065.0,516556.0,609816.0,701016.0,789309.0,851334.0,913025.0,992040.0,1042663.0,1096202.0,1149818.0,1200206.0,1250882.0,3.0144317E7,3.5015548E7,4.1121485E7,4.7995559E7,5.5984294E7,6.3759976E7,7.1640904E7,8.0122492E7,8.811103E7,9.5895146E7,1.02479927E8,1.08700891E8,800663.0,882134.0,1010280.0,1149500.0,1320500.0,1528000.0,1756032.0,2015133.0,2312802.0,2494803.0,2674234.0,2874127.0,413834.0,442829.0,474528.0,501035.0,527678.0,560073.0,562548.0,569473.0,621621.0,692651.0,720230.0,684736.0,9939217.0,1.140635E7,1.3056604E7,1.4770296E7,1.666067E7,1.8396941E7,2.019873E7,2.2987397E7,2.5798239E7,2.8529501E7,3.1167783E7,3.3757175E7,6446316.0,7038035.0,7788944.0,8680909.0,9809596.0,1.1127868E7,1.2587223E7,1.2891952E7,1.3160731E7,1.6603334E7,1.847378E7,1.9951656E7,2.0092996E7,2.1731844E7,2.3634436E7,2.5870271E7,2.846639E7,3.1528087E7,3.4680442E7,3.8028578E7,4.0546538E7,4.3247867E7,4.5598081E7,4.776198E7,485831.0,548080.0,621392.0,706640.0,821782.0,977026.0,1099010.0,1278184.0,1554253.0,1774766.0,1972153.0,2055080.0,9182536.0,9682338.0,1.0332057E7,1.126169E7,1.2412593E7,1.3933198E7,1.5796314E7,1.791718E7,2.0326209E7,2.3001113E7,2.5873917E7,2.890179E7,1.0381988E7,1.1026383E7,1.1805689E7,1.2596822E7,1.3329874E7,1.3852989E7,1.4310401E7,1.4665278E7,1.5174244E7,1.5604464E7,1.612283E7,1.6570613E7,1994794.0,2229407.0,2488550.0,2728150.0,2929100.0,3164900.0,3210650.0,3317166.0,3437674.0,3676187.0,3908037.0,4115771.0,1165790.0,1358828.0,1590597.0,1865490.0,2182908.0,2554598.0,2979423.0,3344353.0,4017939.0,4609572.0,5146848.0,5675356.0,3379468.0,3692184.0,4076008.0,4534062.0,5060262.0,5682086.0,6437188.0,7332638.0,8392818.0,9666252.0,1.1140655E7,1.2894865E7,3.3119096E7,3.717334E7,4.1871351E7,4.7287752E7,5.3740085E7,6.2209173E7,7.3039376E7,8.155152E7,9.3364244E7,1.06207839E8,1.19901274E8,1.35031164E8,3327728.0,3491938.0,3638919.0,3786019.0,3933004.0,4043205.0,4114787.0,4186147.0,4286357.0,4405672.0,4535591.0,4627926.0,507833.0,561977.0,628164.0,714775.0,829050.0,1004533.0,1301048.0,1593882.0,1915208.0,2283635.0,2713462.0,3204897.0,4.134656E7,4.6679944E7,5.3100671E7,6.0641899E7,6.9325921E7,7.8152686E7,9.1462088E7,1.05186881E8,1.20065004E8,1.35564834E8,1.53403524E8,1.69270617E8,940080.0,1063506.0,1215725.0,1405486.0,1616384.0,1839782.0,2036305.0,2253639.0,2484997.0,2734531.0,2990875.0,3242173.0,1555876.0,1770902.0,2009813.0,2287985.0,2614104.0,2984494.0,3366439.0,3886512.0,4483945.0,5154123.0,5884491.0,6667147.0,8025700.0,9146100.0,1.05165E7,1.21322E7,1.39547E7,1.5990099E7,1.8125129E7,2.0195924E7,2.2430449E7,2.4748122E7,2.6769436E7,2.8674757E7,2.2438691E7,2.6072194E7,3.0325264E7,3.53566E7,4.0850141E7,4.6850962E7,5.3456774E7,6.0017788E7,6.7185766E7,7.5012988E7,8.2995088E7,9.1077287E7,2.5730551E7,2.8235346E7,3.0329617E7,3.1785378E7,3.3039545E7,3.4621254E7,3.6227381E7,3.774071E7,3.8370697E7,3.8654957E7,3.8625976E7,3.8518241E7,8526050.0,8817650.0,9019800.0,9103000.0,8970450.0,9662600.0,9859650.0,9915289.0,9927680.0,1.0156415E7,1.0433867E7,1.0642836E7,2227000.0,2260000.0,2448046.0,2648961.0,2847132.0,3080828.0,3279001.0,3444468.0,3585176.0,3759430.0,3859606.0,3942491.0,257700.0,308700.0,358900.0,414024.0,461633.0,492095.0,517810.0,562035.0,622191.0,684810.0,743981.0,798094.0,1.663E7,1.7829327E7,1.8680721E7,1.9284814E7,2.0662648E7,2.1658597E7,2.2356726E7,2.2686371E7,2.2797027E7,2.2562458E7,2.2404337E7,2.2276056E7,2534927.0,2822082.0,3051242.0,3451079.0,3992121.0,4657072.0,5507565.0,6349365.0,7290203.0,7212583.0,7852401.0,8860588.0,60011.0,61325.0,65345.0,70787.0,76595.0,86796.0,98593.0,110812.0,125911.0,145608.0,170372.0,199579.0,4005677.0,4419650.0,4943029.0,5618198.0,6472756.0,8128505.0,1.1254672E7,1.4619745E7,1.6945857E7,2.1229759E7,2.450153E7,2.7601038E7,2755589.0,3054547.0,3430243.0,3965841.0,4588696.0,5260855.0,6147783.0,7171347.0,8307920.0,9535314.0,1.0870037E7,1.2267493E7,6860147.0,7271135.0,7616060.0,7971222.0,8313288.0,8686367.0,9032824.0,9230783.0,9826397.0,1.0336594E7,1.0111559E7,1.0150265E7,2143249.0,2295678.0,2467895.0,2662190.0,2879013.0,3140897.0,3464522.0,3868905.0,4260884.0,4578212.0,5359092.0,6144562.0,1127000.0,1445929.0,1750200.0,1977600.0,2152400.0,2325300.0,2651869.0,2794552.0,3235865.0,3802309.0,4197776.0,4553009.0,3558137.0,3844277.0,4237384.0,4442238.0,4593433.0,4827803.0,5048043.0,5199318.0,5302888.0,5383010.0,5410052.0,5447502.0,1489518.0,1533070.0,1582962.0,1646912.0,1694510.0,1746919.0,1861252.0,1945870.0,1999210.0,2011612.0,2011497.0,2009245.0,2526994.0,2780415.0,3080153.0,3428839.0,3840161.0,4353666.0,5828892.0,6921858.0,6099799.0,6633514.0,7753310.0,9118773.0,1.4264935E7,1.6151549E7,1.8356657E7,2.0997321E7,2.393581E7,2.7129932E7,3.1140029E7,3.5933379E7,3.9964159E7,4.2835005E7,4.4433622E7,4.3997828E7,2.854987E7,2.9841614E7,3.1158061E7,3.2850275E7,3.4513161E7,3.6439E7,3.798331E7,3.8880702E7,3.9549438E7,3.9855442E7,4.0152517E7,4.0448191E7,7982342.0,9128546.0,1.0421936E7,1.1737396E7,1.3016733E7,1.4116836E7,1.5410151E7,1.6495304E7,1.758706E7,1.8698655E7,1.9576783E7,2.0378239E7,8504667.0,9753392.0,1.1183227E7,1.2716129E7,1.4597019E7,1.7104986E7,2.0367053E7,2.472596E7,2.8227588E7,3.2160729E7,3.7090298E7,4.2292929E7,290243.0,326741.0,370006.0,420690.0,480105.0,551425.0,649901.0,779348.0,962344.0,1054486.0,1130269.0,1133066.0,7124673.0,7363802.0,7561588.0,7867931.0,8122293.0,8251648.0,8325260.0,8421403.0,8718867.0,8897619.0,8954175.0,9031088.0,4815000.0,5126000.0,5666000.0,6063000.0,6401400.0,6316424.0,6468126.0,6649942.0,6995447.0,7193761.0,7361757.0,7554661.0,3661549.0,4149908.0,4834621.0,5680812.0,6701172.0,7932503.0,9410494.0,1.1242847E7,1.3219062E7,1.5081016E7,1.7155814E7,1.9314747E7,8550362.0,1.0164215E7,1.1918938E7,1.3648692E7,1.5226039E7,1.6785196E7,1.850139E7,1.9757799E7,2.0686918E7,2.1628605E7,2.2454239E7,2.3174294E7,8322925.0,9452826.0,1.0863958E7,1.2607312E7,1.4706593E7,1.7129565E7,1.9844382E7,2.304063E7,2.6605473E7,3.0686889E7,3.4593779E7,3.813964E7,2.1289402E7,2.5041917E7,2.9263397E7,3.4024249E7,3.9276153E7,4.4148285E7,4.882716E7,5.2910342E7,5.6667095E7,6.0216677E7,6.2806748E7,6.5068149E7,1219113.0,1357445.0,1528098.0,1735550.0,2056351.0,2308582.0,2644765.0,3154264.0,3747553.0,4320890.0,4977378.0,5701579.0,662850.0,764900.0,887498.0,960155.0,975199.0,1039009.0,1116479.0,1191336.0,1183669.0,1138101.0,1101832.0,1056608.0,3647735.0,3950849.0,4286552.0,4786986.0,5303507.0,6005061.0,6734098.0,7724976.0,8523077.0,9231669.0,9770575.0,1.0276158E7,2.2235677E7,2.5670939E7,2.9788695E7,3.3411317E7,3.7492953E7,4.2404033E7,4.7328791E7,5.2881328E7,5.8179144E7,6.3047647E7,6.7308928E7,7.1158647E7,5824797.0,6675501.0,7688797.0,8900294.0,1.0190285E7,1.1457758E7,1.29394E7,1.528305E7,1.825219E7,2.1210254E7,2.4739869E7,2.9170398E7,5.043E7,5.143E7,5.3292E7,5.4959E7,5.6079E7,5.6179E7,5.6339704E7,5.698162E7,5.7866349E7,5.8808266E7,5.9912431E7,6.0776238E7,1.57553E8,1.71984E8,1.86538E8,1.98712E8,2.09896E8,2.20239E8,2.32187835E8,2.42803533E8,2.56894189E8,2.7291176E8,2.87675526E8,3.01139947E8,2252965.0,2424959.0,2598466.0,2748579.0,2829526.0,2873520.0,2953997.0,3045153.0,3149262.0,3262838.0,3363085.0,3447496.0,5439568.0,6702668.0,8143375.0,9709552.0,1.1515649E7,1.3503563E7,1.5620766E7,1.7910182E7,2.0265563E7,2.2374398E7,2.428767E7,2.6084662E7,2.6246839E7,2.8998543E7,3.379614E7,3.946391E7,4.4655014E7,5.0533506E7,5.6142181E7,6.2826491E7,6.9940728E7,7.6048996E7,8.0908147E7,8.5262356E7,1030585.0,1070439.0,1133134.0,1142636.0,1089572.0,1261091.0,1425876.0,1691210.0,2104779.0,2826046.0,3389578.0,4018332.0,4963829.0,5498090.0,6120081.0,6740785.0,7407075.0,8403990.0,9657618.0,1.121934E7,1.3367997E7,1.5826497E7,1.8701257E7,2.2211743E7,2672000.0,3016000.0,3421000.0,3900000.0,4506497.0,5216550.0,6100407.0,7272406.0,8381163.0,9417789.0,1.0595811E7,1.1746035E7,3080907.0,3646340.0,4277736.0,4995432.0,5861135.0,6642107.0,7636524.0,9216418.0,1.070434E7,1.1404948E7,1.1926563E7,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,820.8530296,853.10071,836.1971382,739.9811058,786.11336,978.0114388,852.3959448,649.3413952,635.341351,726.7340548,974.5803384,1601.056136,1942.284244,2312.888958,2760.196931,3313.422188,3533.00391,3630.880722,3738.932735,2497.437901,3193.054604,4604.211737,5937.029526,2449.008185,3013.976023,2550.81688,3246.991771,4182.663766,4910.416756,5745.160213,5681.358539,5023.216647,4797.295051,5288.040382,6223.367465,3520.610273,3827.940465,4269.276742,5522.776375,5473.288005,3008.647355,2756.953672,2430.208311,2627.845685,2277.140884,2773.287312,4797.231267,5911.315053,6856.856212,7133.166023,8052.953021,9443.038526,10079.02674,8997.897412,9139.671389,9308.41871,10967.28195,8797.640716,12779.37964,10039.59564,10949.64959,12217.22686,14526.12465,16788.62948,18334.19751,19477.00928,21888.88903,23424.76683,26997.93657,30687.75473,34435.36744,6137.076492,8842.59803,10750.72111,12834.6024,16661.6256,19749.4223,21597.08362,23687.82607,27042.01868,29095.92066,32417.60769,36126.4927,9867.084765,11635.79945,12753.27514,14804.6727,18268.65839,19340.10196,19211.14731,18524.02406,19035.57917,20292.01679,23403.55927,29796.04834,684.2441716,661.6374577,686.3415538,721.1860862,630.2336265,659.8772322,676.9818656,751.9794035,837.8101643,972.7700352,1136.39043,1391.253792,8343.105127,9714.960623,10991.20676,13149.04119,16672.14356,19117.97448,20979.84589,22525.56308,25575.57069,27561.19663,30485.88375,33692.60508,1062.7522,959.6010805,949.4990641,1035.831411,1085.796879,1029.161251,1277.897616,1225.85601,1191.207681,1232.975292,1372.877931,1441.284873,2677.326347,2127.686326,2180.972546,2586.886053,2980.331339,3548.097832,3156.510452,2753.69149,2961.699694,3326.143191,3413.26269,3822.137084,973.5331948,1353.989176,1709.683679,2172.352423,2860.16975,3528.481305,4126.613157,4314.114757,2546.781445,4766.355904,6018.975239,7446.298803,851.2411407,918.2325349,983.6539764,1214.709294,2263.611114,3214.857818,4551.14215,6205.88385,7954.111645,8647.142313,11003.60508,12569.85177,2108.944355,2487.365989,3336.585802,3429.864357,4985.711467,6660.118654,7030.835878,7807.095818,6950.283021,7957.980824,8131.212843,9065.800825,2444.286648,3008.670727,4254.337839,5577.0028,6597.494398,7612.240438,8224.191647,8239.854824,6302.623438,5970.38876,7696.777725,10680.79282,543.2552413,617.1834648,722.5120206,794.8265597,854.7359763,743.3870368,807.1985855,912.0631417,931.7527731,946.2949618,1037.645221,1217.032994,339.2964587,379.5646281,355.2032273,412.9775136,464.0995039,556.1032651,559.603231,621.8188189,631.6998778,463.1151478,446.4035126,430.0706916,368.4692856,434.0383364,496.9136476,523.4323142,421.6240257,524.9721832,624.4754784,683.8955732,682.3031755,734.28517,896.2260153,1713.778686,1172.667655,1313.048099,1399.607441,1508.453148,1684.146528,1783.432873,2367.983282,2602.664206,1793.163278,1694.337469,1934.011449,2042.09524,11367.16112,12489.95006,13462.48555,16076.58803,18970.57086,22090.88306,22898.79214,26626.51503,26342.88426,28954.92589,33328.96507,36319.23501,1071.310713,1190.844328,1193.068753,1136.056615,1070.013275,1109.374338,956.7529907,844.8763504,747.9055252,740.5063317,738.6906068,706.016537,1178.665927,1308.495577,1389.817618,1196.810565,1104.103987,1133.98495,797.9081006,952.386129,1058.0643,1004.961353,1156.18186,1704.063724,3939.978789,4315.622723,4519.094331,5106.654313,5494.024437,4756.763836,5095.665738,5547.063754,7596.125964,10118.05318,10778.78385,13171.63885,400.448611,575.9870009,487.6740183,612.7056934,676.9000921,741.2374699,962.4213805,1378.904018,1655.784158,2289.234136,3119.280896,4959.114854,2144.115096,2323.805581,2492.351109,2678.729839,3264.660041,3815.80787,4397.575659,4903.2191,5444.648617,6117.361746,5755.259962,7006.580419,1102.990936,1211.148548,1406.648278,1876.029643,1937.577675,1172.603047,1267.100083,1315.980812,1246.90737,1173.618235,1075.811558,986.1478792,780.5423257,905.8602303,896.3146335,861.5932424,904.8960685,795.757282,673.7478181,672.774812,457.7191807,312.188423,241.1658765,277.5518587,2125.621418,2315.056572,2464.783157,2677.939642,3213.152683,3259.178978,4879.507522,4201.194937,4016.239529,3484.164376,3484.06197,3632.557798,2627.009471,2990.010802,3460.937025,4161.727834,5118.146939,5926.876967,5262.734751,5629.915318,6160.416317,6677.045314,7723.447195,9645.06142,1388.594732,1500.895925,1728.869428,2052.050473,2378.201111,2517.736547,2602.710169,2156.956069,1648.073791,1786.265407,1648.800823,1544.750112,3119.23652,4338.231617,5477.890018,6960.297861,9164.090127,11305.38517,13221.82184,13822.58394,8447.794873,9875.604515,11628.38895,14619.22272,5586.53878,6092.174359,5180.75591,5690.268015,5305.445256,6380.494966,7316.918107,7532.924763,5592.843963,5431.990415,6340.646683,8948.102923,6876.14025,8256.343918,10136.86713,11399.44489,13108.4536,14800.16062,15377.22855,16310.4434,14297.02122,16048.51424,17596.21022,22833.30851,9692.385245,11099.65935,13583.31351,15937.21123,18866.20721,20422.9015,21688.04048,25116.17581,26406.73985,29804.34567,32166.50006,35278.41874,2669.529475,2864.969076,3020.989263,3020.050513,3694.212352,3081.761022,2879.468067,2880.102568,2377.156192,1895.016984,1908.260867,2082.481567,1397.717137,1544.402995,1662.137359,1653.723003,2189.874499,2681.9889,2861.092386,2899.842175,3044.214214,3614.101285,4563.808154,6025.374752,3522.110717,3780.546651,4086.114078,4579.074215,5280.99471,6679.62326,7213.791267,6481.776993,7103.702595,7429.455877,5773.044512,6873.262326,1418.822445,1458.915272,1693.335853,1814.880728,2024.008147,2785.493582,3503.729636,3885.46071,3794.755195,4173.181797,4754.604414,5581.180998,3048.3029,3421.523218,3776.803627,4358.595393,4520.246008,5138.922374,4098.344175,4140.442097,4444.2317,5154.825496,5351.568666,5728.353514,375.6431231,426.0964081,582.8419714,915.5960025,672.4122571,958.5668124,927.8253427,966.8968149,1132.055034,2814.480755,7703.4959,12154.08975,328.9405571,344.1618859,380.9958433,468.7949699,514.3242082,505.7538077,524.8758493,521.1341333,582.8585102,913.47079,765.3500015,641.3695236,362.1462796,378.9041632,419.4564161,516.1186438,566.2439442,556.8083834,577.8607471,573.7413142,421.3534653,515.8894013,530.0535319,690.8055759,6424.519071,7545.415386,9371.842561,10921.63626,14358.8759,15605.42283,18533.15761,21141.01223,20647.16499,23723.9502,28204.59057,33207.0844,7029.809327,8662.834898,10560.48553,12999.91766,16107.19171,18292.63514,20293.89746,22066.44214,24703.79615,25889.78487,28926.03234,30470.0167,4293.476475,4976.198099,6631.459222,8358.761987,11401.94841,21745.57328,15113.36194,11864.40844,13522.15752,14722.84188,12521.71392,13206.48452,485.2306591,520.9267111,599.650276,734.7829124,756.0868363,884.7552507,835.8096108,611.6588611,665.6244126,653.7301704,660.5855997,752.7497265,7144.114393,10187.82665,12902.46291,14745.62561,18016.18027,20512.92123,22031.53274,24639.18566,26505.30317,27788.88416,30035.80198,32170.37442,911.2989371,1043.561537,1190.041118,1125.69716,1178.223708,993.2239571,876.032569,847.0061135,925.060154,1005.245812,1111.984578,1327.60891,3530.690067,4916.299889,6017.190733,8513.097016,12724.82957,14195.52428,15268.42089,16120.52839,17541.49634,18747.69814,22514.2548,27538.41188,2428.237769,2617.155967,2750.364446,3242.531147,4031.408271,4879.992748,4820.49479,4246.485974,4439.45084,4684.313807,4858.347495,5186.050003,510.1964923,576.2670245,686.3736739,708.7595409,741.6662307,874.6858643,857.2503577,805.5724718,794.3484384,869.4497668,945.5835837,942.6542111,299.850319,431.7904566,522.0343725,715.5806402,820.2245876,764.7259628,838.1239671,736.4153921,745.5398706,796.6644681,575.7047176,579.231743,1840.366939,1726.887882,1796.589032,1452.057666,1654.456946,1874.298931,2011.159549,1823.015995,1456.309517,1341.726931,1270.364932,1201.637154,2194.926204,2220.487682,2291.156835,2538.269358,2529.842345,3203.208066,3121.760794,3023.096699,3081.694603,3160.454906,3099.72866,3548.330846,3054.421209,3629.076457,4692.648272,6197.962814,8315.928145,11186.14125,14560.53051,20038.47269,24757.60301,28377.63219,30209.01516,39724.97867,5263.673816,6040.180011,7550.359877,9326.64467,10168.65611,11674.83737,12545.99066,12986.47998,10535.62855,11712.7768,14843.93556,18008.94444,7267.688428,9244.001412,10350.15906,13319.89568,15798.06362,19654.96247,23269.6075,26923.20628,25144.39201,28061.09966,31163.20196,36180.78919,546.5657493,590.061996,658.3471509,700.7706107,724.032527,813.337323,855.7235377,976.5126756,1164.406809,1458.817442,1746.769454,2452.210407,749.6816546,858.9002707,849.2897701,762.4317721,1111.107907,1382.702056,1516.872988,1748.356961,2383.140898,3119.335603,2873.91287,3540.651564,3035.326002,3290.257643,4187.329802,5906.731805,9613.818607,11888.59508,7608.334602,6642.881371,7235.653188,8263.590301,9240.761975,11605.71449,4129.766056,6229.333562,8341.737815,8931.459811,9576.037596,14688.23507,14517.90711,11643.57268,3745.640687,3076.239795,4390.717312,4471.061906,5210.280328,5599.077872,6631.597314,7655.568963,9530.772896,11150.98113,12618.32141,13872.86652,17558.81555,24521.94713,34077.04939,40675.99635,4086.522128,5385.278451,7105.630706,8393.741404,12786.93223,13306.61921,15367.0292,17122.47986,18051.52254,20896.60924,21905.59514,25523.2771,4931.404155,6248.656232,8243.58234,10022.40131,12269.27378,14255.98475,16537.4835,19207.23482,22013.64486,24675.02446,27968.09817,28569.7197,2898.530881,4756.525781,5246.107524,6124.703451,7433.889293,6650.195573,6068.05135,6351.237495,7404.923685,7121.924704,6994.774861,7320.880262,3216.956347,4317.694365,6576.649461,9847.788607,14778.78636,16610.37701,19384.10571,22375.94189,26824.89511,28816.58499,28604.5919,31656.06806,1546.907807,1886.080591,2348.009158,2741.796252,2110.856309,2852.351568,4161.415959,4448.679912,3431.593647,3645.379572,3844.917194,4519.461171,853.540919,944.4383152,896.9663732,1056.736457,1222.359968,1267.613204,1348.225791,1361.936856,1341.921721,1360.485021,1287.514732,1463.249282,1088.277758,1571.134655,1621.693598,2143.540609,3701.621503,4106.301249,4106.525293,4106.492315,3726.063507,1690.756814,1646.758151,1593.06548,1030.592226,1487.593537,1536.344387,2029.228142,3030.87665,4657.22102,5622.942464,8533.088805,12104.27872,15993.52796,19233.98818,23348.13973,108382.3529,113523.1329,95458.11176,80894.88326,109347.867,59265.47714,31354.03573,28118.42998,34932.91959,40300.61996,35110.10566,47306.98978,4834.804067,6089.786934,5714.560611,6006.983042,7486.384341,8659.696836,7640.519521,5377.091329,6890.806854,8754.96385,9313.93883,10461.05868,298.8462121,335.9971151,411.8006266,498.6390265,496.5815922,745.3695408,797.2631074,773.9932141,977.4862725,1186.147994,1275.184575,1569.331442,575.5729961,620.9699901,634.1951625,713.6036483,803.0054535,640.3224383,572.1995694,506.1138573,636.6229191,609.1739508,531.4823679,414.5073415,2387.54806,3448.284395,6757.030816,18772.75169,21011.49721,21951.21176,17364.27538,11770.5898,9640.138501,9467.446056,9534.677467,12057.49928,1443.011715,1589.20275,1643.38711,1634.047282,1748.562982,1544.228586,1302.878658,1155.441948,1040.67619,986.2958956,894.6370822,1044.770126,369.1650802,416.3698064,427.9010856,495.5147806,584.6219709,663.2236766,632.8039209,635.5173634,563.2000145,692.2758103,665.4231186,759.3499101,1831.132894,1810.066992,2036.884944,2277.742396,2849.09478,3827.921571,4920.355951,5249.802653,7277.912802,10132.90964,10206.97794,12451.6558,452.3369807,490.3821867,496.1743428,545.0098873,581.3688761,686.3952693,618.0140641,684.1715576,739.014375,790.2579846,951.4097518,1042.581557,743.1159097,846.1202613,1055.896036,1421.145193,1586.851781,1497.492223,1481.150189,1421.603576,1361.369784,1483.136136,1579.019543,1803.151496,1967.955707,2034.037981,2529.067487,2475.387562,2575.484158,3710.982963,3688.037739,4783.586903,6058.253846,7425.705295,9021.815894,10956.99112,3478.125529,4131.546641,4581.609385,5754.733883,6809.40669,7674.929108,9611.147541,8688.156003,9472.384295,9767.29753,10742.44053,11977.57496,786.5668575,912.6626085,1056.353958,1226.04113,1421.741975,1647.511665,2000.603139,2338.008304,1785.402016,1902.2521,2140.739323,3095.772271,2647.585601,3682.259903,4649.593785,5907.850937,7778.414017,9595.929905,11222.58762,11732.51017,7003.339037,6465.613349,6557.194282,9253.896111,1688.20357,1642.002314,1566.353493,1711.04477,1930.194975,2370.619976,2702.620356,2755.046991,2948.047252,2982.101858,3258.495584,3820.17523,468.5260381,495.5868333,556.6863539,566.6691539,724.9178037,502.3197334,462.2114149,389.8761846,410.8968239,472.3460771,633.6179466,823.6856205,331.0,350.0,388.0,349.0,357.0,371.0,424.0,385.0,347.0,415.0,611.0,944.0,2423.780443,2621.448058,3173.215595,3793.694753,3746.080948,3876.485958,4191.100511,3693.731337,3804.537999,3899.52426,4072.324751,4811.060429,545.8657229,597.9363558,652.3968593,676.4422254,674.7881296,694.1124398,718.3730947,775.6324501,897.7403604,1010.892138,1057.206311,1091.359778,8941.571858,11276.19344,12790.84956,15363.25136,18794.74567,21209.0592,21399.46046,23651.32361,26790.94961,30246.13063,33724.75778,36797.93332,10556.57566,12247.39532,13175.678,14463.91893,16046.03728,16233.7177,17632.4104,19007.19129,18363.32494,21050.41377,23189.80135,25185.00911,3112.363948,3457.415947,3634.364406,4643.393534,4688.593267,5486.371089,3470.338156,2955.984375,2170.151724,2253.023004,2474.548819,2749.320965,761.879376,835.5234025,997.7661127,1054.384891,954.2092363,808.8970728,909.7221354,668.3000228,581.182725,580.3052092,601.0745012,619.6768924,1077.281856,1100.592563,1150.927478,1014.514104,1698.388838,1981.951806,1576.97375,1385.029563,1619.848217,1624.941275,1615.286395,2013.977305,10095.42172,11653.97304,13450.40151,16361.87647,18965.05551,23311.34939,26298.63531,31540.9748,33965.66115,41283.16433,44683.97525,49357.19017,1828.230307,2242.746551,2924.638113,4720.942687,10618.03855,11848.34392,12954.79101,18115.22313,18616.70691,19702.05581,19774.83687,22316.19287,684.5971438,747.0835292,803.3427418,942.4082588,1049.938981,1175.921193,1443.429832,1704.686583,1971.829464,2049.350521,2092.712441,2605.94758,2480.380334,2961.800905,3536.540301,4421.009084,5364.249663,5351.912144,7009.601598,7034.779161,6618.74305,7113.692252,7356.031934,9809.185636,1952.308701,2046.154706,2148.027146,2299.376311,2523.337977,3248.373311,4258.503604,3998.875695,4196.411078,4247.400261,3783.674243,4172.838464,3758.523437,4245.256698,4957.037982,5788.09333,5937.827283,6281.290855,6434.501797,6360.943444,4446.380924,5838.347657,5909.020073,7408.905561,1272.880995,1547.944844,1649.552153,1814.12743,1989.37407,2373.204287,2603.273765,2189.634995,2279.324017,2536.534925,2650.921068,3190.481016,4029.329699,4734.253019,5338.752143,6557.152776,8006.506993,9508.141454,8451.531004,9082.351172,7738.881247,10159.58368,12002.23908,15389.92468,3068.319867,3774.571743,4727.954889,6361.517993,9022.247417,10172.48572,11753.84291,13039.30876,16207.26663,17641.03156,19970.90787,20509.64777,3081.959785,3907.156189,5108.34463,6929.277714,9123.041742,9770.524921,10330.98915,12281.34191,14641.58711,16999.4333,18855.60618,19328.70901,2718.885295,2769.451844,3173.72334,4021.175739,5047.658563,4319.804067,5267.219353,5303.377488,6101.255823,6071.941411,6316.1652,7670.122558,3144.613186,3943.370225,4734.997586,6470.866545,8011.414402,9356.39724,9605.314053,9696.273295,6598.409903,7346.547557,7885.360081,10808.47561,493.3238752,540.2893983,597.4730727,510.9637142,590.5806638,670.0806011,881.5706467,847.991217,737.0685949,589.9445051,785.6537648,863.0884639,879.5835855,860.7369026,1071.551119,1384.840593,1532.985254,1737.561657,1890.218117,1516.525457,1428.777814,1339.076036,1353.09239,1598.435089,6459.554823,8157.591248,11626.41975,16903.04886,24837.42865,34167.7626,33693.17525,21198.26136,24841.61777,20586.69019,19014.54118,21654.83194,1450.356983,1567.653006,1654.988723,1612.404632,1597.712056,1561.769116,1518.479984,1441.72072,1367.899369,1392.368347,1519.635262,1712.472136,3581.459448,4981.090891,6289.629157,7991.707066,10522.06749,12980.66956,15181.0927,15870.87851,9325.068238,7914.320304,7236.075251,9786.534714,879.7877358,1004.484437,1116.639877,1206.043465,1353.759762,1348.285159,1465.010784,1294.447788,1068.696278,574.6481576,699.489713,862.5407561,2315.138227,2843.104409,3674.735572,4977.41854,8597.756202,11210.08948,15169.16112,18861.53081,24769.8912,33519.4766,36023.1054,47143.17964,5074.659104,6093.26298,7481.107598,8412.902397,9674.167626,10922.66404,11348.54585,12037.26758,9498.467723,12126.23065,13638.77837,18678.31435,4215.041741,5862.276629,7402.303395,9405.489397,12383.4862,15277.03017,17866.72175,18678.53492,14214.71681,17161.10735,20660.01936,25768.25759,1135.749842,1258.147413,1369.488336,1284.73318,1254.576127,1450.992513,1176.807031,1093.244963,926.9602964,930.5964284,882.0818218,926.1410683,4725.295531,5487.104219,5768.729717,7114.477971,7765.962636,8028.651439,8568.266228,7825.823398,7225.069258,7479.188244,7710.946444,9269.657808,3834.034742,4564.80241,5693.843879,7993.512294,10638.75131,13236.92117,13926.16997,15764.98313,18603.06452,20445.29896,24835.47166,28821.0637,1083.53203,1072.546602,1074.47196,1135.514326,1213.39553,1348.775651,1648.079789,1876.766827,2153.739222,2664.477257,3015.378833,3970.095407,1615.991129,1770.337074,1959.593767,1687.997641,1659.652775,2202.988423,1895.544073,1507.819159,1492.197043,1632.210764,1993.398314,2602.394995,1148.376626,1244.708364,1856.182125,2613.101665,3364.836625,3781.410618,3895.384018,3984.839812,3553.0224,3876.76846,4128.116943,4513.480643,8527.844662,9911.878226,12329.44192,15258.29697,17832.02464,18855.72521,20667.38125,23586.92927,23880.01683,25266.59499,29341.63093,33859.74835,14734.23275,17909.48973,20431.0927,22966.14432,27195.11304,26982.29052,28397.71512,30281.70459,31871.5303,32135.32301,34480.95771,37506.41907,1643.485354,2117.234893,2193.037133,1881.923632,2571.423014,3195.484582,3761.837715,3116.774285,3340.542768,4014.238972,4090.925331,4184.548089,1206.947913,1507.86129,1822.879028,2643.858681,4062.523897,5596.519826,7426.354774,11054.56175,15215.6579,20206.82098,23235.42329,28718.27684,716.6500721,698.5356073,722.0038073,848.2186575,915.9850592,962.4922932,874.2426069,831.8220794,825.682454,789.1862231,899.0742111,1107.482182,757.7974177,793.5774148,1002.199172,1295.46066,1524.358936,1961.224635,2393.219781,2982.653773,4616.896545,5852.625497,5913.187529,7458.396327,859.8086567,925.9083202,1067.53481,1477.59676,1649.660188,1532.776998,1344.577953,1202.201361,1034.298904,982.2869243,886.2205765,882.9699438,3023.271928,4100.3934,4997.523971,5621.368472,6619.551419,7899.554209,9119.528607,7388.597823,7370.990932,8792.573126,11460.60023,18008.50924,1468.475631,1395.232468,1660.30321,1932.360167,2753.285994,3120.876811,3560.233174,3810.419296,4332.720164,4876.798614,5722.895655,7092.923025,1969.10098,2218.754257,2322.869908,2826.356387,3450.69638,4269.122326,4241.356344,5089.043686,5678.348271,6601.429915,6508.085718,8458.276384,734.753484,774.3710692,767.2717398,908.9185217,950.735869,843.7331372,682.2662268,617.7244065,644.1707969,816.559081,927.7210018,1056.380121,9979.508487,11283.17795,12477.17707,14142.85089,15895.11641,17428.74846,18232.42452,21664.78767,22705.09254,26074.53136,29478.99919,33203.26128,13990.48208,14847.12712,16173.14586,19530.36557,21806.03594,24072.63213,25009.55914,29884.35041,32003.93224,35767.43303,39097.09955,42951.65309,5716.766744,6150.772969,5603.357717,5444.61962,5703.408898,6504.339663,6920.223051,7452.398969,8137.004775,9230.240708,7727.002004,10611.46299,7689.799761,9802.466526,8422.974165,9541.474188,10505.25966,13143.95095,11152.41011,9883.584648,10733.92631,10165.49518,8605.047831,11415.80569,605.0664917,676.2854478,772.0491602,637.1232887,699.5016441,713.5371196,707.2357863,820.7994449,989.0231487,1385.896769,1764.456677,2441.576404,1515.592329,1827.067742,2198.956312,2649.715007,3133.409277,3682.831494,4336.032082,5107.197384,6017.654756,7110.667619,4515.487575,3025.349798,781.7175761,804.8304547,825.6232006,862.4421463,1265.047031,1829.765177,1977.55701,1971.741538,1879.496673,2117.484526,2234.820827,2280.769906,1147.388831,1311.956766,1452.725766,1777.077318,1773.498265,1588.688299,1408.678565,1213.315116,1210.884633,1071.353818,1071.613938,1271.211593,406.8841148,518.7642681,527.2721818,569.7950712,799.3621758,685.5876821,788.8550411,706.1573059,693.4207856,792.4499603,672.0386227,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"breaks\":[1000.0,10000.0,25000.0,50000.0,100000.0],\n",
       "\"trans\":\"log10\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"FYnR0a\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144591cd0>"
      ]
     },
     "execution_count": 77,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             ) +\n",
    "        geom_point(alpha=0.5) +\n",
    "        scale_x_log10(\n",
    "            breaks = [1000, 10000, 25000, 50000, 100000],\n",
    "            )\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "And we could also make the break labels human-readable by changing the format in which they appear using the `numerize()` function (does not come with `lets_plot`)."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 78,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"aC86Pc\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,30.332,31.997,34.02,36.088,38.438,39.854,40.822,41.674,41.763,42.129,43.828,55.23,59.28,64.82,66.22,67.69,68.93,70.42,72.0,71.581,72.95,75.651,76.423,43.077,45.685,48.303,51.407,54.518,58.014,61.368,65.799,67.744,69.152,70.994,72.301,30.015,31.999,34.0,35.985,37.928,39.483,39.942,39.906,40.647,40.963,41.003,42.731,62.485,64.399,65.142,65.634,67.065,68.481,69.942,70.774,71.868,73.275,74.34,75.32,69.12,70.33,70.93,71.1,71.93,73.49,74.74,76.32,77.56,78.83,80.37,81.235,66.8,67.48,69.54,70.14,70.63,72.17,73.18,74.94,76.04,77.51,78.98,79.829,50.939,53.832,56.923,59.923,63.3,65.593,69.052,70.75,72.601,73.925,74.795,75.635,37.484,39.348,41.216,43.453,45.252,46.923,50.009,52.819,56.018,59.412,62.013,64.062,68.0,69.24,70.25,70.94,71.44,72.8,73.93,75.35,76.46,77.53,78.32,79.441,38.223,40.358,42.618,44.885,47.014,49.19,50.904,52.337,53.919,54.777,54.406,56.728,40.414,41.89,43.428,45.032,46.714,50.023,53.859,57.251,59.957,62.05,63.883,65.554,53.82,58.45,61.93,64.79,67.45,69.86,70.69,71.14,72.178,73.244,74.09,74.852,47.622,49.618,51.52,53.298,56.024,59.319,61.484,63.622,62.745,52.556,46.634,50.728,50.917,53.285,55.665,57.632,59.504,61.489,63.336,65.205,67.057,69.388,71.006,72.39,59.6,66.61,69.51,70.42,70.9,70.81,71.08,71.34,71.19,70.32,72.14,73.005,31.975,34.906,37.814,40.697,43.591,46.137,48.122,49.557,50.26,50.324,50.65,52.295,39.031,40.533,42.045,43.548,44.057,45.91,47.471,48.211,44.736,45.326,47.36,49.58,39.417,41.366,43.415,45.415,40.317,31.22,50.957,53.914,55.803,56.534,56.752,59.723,38.523,40.428,42.643,44.799,47.049,49.355,52.961,54.985,54.314,52.199,49.856,50.43,68.75,69.96,71.3,72.13,72.88,74.21,75.76,76.86,77.95,78.61,79.77,80.653,35.463,37.464,39.475,41.478,43.457,46.775,48.295,50.485,49.396,46.066,43.308,44.741,38.092,39.881,41.716,43.601,45.569,47.383,49.517,51.051,51.724,51.573,50.525,50.651,54.745,56.074,57.924,60.523,63.441,67.052,70.565,72.492,74.126,75.816,77.86,78.553,44.0,50.54896,44.50136,58.38112,63.11888,63.96736,65.525,67.274,68.69,70.426,72.028,72.961,50.643,55.118,57.863,59.963,61.623,63.837,66.653,67.768,68.421,70.313,71.682,72.889,40.715,42.46,44.467,46.472,48.944,50.939,52.933,54.926,57.939,60.66,62.974,65.152,39.143,40.652,42.122,44.056,45.989,47.804,47.784,47.412,45.548,42.587,44.966,46.462,42.111,45.053,48.435,52.04,54.907,55.625,56.695,57.47,56.433,52.962,52.97,55.322,57.206,60.026,62.842,65.424,67.849,70.75,73.45,74.752,75.713,77.26,78.123,78.782,40.477,42.469,44.93,47.35,49.801,52.374,53.983,54.655,52.044,47.991,46.832,48.328,61.21,64.77,67.13,68.5,69.61,70.64,70.46,71.52,72.527,73.68,74.876,75.748,59.421,62.325,65.246,68.29,70.723,72.649,73.717,74.174,74.414,76.151,77.158,78.273,66.87,69.03,69.9,70.38,70.29,70.71,70.96,71.58,72.4,74.01,75.51,76.486,70.78,71.81,72.35,72.96,73.47,74.69,74.63,74.8,75.33,76.11,77.18,78.332,34.812,37.328,39.693,42.074,44.366,46.519,48.812,50.04,51.604,53.157,53.373,54.791,45.928,49.828,53.459,56.751,59.631,61.788,63.727,66.046,68.457,69.957,70.847,72.235,48.357,51.356,54.64,56.678,58.796,61.31,64.342,67.231,69.613,72.312,74.173,74.994,41.893,44.444,46.992,49.293,51.137,53.319,56.006,59.797,63.674,67.217,69.806,71.338,45.262,48.57,52.307,55.855,58.207,56.696,56.604,63.154,66.798,69.535,70.734,71.878,34.482,35.983,37.485,38.987,40.516,42.024,43.662,45.664,47.545,48.245,49.348,51.579,35.928,38.047,40.158,42.189,44.142,44.535,43.89,46.453,49.991,53.378,55.24,58.04,34.078,36.667,40.059,42.115,43.515,44.51,44.916,46.684,48.091,49.402,50.725,52.947,66.55,67.49,68.75,69.83,70.87,72.52,74.55,74.83,75.7,77.13,78.37,79.313,67.41,68.93,70.51,71.55,72.38,73.83,74.89,76.34,77.46,78.64,79.59,80.657,37.003,38.999,40.489,44.598,48.69,52.79,56.564,60.19,61.366,60.461,56.761,56.735,30.0,32.065,33.896,35.857,38.308,41.842,45.58,49.265,52.644,55.861,58.041,59.448,67.5,69.1,70.3,70.8,71.0,72.5,73.8,74.847,76.07,77.34,78.67,79.406,43.149,44.779,46.452,48.072,49.875,51.756,53.744,55.729,57.501,58.556,58.453,60.022,65.86,67.86,69.51,71.0,72.34,73.68,75.24,76.67,77.03,77.869,78.256,79.483,42.023,44.142,46.954,50.016,53.738,56.029,58.137,60.782,63.373,66.322,68.978,70.259,33.609,34.558,35.753,37.197,38.842,40.762,42.891,45.552,48.576,51.455,53.676,56.007,32.5,33.489,34.488,35.492,36.486,37.465,39.327,41.245,43.266,44.873,45.504,46.388,37.579,40.696,43.59,46.243,48.042,49.923,51.461,53.636,55.089,56.671,58.137,60.916,41.912,44.665,48.041,50.924,53.884,57.402,60.909,64.492,66.399,67.659,68.565,70.198,60.96,64.75,67.65,70.0,72.0,73.6,75.45,76.2,77.601,80.0,81.495,82.208,64.03,66.41,67.96,69.5,69.76,69.95,69.39,69.58,69.17,71.04,72.59,73.338,72.49,73.47,73.68,73.73,74.46,76.11,76.99,77.23,78.77,78.95,80.5,81.757,37.373,40.249,43.605,47.193,50.651,54.208,56.596,58.553,60.223,61.765,62.879,64.698,37.468,39.918,42.518,45.964,49.203,52.702,56.159,60.137,62.681,66.041,68.588,70.65,44.869,47.181,49.325,52.469,55.234,57.702,59.62,63.04,65.742,68.042,69.451,70.964,45.32,48.437,51.457,54.459,56.95,60.413,62.038,65.044,59.461,58.811,57.046,59.545,66.91,68.9,70.29,71.08,71.28,72.03,73.1,74.36,75.467,76.122,77.783,78.885,65.39,67.84,69.39,70.75,71.63,73.06,74.45,75.6,76.93,78.269,79.696,80.745,65.94,67.81,69.24,71.06,72.19,73.48,74.98,76.42,77.44,78.82,80.24,80.546,58.53,62.61,65.61,67.51,69.0,70.11,71.21,71.77,71.766,72.262,72.047,72.567,63.03,65.5,68.73,71.43,73.42,75.38,77.11,78.67,79.36,80.69,82.0,82.603,43.158,45.669,48.126,51.629,56.528,61.134,63.739,65.869,68.015,69.772,71.263,72.535,42.27,44.686,47.949,50.654,53.559,56.155,58.766,59.339,59.285,54.407,50.992,54.11,50.056,54.081,56.656,59.942,63.983,67.159,69.1,70.647,69.978,67.727,66.662,67.297,47.453,52.681,55.292,57.716,62.612,64.766,67.123,69.81,72.244,74.647,77.045,78.623,55.565,58.033,60.47,64.624,67.712,69.343,71.309,74.174,75.19,76.156,76.904,77.588,55.928,59.489,62.094,63.87,65.421,66.099,66.983,67.926,69.292,70.265,71.028,71.993,42.138,45.047,47.747,48.492,49.767,52.208,55.078,57.18,59.685,55.558,44.593,42.592,38.48,39.486,40.502,41.536,42.614,43.764,44.852,46.027,40.802,42.221,43.753,45.678,42.723,45.289,47.808,50.227,52.773,57.442,62.155,66.234,68.755,71.555,72.737,73.952,36.681,38.865,40.848,42.881,44.851,46.881,48.969,49.35,52.214,54.978,57.286,59.443,36.256,37.207,38.41,39.487,41.766,43.767,45.642,47.457,49.42,47.495,45.009,48.303,48.463,52.102,55.737,59.371,63.01,65.256,68.0,69.5,70.693,71.938,73.044,74.241,33.685,35.307,36.936,38.487,39.977,41.714,43.916,46.364,48.388,49.903,51.818,54.467,40.543,42.338,44.248,46.289,48.437,50.852,53.599,56.145,58.333,60.43,62.247,64.164,50.986,58.089,60.246,61.557,62.944,64.93,66.711,68.74,69.745,70.736,71.954,72.801,50.789,55.19,58.299,60.11,62.361,65.032,67.405,69.498,71.455,73.67,74.902,76.195,42.244,45.248,48.251,51.253,53.754,55.491,57.489,60.222,61.271,63.625,65.033,66.803,59.164,61.448,63.728,67.178,70.636,73.066,74.101,74.865,75.435,75.445,73.981,74.543,42.873,45.423,47.924,50.335,52.862,55.73,59.65,62.677,65.393,67.66,69.615,71.164,31.286,33.779,36.161,38.113,40.328,42.495,42.795,42.861,44.284,46.344,44.026,42.082,36.319,41.905,45.108,49.379,53.07,56.059,58.056,58.339,59.32,60.328,59.908,62.069,41.725,45.226,48.386,51.159,53.867,56.437,58.968,60.835,61.999,58.909,51.479,52.906,36.157,37.686,39.393,41.472,43.971,46.748,49.594,52.537,55.727,59.426,61.34,63.785,72.13,72.99,73.23,73.82,73.75,75.24,76.05,76.83,77.42,78.03,78.53,79.762,69.39,70.26,71.24,71.52,71.89,72.22,73.84,74.32,76.33,77.55,79.11,80.204,42.314,45.432,48.632,51.884,55.151,57.47,59.298,62.008,65.843,68.426,70.836,72.899,37.444,38.598,39.487,40.118,40.546,41.291,42.598,44.555,47.391,51.313,54.496,56.867,36.324,37.802,39.36,41.04,42.821,44.514,45.826,46.886,47.472,47.464,46.608,46.859,72.67,73.44,73.47,74.08,74.34,75.37,75.97,75.89,77.32,78.32,79.05,80.196,37.578,40.08,43.165,46.988,52.143,57.367,62.728,67.734,71.197,72.499,74.193,75.64,43.436,45.557,47.67,49.8,51.929,54.043,56.158,58.245,60.838,61.818,63.61,65.483,55.191,59.201,61.817,64.071,66.216,68.681,70.472,71.523,72.462,73.738,74.712,75.537,62.649,63.196,64.361,64.951,65.815,66.353,66.874,67.378,68.225,69.4,70.755,71.752,43.902,46.263,49.096,51.445,55.448,58.447,61.406,64.134,66.458,68.386,69.906,71.421,47.752,51.334,54.757,56.393,58.065,60.06,62.082,64.151,66.458,68.564,70.303,71.688,61.31,65.77,67.64,69.61,70.85,70.67,71.32,70.98,70.99,72.75,74.67,75.563,59.82,61.51,64.39,66.6,69.26,70.41,72.77,74.06,74.86,75.97,77.29,78.098,64.28,68.54,69.62,71.1,72.16,73.44,73.75,74.63,73.911,74.917,77.778,78.746,52.724,55.09,57.666,60.542,64.274,67.064,69.885,71.913,73.615,74.772,75.744,76.442,61.05,64.1,66.8,66.8,69.21,69.46,69.66,69.53,69.36,69.72,71.322,72.476,40.0,41.5,43.0,44.1,44.6,45.0,46.218,44.02,23.599,36.087,43.413,46.242,46.471,48.945,51.893,54.425,56.48,58.55,60.351,61.728,62.742,63.306,64.337,65.528,39.875,42.868,45.914,49.901,53.886,58.69,63.012,66.295,68.768,70.533,71.626,72.777,37.278,39.329,41.454,43.563,45.815,48.879,52.379,55.769,58.196,60.187,61.6,63.062,57.996,61.685,64.531,66.914,68.7,70.3,70.162,71.218,71.659,72.232,73.213,74.002,30.331,31.57,32.767,34.113,35.4,36.788,38.445,40.006,38.333,39.897,41.012,42.568,60.396,63.179,65.798,67.946,69.521,70.795,71.76,73.56,75.788,77.158,78.77,79.972,64.36,67.45,70.33,70.98,70.35,70.45,70.8,71.08,71.38,72.71,73.8,74.663,65.57,67.85,69.15,69.18,69.82,70.97,71.063,72.25,73.64,75.13,76.66,77.926,32.978,34.977,36.981,38.977,40.973,41.974,42.955,44.501,39.658,43.795,45.936,48.159,45.009,47.985,49.951,51.927,53.696,55.527,58.161,60.834,61.888,60.236,53.365,49.339,64.94,66.66,69.69,71.44,73.06,74.39,76.3,76.9,77.57,78.77,79.78,80.941,57.593,61.456,62.192,64.266,65.042,65.949,68.757,69.011,70.379,70.457,70.815,72.396,38.635,39.624,40.87,42.858,45.083,47.8,50.338,51.744,53.556,55.373,56.369,58.556,41.407,43.424,44.992,46.633,49.552,52.537,55.561,57.678,58.474,54.289,43.869,39.613,71.86,72.49,73.37,74.16,74.72,75.44,76.42,77.19,78.16,79.39,80.04,80.884,69.62,70.56,71.32,72.77,73.78,75.39,76.21,77.41,78.03,79.37,80.62,81.701,45.883,48.284,50.305,53.655,57.296,61.195,64.59,66.974,69.249,71.527,73.053,74.143,58.5,62.4,65.2,67.5,69.39,70.59,72.16,73.4,74.26,75.25,76.99,78.4,41.215,42.974,44.246,45.757,47.62,49.919,50.608,51.535,50.44,48.466,49.651,52.517,50.848,53.63,56.061,58.285,60.405,62.494,64.597,66.084,67.298,67.521,68.564,70.616,38.596,41.208,43.922,46.769,49.759,52.887,55.471,56.941,58.061,58.39,57.561,58.42,59.1,61.8,64.9,65.4,65.9,68.3,68.832,69.582,69.862,69.465,68.976,69.819,44.6,47.1,49.579,52.053,55.602,59.837,64.048,66.894,70.001,71.973,73.042,73.923,43.585,48.079,52.098,54.336,57.005,59.507,61.036,63.108,66.146,68.835,70.845,71.777,39.978,42.571,45.344,48.051,51.016,50.35,49.849,51.509,48.825,44.578,47.813,51.542,69.18,70.42,70.76,71.36,72.01,72.76,74.04,75.007,76.42,77.218,78.471,79.425,68.44,69.49,70.21,70.76,71.34,73.38,74.65,75.02,76.09,76.81,77.31,78.242,66.071,67.044,68.253,68.468,68.673,69.481,70.805,71.918,72.752,74.223,75.307,76.384,55.088,57.907,60.77,63.479,65.712,67.456,68.557,70.19,71.15,72.146,72.766,73.747,40.412,42.887,45.363,47.838,50.254,55.764,58.816,62.82,67.662,70.672,73.017,74.249,43.16,45.671,48.127,51.631,56.532,60.765,64.406,67.046,69.718,71.096,72.37,73.422,32.548,33.97,35.18,36.984,39.848,44.175,49.113,52.922,55.599,58.02,60.308,62.698,42.038,44.077,46.023,47.768,50.107,51.386,51.821,50.821,46.1,40.238,39.193,42.384,48.451,50.469,52.358,53.995,55.635,57.674,60.363,62.351,60.377,46.809,39.989,43.487],\n",
       "\"pop\":[8425333.0,9240934.0,1.0267083E7,1.1537966E7,1.307946E7,1.4880372E7,1.2881816E7,1.3867957E7,1.6317921E7,2.2227415E7,2.5268405E7,3.1889923E7,1282697.0,1476505.0,1728137.0,1984060.0,2263554.0,2509048.0,2780097.0,3075321.0,3326498.0,3428038.0,3508512.0,3600523.0,9279525.0,1.0270856E7,1.1000948E7,1.2760499E7,1.4760787E7,1.7152804E7,2.0033753E7,2.3254956E7,2.6298373E7,2.9072015E7,3.1287142E7,3.3333216E7,4232095.0,4561361.0,4826015.0,5247469.0,5894858.0,6162675.0,7016384.0,7874230.0,8735988.0,9875024.0,1.0866106E7,1.2420476E7,1.7876956E7,1.9610538E7,2.1283783E7,2.2934225E7,2.4779799E7,2.6983828E7,2.9341374E7,3.1620918E7,3.3958947E7,3.6203463E7,3.8331121E7,4.0301927E7,8691212.0,9712569.0,1.0794968E7,1.1872264E7,1.3177E7,1.40741E7,1.51842E7,1.6257249E7,1.7481977E7,1.8565243E7,1.9546792E7,2.0434176E7,6927772.0,6965860.0,7129864.0,7376998.0,7544201.0,7568430.0,7574613.0,7578903.0,7914969.0,8069876.0,8148312.0,8199783.0,120447.0,138655.0,171863.0,202182.0,230800.0,297410.0,377967.0,454612.0,529491.0,598561.0,656397.0,708573.0,4.6886859E7,5.1365468E7,5.6839289E7,6.2821884E7,7.0759295E7,8.0428306E7,9.3074406E7,1.03764241E8,1.13704579E8,1.23315288E8,1.3565679E8,1.50448339E8,8730405.0,8989111.0,9218400.0,9556500.0,9709100.0,9821800.0,9856303.0,9870200.0,1.0045622E7,1.0199787E7,1.031197E7,1.0392226E7,1738315.0,1925173.0,2151895.0,2427334.0,2761407.0,3168267.0,3641603.0,4243788.0,4981671.0,6066080.0,7026113.0,8078314.0,2883315.0,3211738.0,3593918.0,4040665.0,4565872.0,5079716.0,5642224.0,6156369.0,6893451.0,7693188.0,8445134.0,9119152.0,2791000.0,3076000.0,3349000.0,3585000.0,3819000.0,4086000.0,4172693.0,4338977.0,4256013.0,3607000.0,4165416.0,4552198.0,442308.0,474639.0,512764.0,553541.0,619351.0,781472.0,970347.0,1151184.0,1342614.0,1536536.0,1630347.0,1639131.0,5.660256E7,6.5551171E7,7.603939E7,8.8049823E7,1.00840058E8,1.14313951E8,1.28962939E8,1.42938076E8,1.55975974E8,1.68546719E8,1.79914212E8,1.90010647E8,7274900.0,7651254.0,8012946.0,8310226.0,8576200.0,8797022.0,8892098.0,8971958.0,8658506.0,8066057.0,7661799.0,7322858.0,4469979.0,4713416.0,4919632.0,5127935.0,5433886.0,5889574.0,6634596.0,7586551.0,8878303.0,1.0352843E7,1.2251209E7,1.4326203E7,2445618.0,2667518.0,2961915.0,3330989.0,3529983.0,3834415.0,4580410.0,5126023.0,5809236.0,6121610.0,7021078.0,8390505.0,4693836.0,5322536.0,6083619.0,6960067.0,7450606.0,6978607.0,7272485.0,8371791.0,1.0150094E7,1.1782962E7,1.2926707E7,1.4131858E7,5009067.0,5359923.0,5793633.0,6335506.0,7021028.0,7959865.0,9250831.0,1.0780667E7,1.2467171E7,1.4195809E7,1.5929988E7,1.7696293E7,1.4785584E7,1.7010154E7,1.8985849E7,2.0819767E7,2.22845E7,2.37964E7,2.52019E7,2.65497E7,2.8523502E7,3.0305843E7,3.1902268E7,3.3390141E7,1291695.0,1392284.0,1523478.0,1733638.0,1927260.0,2167533.0,2476971.0,2840009.0,3265124.0,3696513.0,4048013.0,4369038.0,2682462.0,2894855.0,3150417.0,3495967.0,3899068.0,4388260.0,4875118.0,5498955.0,6429417.0,7562011.0,8835739.0,1.0238807E7,6377619.0,7048426.0,7961258.0,8858908.0,9717524.0,1.0599793E7,1.1487112E7,1.2463354E7,1.3572994E7,1.4599929E7,1.5497046E7,1.6284741E7,5.56263527E8,6.37408E8,6.6577E8,7.5455E8,8.6203E8,9.43455E8,1.000281E9,1.084035E9,1.16497E9,1.230075E9,1.2804E9,1.318683096E9,1.2350771E7,1.4485993E7,1.7009885E7,1.9764027E7,2.254289E7,2.5094412E7,2.7764644E7,3.0964245E7,3.4202721E7,3.765783E7,4.1008227E7,4.422755E7,153936.0,170928.0,191689.0,217378.0,250027.0,304739.0,348643.0,395114.0,454429.0,527982.0,614382.0,710960.0,1.4100005E7,1.5577932E7,1.7486434E7,1.9941073E7,2.3007669E7,2.648087E7,3.0646495E7,3.5481645E7,4.1672143E7,4.7798986E7,5.5379852E7,6.4606759E7,854885.0,940458.0,1047924.0,1179760.0,1340458.0,1536769.0,1774735.0,2064095.0,2409073.0,2800947.0,3328795.0,3800610.0,926317.0,1112300.0,1345187.0,1588717.0,1834796.0,2108457.0,2424367.0,2799811.0,3173216.0,3518107.0,3834934.0,4133884.0,2977019.0,3300000.0,3832408.0,4744870.0,6071696.0,7459574.0,9025951.0,1.0761098E7,1.2772596E7,1.4625967E7,1.6252726E7,1.8013409E7,3882229.0,3991242.0,4076557.0,4174366.0,4225310.0,4318673.0,4413368.0,4484310.0,4494013.0,4444595.0,4481020.0,4493312.0,6007797.0,6640752.0,7254373.0,8139332.0,8831348.0,9537988.0,9789224.0,1.0239839E7,1.072326E7,1.0983007E7,1.1226999E7,1.1416987E7,9125183.0,9513758.0,9620282.0,9835109.0,9862158.0,1.0161915E7,1.0303704E7,1.0311597E7,1.0315702E7,1.0300707E7,1.0256295E7,1.0228744E7,4334000.0,4487831.0,4646899.0,4838800.0,4991596.0,5088419.0,5117810.0,5127024.0,5171393.0,5283663.0,5374693.0,5468120.0,63149.0,71851.0,89898.0,127617.0,178848.0,228694.0,305991.0,311025.0,384156.0,417908.0,447416.0,496374.0,2491346.0,2923186.0,3453434.0,4049146.0,4671329.0,5302800.0,5968349.0,6655297.0,7351181.0,7992357.0,8650322.0,9319622.0,3548753.0,4058385.0,4681707.0,5432424.0,6298651.0,7278866.0,8365850.0,9545158.0,1.0748394E7,1.1911819E7,1.2921234E7,1.375568E7,2.2223309E7,2.5009741E7,2.8173309E7,3.1681188E7,3.4807417E7,3.8783863E7,4.5681811E7,5.2799062E7,5.9402198E7,6.6134291E7,7.3312559E7,8.0264543E7,2042865.0,2355805.0,2747687.0,3232927.0,3790903.0,4282586.0,4474873.0,4842194.0,5274649.0,5783439.0,6353681.0,6939688.0,216964.0,232922.0,249220.0,259864.0,277603.0,192675.0,285483.0,341244.0,387838.0,439971.0,495627.0,551201.0,1438760.0,1542611.0,1666618.0,1820319.0,2260187.0,2512642.0,2637297.0,2915959.0,3668440.0,4058319.0,4414865.0,4906585.0,2.0860941E7,2.2815614E7,2.5145372E7,2.7860297E7,3.0770372E7,3.4617799E7,3.8111756E7,4.299953E7,5.2088559E7,5.9861301E7,6.7946797E7,7.6511887E7,4090500.0,4324000.0,4491443.0,4605744.0,4639657.0,4738902.0,4826933.0,4931729.0,5041039.0,5134406.0,5193039.0,5238460.0,4.2459667E7,4.4310863E7,4.7124E7,4.9569E7,5.1732E7,5.3165019E7,5.4433565E7,5.56301E7,5.7374179E7,5.8623428E7,5.9925035E7,6.1083916E7,420702.0,434904.0,455661.0,489004.0,537977.0,706367.0,753874.0,880397.0,985739.0,1126189.0,1299304.0,1454867.0,284320.0,323150.0,374020.0,439593.0,517101.0,608274.0,715523.0,848406.0,1025384.0,1235767.0,1457766.0,1688359.0,6.9145952E7,7.1019069E7,7.3739117E7,7.6368453E7,7.8717088E7,7.8160773E7,7.8335266E7,7.7718298E7,8.0597764E7,8.2011073E7,8.2350671E7,8.2400996E7,5581001.0,6391288.0,7355248.0,8490213.0,9354120.0,1.0538093E7,1.1400338E7,1.4168101E7,1.6278738E7,1.8418288E7,2.0550751E7,2.2873338E7,7733250.0,8096218.0,8448233.0,8716441.0,8888628.0,9308479.0,9786480.0,9974490.0,1.0325429E7,1.0502372E7,1.0603863E7,1.070629E7,3146381.0,3640876.0,4208858.0,4690773.0,5149581.0,5703430.0,6395630.0,7326406.0,8486949.0,9803875.0,1.117865E7,1.2572928E7,2664249.0,2876726.0,3140003.0,3451418.0,3811387.0,4227026.0,4710497.0,5650262.0,6990574.0,8048834.0,8807818.0,9947814.0,580653.0,601095.0,627820.0,601287.0,625361.0,745228.0,825987.0,927524.0,1050938.0,1193708.0,1332459.0,1472041.0,3201488.0,3507701.0,3880130.0,4318137.0,4698301.0,4908554.0,5198399.0,5756203.0,6326682.0,6913545.0,7607651.0,8502814.0,1517453.0,1770390.0,2090162.0,2500689.0,2965146.0,3055235.0,3669448.0,4372203.0,5077347.0,5867957.0,6677328.0,7483763.0,2125900.0,2736300.0,3305200.0,3722800.0,4115700.0,4583700.0,5264500.0,5584510.0,5829696.0,6495918.0,6762476.0,6980412.0,9504000.0,9839000.0,1.0063E7,1.0223422E7,1.0394091E7,1.0637171E7,1.0705535E7,1.061274E7,1.0348684E7,1.0244684E7,1.0083313E7,9956108.0,147962.0,165110.0,182053.0,198676.0,209275.0,221823.0,233997.0,244676.0,259012.0,271192.0,288030.0,301931.0,3.72E8,4.09E8,4.54E8,5.06E8,5.67E8,6.34E8,7.08E8,7.88E8,8.72E8,9.59E8,1.034172547E9,1.110396331E9,8.2052E7,9.0124E7,9.9028E7,1.09343E8,1.21282E8,1.36725E8,1.53343E8,1.69276E8,1.84816E8,1.99278E8,2.1106E8,2.23547E8,1.7272E7,1.9792E7,2.2874E7,2.6538E7,3.0614E7,3.5480679E7,4.3072751E7,5.1889696E7,6.0397973E7,6.3327987E7,6.6907826E7,6.945357E7,5441766.0,6248643.0,7240260.0,8519282.0,1.0061506E7,1.1882916E7,1.4173318E7,1.6543189E7,1.7861905E7,2.0775703E7,2.4001816E7,2.7499638E7,2952156.0,2878220.0,2830000.0,2900100.0,3024400.0,3271900.0,3480000.0,3539900.0,3557761.0,3667233.0,3879155.0,4109086.0,1620914.0,1944401.0,2310904.0,2693585.0,3095893.0,3495918.0,3858421.0,4203148.0,4936550.0,5531387.0,6029529.0,6426679.0,4.7666E7,4.9182E7,5.08432E7,5.26671E7,5.4365564E7,5.6059245E7,5.6535636E7,5.6729703E7,5.6840847E7,5.7479469E7,5.7926999E7,5.8147733E7,1426095.0,1535090.0,1665128.0,1861096.0,1997616.0,2156814.0,2298309.0,2326606.0,2378618.0,2531311.0,2664659.0,2780132.0,8.6459025E7,9.1563009E7,9.5831757E7,1.00825279E8,1.07188273E8,1.13872473E8,1.18454974E8,1.22091325E8,1.24329269E8,1.25956499E8,1.27065841E8,1.27467972E8,607914.0,746559.0,933559.0,1255058.0,1613551.0,1937652.0,2347031.0,2820042.0,3867409.0,4526235.0,5307470.0,6053193.0,6464046.0,7454779.0,8678557.0,1.0191512E7,1.2044785E7,1.4500404E7,1.7661452E7,2.1198082E7,2.5020539E7,2.8263827E7,3.1386842E7,3.5610177E7,8865488.0,9411381.0,1.0917494E7,1.2617009E7,1.4781241E7,1.632532E7,1.7647518E7,1.9067554E7,2.0711375E7,2.1585105E7,2.2215365E7,2.3301725E7,2.0947571E7,2.2611552E7,2.6420307E7,3.0131E7,3.3505E7,3.6436E7,3.9326E7,4.1622E7,4.380545E7,4.6173816E7,4.796915E7,4.904479E7,160000.0,212846.0,358266.0,575003.0,841934.0,1140357.0,1497494.0,1891487.0,1418095.0,1765345.0,2111561.0,2505559.0,1439529.0,1647412.0,1886848.0,2186894.0,2680018.0,3115787.0,3086876.0,3089353.0,3219994.0,3430388.0,3677780.0,3921278.0,748747.0,813338.0,893143.0,996380.0,1116779.0,1251524.0,1411807.0,1599200.0,1803195.0,1982823.0,2046772.0,2012649.0,863308.0,975950.0,1112796.0,1279406.0,1482628.0,1703617.0,1956875.0,2269414.0,1912974.0,2200725.0,2814651.0,3193942.0,1019729.0,1201578.0,1441863.0,1759224.0,2183877.0,2721783.0,3344074.0,3799845.0,4364501.0,4759670.0,5368585.0,6036914.0,4762912.0,5181679.0,5703324.0,6334556.0,7082430.0,8007166.0,9171477.0,1.0568642E7,1.2210395E7,1.4165114E7,1.6473477E7,1.9167654E7,2917802.0,3221238.0,3628608.0,4147252.0,4730997.0,5637246.0,6502825.0,7824747.0,1.0014249E7,1.0419991E7,1.1824495E7,1.3327079E7,6748378.0,7739235.0,8906385.0,1.0154878E7,1.1441462E7,1.2845381E7,1.4441916E7,1.6331785E7,1.8319502E7,2.0476091E7,2.2662365E7,2.4821286E7,3838168.0,4241884.0,4690372.0,5212416.0,5828158.0,6491649.0,6998256.0,7634008.0,8416215.0,9384984.0,1.0580176E7,1.2031795E7,1022556.0,1076852.0,1146757.0,1230542.0,1332786.0,1456688.0,1622136.0,1841240.0,2119465.0,2444741.0,2828858.0,3270065.0,516556.0,609816.0,701016.0,789309.0,851334.0,913025.0,992040.0,1042663.0,1096202.0,1149818.0,1200206.0,1250882.0,3.0144317E7,3.5015548E7,4.1121485E7,4.7995559E7,5.5984294E7,6.3759976E7,7.1640904E7,8.0122492E7,8.811103E7,9.5895146E7,1.02479927E8,1.08700891E8,800663.0,882134.0,1010280.0,1149500.0,1320500.0,1528000.0,1756032.0,2015133.0,2312802.0,2494803.0,2674234.0,2874127.0,413834.0,442829.0,474528.0,501035.0,527678.0,560073.0,562548.0,569473.0,621621.0,692651.0,720230.0,684736.0,9939217.0,1.140635E7,1.3056604E7,1.4770296E7,1.666067E7,1.8396941E7,2.019873E7,2.2987397E7,2.5798239E7,2.8529501E7,3.1167783E7,3.3757175E7,6446316.0,7038035.0,7788944.0,8680909.0,9809596.0,1.1127868E7,1.2587223E7,1.2891952E7,1.3160731E7,1.6603334E7,1.847378E7,1.9951656E7,2.0092996E7,2.1731844E7,2.3634436E7,2.5870271E7,2.846639E7,3.1528087E7,3.4680442E7,3.8028578E7,4.0546538E7,4.3247867E7,4.5598081E7,4.776198E7,485831.0,548080.0,621392.0,706640.0,821782.0,977026.0,1099010.0,1278184.0,1554253.0,1774766.0,1972153.0,2055080.0,9182536.0,9682338.0,1.0332057E7,1.126169E7,1.2412593E7,1.3933198E7,1.5796314E7,1.791718E7,2.0326209E7,2.3001113E7,2.5873917E7,2.890179E7,1.0381988E7,1.1026383E7,1.1805689E7,1.2596822E7,1.3329874E7,1.3852989E7,1.4310401E7,1.4665278E7,1.5174244E7,1.5604464E7,1.612283E7,1.6570613E7,1994794.0,2229407.0,2488550.0,2728150.0,2929100.0,3164900.0,3210650.0,3317166.0,3437674.0,3676187.0,3908037.0,4115771.0,1165790.0,1358828.0,1590597.0,1865490.0,2182908.0,2554598.0,2979423.0,3344353.0,4017939.0,4609572.0,5146848.0,5675356.0,3379468.0,3692184.0,4076008.0,4534062.0,5060262.0,5682086.0,6437188.0,7332638.0,8392818.0,9666252.0,1.1140655E7,1.2894865E7,3.3119096E7,3.717334E7,4.1871351E7,4.7287752E7,5.3740085E7,6.2209173E7,7.3039376E7,8.155152E7,9.3364244E7,1.06207839E8,1.19901274E8,1.35031164E8,3327728.0,3491938.0,3638919.0,3786019.0,3933004.0,4043205.0,4114787.0,4186147.0,4286357.0,4405672.0,4535591.0,4627926.0,507833.0,561977.0,628164.0,714775.0,829050.0,1004533.0,1301048.0,1593882.0,1915208.0,2283635.0,2713462.0,3204897.0,4.134656E7,4.6679944E7,5.3100671E7,6.0641899E7,6.9325921E7,7.8152686E7,9.1462088E7,1.05186881E8,1.20065004E8,1.35564834E8,1.53403524E8,1.69270617E8,940080.0,1063506.0,1215725.0,1405486.0,1616384.0,1839782.0,2036305.0,2253639.0,2484997.0,2734531.0,2990875.0,3242173.0,1555876.0,1770902.0,2009813.0,2287985.0,2614104.0,2984494.0,3366439.0,3886512.0,4483945.0,5154123.0,5884491.0,6667147.0,8025700.0,9146100.0,1.05165E7,1.21322E7,1.39547E7,1.5990099E7,1.8125129E7,2.0195924E7,2.2430449E7,2.4748122E7,2.6769436E7,2.8674757E7,2.2438691E7,2.6072194E7,3.0325264E7,3.53566E7,4.0850141E7,4.6850962E7,5.3456774E7,6.0017788E7,6.7185766E7,7.5012988E7,8.2995088E7,9.1077287E7,2.5730551E7,2.8235346E7,3.0329617E7,3.1785378E7,3.3039545E7,3.4621254E7,3.6227381E7,3.774071E7,3.8370697E7,3.8654957E7,3.8625976E7,3.8518241E7,8526050.0,8817650.0,9019800.0,9103000.0,8970450.0,9662600.0,9859650.0,9915289.0,9927680.0,1.0156415E7,1.0433867E7,1.0642836E7,2227000.0,2260000.0,2448046.0,2648961.0,2847132.0,3080828.0,3279001.0,3444468.0,3585176.0,3759430.0,3859606.0,3942491.0,257700.0,308700.0,358900.0,414024.0,461633.0,492095.0,517810.0,562035.0,622191.0,684810.0,743981.0,798094.0,1.663E7,1.7829327E7,1.8680721E7,1.9284814E7,2.0662648E7,2.1658597E7,2.2356726E7,2.2686371E7,2.2797027E7,2.2562458E7,2.2404337E7,2.2276056E7,2534927.0,2822082.0,3051242.0,3451079.0,3992121.0,4657072.0,5507565.0,6349365.0,7290203.0,7212583.0,7852401.0,8860588.0,60011.0,61325.0,65345.0,70787.0,76595.0,86796.0,98593.0,110812.0,125911.0,145608.0,170372.0,199579.0,4005677.0,4419650.0,4943029.0,5618198.0,6472756.0,8128505.0,1.1254672E7,1.4619745E7,1.6945857E7,2.1229759E7,2.450153E7,2.7601038E7,2755589.0,3054547.0,3430243.0,3965841.0,4588696.0,5260855.0,6147783.0,7171347.0,8307920.0,9535314.0,1.0870037E7,1.2267493E7,6860147.0,7271135.0,7616060.0,7971222.0,8313288.0,8686367.0,9032824.0,9230783.0,9826397.0,1.0336594E7,1.0111559E7,1.0150265E7,2143249.0,2295678.0,2467895.0,2662190.0,2879013.0,3140897.0,3464522.0,3868905.0,4260884.0,4578212.0,5359092.0,6144562.0,1127000.0,1445929.0,1750200.0,1977600.0,2152400.0,2325300.0,2651869.0,2794552.0,3235865.0,3802309.0,4197776.0,4553009.0,3558137.0,3844277.0,4237384.0,4442238.0,4593433.0,4827803.0,5048043.0,5199318.0,5302888.0,5383010.0,5410052.0,5447502.0,1489518.0,1533070.0,1582962.0,1646912.0,1694510.0,1746919.0,1861252.0,1945870.0,1999210.0,2011612.0,2011497.0,2009245.0,2526994.0,2780415.0,3080153.0,3428839.0,3840161.0,4353666.0,5828892.0,6921858.0,6099799.0,6633514.0,7753310.0,9118773.0,1.4264935E7,1.6151549E7,1.8356657E7,2.0997321E7,2.393581E7,2.7129932E7,3.1140029E7,3.5933379E7,3.9964159E7,4.2835005E7,4.4433622E7,4.3997828E7,2.854987E7,2.9841614E7,3.1158061E7,3.2850275E7,3.4513161E7,3.6439E7,3.798331E7,3.8880702E7,3.9549438E7,3.9855442E7,4.0152517E7,4.0448191E7,7982342.0,9128546.0,1.0421936E7,1.1737396E7,1.3016733E7,1.4116836E7,1.5410151E7,1.6495304E7,1.758706E7,1.8698655E7,1.9576783E7,2.0378239E7,8504667.0,9753392.0,1.1183227E7,1.2716129E7,1.4597019E7,1.7104986E7,2.0367053E7,2.472596E7,2.8227588E7,3.2160729E7,3.7090298E7,4.2292929E7,290243.0,326741.0,370006.0,420690.0,480105.0,551425.0,649901.0,779348.0,962344.0,1054486.0,1130269.0,1133066.0,7124673.0,7363802.0,7561588.0,7867931.0,8122293.0,8251648.0,8325260.0,8421403.0,8718867.0,8897619.0,8954175.0,9031088.0,4815000.0,5126000.0,5666000.0,6063000.0,6401400.0,6316424.0,6468126.0,6649942.0,6995447.0,7193761.0,7361757.0,7554661.0,3661549.0,4149908.0,4834621.0,5680812.0,6701172.0,7932503.0,9410494.0,1.1242847E7,1.3219062E7,1.5081016E7,1.7155814E7,1.9314747E7,8550362.0,1.0164215E7,1.1918938E7,1.3648692E7,1.5226039E7,1.6785196E7,1.850139E7,1.9757799E7,2.0686918E7,2.1628605E7,2.2454239E7,2.3174294E7,8322925.0,9452826.0,1.0863958E7,1.2607312E7,1.4706593E7,1.7129565E7,1.9844382E7,2.304063E7,2.6605473E7,3.0686889E7,3.4593779E7,3.813964E7,2.1289402E7,2.5041917E7,2.9263397E7,3.4024249E7,3.9276153E7,4.4148285E7,4.882716E7,5.2910342E7,5.6667095E7,6.0216677E7,6.2806748E7,6.5068149E7,1219113.0,1357445.0,1528098.0,1735550.0,2056351.0,2308582.0,2644765.0,3154264.0,3747553.0,4320890.0,4977378.0,5701579.0,662850.0,764900.0,887498.0,960155.0,975199.0,1039009.0,1116479.0,1191336.0,1183669.0,1138101.0,1101832.0,1056608.0,3647735.0,3950849.0,4286552.0,4786986.0,5303507.0,6005061.0,6734098.0,7724976.0,8523077.0,9231669.0,9770575.0,1.0276158E7,2.2235677E7,2.5670939E7,2.9788695E7,3.3411317E7,3.7492953E7,4.2404033E7,4.7328791E7,5.2881328E7,5.8179144E7,6.3047647E7,6.7308928E7,7.1158647E7,5824797.0,6675501.0,7688797.0,8900294.0,1.0190285E7,1.1457758E7,1.29394E7,1.528305E7,1.825219E7,2.1210254E7,2.4739869E7,2.9170398E7,5.043E7,5.143E7,5.3292E7,5.4959E7,5.6079E7,5.6179E7,5.6339704E7,5.698162E7,5.7866349E7,5.8808266E7,5.9912431E7,6.0776238E7,1.57553E8,1.71984E8,1.86538E8,1.98712E8,2.09896E8,2.20239E8,2.32187835E8,2.42803533E8,2.56894189E8,2.7291176E8,2.87675526E8,3.01139947E8,2252965.0,2424959.0,2598466.0,2748579.0,2829526.0,2873520.0,2953997.0,3045153.0,3149262.0,3262838.0,3363085.0,3447496.0,5439568.0,6702668.0,8143375.0,9709552.0,1.1515649E7,1.3503563E7,1.5620766E7,1.7910182E7,2.0265563E7,2.2374398E7,2.428767E7,2.6084662E7,2.6246839E7,2.8998543E7,3.379614E7,3.946391E7,4.4655014E7,5.0533506E7,5.6142181E7,6.2826491E7,6.9940728E7,7.6048996E7,8.0908147E7,8.5262356E7,1030585.0,1070439.0,1133134.0,1142636.0,1089572.0,1261091.0,1425876.0,1691210.0,2104779.0,2826046.0,3389578.0,4018332.0,4963829.0,5498090.0,6120081.0,6740785.0,7407075.0,8403990.0,9657618.0,1.121934E7,1.3367997E7,1.5826497E7,1.8701257E7,2.2211743E7,2672000.0,3016000.0,3421000.0,3900000.0,4506497.0,5216550.0,6100407.0,7272406.0,8381163.0,9417789.0,1.0595811E7,1.1746035E7,3080907.0,3646340.0,4277736.0,4995432.0,5861135.0,6642107.0,7636524.0,9216418.0,1.070434E7,1.1404948E7,1.1926563E7,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,820.8530296,853.10071,836.1971382,739.9811058,786.11336,978.0114388,852.3959448,649.3413952,635.341351,726.7340548,974.5803384,1601.056136,1942.284244,2312.888958,2760.196931,3313.422188,3533.00391,3630.880722,3738.932735,2497.437901,3193.054604,4604.211737,5937.029526,2449.008185,3013.976023,2550.81688,3246.991771,4182.663766,4910.416756,5745.160213,5681.358539,5023.216647,4797.295051,5288.040382,6223.367465,3520.610273,3827.940465,4269.276742,5522.776375,5473.288005,3008.647355,2756.953672,2430.208311,2627.845685,2277.140884,2773.287312,4797.231267,5911.315053,6856.856212,7133.166023,8052.953021,9443.038526,10079.02674,8997.897412,9139.671389,9308.41871,10967.28195,8797.640716,12779.37964,10039.59564,10949.64959,12217.22686,14526.12465,16788.62948,18334.19751,19477.00928,21888.88903,23424.76683,26997.93657,30687.75473,34435.36744,6137.076492,8842.59803,10750.72111,12834.6024,16661.6256,19749.4223,21597.08362,23687.82607,27042.01868,29095.92066,32417.60769,36126.4927,9867.084765,11635.79945,12753.27514,14804.6727,18268.65839,19340.10196,19211.14731,18524.02406,19035.57917,20292.01679,23403.55927,29796.04834,684.2441716,661.6374577,686.3415538,721.1860862,630.2336265,659.8772322,676.9818656,751.9794035,837.8101643,972.7700352,1136.39043,1391.253792,8343.105127,9714.960623,10991.20676,13149.04119,16672.14356,19117.97448,20979.84589,22525.56308,25575.57069,27561.19663,30485.88375,33692.60508,1062.7522,959.6010805,949.4990641,1035.831411,1085.796879,1029.161251,1277.897616,1225.85601,1191.207681,1232.975292,1372.877931,1441.284873,2677.326347,2127.686326,2180.972546,2586.886053,2980.331339,3548.097832,3156.510452,2753.69149,2961.699694,3326.143191,3413.26269,3822.137084,973.5331948,1353.989176,1709.683679,2172.352423,2860.16975,3528.481305,4126.613157,4314.114757,2546.781445,4766.355904,6018.975239,7446.298803,851.2411407,918.2325349,983.6539764,1214.709294,2263.611114,3214.857818,4551.14215,6205.88385,7954.111645,8647.142313,11003.60508,12569.85177,2108.944355,2487.365989,3336.585802,3429.864357,4985.711467,6660.118654,7030.835878,7807.095818,6950.283021,7957.980824,8131.212843,9065.800825,2444.286648,3008.670727,4254.337839,5577.0028,6597.494398,7612.240438,8224.191647,8239.854824,6302.623438,5970.38876,7696.777725,10680.79282,543.2552413,617.1834648,722.5120206,794.8265597,854.7359763,743.3870368,807.1985855,912.0631417,931.7527731,946.2949618,1037.645221,1217.032994,339.2964587,379.5646281,355.2032273,412.9775136,464.0995039,556.1032651,559.603231,621.8188189,631.6998778,463.1151478,446.4035126,430.0706916,368.4692856,434.0383364,496.9136476,523.4323142,421.6240257,524.9721832,624.4754784,683.8955732,682.3031755,734.28517,896.2260153,1713.778686,1172.667655,1313.048099,1399.607441,1508.453148,1684.146528,1783.432873,2367.983282,2602.664206,1793.163278,1694.337469,1934.011449,2042.09524,11367.16112,12489.95006,13462.48555,16076.58803,18970.57086,22090.88306,22898.79214,26626.51503,26342.88426,28954.92589,33328.96507,36319.23501,1071.310713,1190.844328,1193.068753,1136.056615,1070.013275,1109.374338,956.7529907,844.8763504,747.9055252,740.5063317,738.6906068,706.016537,1178.665927,1308.495577,1389.817618,1196.810565,1104.103987,1133.98495,797.9081006,952.386129,1058.0643,1004.961353,1156.18186,1704.063724,3939.978789,4315.622723,4519.094331,5106.654313,5494.024437,4756.763836,5095.665738,5547.063754,7596.125964,10118.05318,10778.78385,13171.63885,400.448611,575.9870009,487.6740183,612.7056934,676.9000921,741.2374699,962.4213805,1378.904018,1655.784158,2289.234136,3119.280896,4959.114854,2144.115096,2323.805581,2492.351109,2678.729839,3264.660041,3815.80787,4397.575659,4903.2191,5444.648617,6117.361746,5755.259962,7006.580419,1102.990936,1211.148548,1406.648278,1876.029643,1937.577675,1172.603047,1267.100083,1315.980812,1246.90737,1173.618235,1075.811558,986.1478792,780.5423257,905.8602303,896.3146335,861.5932424,904.8960685,795.757282,673.7478181,672.774812,457.7191807,312.188423,241.1658765,277.5518587,2125.621418,2315.056572,2464.783157,2677.939642,3213.152683,3259.178978,4879.507522,4201.194937,4016.239529,3484.164376,3484.06197,3632.557798,2627.009471,2990.010802,3460.937025,4161.727834,5118.146939,5926.876967,5262.734751,5629.915318,6160.416317,6677.045314,7723.447195,9645.06142,1388.594732,1500.895925,1728.869428,2052.050473,2378.201111,2517.736547,2602.710169,2156.956069,1648.073791,1786.265407,1648.800823,1544.750112,3119.23652,4338.231617,5477.890018,6960.297861,9164.090127,11305.38517,13221.82184,13822.58394,8447.794873,9875.604515,11628.38895,14619.22272,5586.53878,6092.174359,5180.75591,5690.268015,5305.445256,6380.494966,7316.918107,7532.924763,5592.843963,5431.990415,6340.646683,8948.102923,6876.14025,8256.343918,10136.86713,11399.44489,13108.4536,14800.16062,15377.22855,16310.4434,14297.02122,16048.51424,17596.21022,22833.30851,9692.385245,11099.65935,13583.31351,15937.21123,18866.20721,20422.9015,21688.04048,25116.17581,26406.73985,29804.34567,32166.50006,35278.41874,2669.529475,2864.969076,3020.989263,3020.050513,3694.212352,3081.761022,2879.468067,2880.102568,2377.156192,1895.016984,1908.260867,2082.481567,1397.717137,1544.402995,1662.137359,1653.723003,2189.874499,2681.9889,2861.092386,2899.842175,3044.214214,3614.101285,4563.808154,6025.374752,3522.110717,3780.546651,4086.114078,4579.074215,5280.99471,6679.62326,7213.791267,6481.776993,7103.702595,7429.455877,5773.044512,6873.262326,1418.822445,1458.915272,1693.335853,1814.880728,2024.008147,2785.493582,3503.729636,3885.46071,3794.755195,4173.181797,4754.604414,5581.180998,3048.3029,3421.523218,3776.803627,4358.595393,4520.246008,5138.922374,4098.344175,4140.442097,4444.2317,5154.825496,5351.568666,5728.353514,375.6431231,426.0964081,582.8419714,915.5960025,672.4122571,958.5668124,927.8253427,966.8968149,1132.055034,2814.480755,7703.4959,12154.08975,328.9405571,344.1618859,380.9958433,468.7949699,514.3242082,505.7538077,524.8758493,521.1341333,582.8585102,913.47079,765.3500015,641.3695236,362.1462796,378.9041632,419.4564161,516.1186438,566.2439442,556.8083834,577.8607471,573.7413142,421.3534653,515.8894013,530.0535319,690.8055759,6424.519071,7545.415386,9371.842561,10921.63626,14358.8759,15605.42283,18533.15761,21141.01223,20647.16499,23723.9502,28204.59057,33207.0844,7029.809327,8662.834898,10560.48553,12999.91766,16107.19171,18292.63514,20293.89746,22066.44214,24703.79615,25889.78487,28926.03234,30470.0167,4293.476475,4976.198099,6631.459222,8358.761987,11401.94841,21745.57328,15113.36194,11864.40844,13522.15752,14722.84188,12521.71392,13206.48452,485.2306591,520.9267111,599.650276,734.7829124,756.0868363,884.7552507,835.8096108,611.6588611,665.6244126,653.7301704,660.5855997,752.7497265,7144.114393,10187.82665,12902.46291,14745.62561,18016.18027,20512.92123,22031.53274,24639.18566,26505.30317,27788.88416,30035.80198,32170.37442,911.2989371,1043.561537,1190.041118,1125.69716,1178.223708,993.2239571,876.032569,847.0061135,925.060154,1005.245812,1111.984578,1327.60891,3530.690067,4916.299889,6017.190733,8513.097016,12724.82957,14195.52428,15268.42089,16120.52839,17541.49634,18747.69814,22514.2548,27538.41188,2428.237769,2617.155967,2750.364446,3242.531147,4031.408271,4879.992748,4820.49479,4246.485974,4439.45084,4684.313807,4858.347495,5186.050003,510.1964923,576.2670245,686.3736739,708.7595409,741.6662307,874.6858643,857.2503577,805.5724718,794.3484384,869.4497668,945.5835837,942.6542111,299.850319,431.7904566,522.0343725,715.5806402,820.2245876,764.7259628,838.1239671,736.4153921,745.5398706,796.6644681,575.7047176,579.231743,1840.366939,1726.887882,1796.589032,1452.057666,1654.456946,1874.298931,2011.159549,1823.015995,1456.309517,1341.726931,1270.364932,1201.637154,2194.926204,2220.487682,2291.156835,2538.269358,2529.842345,3203.208066,3121.760794,3023.096699,3081.694603,3160.454906,3099.72866,3548.330846,3054.421209,3629.076457,4692.648272,6197.962814,8315.928145,11186.14125,14560.53051,20038.47269,24757.60301,28377.63219,30209.01516,39724.97867,5263.673816,6040.180011,7550.359877,9326.64467,10168.65611,11674.83737,12545.99066,12986.47998,10535.62855,11712.7768,14843.93556,18008.94444,7267.688428,9244.001412,10350.15906,13319.89568,15798.06362,19654.96247,23269.6075,26923.20628,25144.39201,28061.09966,31163.20196,36180.78919,546.5657493,590.061996,658.3471509,700.7706107,724.032527,813.337323,855.7235377,976.5126756,1164.406809,1458.817442,1746.769454,2452.210407,749.6816546,858.9002707,849.2897701,762.4317721,1111.107907,1382.702056,1516.872988,1748.356961,2383.140898,3119.335603,2873.91287,3540.651564,3035.326002,3290.257643,4187.329802,5906.731805,9613.818607,11888.59508,7608.334602,6642.881371,7235.653188,8263.590301,9240.761975,11605.71449,4129.766056,6229.333562,8341.737815,8931.459811,9576.037596,14688.23507,14517.90711,11643.57268,3745.640687,3076.239795,4390.717312,4471.061906,5210.280328,5599.077872,6631.597314,7655.568963,9530.772896,11150.98113,12618.32141,13872.86652,17558.81555,24521.94713,34077.04939,40675.99635,4086.522128,5385.278451,7105.630706,8393.741404,12786.93223,13306.61921,15367.0292,17122.47986,18051.52254,20896.60924,21905.59514,25523.2771,4931.404155,6248.656232,8243.58234,10022.40131,12269.27378,14255.98475,16537.4835,19207.23482,22013.64486,24675.02446,27968.09817,28569.7197,2898.530881,4756.525781,5246.107524,6124.703451,7433.889293,6650.195573,6068.05135,6351.237495,7404.923685,7121.924704,6994.774861,7320.880262,3216.956347,4317.694365,6576.649461,9847.788607,14778.78636,16610.37701,19384.10571,22375.94189,26824.89511,28816.58499,28604.5919,31656.06806,1546.907807,1886.080591,2348.009158,2741.796252,2110.856309,2852.351568,4161.415959,4448.679912,3431.593647,3645.379572,3844.917194,4519.461171,853.540919,944.4383152,896.9663732,1056.736457,1222.359968,1267.613204,1348.225791,1361.936856,1341.921721,1360.485021,1287.514732,1463.249282,1088.277758,1571.134655,1621.693598,2143.540609,3701.621503,4106.301249,4106.525293,4106.492315,3726.063507,1690.756814,1646.758151,1593.06548,1030.592226,1487.593537,1536.344387,2029.228142,3030.87665,4657.22102,5622.942464,8533.088805,12104.27872,15993.52796,19233.98818,23348.13973,108382.3529,113523.1329,95458.11176,80894.88326,109347.867,59265.47714,31354.03573,28118.42998,34932.91959,40300.61996,35110.10566,47306.98978,4834.804067,6089.786934,5714.560611,6006.983042,7486.384341,8659.696836,7640.519521,5377.091329,6890.806854,8754.96385,9313.93883,10461.05868,298.8462121,335.9971151,411.8006266,498.6390265,496.5815922,745.3695408,797.2631074,773.9932141,977.4862725,1186.147994,1275.184575,1569.331442,575.5729961,620.9699901,634.1951625,713.6036483,803.0054535,640.3224383,572.1995694,506.1138573,636.6229191,609.1739508,531.4823679,414.5073415,2387.54806,3448.284395,6757.030816,18772.75169,21011.49721,21951.21176,17364.27538,11770.5898,9640.138501,9467.446056,9534.677467,12057.49928,1443.011715,1589.20275,1643.38711,1634.047282,1748.562982,1544.228586,1302.878658,1155.441948,1040.67619,986.2958956,894.6370822,1044.770126,369.1650802,416.3698064,427.9010856,495.5147806,584.6219709,663.2236766,632.8039209,635.5173634,563.2000145,692.2758103,665.4231186,759.3499101,1831.132894,1810.066992,2036.884944,2277.742396,2849.09478,3827.921571,4920.355951,5249.802653,7277.912802,10132.90964,10206.97794,12451.6558,452.3369807,490.3821867,496.1743428,545.0098873,581.3688761,686.3952693,618.0140641,684.1715576,739.014375,790.2579846,951.4097518,1042.581557,743.1159097,846.1202613,1055.896036,1421.145193,1586.851781,1497.492223,1481.150189,1421.603576,1361.369784,1483.136136,1579.019543,1803.151496,1967.955707,2034.037981,2529.067487,2475.387562,2575.484158,3710.982963,3688.037739,4783.586903,6058.253846,7425.705295,9021.815894,10956.99112,3478.125529,4131.546641,4581.609385,5754.733883,6809.40669,7674.929108,9611.147541,8688.156003,9472.384295,9767.29753,10742.44053,11977.57496,786.5668575,912.6626085,1056.353958,1226.04113,1421.741975,1647.511665,2000.603139,2338.008304,1785.402016,1902.2521,2140.739323,3095.772271,2647.585601,3682.259903,4649.593785,5907.850937,7778.414017,9595.929905,11222.58762,11732.51017,7003.339037,6465.613349,6557.194282,9253.896111,1688.20357,1642.002314,1566.353493,1711.04477,1930.194975,2370.619976,2702.620356,2755.046991,2948.047252,2982.101858,3258.495584,3820.17523,468.5260381,495.5868333,556.6863539,566.6691539,724.9178037,502.3197334,462.2114149,389.8761846,410.8968239,472.3460771,633.6179466,823.6856205,331.0,350.0,388.0,349.0,357.0,371.0,424.0,385.0,347.0,415.0,611.0,944.0,2423.780443,2621.448058,3173.215595,3793.694753,3746.080948,3876.485958,4191.100511,3693.731337,3804.537999,3899.52426,4072.324751,4811.060429,545.8657229,597.9363558,652.3968593,676.4422254,674.7881296,694.1124398,718.3730947,775.6324501,897.7403604,1010.892138,1057.206311,1091.359778,8941.571858,11276.19344,12790.84956,15363.25136,18794.74567,21209.0592,21399.46046,23651.32361,26790.94961,30246.13063,33724.75778,36797.93332,10556.57566,12247.39532,13175.678,14463.91893,16046.03728,16233.7177,17632.4104,19007.19129,18363.32494,21050.41377,23189.80135,25185.00911,3112.363948,3457.415947,3634.364406,4643.393534,4688.593267,5486.371089,3470.338156,2955.984375,2170.151724,2253.023004,2474.548819,2749.320965,761.879376,835.5234025,997.7661127,1054.384891,954.2092363,808.8970728,909.7221354,668.3000228,581.182725,580.3052092,601.0745012,619.6768924,1077.281856,1100.592563,1150.927478,1014.514104,1698.388838,1981.951806,1576.97375,1385.029563,1619.848217,1624.941275,1615.286395,2013.977305,10095.42172,11653.97304,13450.40151,16361.87647,18965.05551,23311.34939,26298.63531,31540.9748,33965.66115,41283.16433,44683.97525,49357.19017,1828.230307,2242.746551,2924.638113,4720.942687,10618.03855,11848.34392,12954.79101,18115.22313,18616.70691,19702.05581,19774.83687,22316.19287,684.5971438,747.0835292,803.3427418,942.4082588,1049.938981,1175.921193,1443.429832,1704.686583,1971.829464,2049.350521,2092.712441,2605.94758,2480.380334,2961.800905,3536.540301,4421.009084,5364.249663,5351.912144,7009.601598,7034.779161,6618.74305,7113.692252,7356.031934,9809.185636,1952.308701,2046.154706,2148.027146,2299.376311,2523.337977,3248.373311,4258.503604,3998.875695,4196.411078,4247.400261,3783.674243,4172.838464,3758.523437,4245.256698,4957.037982,5788.09333,5937.827283,6281.290855,6434.501797,6360.943444,4446.380924,5838.347657,5909.020073,7408.905561,1272.880995,1547.944844,1649.552153,1814.12743,1989.37407,2373.204287,2603.273765,2189.634995,2279.324017,2536.534925,2650.921068,3190.481016,4029.329699,4734.253019,5338.752143,6557.152776,8006.506993,9508.141454,8451.531004,9082.351172,7738.881247,10159.58368,12002.23908,15389.92468,3068.319867,3774.571743,4727.954889,6361.517993,9022.247417,10172.48572,11753.84291,13039.30876,16207.26663,17641.03156,19970.90787,20509.64777,3081.959785,3907.156189,5108.34463,6929.277714,9123.041742,9770.524921,10330.98915,12281.34191,14641.58711,16999.4333,18855.60618,19328.70901,2718.885295,2769.451844,3173.72334,4021.175739,5047.658563,4319.804067,5267.219353,5303.377488,6101.255823,6071.941411,6316.1652,7670.122558,3144.613186,3943.370225,4734.997586,6470.866545,8011.414402,9356.39724,9605.314053,9696.273295,6598.409903,7346.547557,7885.360081,10808.47561,493.3238752,540.2893983,597.4730727,510.9637142,590.5806638,670.0806011,881.5706467,847.991217,737.0685949,589.9445051,785.6537648,863.0884639,879.5835855,860.7369026,1071.551119,1384.840593,1532.985254,1737.561657,1890.218117,1516.525457,1428.777814,1339.076036,1353.09239,1598.435089,6459.554823,8157.591248,11626.41975,16903.04886,24837.42865,34167.7626,33693.17525,21198.26136,24841.61777,20586.69019,19014.54118,21654.83194,1450.356983,1567.653006,1654.988723,1612.404632,1597.712056,1561.769116,1518.479984,1441.72072,1367.899369,1392.368347,1519.635262,1712.472136,3581.459448,4981.090891,6289.629157,7991.707066,10522.06749,12980.66956,15181.0927,15870.87851,9325.068238,7914.320304,7236.075251,9786.534714,879.7877358,1004.484437,1116.639877,1206.043465,1353.759762,1348.285159,1465.010784,1294.447788,1068.696278,574.6481576,699.489713,862.5407561,2315.138227,2843.104409,3674.735572,4977.41854,8597.756202,11210.08948,15169.16112,18861.53081,24769.8912,33519.4766,36023.1054,47143.17964,5074.659104,6093.26298,7481.107598,8412.902397,9674.167626,10922.66404,11348.54585,12037.26758,9498.467723,12126.23065,13638.77837,18678.31435,4215.041741,5862.276629,7402.303395,9405.489397,12383.4862,15277.03017,17866.72175,18678.53492,14214.71681,17161.10735,20660.01936,25768.25759,1135.749842,1258.147413,1369.488336,1284.73318,1254.576127,1450.992513,1176.807031,1093.244963,926.9602964,930.5964284,882.0818218,926.1410683,4725.295531,5487.104219,5768.729717,7114.477971,7765.962636,8028.651439,8568.266228,7825.823398,7225.069258,7479.188244,7710.946444,9269.657808,3834.034742,4564.80241,5693.843879,7993.512294,10638.75131,13236.92117,13926.16997,15764.98313,18603.06452,20445.29896,24835.47166,28821.0637,1083.53203,1072.546602,1074.47196,1135.514326,1213.39553,1348.775651,1648.079789,1876.766827,2153.739222,2664.477257,3015.378833,3970.095407,1615.991129,1770.337074,1959.593767,1687.997641,1659.652775,2202.988423,1895.544073,1507.819159,1492.197043,1632.210764,1993.398314,2602.394995,1148.376626,1244.708364,1856.182125,2613.101665,3364.836625,3781.410618,3895.384018,3984.839812,3553.0224,3876.76846,4128.116943,4513.480643,8527.844662,9911.878226,12329.44192,15258.29697,17832.02464,18855.72521,20667.38125,23586.92927,23880.01683,25266.59499,29341.63093,33859.74835,14734.23275,17909.48973,20431.0927,22966.14432,27195.11304,26982.29052,28397.71512,30281.70459,31871.5303,32135.32301,34480.95771,37506.41907,1643.485354,2117.234893,2193.037133,1881.923632,2571.423014,3195.484582,3761.837715,3116.774285,3340.542768,4014.238972,4090.925331,4184.548089,1206.947913,1507.86129,1822.879028,2643.858681,4062.523897,5596.519826,7426.354774,11054.56175,15215.6579,20206.82098,23235.42329,28718.27684,716.6500721,698.5356073,722.0038073,848.2186575,915.9850592,962.4922932,874.2426069,831.8220794,825.682454,789.1862231,899.0742111,1107.482182,757.7974177,793.5774148,1002.199172,1295.46066,1524.358936,1961.224635,2393.219781,2982.653773,4616.896545,5852.625497,5913.187529,7458.396327,859.8086567,925.9083202,1067.53481,1477.59676,1649.660188,1532.776998,1344.577953,1202.201361,1034.298904,982.2869243,886.2205765,882.9699438,3023.271928,4100.3934,4997.523971,5621.368472,6619.551419,7899.554209,9119.528607,7388.597823,7370.990932,8792.573126,11460.60023,18008.50924,1468.475631,1395.232468,1660.30321,1932.360167,2753.285994,3120.876811,3560.233174,3810.419296,4332.720164,4876.798614,5722.895655,7092.923025,1969.10098,2218.754257,2322.869908,2826.356387,3450.69638,4269.122326,4241.356344,5089.043686,5678.348271,6601.429915,6508.085718,8458.276384,734.753484,774.3710692,767.2717398,908.9185217,950.735869,843.7331372,682.2662268,617.7244065,644.1707969,816.559081,927.7210018,1056.380121,9979.508487,11283.17795,12477.17707,14142.85089,15895.11641,17428.74846,18232.42452,21664.78767,22705.09254,26074.53136,29478.99919,33203.26128,13990.48208,14847.12712,16173.14586,19530.36557,21806.03594,24072.63213,25009.55914,29884.35041,32003.93224,35767.43303,39097.09955,42951.65309,5716.766744,6150.772969,5603.357717,5444.61962,5703.408898,6504.339663,6920.223051,7452.398969,8137.004775,9230.240708,7727.002004,10611.46299,7689.799761,9802.466526,8422.974165,9541.474188,10505.25966,13143.95095,11152.41011,9883.584648,10733.92631,10165.49518,8605.047831,11415.80569,605.0664917,676.2854478,772.0491602,637.1232887,699.5016441,713.5371196,707.2357863,820.7994449,989.0231487,1385.896769,1764.456677,2441.576404,1515.592329,1827.067742,2198.956312,2649.715007,3133.409277,3682.831494,4336.032082,5107.197384,6017.654756,7110.667619,4515.487575,3025.349798,781.7175761,804.8304547,825.6232006,862.4421463,1265.047031,1829.765177,1977.55701,1971.741538,1879.496673,2117.484526,2234.820827,2280.769906,1147.388831,1311.956766,1452.725766,1777.077318,1773.498265,1588.688299,1408.678565,1213.315116,1210.884633,1071.353818,1071.613938,1271.211593,406.8841148,518.7642681,527.2721818,569.7950712,799.3621758,685.5876821,788.8550411,706.1573059,693.4207856,792.4499603,672.0386227,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"breaks\":[1000.0,10000.0,25000.0,50000.0,100000.0],\n",
       "\"labels\":[\"$1K\",\"$10K\",\"$25K\",\"$50K\",\"$100K\"],\n",
       "\"trans\":\"log10\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"aC86Pc\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x1445c8cd0>"
      ]
     },
     "execution_count": 78,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                                x = 'gdpPercap', \n",
    "                                y = 'lifeExp', \n",
    "                                color = 'continent', \n",
    "                                size = 'pop')\n",
    "             ) +\n",
    "            #  add country name to hover\n",
    "        geom_point(alpha=0.5) +\n",
    "        scale_x_log10(\n",
    "            breaks = [1000, 10000, 25000, 50000, 100000],\n",
    "            labels = [f'${nz.numerize(x)}' for x in [1000, 10000, 25000, 50000, 100000]]\n",
    "            )\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Explore different themes"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's add on a theme and try changing it around to see what works best."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 79,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"fa6XQ2\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,30.332,31.997,34.02,36.088,38.438,39.854,40.822,41.674,41.763,42.129,43.828,55.23,59.28,64.82,66.22,67.69,68.93,70.42,72.0,71.581,72.95,75.651,76.423,43.077,45.685,48.303,51.407,54.518,58.014,61.368,65.799,67.744,69.152,70.994,72.301,30.015,31.999,34.0,35.985,37.928,39.483,39.942,39.906,40.647,40.963,41.003,42.731,62.485,64.399,65.142,65.634,67.065,68.481,69.942,70.774,71.868,73.275,74.34,75.32,69.12,70.33,70.93,71.1,71.93,73.49,74.74,76.32,77.56,78.83,80.37,81.235,66.8,67.48,69.54,70.14,70.63,72.17,73.18,74.94,76.04,77.51,78.98,79.829,50.939,53.832,56.923,59.923,63.3,65.593,69.052,70.75,72.601,73.925,74.795,75.635,37.484,39.348,41.216,43.453,45.252,46.923,50.009,52.819,56.018,59.412,62.013,64.062,68.0,69.24,70.25,70.94,71.44,72.8,73.93,75.35,76.46,77.53,78.32,79.441,38.223,40.358,42.618,44.885,47.014,49.19,50.904,52.337,53.919,54.777,54.406,56.728,40.414,41.89,43.428,45.032,46.714,50.023,53.859,57.251,59.957,62.05,63.883,65.554,53.82,58.45,61.93,64.79,67.45,69.86,70.69,71.14,72.178,73.244,74.09,74.852,47.622,49.618,51.52,53.298,56.024,59.319,61.484,63.622,62.745,52.556,46.634,50.728,50.917,53.285,55.665,57.632,59.504,61.489,63.336,65.205,67.057,69.388,71.006,72.39,59.6,66.61,69.51,70.42,70.9,70.81,71.08,71.34,71.19,70.32,72.14,73.005,31.975,34.906,37.814,40.697,43.591,46.137,48.122,49.557,50.26,50.324,50.65,52.295,39.031,40.533,42.045,43.548,44.057,45.91,47.471,48.211,44.736,45.326,47.36,49.58,39.417,41.366,43.415,45.415,40.317,31.22,50.957,53.914,55.803,56.534,56.752,59.723,38.523,40.428,42.643,44.799,47.049,49.355,52.961,54.985,54.314,52.199,49.856,50.43,68.75,69.96,71.3,72.13,72.88,74.21,75.76,76.86,77.95,78.61,79.77,80.653,35.463,37.464,39.475,41.478,43.457,46.775,48.295,50.485,49.396,46.066,43.308,44.741,38.092,39.881,41.716,43.601,45.569,47.383,49.517,51.051,51.724,51.573,50.525,50.651,54.745,56.074,57.924,60.523,63.441,67.052,70.565,72.492,74.126,75.816,77.86,78.553,44.0,50.54896,44.50136,58.38112,63.11888,63.96736,65.525,67.274,68.69,70.426,72.028,72.961,50.643,55.118,57.863,59.963,61.623,63.837,66.653,67.768,68.421,70.313,71.682,72.889,40.715,42.46,44.467,46.472,48.944,50.939,52.933,54.926,57.939,60.66,62.974,65.152,39.143,40.652,42.122,44.056,45.989,47.804,47.784,47.412,45.548,42.587,44.966,46.462,42.111,45.053,48.435,52.04,54.907,55.625,56.695,57.47,56.433,52.962,52.97,55.322,57.206,60.026,62.842,65.424,67.849,70.75,73.45,74.752,75.713,77.26,78.123,78.782,40.477,42.469,44.93,47.35,49.801,52.374,53.983,54.655,52.044,47.991,46.832,48.328,61.21,64.77,67.13,68.5,69.61,70.64,70.46,71.52,72.527,73.68,74.876,75.748,59.421,62.325,65.246,68.29,70.723,72.649,73.717,74.174,74.414,76.151,77.158,78.273,66.87,69.03,69.9,70.38,70.29,70.71,70.96,71.58,72.4,74.01,75.51,76.486,70.78,71.81,72.35,72.96,73.47,74.69,74.63,74.8,75.33,76.11,77.18,78.332,34.812,37.328,39.693,42.074,44.366,46.519,48.812,50.04,51.604,53.157,53.373,54.791,45.928,49.828,53.459,56.751,59.631,61.788,63.727,66.046,68.457,69.957,70.847,72.235,48.357,51.356,54.64,56.678,58.796,61.31,64.342,67.231,69.613,72.312,74.173,74.994,41.893,44.444,46.992,49.293,51.137,53.319,56.006,59.797,63.674,67.217,69.806,71.338,45.262,48.57,52.307,55.855,58.207,56.696,56.604,63.154,66.798,69.535,70.734,71.878,34.482,35.983,37.485,38.987,40.516,42.024,43.662,45.664,47.545,48.245,49.348,51.579,35.928,38.047,40.158,42.189,44.142,44.535,43.89,46.453,49.991,53.378,55.24,58.04,34.078,36.667,40.059,42.115,43.515,44.51,44.916,46.684,48.091,49.402,50.725,52.947,66.55,67.49,68.75,69.83,70.87,72.52,74.55,74.83,75.7,77.13,78.37,79.313,67.41,68.93,70.51,71.55,72.38,73.83,74.89,76.34,77.46,78.64,79.59,80.657,37.003,38.999,40.489,44.598,48.69,52.79,56.564,60.19,61.366,60.461,56.761,56.735,30.0,32.065,33.896,35.857,38.308,41.842,45.58,49.265,52.644,55.861,58.041,59.448,67.5,69.1,70.3,70.8,71.0,72.5,73.8,74.847,76.07,77.34,78.67,79.406,43.149,44.779,46.452,48.072,49.875,51.756,53.744,55.729,57.501,58.556,58.453,60.022,65.86,67.86,69.51,71.0,72.34,73.68,75.24,76.67,77.03,77.869,78.256,79.483,42.023,44.142,46.954,50.016,53.738,56.029,58.137,60.782,63.373,66.322,68.978,70.259,33.609,34.558,35.753,37.197,38.842,40.762,42.891,45.552,48.576,51.455,53.676,56.007,32.5,33.489,34.488,35.492,36.486,37.465,39.327,41.245,43.266,44.873,45.504,46.388,37.579,40.696,43.59,46.243,48.042,49.923,51.461,53.636,55.089,56.671,58.137,60.916,41.912,44.665,48.041,50.924,53.884,57.402,60.909,64.492,66.399,67.659,68.565,70.198,60.96,64.75,67.65,70.0,72.0,73.6,75.45,76.2,77.601,80.0,81.495,82.208,64.03,66.41,67.96,69.5,69.76,69.95,69.39,69.58,69.17,71.04,72.59,73.338,72.49,73.47,73.68,73.73,74.46,76.11,76.99,77.23,78.77,78.95,80.5,81.757,37.373,40.249,43.605,47.193,50.651,54.208,56.596,58.553,60.223,61.765,62.879,64.698,37.468,39.918,42.518,45.964,49.203,52.702,56.159,60.137,62.681,66.041,68.588,70.65,44.869,47.181,49.325,52.469,55.234,57.702,59.62,63.04,65.742,68.042,69.451,70.964,45.32,48.437,51.457,54.459,56.95,60.413,62.038,65.044,59.461,58.811,57.046,59.545,66.91,68.9,70.29,71.08,71.28,72.03,73.1,74.36,75.467,76.122,77.783,78.885,65.39,67.84,69.39,70.75,71.63,73.06,74.45,75.6,76.93,78.269,79.696,80.745,65.94,67.81,69.24,71.06,72.19,73.48,74.98,76.42,77.44,78.82,80.24,80.546,58.53,62.61,65.61,67.51,69.0,70.11,71.21,71.77,71.766,72.262,72.047,72.567,63.03,65.5,68.73,71.43,73.42,75.38,77.11,78.67,79.36,80.69,82.0,82.603,43.158,45.669,48.126,51.629,56.528,61.134,63.739,65.869,68.015,69.772,71.263,72.535,42.27,44.686,47.949,50.654,53.559,56.155,58.766,59.339,59.285,54.407,50.992,54.11,50.056,54.081,56.656,59.942,63.983,67.159,69.1,70.647,69.978,67.727,66.662,67.297,47.453,52.681,55.292,57.716,62.612,64.766,67.123,69.81,72.244,74.647,77.045,78.623,55.565,58.033,60.47,64.624,67.712,69.343,71.309,74.174,75.19,76.156,76.904,77.588,55.928,59.489,62.094,63.87,65.421,66.099,66.983,67.926,69.292,70.265,71.028,71.993,42.138,45.047,47.747,48.492,49.767,52.208,55.078,57.18,59.685,55.558,44.593,42.592,38.48,39.486,40.502,41.536,42.614,43.764,44.852,46.027,40.802,42.221,43.753,45.678,42.723,45.289,47.808,50.227,52.773,57.442,62.155,66.234,68.755,71.555,72.737,73.952,36.681,38.865,40.848,42.881,44.851,46.881,48.969,49.35,52.214,54.978,57.286,59.443,36.256,37.207,38.41,39.487,41.766,43.767,45.642,47.457,49.42,47.495,45.009,48.303,48.463,52.102,55.737,59.371,63.01,65.256,68.0,69.5,70.693,71.938,73.044,74.241,33.685,35.307,36.936,38.487,39.977,41.714,43.916,46.364,48.388,49.903,51.818,54.467,40.543,42.338,44.248,46.289,48.437,50.852,53.599,56.145,58.333,60.43,62.247,64.164,50.986,58.089,60.246,61.557,62.944,64.93,66.711,68.74,69.745,70.736,71.954,72.801,50.789,55.19,58.299,60.11,62.361,65.032,67.405,69.498,71.455,73.67,74.902,76.195,42.244,45.248,48.251,51.253,53.754,55.491,57.489,60.222,61.271,63.625,65.033,66.803,59.164,61.448,63.728,67.178,70.636,73.066,74.101,74.865,75.435,75.445,73.981,74.543,42.873,45.423,47.924,50.335,52.862,55.73,59.65,62.677,65.393,67.66,69.615,71.164,31.286,33.779,36.161,38.113,40.328,42.495,42.795,42.861,44.284,46.344,44.026,42.082,36.319,41.905,45.108,49.379,53.07,56.059,58.056,58.339,59.32,60.328,59.908,62.069,41.725,45.226,48.386,51.159,53.867,56.437,58.968,60.835,61.999,58.909,51.479,52.906,36.157,37.686,39.393,41.472,43.971,46.748,49.594,52.537,55.727,59.426,61.34,63.785,72.13,72.99,73.23,73.82,73.75,75.24,76.05,76.83,77.42,78.03,78.53,79.762,69.39,70.26,71.24,71.52,71.89,72.22,73.84,74.32,76.33,77.55,79.11,80.204,42.314,45.432,48.632,51.884,55.151,57.47,59.298,62.008,65.843,68.426,70.836,72.899,37.444,38.598,39.487,40.118,40.546,41.291,42.598,44.555,47.391,51.313,54.496,56.867,36.324,37.802,39.36,41.04,42.821,44.514,45.826,46.886,47.472,47.464,46.608,46.859,72.67,73.44,73.47,74.08,74.34,75.37,75.97,75.89,77.32,78.32,79.05,80.196,37.578,40.08,43.165,46.988,52.143,57.367,62.728,67.734,71.197,72.499,74.193,75.64,43.436,45.557,47.67,49.8,51.929,54.043,56.158,58.245,60.838,61.818,63.61,65.483,55.191,59.201,61.817,64.071,66.216,68.681,70.472,71.523,72.462,73.738,74.712,75.537,62.649,63.196,64.361,64.951,65.815,66.353,66.874,67.378,68.225,69.4,70.755,71.752,43.902,46.263,49.096,51.445,55.448,58.447,61.406,64.134,66.458,68.386,69.906,71.421,47.752,51.334,54.757,56.393,58.065,60.06,62.082,64.151,66.458,68.564,70.303,71.688,61.31,65.77,67.64,69.61,70.85,70.67,71.32,70.98,70.99,72.75,74.67,75.563,59.82,61.51,64.39,66.6,69.26,70.41,72.77,74.06,74.86,75.97,77.29,78.098,64.28,68.54,69.62,71.1,72.16,73.44,73.75,74.63,73.911,74.917,77.778,78.746,52.724,55.09,57.666,60.542,64.274,67.064,69.885,71.913,73.615,74.772,75.744,76.442,61.05,64.1,66.8,66.8,69.21,69.46,69.66,69.53,69.36,69.72,71.322,72.476,40.0,41.5,43.0,44.1,44.6,45.0,46.218,44.02,23.599,36.087,43.413,46.242,46.471,48.945,51.893,54.425,56.48,58.55,60.351,61.728,62.742,63.306,64.337,65.528,39.875,42.868,45.914,49.901,53.886,58.69,63.012,66.295,68.768,70.533,71.626,72.777,37.278,39.329,41.454,43.563,45.815,48.879,52.379,55.769,58.196,60.187,61.6,63.062,57.996,61.685,64.531,66.914,68.7,70.3,70.162,71.218,71.659,72.232,73.213,74.002,30.331,31.57,32.767,34.113,35.4,36.788,38.445,40.006,38.333,39.897,41.012,42.568,60.396,63.179,65.798,67.946,69.521,70.795,71.76,73.56,75.788,77.158,78.77,79.972,64.36,67.45,70.33,70.98,70.35,70.45,70.8,71.08,71.38,72.71,73.8,74.663,65.57,67.85,69.15,69.18,69.82,70.97,71.063,72.25,73.64,75.13,76.66,77.926,32.978,34.977,36.981,38.977,40.973,41.974,42.955,44.501,39.658,43.795,45.936,48.159,45.009,47.985,49.951,51.927,53.696,55.527,58.161,60.834,61.888,60.236,53.365,49.339,64.94,66.66,69.69,71.44,73.06,74.39,76.3,76.9,77.57,78.77,79.78,80.941,57.593,61.456,62.192,64.266,65.042,65.949,68.757,69.011,70.379,70.457,70.815,72.396,38.635,39.624,40.87,42.858,45.083,47.8,50.338,51.744,53.556,55.373,56.369,58.556,41.407,43.424,44.992,46.633,49.552,52.537,55.561,57.678,58.474,54.289,43.869,39.613,71.86,72.49,73.37,74.16,74.72,75.44,76.42,77.19,78.16,79.39,80.04,80.884,69.62,70.56,71.32,72.77,73.78,75.39,76.21,77.41,78.03,79.37,80.62,81.701,45.883,48.284,50.305,53.655,57.296,61.195,64.59,66.974,69.249,71.527,73.053,74.143,58.5,62.4,65.2,67.5,69.39,70.59,72.16,73.4,74.26,75.25,76.99,78.4,41.215,42.974,44.246,45.757,47.62,49.919,50.608,51.535,50.44,48.466,49.651,52.517,50.848,53.63,56.061,58.285,60.405,62.494,64.597,66.084,67.298,67.521,68.564,70.616,38.596,41.208,43.922,46.769,49.759,52.887,55.471,56.941,58.061,58.39,57.561,58.42,59.1,61.8,64.9,65.4,65.9,68.3,68.832,69.582,69.862,69.465,68.976,69.819,44.6,47.1,49.579,52.053,55.602,59.837,64.048,66.894,70.001,71.973,73.042,73.923,43.585,48.079,52.098,54.336,57.005,59.507,61.036,63.108,66.146,68.835,70.845,71.777,39.978,42.571,45.344,48.051,51.016,50.35,49.849,51.509,48.825,44.578,47.813,51.542,69.18,70.42,70.76,71.36,72.01,72.76,74.04,75.007,76.42,77.218,78.471,79.425,68.44,69.49,70.21,70.76,71.34,73.38,74.65,75.02,76.09,76.81,77.31,78.242,66.071,67.044,68.253,68.468,68.673,69.481,70.805,71.918,72.752,74.223,75.307,76.384,55.088,57.907,60.77,63.479,65.712,67.456,68.557,70.19,71.15,72.146,72.766,73.747,40.412,42.887,45.363,47.838,50.254,55.764,58.816,62.82,67.662,70.672,73.017,74.249,43.16,45.671,48.127,51.631,56.532,60.765,64.406,67.046,69.718,71.096,72.37,73.422,32.548,33.97,35.18,36.984,39.848,44.175,49.113,52.922,55.599,58.02,60.308,62.698,42.038,44.077,46.023,47.768,50.107,51.386,51.821,50.821,46.1,40.238,39.193,42.384,48.451,50.469,52.358,53.995,55.635,57.674,60.363,62.351,60.377,46.809,39.989,43.487],\n",
       "\"pop\":[8425333.0,9240934.0,1.0267083E7,1.1537966E7,1.307946E7,1.4880372E7,1.2881816E7,1.3867957E7,1.6317921E7,2.2227415E7,2.5268405E7,3.1889923E7,1282697.0,1476505.0,1728137.0,1984060.0,2263554.0,2509048.0,2780097.0,3075321.0,3326498.0,3428038.0,3508512.0,3600523.0,9279525.0,1.0270856E7,1.1000948E7,1.2760499E7,1.4760787E7,1.7152804E7,2.0033753E7,2.3254956E7,2.6298373E7,2.9072015E7,3.1287142E7,3.3333216E7,4232095.0,4561361.0,4826015.0,5247469.0,5894858.0,6162675.0,7016384.0,7874230.0,8735988.0,9875024.0,1.0866106E7,1.2420476E7,1.7876956E7,1.9610538E7,2.1283783E7,2.2934225E7,2.4779799E7,2.6983828E7,2.9341374E7,3.1620918E7,3.3958947E7,3.6203463E7,3.8331121E7,4.0301927E7,8691212.0,9712569.0,1.0794968E7,1.1872264E7,1.3177E7,1.40741E7,1.51842E7,1.6257249E7,1.7481977E7,1.8565243E7,1.9546792E7,2.0434176E7,6927772.0,6965860.0,7129864.0,7376998.0,7544201.0,7568430.0,7574613.0,7578903.0,7914969.0,8069876.0,8148312.0,8199783.0,120447.0,138655.0,171863.0,202182.0,230800.0,297410.0,377967.0,454612.0,529491.0,598561.0,656397.0,708573.0,4.6886859E7,5.1365468E7,5.6839289E7,6.2821884E7,7.0759295E7,8.0428306E7,9.3074406E7,1.03764241E8,1.13704579E8,1.23315288E8,1.3565679E8,1.50448339E8,8730405.0,8989111.0,9218400.0,9556500.0,9709100.0,9821800.0,9856303.0,9870200.0,1.0045622E7,1.0199787E7,1.031197E7,1.0392226E7,1738315.0,1925173.0,2151895.0,2427334.0,2761407.0,3168267.0,3641603.0,4243788.0,4981671.0,6066080.0,7026113.0,8078314.0,2883315.0,3211738.0,3593918.0,4040665.0,4565872.0,5079716.0,5642224.0,6156369.0,6893451.0,7693188.0,8445134.0,9119152.0,2791000.0,3076000.0,3349000.0,3585000.0,3819000.0,4086000.0,4172693.0,4338977.0,4256013.0,3607000.0,4165416.0,4552198.0,442308.0,474639.0,512764.0,553541.0,619351.0,781472.0,970347.0,1151184.0,1342614.0,1536536.0,1630347.0,1639131.0,5.660256E7,6.5551171E7,7.603939E7,8.8049823E7,1.00840058E8,1.14313951E8,1.28962939E8,1.42938076E8,1.55975974E8,1.68546719E8,1.79914212E8,1.90010647E8,7274900.0,7651254.0,8012946.0,8310226.0,8576200.0,8797022.0,8892098.0,8971958.0,8658506.0,8066057.0,7661799.0,7322858.0,4469979.0,4713416.0,4919632.0,5127935.0,5433886.0,5889574.0,6634596.0,7586551.0,8878303.0,1.0352843E7,1.2251209E7,1.4326203E7,2445618.0,2667518.0,2961915.0,3330989.0,3529983.0,3834415.0,4580410.0,5126023.0,5809236.0,6121610.0,7021078.0,8390505.0,4693836.0,5322536.0,6083619.0,6960067.0,7450606.0,6978607.0,7272485.0,8371791.0,1.0150094E7,1.1782962E7,1.2926707E7,1.4131858E7,5009067.0,5359923.0,5793633.0,6335506.0,7021028.0,7959865.0,9250831.0,1.0780667E7,1.2467171E7,1.4195809E7,1.5929988E7,1.7696293E7,1.4785584E7,1.7010154E7,1.8985849E7,2.0819767E7,2.22845E7,2.37964E7,2.52019E7,2.65497E7,2.8523502E7,3.0305843E7,3.1902268E7,3.3390141E7,1291695.0,1392284.0,1523478.0,1733638.0,1927260.0,2167533.0,2476971.0,2840009.0,3265124.0,3696513.0,4048013.0,4369038.0,2682462.0,2894855.0,3150417.0,3495967.0,3899068.0,4388260.0,4875118.0,5498955.0,6429417.0,7562011.0,8835739.0,1.0238807E7,6377619.0,7048426.0,7961258.0,8858908.0,9717524.0,1.0599793E7,1.1487112E7,1.2463354E7,1.3572994E7,1.4599929E7,1.5497046E7,1.6284741E7,5.56263527E8,6.37408E8,6.6577E8,7.5455E8,8.6203E8,9.43455E8,1.000281E9,1.084035E9,1.16497E9,1.230075E9,1.2804E9,1.318683096E9,1.2350771E7,1.4485993E7,1.7009885E7,1.9764027E7,2.254289E7,2.5094412E7,2.7764644E7,3.0964245E7,3.4202721E7,3.765783E7,4.1008227E7,4.422755E7,153936.0,170928.0,191689.0,217378.0,250027.0,304739.0,348643.0,395114.0,454429.0,527982.0,614382.0,710960.0,1.4100005E7,1.5577932E7,1.7486434E7,1.9941073E7,2.3007669E7,2.648087E7,3.0646495E7,3.5481645E7,4.1672143E7,4.7798986E7,5.5379852E7,6.4606759E7,854885.0,940458.0,1047924.0,1179760.0,1340458.0,1536769.0,1774735.0,2064095.0,2409073.0,2800947.0,3328795.0,3800610.0,926317.0,1112300.0,1345187.0,1588717.0,1834796.0,2108457.0,2424367.0,2799811.0,3173216.0,3518107.0,3834934.0,4133884.0,2977019.0,3300000.0,3832408.0,4744870.0,6071696.0,7459574.0,9025951.0,1.0761098E7,1.2772596E7,1.4625967E7,1.6252726E7,1.8013409E7,3882229.0,3991242.0,4076557.0,4174366.0,4225310.0,4318673.0,4413368.0,4484310.0,4494013.0,4444595.0,4481020.0,4493312.0,6007797.0,6640752.0,7254373.0,8139332.0,8831348.0,9537988.0,9789224.0,1.0239839E7,1.072326E7,1.0983007E7,1.1226999E7,1.1416987E7,9125183.0,9513758.0,9620282.0,9835109.0,9862158.0,1.0161915E7,1.0303704E7,1.0311597E7,1.0315702E7,1.0300707E7,1.0256295E7,1.0228744E7,4334000.0,4487831.0,4646899.0,4838800.0,4991596.0,5088419.0,5117810.0,5127024.0,5171393.0,5283663.0,5374693.0,5468120.0,63149.0,71851.0,89898.0,127617.0,178848.0,228694.0,305991.0,311025.0,384156.0,417908.0,447416.0,496374.0,2491346.0,2923186.0,3453434.0,4049146.0,4671329.0,5302800.0,5968349.0,6655297.0,7351181.0,7992357.0,8650322.0,9319622.0,3548753.0,4058385.0,4681707.0,5432424.0,6298651.0,7278866.0,8365850.0,9545158.0,1.0748394E7,1.1911819E7,1.2921234E7,1.375568E7,2.2223309E7,2.5009741E7,2.8173309E7,3.1681188E7,3.4807417E7,3.8783863E7,4.5681811E7,5.2799062E7,5.9402198E7,6.6134291E7,7.3312559E7,8.0264543E7,2042865.0,2355805.0,2747687.0,3232927.0,3790903.0,4282586.0,4474873.0,4842194.0,5274649.0,5783439.0,6353681.0,6939688.0,216964.0,232922.0,249220.0,259864.0,277603.0,192675.0,285483.0,341244.0,387838.0,439971.0,495627.0,551201.0,1438760.0,1542611.0,1666618.0,1820319.0,2260187.0,2512642.0,2637297.0,2915959.0,3668440.0,4058319.0,4414865.0,4906585.0,2.0860941E7,2.2815614E7,2.5145372E7,2.7860297E7,3.0770372E7,3.4617799E7,3.8111756E7,4.299953E7,5.2088559E7,5.9861301E7,6.7946797E7,7.6511887E7,4090500.0,4324000.0,4491443.0,4605744.0,4639657.0,4738902.0,4826933.0,4931729.0,5041039.0,5134406.0,5193039.0,5238460.0,4.2459667E7,4.4310863E7,4.7124E7,4.9569E7,5.1732E7,5.3165019E7,5.4433565E7,5.56301E7,5.7374179E7,5.8623428E7,5.9925035E7,6.1083916E7,420702.0,434904.0,455661.0,489004.0,537977.0,706367.0,753874.0,880397.0,985739.0,1126189.0,1299304.0,1454867.0,284320.0,323150.0,374020.0,439593.0,517101.0,608274.0,715523.0,848406.0,1025384.0,1235767.0,1457766.0,1688359.0,6.9145952E7,7.1019069E7,7.3739117E7,7.6368453E7,7.8717088E7,7.8160773E7,7.8335266E7,7.7718298E7,8.0597764E7,8.2011073E7,8.2350671E7,8.2400996E7,5581001.0,6391288.0,7355248.0,8490213.0,9354120.0,1.0538093E7,1.1400338E7,1.4168101E7,1.6278738E7,1.8418288E7,2.0550751E7,2.2873338E7,7733250.0,8096218.0,8448233.0,8716441.0,8888628.0,9308479.0,9786480.0,9974490.0,1.0325429E7,1.0502372E7,1.0603863E7,1.070629E7,3146381.0,3640876.0,4208858.0,4690773.0,5149581.0,5703430.0,6395630.0,7326406.0,8486949.0,9803875.0,1.117865E7,1.2572928E7,2664249.0,2876726.0,3140003.0,3451418.0,3811387.0,4227026.0,4710497.0,5650262.0,6990574.0,8048834.0,8807818.0,9947814.0,580653.0,601095.0,627820.0,601287.0,625361.0,745228.0,825987.0,927524.0,1050938.0,1193708.0,1332459.0,1472041.0,3201488.0,3507701.0,3880130.0,4318137.0,4698301.0,4908554.0,5198399.0,5756203.0,6326682.0,6913545.0,7607651.0,8502814.0,1517453.0,1770390.0,2090162.0,2500689.0,2965146.0,3055235.0,3669448.0,4372203.0,5077347.0,5867957.0,6677328.0,7483763.0,2125900.0,2736300.0,3305200.0,3722800.0,4115700.0,4583700.0,5264500.0,5584510.0,5829696.0,6495918.0,6762476.0,6980412.0,9504000.0,9839000.0,1.0063E7,1.0223422E7,1.0394091E7,1.0637171E7,1.0705535E7,1.061274E7,1.0348684E7,1.0244684E7,1.0083313E7,9956108.0,147962.0,165110.0,182053.0,198676.0,209275.0,221823.0,233997.0,244676.0,259012.0,271192.0,288030.0,301931.0,3.72E8,4.09E8,4.54E8,5.06E8,5.67E8,6.34E8,7.08E8,7.88E8,8.72E8,9.59E8,1.034172547E9,1.110396331E9,8.2052E7,9.0124E7,9.9028E7,1.09343E8,1.21282E8,1.36725E8,1.53343E8,1.69276E8,1.84816E8,1.99278E8,2.1106E8,2.23547E8,1.7272E7,1.9792E7,2.2874E7,2.6538E7,3.0614E7,3.5480679E7,4.3072751E7,5.1889696E7,6.0397973E7,6.3327987E7,6.6907826E7,6.945357E7,5441766.0,6248643.0,7240260.0,8519282.0,1.0061506E7,1.1882916E7,1.4173318E7,1.6543189E7,1.7861905E7,2.0775703E7,2.4001816E7,2.7499638E7,2952156.0,2878220.0,2830000.0,2900100.0,3024400.0,3271900.0,3480000.0,3539900.0,3557761.0,3667233.0,3879155.0,4109086.0,1620914.0,1944401.0,2310904.0,2693585.0,3095893.0,3495918.0,3858421.0,4203148.0,4936550.0,5531387.0,6029529.0,6426679.0,4.7666E7,4.9182E7,5.08432E7,5.26671E7,5.4365564E7,5.6059245E7,5.6535636E7,5.6729703E7,5.6840847E7,5.7479469E7,5.7926999E7,5.8147733E7,1426095.0,1535090.0,1665128.0,1861096.0,1997616.0,2156814.0,2298309.0,2326606.0,2378618.0,2531311.0,2664659.0,2780132.0,8.6459025E7,9.1563009E7,9.5831757E7,1.00825279E8,1.07188273E8,1.13872473E8,1.18454974E8,1.22091325E8,1.24329269E8,1.25956499E8,1.27065841E8,1.27467972E8,607914.0,746559.0,933559.0,1255058.0,1613551.0,1937652.0,2347031.0,2820042.0,3867409.0,4526235.0,5307470.0,6053193.0,6464046.0,7454779.0,8678557.0,1.0191512E7,1.2044785E7,1.4500404E7,1.7661452E7,2.1198082E7,2.5020539E7,2.8263827E7,3.1386842E7,3.5610177E7,8865488.0,9411381.0,1.0917494E7,1.2617009E7,1.4781241E7,1.632532E7,1.7647518E7,1.9067554E7,2.0711375E7,2.1585105E7,2.2215365E7,2.3301725E7,2.0947571E7,2.2611552E7,2.6420307E7,3.0131E7,3.3505E7,3.6436E7,3.9326E7,4.1622E7,4.380545E7,4.6173816E7,4.796915E7,4.904479E7,160000.0,212846.0,358266.0,575003.0,841934.0,1140357.0,1497494.0,1891487.0,1418095.0,1765345.0,2111561.0,2505559.0,1439529.0,1647412.0,1886848.0,2186894.0,2680018.0,3115787.0,3086876.0,3089353.0,3219994.0,3430388.0,3677780.0,3921278.0,748747.0,813338.0,893143.0,996380.0,1116779.0,1251524.0,1411807.0,1599200.0,1803195.0,1982823.0,2046772.0,2012649.0,863308.0,975950.0,1112796.0,1279406.0,1482628.0,1703617.0,1956875.0,2269414.0,1912974.0,2200725.0,2814651.0,3193942.0,1019729.0,1201578.0,1441863.0,1759224.0,2183877.0,2721783.0,3344074.0,3799845.0,4364501.0,4759670.0,5368585.0,6036914.0,4762912.0,5181679.0,5703324.0,6334556.0,7082430.0,8007166.0,9171477.0,1.0568642E7,1.2210395E7,1.4165114E7,1.6473477E7,1.9167654E7,2917802.0,3221238.0,3628608.0,4147252.0,4730997.0,5637246.0,6502825.0,7824747.0,1.0014249E7,1.0419991E7,1.1824495E7,1.3327079E7,6748378.0,7739235.0,8906385.0,1.0154878E7,1.1441462E7,1.2845381E7,1.4441916E7,1.6331785E7,1.8319502E7,2.0476091E7,2.2662365E7,2.4821286E7,3838168.0,4241884.0,4690372.0,5212416.0,5828158.0,6491649.0,6998256.0,7634008.0,8416215.0,9384984.0,1.0580176E7,1.2031795E7,1022556.0,1076852.0,1146757.0,1230542.0,1332786.0,1456688.0,1622136.0,1841240.0,2119465.0,2444741.0,2828858.0,3270065.0,516556.0,609816.0,701016.0,789309.0,851334.0,913025.0,992040.0,1042663.0,1096202.0,1149818.0,1200206.0,1250882.0,3.0144317E7,3.5015548E7,4.1121485E7,4.7995559E7,5.5984294E7,6.3759976E7,7.1640904E7,8.0122492E7,8.811103E7,9.5895146E7,1.02479927E8,1.08700891E8,800663.0,882134.0,1010280.0,1149500.0,1320500.0,1528000.0,1756032.0,2015133.0,2312802.0,2494803.0,2674234.0,2874127.0,413834.0,442829.0,474528.0,501035.0,527678.0,560073.0,562548.0,569473.0,621621.0,692651.0,720230.0,684736.0,9939217.0,1.140635E7,1.3056604E7,1.4770296E7,1.666067E7,1.8396941E7,2.019873E7,2.2987397E7,2.5798239E7,2.8529501E7,3.1167783E7,3.3757175E7,6446316.0,7038035.0,7788944.0,8680909.0,9809596.0,1.1127868E7,1.2587223E7,1.2891952E7,1.3160731E7,1.6603334E7,1.847378E7,1.9951656E7,2.0092996E7,2.1731844E7,2.3634436E7,2.5870271E7,2.846639E7,3.1528087E7,3.4680442E7,3.8028578E7,4.0546538E7,4.3247867E7,4.5598081E7,4.776198E7,485831.0,548080.0,621392.0,706640.0,821782.0,977026.0,1099010.0,1278184.0,1554253.0,1774766.0,1972153.0,2055080.0,9182536.0,9682338.0,1.0332057E7,1.126169E7,1.2412593E7,1.3933198E7,1.5796314E7,1.791718E7,2.0326209E7,2.3001113E7,2.5873917E7,2.890179E7,1.0381988E7,1.1026383E7,1.1805689E7,1.2596822E7,1.3329874E7,1.3852989E7,1.4310401E7,1.4665278E7,1.5174244E7,1.5604464E7,1.612283E7,1.6570613E7,1994794.0,2229407.0,2488550.0,2728150.0,2929100.0,3164900.0,3210650.0,3317166.0,3437674.0,3676187.0,3908037.0,4115771.0,1165790.0,1358828.0,1590597.0,1865490.0,2182908.0,2554598.0,2979423.0,3344353.0,4017939.0,4609572.0,5146848.0,5675356.0,3379468.0,3692184.0,4076008.0,4534062.0,5060262.0,5682086.0,6437188.0,7332638.0,8392818.0,9666252.0,1.1140655E7,1.2894865E7,3.3119096E7,3.717334E7,4.1871351E7,4.7287752E7,5.3740085E7,6.2209173E7,7.3039376E7,8.155152E7,9.3364244E7,1.06207839E8,1.19901274E8,1.35031164E8,3327728.0,3491938.0,3638919.0,3786019.0,3933004.0,4043205.0,4114787.0,4186147.0,4286357.0,4405672.0,4535591.0,4627926.0,507833.0,561977.0,628164.0,714775.0,829050.0,1004533.0,1301048.0,1593882.0,1915208.0,2283635.0,2713462.0,3204897.0,4.134656E7,4.6679944E7,5.3100671E7,6.0641899E7,6.9325921E7,7.8152686E7,9.1462088E7,1.05186881E8,1.20065004E8,1.35564834E8,1.53403524E8,1.69270617E8,940080.0,1063506.0,1215725.0,1405486.0,1616384.0,1839782.0,2036305.0,2253639.0,2484997.0,2734531.0,2990875.0,3242173.0,1555876.0,1770902.0,2009813.0,2287985.0,2614104.0,2984494.0,3366439.0,3886512.0,4483945.0,5154123.0,5884491.0,6667147.0,8025700.0,9146100.0,1.05165E7,1.21322E7,1.39547E7,1.5990099E7,1.8125129E7,2.0195924E7,2.2430449E7,2.4748122E7,2.6769436E7,2.8674757E7,2.2438691E7,2.6072194E7,3.0325264E7,3.53566E7,4.0850141E7,4.6850962E7,5.3456774E7,6.0017788E7,6.7185766E7,7.5012988E7,8.2995088E7,9.1077287E7,2.5730551E7,2.8235346E7,3.0329617E7,3.1785378E7,3.3039545E7,3.4621254E7,3.6227381E7,3.774071E7,3.8370697E7,3.8654957E7,3.8625976E7,3.8518241E7,8526050.0,8817650.0,9019800.0,9103000.0,8970450.0,9662600.0,9859650.0,9915289.0,9927680.0,1.0156415E7,1.0433867E7,1.0642836E7,2227000.0,2260000.0,2448046.0,2648961.0,2847132.0,3080828.0,3279001.0,3444468.0,3585176.0,3759430.0,3859606.0,3942491.0,257700.0,308700.0,358900.0,414024.0,461633.0,492095.0,517810.0,562035.0,622191.0,684810.0,743981.0,798094.0,1.663E7,1.7829327E7,1.8680721E7,1.9284814E7,2.0662648E7,2.1658597E7,2.2356726E7,2.2686371E7,2.2797027E7,2.2562458E7,2.2404337E7,2.2276056E7,2534927.0,2822082.0,3051242.0,3451079.0,3992121.0,4657072.0,5507565.0,6349365.0,7290203.0,7212583.0,7852401.0,8860588.0,60011.0,61325.0,65345.0,70787.0,76595.0,86796.0,98593.0,110812.0,125911.0,145608.0,170372.0,199579.0,4005677.0,4419650.0,4943029.0,5618198.0,6472756.0,8128505.0,1.1254672E7,1.4619745E7,1.6945857E7,2.1229759E7,2.450153E7,2.7601038E7,2755589.0,3054547.0,3430243.0,3965841.0,4588696.0,5260855.0,6147783.0,7171347.0,8307920.0,9535314.0,1.0870037E7,1.2267493E7,6860147.0,7271135.0,7616060.0,7971222.0,8313288.0,8686367.0,9032824.0,9230783.0,9826397.0,1.0336594E7,1.0111559E7,1.0150265E7,2143249.0,2295678.0,2467895.0,2662190.0,2879013.0,3140897.0,3464522.0,3868905.0,4260884.0,4578212.0,5359092.0,6144562.0,1127000.0,1445929.0,1750200.0,1977600.0,2152400.0,2325300.0,2651869.0,2794552.0,3235865.0,3802309.0,4197776.0,4553009.0,3558137.0,3844277.0,4237384.0,4442238.0,4593433.0,4827803.0,5048043.0,5199318.0,5302888.0,5383010.0,5410052.0,5447502.0,1489518.0,1533070.0,1582962.0,1646912.0,1694510.0,1746919.0,1861252.0,1945870.0,1999210.0,2011612.0,2011497.0,2009245.0,2526994.0,2780415.0,3080153.0,3428839.0,3840161.0,4353666.0,5828892.0,6921858.0,6099799.0,6633514.0,7753310.0,9118773.0,1.4264935E7,1.6151549E7,1.8356657E7,2.0997321E7,2.393581E7,2.7129932E7,3.1140029E7,3.5933379E7,3.9964159E7,4.2835005E7,4.4433622E7,4.3997828E7,2.854987E7,2.9841614E7,3.1158061E7,3.2850275E7,3.4513161E7,3.6439E7,3.798331E7,3.8880702E7,3.9549438E7,3.9855442E7,4.0152517E7,4.0448191E7,7982342.0,9128546.0,1.0421936E7,1.1737396E7,1.3016733E7,1.4116836E7,1.5410151E7,1.6495304E7,1.758706E7,1.8698655E7,1.9576783E7,2.0378239E7,8504667.0,9753392.0,1.1183227E7,1.2716129E7,1.4597019E7,1.7104986E7,2.0367053E7,2.472596E7,2.8227588E7,3.2160729E7,3.7090298E7,4.2292929E7,290243.0,326741.0,370006.0,420690.0,480105.0,551425.0,649901.0,779348.0,962344.0,1054486.0,1130269.0,1133066.0,7124673.0,7363802.0,7561588.0,7867931.0,8122293.0,8251648.0,8325260.0,8421403.0,8718867.0,8897619.0,8954175.0,9031088.0,4815000.0,5126000.0,5666000.0,6063000.0,6401400.0,6316424.0,6468126.0,6649942.0,6995447.0,7193761.0,7361757.0,7554661.0,3661549.0,4149908.0,4834621.0,5680812.0,6701172.0,7932503.0,9410494.0,1.1242847E7,1.3219062E7,1.5081016E7,1.7155814E7,1.9314747E7,8550362.0,1.0164215E7,1.1918938E7,1.3648692E7,1.5226039E7,1.6785196E7,1.850139E7,1.9757799E7,2.0686918E7,2.1628605E7,2.2454239E7,2.3174294E7,8322925.0,9452826.0,1.0863958E7,1.2607312E7,1.4706593E7,1.7129565E7,1.9844382E7,2.304063E7,2.6605473E7,3.0686889E7,3.4593779E7,3.813964E7,2.1289402E7,2.5041917E7,2.9263397E7,3.4024249E7,3.9276153E7,4.4148285E7,4.882716E7,5.2910342E7,5.6667095E7,6.0216677E7,6.2806748E7,6.5068149E7,1219113.0,1357445.0,1528098.0,1735550.0,2056351.0,2308582.0,2644765.0,3154264.0,3747553.0,4320890.0,4977378.0,5701579.0,662850.0,764900.0,887498.0,960155.0,975199.0,1039009.0,1116479.0,1191336.0,1183669.0,1138101.0,1101832.0,1056608.0,3647735.0,3950849.0,4286552.0,4786986.0,5303507.0,6005061.0,6734098.0,7724976.0,8523077.0,9231669.0,9770575.0,1.0276158E7,2.2235677E7,2.5670939E7,2.9788695E7,3.3411317E7,3.7492953E7,4.2404033E7,4.7328791E7,5.2881328E7,5.8179144E7,6.3047647E7,6.7308928E7,7.1158647E7,5824797.0,6675501.0,7688797.0,8900294.0,1.0190285E7,1.1457758E7,1.29394E7,1.528305E7,1.825219E7,2.1210254E7,2.4739869E7,2.9170398E7,5.043E7,5.143E7,5.3292E7,5.4959E7,5.6079E7,5.6179E7,5.6339704E7,5.698162E7,5.7866349E7,5.8808266E7,5.9912431E7,6.0776238E7,1.57553E8,1.71984E8,1.86538E8,1.98712E8,2.09896E8,2.20239E8,2.32187835E8,2.42803533E8,2.56894189E8,2.7291176E8,2.87675526E8,3.01139947E8,2252965.0,2424959.0,2598466.0,2748579.0,2829526.0,2873520.0,2953997.0,3045153.0,3149262.0,3262838.0,3363085.0,3447496.0,5439568.0,6702668.0,8143375.0,9709552.0,1.1515649E7,1.3503563E7,1.5620766E7,1.7910182E7,2.0265563E7,2.2374398E7,2.428767E7,2.6084662E7,2.6246839E7,2.8998543E7,3.379614E7,3.946391E7,4.4655014E7,5.0533506E7,5.6142181E7,6.2826491E7,6.9940728E7,7.6048996E7,8.0908147E7,8.5262356E7,1030585.0,1070439.0,1133134.0,1142636.0,1089572.0,1261091.0,1425876.0,1691210.0,2104779.0,2826046.0,3389578.0,4018332.0,4963829.0,5498090.0,6120081.0,6740785.0,7407075.0,8403990.0,9657618.0,1.121934E7,1.3367997E7,1.5826497E7,1.8701257E7,2.2211743E7,2672000.0,3016000.0,3421000.0,3900000.0,4506497.0,5216550.0,6100407.0,7272406.0,8381163.0,9417789.0,1.0595811E7,1.1746035E7,3080907.0,3646340.0,4277736.0,4995432.0,5861135.0,6642107.0,7636524.0,9216418.0,1.070434E7,1.1404948E7,1.1926563E7,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,820.8530296,853.10071,836.1971382,739.9811058,786.11336,978.0114388,852.3959448,649.3413952,635.341351,726.7340548,974.5803384,1601.056136,1942.284244,2312.888958,2760.196931,3313.422188,3533.00391,3630.880722,3738.932735,2497.437901,3193.054604,4604.211737,5937.029526,2449.008185,3013.976023,2550.81688,3246.991771,4182.663766,4910.416756,5745.160213,5681.358539,5023.216647,4797.295051,5288.040382,6223.367465,3520.610273,3827.940465,4269.276742,5522.776375,5473.288005,3008.647355,2756.953672,2430.208311,2627.845685,2277.140884,2773.287312,4797.231267,5911.315053,6856.856212,7133.166023,8052.953021,9443.038526,10079.02674,8997.897412,9139.671389,9308.41871,10967.28195,8797.640716,12779.37964,10039.59564,10949.64959,12217.22686,14526.12465,16788.62948,18334.19751,19477.00928,21888.88903,23424.76683,26997.93657,30687.75473,34435.36744,6137.076492,8842.59803,10750.72111,12834.6024,16661.6256,19749.4223,21597.08362,23687.82607,27042.01868,29095.92066,32417.60769,36126.4927,9867.084765,11635.79945,12753.27514,14804.6727,18268.65839,19340.10196,19211.14731,18524.02406,19035.57917,20292.01679,23403.55927,29796.04834,684.2441716,661.6374577,686.3415538,721.1860862,630.2336265,659.8772322,676.9818656,751.9794035,837.8101643,972.7700352,1136.39043,1391.253792,8343.105127,9714.960623,10991.20676,13149.04119,16672.14356,19117.97448,20979.84589,22525.56308,25575.57069,27561.19663,30485.88375,33692.60508,1062.7522,959.6010805,949.4990641,1035.831411,1085.796879,1029.161251,1277.897616,1225.85601,1191.207681,1232.975292,1372.877931,1441.284873,2677.326347,2127.686326,2180.972546,2586.886053,2980.331339,3548.097832,3156.510452,2753.69149,2961.699694,3326.143191,3413.26269,3822.137084,973.5331948,1353.989176,1709.683679,2172.352423,2860.16975,3528.481305,4126.613157,4314.114757,2546.781445,4766.355904,6018.975239,7446.298803,851.2411407,918.2325349,983.6539764,1214.709294,2263.611114,3214.857818,4551.14215,6205.88385,7954.111645,8647.142313,11003.60508,12569.85177,2108.944355,2487.365989,3336.585802,3429.864357,4985.711467,6660.118654,7030.835878,7807.095818,6950.283021,7957.980824,8131.212843,9065.800825,2444.286648,3008.670727,4254.337839,5577.0028,6597.494398,7612.240438,8224.191647,8239.854824,6302.623438,5970.38876,7696.777725,10680.79282,543.2552413,617.1834648,722.5120206,794.8265597,854.7359763,743.3870368,807.1985855,912.0631417,931.7527731,946.2949618,1037.645221,1217.032994,339.2964587,379.5646281,355.2032273,412.9775136,464.0995039,556.1032651,559.603231,621.8188189,631.6998778,463.1151478,446.4035126,430.0706916,368.4692856,434.0383364,496.9136476,523.4323142,421.6240257,524.9721832,624.4754784,683.8955732,682.3031755,734.28517,896.2260153,1713.778686,1172.667655,1313.048099,1399.607441,1508.453148,1684.146528,1783.432873,2367.983282,2602.664206,1793.163278,1694.337469,1934.011449,2042.09524,11367.16112,12489.95006,13462.48555,16076.58803,18970.57086,22090.88306,22898.79214,26626.51503,26342.88426,28954.92589,33328.96507,36319.23501,1071.310713,1190.844328,1193.068753,1136.056615,1070.013275,1109.374338,956.7529907,844.8763504,747.9055252,740.5063317,738.6906068,706.016537,1178.665927,1308.495577,1389.817618,1196.810565,1104.103987,1133.98495,797.9081006,952.386129,1058.0643,1004.961353,1156.18186,1704.063724,3939.978789,4315.622723,4519.094331,5106.654313,5494.024437,4756.763836,5095.665738,5547.063754,7596.125964,10118.05318,10778.78385,13171.63885,400.448611,575.9870009,487.6740183,612.7056934,676.9000921,741.2374699,962.4213805,1378.904018,1655.784158,2289.234136,3119.280896,4959.114854,2144.115096,2323.805581,2492.351109,2678.729839,3264.660041,3815.80787,4397.575659,4903.2191,5444.648617,6117.361746,5755.259962,7006.580419,1102.990936,1211.148548,1406.648278,1876.029643,1937.577675,1172.603047,1267.100083,1315.980812,1246.90737,1173.618235,1075.811558,986.1478792,780.5423257,905.8602303,896.3146335,861.5932424,904.8960685,795.757282,673.7478181,672.774812,457.7191807,312.188423,241.1658765,277.5518587,2125.621418,2315.056572,2464.783157,2677.939642,3213.152683,3259.178978,4879.507522,4201.194937,4016.239529,3484.164376,3484.06197,3632.557798,2627.009471,2990.010802,3460.937025,4161.727834,5118.146939,5926.876967,5262.734751,5629.915318,6160.416317,6677.045314,7723.447195,9645.06142,1388.594732,1500.895925,1728.869428,2052.050473,2378.201111,2517.736547,2602.710169,2156.956069,1648.073791,1786.265407,1648.800823,1544.750112,3119.23652,4338.231617,5477.890018,6960.297861,9164.090127,11305.38517,13221.82184,13822.58394,8447.794873,9875.604515,11628.38895,14619.22272,5586.53878,6092.174359,5180.75591,5690.268015,5305.445256,6380.494966,7316.918107,7532.924763,5592.843963,5431.990415,6340.646683,8948.102923,6876.14025,8256.343918,10136.86713,11399.44489,13108.4536,14800.16062,15377.22855,16310.4434,14297.02122,16048.51424,17596.21022,22833.30851,9692.385245,11099.65935,13583.31351,15937.21123,18866.20721,20422.9015,21688.04048,25116.17581,26406.73985,29804.34567,32166.50006,35278.41874,2669.529475,2864.969076,3020.989263,3020.050513,3694.212352,3081.761022,2879.468067,2880.102568,2377.156192,1895.016984,1908.260867,2082.481567,1397.717137,1544.402995,1662.137359,1653.723003,2189.874499,2681.9889,2861.092386,2899.842175,3044.214214,3614.101285,4563.808154,6025.374752,3522.110717,3780.546651,4086.114078,4579.074215,5280.99471,6679.62326,7213.791267,6481.776993,7103.702595,7429.455877,5773.044512,6873.262326,1418.822445,1458.915272,1693.335853,1814.880728,2024.008147,2785.493582,3503.729636,3885.46071,3794.755195,4173.181797,4754.604414,5581.180998,3048.3029,3421.523218,3776.803627,4358.595393,4520.246008,5138.922374,4098.344175,4140.442097,4444.2317,5154.825496,5351.568666,5728.353514,375.6431231,426.0964081,582.8419714,915.5960025,672.4122571,958.5668124,927.8253427,966.8968149,1132.055034,2814.480755,7703.4959,12154.08975,328.9405571,344.1618859,380.9958433,468.7949699,514.3242082,505.7538077,524.8758493,521.1341333,582.8585102,913.47079,765.3500015,641.3695236,362.1462796,378.9041632,419.4564161,516.1186438,566.2439442,556.8083834,577.8607471,573.7413142,421.3534653,515.8894013,530.0535319,690.8055759,6424.519071,7545.415386,9371.842561,10921.63626,14358.8759,15605.42283,18533.15761,21141.01223,20647.16499,23723.9502,28204.59057,33207.0844,7029.809327,8662.834898,10560.48553,12999.91766,16107.19171,18292.63514,20293.89746,22066.44214,24703.79615,25889.78487,28926.03234,30470.0167,4293.476475,4976.198099,6631.459222,8358.761987,11401.94841,21745.57328,15113.36194,11864.40844,13522.15752,14722.84188,12521.71392,13206.48452,485.2306591,520.9267111,599.650276,734.7829124,756.0868363,884.7552507,835.8096108,611.6588611,665.6244126,653.7301704,660.5855997,752.7497265,7144.114393,10187.82665,12902.46291,14745.62561,18016.18027,20512.92123,22031.53274,24639.18566,26505.30317,27788.88416,30035.80198,32170.37442,911.2989371,1043.561537,1190.041118,1125.69716,1178.223708,993.2239571,876.032569,847.0061135,925.060154,1005.245812,1111.984578,1327.60891,3530.690067,4916.299889,6017.190733,8513.097016,12724.82957,14195.52428,15268.42089,16120.52839,17541.49634,18747.69814,22514.2548,27538.41188,2428.237769,2617.155967,2750.364446,3242.531147,4031.408271,4879.992748,4820.49479,4246.485974,4439.45084,4684.313807,4858.347495,5186.050003,510.1964923,576.2670245,686.3736739,708.7595409,741.6662307,874.6858643,857.2503577,805.5724718,794.3484384,869.4497668,945.5835837,942.6542111,299.850319,431.7904566,522.0343725,715.5806402,820.2245876,764.7259628,838.1239671,736.4153921,745.5398706,796.6644681,575.7047176,579.231743,1840.366939,1726.887882,1796.589032,1452.057666,1654.456946,1874.298931,2011.159549,1823.015995,1456.309517,1341.726931,1270.364932,1201.637154,2194.926204,2220.487682,2291.156835,2538.269358,2529.842345,3203.208066,3121.760794,3023.096699,3081.694603,3160.454906,3099.72866,3548.330846,3054.421209,3629.076457,4692.648272,6197.962814,8315.928145,11186.14125,14560.53051,20038.47269,24757.60301,28377.63219,30209.01516,39724.97867,5263.673816,6040.180011,7550.359877,9326.64467,10168.65611,11674.83737,12545.99066,12986.47998,10535.62855,11712.7768,14843.93556,18008.94444,7267.688428,9244.001412,10350.15906,13319.89568,15798.06362,19654.96247,23269.6075,26923.20628,25144.39201,28061.09966,31163.20196,36180.78919,546.5657493,590.061996,658.3471509,700.7706107,724.032527,813.337323,855.7235377,976.5126756,1164.406809,1458.817442,1746.769454,2452.210407,749.6816546,858.9002707,849.2897701,762.4317721,1111.107907,1382.702056,1516.872988,1748.356961,2383.140898,3119.335603,2873.91287,3540.651564,3035.326002,3290.257643,4187.329802,5906.731805,9613.818607,11888.59508,7608.334602,6642.881371,7235.653188,8263.590301,9240.761975,11605.71449,4129.766056,6229.333562,8341.737815,8931.459811,9576.037596,14688.23507,14517.90711,11643.57268,3745.640687,3076.239795,4390.717312,4471.061906,5210.280328,5599.077872,6631.597314,7655.568963,9530.772896,11150.98113,12618.32141,13872.86652,17558.81555,24521.94713,34077.04939,40675.99635,4086.522128,5385.278451,7105.630706,8393.741404,12786.93223,13306.61921,15367.0292,17122.47986,18051.52254,20896.60924,21905.59514,25523.2771,4931.404155,6248.656232,8243.58234,10022.40131,12269.27378,14255.98475,16537.4835,19207.23482,22013.64486,24675.02446,27968.09817,28569.7197,2898.530881,4756.525781,5246.107524,6124.703451,7433.889293,6650.195573,6068.05135,6351.237495,7404.923685,7121.924704,6994.774861,7320.880262,3216.956347,4317.694365,6576.649461,9847.788607,14778.78636,16610.37701,19384.10571,22375.94189,26824.89511,28816.58499,28604.5919,31656.06806,1546.907807,1886.080591,2348.009158,2741.796252,2110.856309,2852.351568,4161.415959,4448.679912,3431.593647,3645.379572,3844.917194,4519.461171,853.540919,944.4383152,896.9663732,1056.736457,1222.359968,1267.613204,1348.225791,1361.936856,1341.921721,1360.485021,1287.514732,1463.249282,1088.277758,1571.134655,1621.693598,2143.540609,3701.621503,4106.301249,4106.525293,4106.492315,3726.063507,1690.756814,1646.758151,1593.06548,1030.592226,1487.593537,1536.344387,2029.228142,3030.87665,4657.22102,5622.942464,8533.088805,12104.27872,15993.52796,19233.98818,23348.13973,108382.3529,113523.1329,95458.11176,80894.88326,109347.867,59265.47714,31354.03573,28118.42998,34932.91959,40300.61996,35110.10566,47306.98978,4834.804067,6089.786934,5714.560611,6006.983042,7486.384341,8659.696836,7640.519521,5377.091329,6890.806854,8754.96385,9313.93883,10461.05868,298.8462121,335.9971151,411.8006266,498.6390265,496.5815922,745.3695408,797.2631074,773.9932141,977.4862725,1186.147994,1275.184575,1569.331442,575.5729961,620.9699901,634.1951625,713.6036483,803.0054535,640.3224383,572.1995694,506.1138573,636.6229191,609.1739508,531.4823679,414.5073415,2387.54806,3448.284395,6757.030816,18772.75169,21011.49721,21951.21176,17364.27538,11770.5898,9640.138501,9467.446056,9534.677467,12057.49928,1443.011715,1589.20275,1643.38711,1634.047282,1748.562982,1544.228586,1302.878658,1155.441948,1040.67619,986.2958956,894.6370822,1044.770126,369.1650802,416.3698064,427.9010856,495.5147806,584.6219709,663.2236766,632.8039209,635.5173634,563.2000145,692.2758103,665.4231186,759.3499101,1831.132894,1810.066992,2036.884944,2277.742396,2849.09478,3827.921571,4920.355951,5249.802653,7277.912802,10132.90964,10206.97794,12451.6558,452.3369807,490.3821867,496.1743428,545.0098873,581.3688761,686.3952693,618.0140641,684.1715576,739.014375,790.2579846,951.4097518,1042.581557,743.1159097,846.1202613,1055.896036,1421.145193,1586.851781,1497.492223,1481.150189,1421.603576,1361.369784,1483.136136,1579.019543,1803.151496,1967.955707,2034.037981,2529.067487,2475.387562,2575.484158,3710.982963,3688.037739,4783.586903,6058.253846,7425.705295,9021.815894,10956.99112,3478.125529,4131.546641,4581.609385,5754.733883,6809.40669,7674.929108,9611.147541,8688.156003,9472.384295,9767.29753,10742.44053,11977.57496,786.5668575,912.6626085,1056.353958,1226.04113,1421.741975,1647.511665,2000.603139,2338.008304,1785.402016,1902.2521,2140.739323,3095.772271,2647.585601,3682.259903,4649.593785,5907.850937,7778.414017,9595.929905,11222.58762,11732.51017,7003.339037,6465.613349,6557.194282,9253.896111,1688.20357,1642.002314,1566.353493,1711.04477,1930.194975,2370.619976,2702.620356,2755.046991,2948.047252,2982.101858,3258.495584,3820.17523,468.5260381,495.5868333,556.6863539,566.6691539,724.9178037,502.3197334,462.2114149,389.8761846,410.8968239,472.3460771,633.6179466,823.6856205,331.0,350.0,388.0,349.0,357.0,371.0,424.0,385.0,347.0,415.0,611.0,944.0,2423.780443,2621.448058,3173.215595,3793.694753,3746.080948,3876.485958,4191.100511,3693.731337,3804.537999,3899.52426,4072.324751,4811.060429,545.8657229,597.9363558,652.3968593,676.4422254,674.7881296,694.1124398,718.3730947,775.6324501,897.7403604,1010.892138,1057.206311,1091.359778,8941.571858,11276.19344,12790.84956,15363.25136,18794.74567,21209.0592,21399.46046,23651.32361,26790.94961,30246.13063,33724.75778,36797.93332,10556.57566,12247.39532,13175.678,14463.91893,16046.03728,16233.7177,17632.4104,19007.19129,18363.32494,21050.41377,23189.80135,25185.00911,3112.363948,3457.415947,3634.364406,4643.393534,4688.593267,5486.371089,3470.338156,2955.984375,2170.151724,2253.023004,2474.548819,2749.320965,761.879376,835.5234025,997.7661127,1054.384891,954.2092363,808.8970728,909.7221354,668.3000228,581.182725,580.3052092,601.0745012,619.6768924,1077.281856,1100.592563,1150.927478,1014.514104,1698.388838,1981.951806,1576.97375,1385.029563,1619.848217,1624.941275,1615.286395,2013.977305,10095.42172,11653.97304,13450.40151,16361.87647,18965.05551,23311.34939,26298.63531,31540.9748,33965.66115,41283.16433,44683.97525,49357.19017,1828.230307,2242.746551,2924.638113,4720.942687,10618.03855,11848.34392,12954.79101,18115.22313,18616.70691,19702.05581,19774.83687,22316.19287,684.5971438,747.0835292,803.3427418,942.4082588,1049.938981,1175.921193,1443.429832,1704.686583,1971.829464,2049.350521,2092.712441,2605.94758,2480.380334,2961.800905,3536.540301,4421.009084,5364.249663,5351.912144,7009.601598,7034.779161,6618.74305,7113.692252,7356.031934,9809.185636,1952.308701,2046.154706,2148.027146,2299.376311,2523.337977,3248.373311,4258.503604,3998.875695,4196.411078,4247.400261,3783.674243,4172.838464,3758.523437,4245.256698,4957.037982,5788.09333,5937.827283,6281.290855,6434.501797,6360.943444,4446.380924,5838.347657,5909.020073,7408.905561,1272.880995,1547.944844,1649.552153,1814.12743,1989.37407,2373.204287,2603.273765,2189.634995,2279.324017,2536.534925,2650.921068,3190.481016,4029.329699,4734.253019,5338.752143,6557.152776,8006.506993,9508.141454,8451.531004,9082.351172,7738.881247,10159.58368,12002.23908,15389.92468,3068.319867,3774.571743,4727.954889,6361.517993,9022.247417,10172.48572,11753.84291,13039.30876,16207.26663,17641.03156,19970.90787,20509.64777,3081.959785,3907.156189,5108.34463,6929.277714,9123.041742,9770.524921,10330.98915,12281.34191,14641.58711,16999.4333,18855.60618,19328.70901,2718.885295,2769.451844,3173.72334,4021.175739,5047.658563,4319.804067,5267.219353,5303.377488,6101.255823,6071.941411,6316.1652,7670.122558,3144.613186,3943.370225,4734.997586,6470.866545,8011.414402,9356.39724,9605.314053,9696.273295,6598.409903,7346.547557,7885.360081,10808.47561,493.3238752,540.2893983,597.4730727,510.9637142,590.5806638,670.0806011,881.5706467,847.991217,737.0685949,589.9445051,785.6537648,863.0884639,879.5835855,860.7369026,1071.551119,1384.840593,1532.985254,1737.561657,1890.218117,1516.525457,1428.777814,1339.076036,1353.09239,1598.435089,6459.554823,8157.591248,11626.41975,16903.04886,24837.42865,34167.7626,33693.17525,21198.26136,24841.61777,20586.69019,19014.54118,21654.83194,1450.356983,1567.653006,1654.988723,1612.404632,1597.712056,1561.769116,1518.479984,1441.72072,1367.899369,1392.368347,1519.635262,1712.472136,3581.459448,4981.090891,6289.629157,7991.707066,10522.06749,12980.66956,15181.0927,15870.87851,9325.068238,7914.320304,7236.075251,9786.534714,879.7877358,1004.484437,1116.639877,1206.043465,1353.759762,1348.285159,1465.010784,1294.447788,1068.696278,574.6481576,699.489713,862.5407561,2315.138227,2843.104409,3674.735572,4977.41854,8597.756202,11210.08948,15169.16112,18861.53081,24769.8912,33519.4766,36023.1054,47143.17964,5074.659104,6093.26298,7481.107598,8412.902397,9674.167626,10922.66404,11348.54585,12037.26758,9498.467723,12126.23065,13638.77837,18678.31435,4215.041741,5862.276629,7402.303395,9405.489397,12383.4862,15277.03017,17866.72175,18678.53492,14214.71681,17161.10735,20660.01936,25768.25759,1135.749842,1258.147413,1369.488336,1284.73318,1254.576127,1450.992513,1176.807031,1093.244963,926.9602964,930.5964284,882.0818218,926.1410683,4725.295531,5487.104219,5768.729717,7114.477971,7765.962636,8028.651439,8568.266228,7825.823398,7225.069258,7479.188244,7710.946444,9269.657808,3834.034742,4564.80241,5693.843879,7993.512294,10638.75131,13236.92117,13926.16997,15764.98313,18603.06452,20445.29896,24835.47166,28821.0637,1083.53203,1072.546602,1074.47196,1135.514326,1213.39553,1348.775651,1648.079789,1876.766827,2153.739222,2664.477257,3015.378833,3970.095407,1615.991129,1770.337074,1959.593767,1687.997641,1659.652775,2202.988423,1895.544073,1507.819159,1492.197043,1632.210764,1993.398314,2602.394995,1148.376626,1244.708364,1856.182125,2613.101665,3364.836625,3781.410618,3895.384018,3984.839812,3553.0224,3876.76846,4128.116943,4513.480643,8527.844662,9911.878226,12329.44192,15258.29697,17832.02464,18855.72521,20667.38125,23586.92927,23880.01683,25266.59499,29341.63093,33859.74835,14734.23275,17909.48973,20431.0927,22966.14432,27195.11304,26982.29052,28397.71512,30281.70459,31871.5303,32135.32301,34480.95771,37506.41907,1643.485354,2117.234893,2193.037133,1881.923632,2571.423014,3195.484582,3761.837715,3116.774285,3340.542768,4014.238972,4090.925331,4184.548089,1206.947913,1507.86129,1822.879028,2643.858681,4062.523897,5596.519826,7426.354774,11054.56175,15215.6579,20206.82098,23235.42329,28718.27684,716.6500721,698.5356073,722.0038073,848.2186575,915.9850592,962.4922932,874.2426069,831.8220794,825.682454,789.1862231,899.0742111,1107.482182,757.7974177,793.5774148,1002.199172,1295.46066,1524.358936,1961.224635,2393.219781,2982.653773,4616.896545,5852.625497,5913.187529,7458.396327,859.8086567,925.9083202,1067.53481,1477.59676,1649.660188,1532.776998,1344.577953,1202.201361,1034.298904,982.2869243,886.2205765,882.9699438,3023.271928,4100.3934,4997.523971,5621.368472,6619.551419,7899.554209,9119.528607,7388.597823,7370.990932,8792.573126,11460.60023,18008.50924,1468.475631,1395.232468,1660.30321,1932.360167,2753.285994,3120.876811,3560.233174,3810.419296,4332.720164,4876.798614,5722.895655,7092.923025,1969.10098,2218.754257,2322.869908,2826.356387,3450.69638,4269.122326,4241.356344,5089.043686,5678.348271,6601.429915,6508.085718,8458.276384,734.753484,774.3710692,767.2717398,908.9185217,950.735869,843.7331372,682.2662268,617.7244065,644.1707969,816.559081,927.7210018,1056.380121,9979.508487,11283.17795,12477.17707,14142.85089,15895.11641,17428.74846,18232.42452,21664.78767,22705.09254,26074.53136,29478.99919,33203.26128,13990.48208,14847.12712,16173.14586,19530.36557,21806.03594,24072.63213,25009.55914,29884.35041,32003.93224,35767.43303,39097.09955,42951.65309,5716.766744,6150.772969,5603.357717,5444.61962,5703.408898,6504.339663,6920.223051,7452.398969,8137.004775,9230.240708,7727.002004,10611.46299,7689.799761,9802.466526,8422.974165,9541.474188,10505.25966,13143.95095,11152.41011,9883.584648,10733.92631,10165.49518,8605.047831,11415.80569,605.0664917,676.2854478,772.0491602,637.1232887,699.5016441,713.5371196,707.2357863,820.7994449,989.0231487,1385.896769,1764.456677,2441.576404,1515.592329,1827.067742,2198.956312,2649.715007,3133.409277,3682.831494,4336.032082,5107.197384,6017.654756,7110.667619,4515.487575,3025.349798,781.7175761,804.8304547,825.6232006,862.4421463,1265.047031,1829.765177,1977.55701,1971.741538,1879.496673,2117.484526,2234.820827,2280.769906,1147.388831,1311.956766,1452.725766,1777.077318,1773.498265,1588.688299,1408.678565,1213.315116,1210.884633,1071.353818,1071.613938,1271.211593,406.8841148,518.7642681,527.2721818,569.7950712,799.3621758,685.5876821,788.8550411,706.1573059,693.4207856,792.4499603,672.0386227,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"breaks\":[1000.0,10000.0,25000.0,50000.0,100000.0],\n",
       "\"labels\":[\"$1K\",\"$10K\",\"$25K\",\"$50K\",\"$100K\"],\n",
       "\"trans\":\"log10\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"fa6XQ2\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x1445cbad0>"
      ]
     },
     "execution_count": 79,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             ) +\n",
    "            #  add country name to hover\n",
    "        geom_point(alpha=0.5) +\n",
    "        scale_x_log10(\n",
    "            breaks = [1000, 10000, 25000, 50000, 100000],\n",
    "            labels = [f'${nz.numerize(x)}' for x in [1000, 10000, 25000, 50000, 100000]]\n",
    "            ) +\n",
    "        theme_minimal()        \n",
    ")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 80,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"egXfeh\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,30.332,31.997,34.02,36.088,38.438,39.854,40.822,41.674,41.763,42.129,43.828,55.23,59.28,64.82,66.22,67.69,68.93,70.42,72.0,71.581,72.95,75.651,76.423,43.077,45.685,48.303,51.407,54.518,58.014,61.368,65.799,67.744,69.152,70.994,72.301,30.015,31.999,34.0,35.985,37.928,39.483,39.942,39.906,40.647,40.963,41.003,42.731,62.485,64.399,65.142,65.634,67.065,68.481,69.942,70.774,71.868,73.275,74.34,75.32,69.12,70.33,70.93,71.1,71.93,73.49,74.74,76.32,77.56,78.83,80.37,81.235,66.8,67.48,69.54,70.14,70.63,72.17,73.18,74.94,76.04,77.51,78.98,79.829,50.939,53.832,56.923,59.923,63.3,65.593,69.052,70.75,72.601,73.925,74.795,75.635,37.484,39.348,41.216,43.453,45.252,46.923,50.009,52.819,56.018,59.412,62.013,64.062,68.0,69.24,70.25,70.94,71.44,72.8,73.93,75.35,76.46,77.53,78.32,79.441,38.223,40.358,42.618,44.885,47.014,49.19,50.904,52.337,53.919,54.777,54.406,56.728,40.414,41.89,43.428,45.032,46.714,50.023,53.859,57.251,59.957,62.05,63.883,65.554,53.82,58.45,61.93,64.79,67.45,69.86,70.69,71.14,72.178,73.244,74.09,74.852,47.622,49.618,51.52,53.298,56.024,59.319,61.484,63.622,62.745,52.556,46.634,50.728,50.917,53.285,55.665,57.632,59.504,61.489,63.336,65.205,67.057,69.388,71.006,72.39,59.6,66.61,69.51,70.42,70.9,70.81,71.08,71.34,71.19,70.32,72.14,73.005,31.975,34.906,37.814,40.697,43.591,46.137,48.122,49.557,50.26,50.324,50.65,52.295,39.031,40.533,42.045,43.548,44.057,45.91,47.471,48.211,44.736,45.326,47.36,49.58,39.417,41.366,43.415,45.415,40.317,31.22,50.957,53.914,55.803,56.534,56.752,59.723,38.523,40.428,42.643,44.799,47.049,49.355,52.961,54.985,54.314,52.199,49.856,50.43,68.75,69.96,71.3,72.13,72.88,74.21,75.76,76.86,77.95,78.61,79.77,80.653,35.463,37.464,39.475,41.478,43.457,46.775,48.295,50.485,49.396,46.066,43.308,44.741,38.092,39.881,41.716,43.601,45.569,47.383,49.517,51.051,51.724,51.573,50.525,50.651,54.745,56.074,57.924,60.523,63.441,67.052,70.565,72.492,74.126,75.816,77.86,78.553,44.0,50.54896,44.50136,58.38112,63.11888,63.96736,65.525,67.274,68.69,70.426,72.028,72.961,50.643,55.118,57.863,59.963,61.623,63.837,66.653,67.768,68.421,70.313,71.682,72.889,40.715,42.46,44.467,46.472,48.944,50.939,52.933,54.926,57.939,60.66,62.974,65.152,39.143,40.652,42.122,44.056,45.989,47.804,47.784,47.412,45.548,42.587,44.966,46.462,42.111,45.053,48.435,52.04,54.907,55.625,56.695,57.47,56.433,52.962,52.97,55.322,57.206,60.026,62.842,65.424,67.849,70.75,73.45,74.752,75.713,77.26,78.123,78.782,40.477,42.469,44.93,47.35,49.801,52.374,53.983,54.655,52.044,47.991,46.832,48.328,61.21,64.77,67.13,68.5,69.61,70.64,70.46,71.52,72.527,73.68,74.876,75.748,59.421,62.325,65.246,68.29,70.723,72.649,73.717,74.174,74.414,76.151,77.158,78.273,66.87,69.03,69.9,70.38,70.29,70.71,70.96,71.58,72.4,74.01,75.51,76.486,70.78,71.81,72.35,72.96,73.47,74.69,74.63,74.8,75.33,76.11,77.18,78.332,34.812,37.328,39.693,42.074,44.366,46.519,48.812,50.04,51.604,53.157,53.373,54.791,45.928,49.828,53.459,56.751,59.631,61.788,63.727,66.046,68.457,69.957,70.847,72.235,48.357,51.356,54.64,56.678,58.796,61.31,64.342,67.231,69.613,72.312,74.173,74.994,41.893,44.444,46.992,49.293,51.137,53.319,56.006,59.797,63.674,67.217,69.806,71.338,45.262,48.57,52.307,55.855,58.207,56.696,56.604,63.154,66.798,69.535,70.734,71.878,34.482,35.983,37.485,38.987,40.516,42.024,43.662,45.664,47.545,48.245,49.348,51.579,35.928,38.047,40.158,42.189,44.142,44.535,43.89,46.453,49.991,53.378,55.24,58.04,34.078,36.667,40.059,42.115,43.515,44.51,44.916,46.684,48.091,49.402,50.725,52.947,66.55,67.49,68.75,69.83,70.87,72.52,74.55,74.83,75.7,77.13,78.37,79.313,67.41,68.93,70.51,71.55,72.38,73.83,74.89,76.34,77.46,78.64,79.59,80.657,37.003,38.999,40.489,44.598,48.69,52.79,56.564,60.19,61.366,60.461,56.761,56.735,30.0,32.065,33.896,35.857,38.308,41.842,45.58,49.265,52.644,55.861,58.041,59.448,67.5,69.1,70.3,70.8,71.0,72.5,73.8,74.847,76.07,77.34,78.67,79.406,43.149,44.779,46.452,48.072,49.875,51.756,53.744,55.729,57.501,58.556,58.453,60.022,65.86,67.86,69.51,71.0,72.34,73.68,75.24,76.67,77.03,77.869,78.256,79.483,42.023,44.142,46.954,50.016,53.738,56.029,58.137,60.782,63.373,66.322,68.978,70.259,33.609,34.558,35.753,37.197,38.842,40.762,42.891,45.552,48.576,51.455,53.676,56.007,32.5,33.489,34.488,35.492,36.486,37.465,39.327,41.245,43.266,44.873,45.504,46.388,37.579,40.696,43.59,46.243,48.042,49.923,51.461,53.636,55.089,56.671,58.137,60.916,41.912,44.665,48.041,50.924,53.884,57.402,60.909,64.492,66.399,67.659,68.565,70.198,60.96,64.75,67.65,70.0,72.0,73.6,75.45,76.2,77.601,80.0,81.495,82.208,64.03,66.41,67.96,69.5,69.76,69.95,69.39,69.58,69.17,71.04,72.59,73.338,72.49,73.47,73.68,73.73,74.46,76.11,76.99,77.23,78.77,78.95,80.5,81.757,37.373,40.249,43.605,47.193,50.651,54.208,56.596,58.553,60.223,61.765,62.879,64.698,37.468,39.918,42.518,45.964,49.203,52.702,56.159,60.137,62.681,66.041,68.588,70.65,44.869,47.181,49.325,52.469,55.234,57.702,59.62,63.04,65.742,68.042,69.451,70.964,45.32,48.437,51.457,54.459,56.95,60.413,62.038,65.044,59.461,58.811,57.046,59.545,66.91,68.9,70.29,71.08,71.28,72.03,73.1,74.36,75.467,76.122,77.783,78.885,65.39,67.84,69.39,70.75,71.63,73.06,74.45,75.6,76.93,78.269,79.696,80.745,65.94,67.81,69.24,71.06,72.19,73.48,74.98,76.42,77.44,78.82,80.24,80.546,58.53,62.61,65.61,67.51,69.0,70.11,71.21,71.77,71.766,72.262,72.047,72.567,63.03,65.5,68.73,71.43,73.42,75.38,77.11,78.67,79.36,80.69,82.0,82.603,43.158,45.669,48.126,51.629,56.528,61.134,63.739,65.869,68.015,69.772,71.263,72.535,42.27,44.686,47.949,50.654,53.559,56.155,58.766,59.339,59.285,54.407,50.992,54.11,50.056,54.081,56.656,59.942,63.983,67.159,69.1,70.647,69.978,67.727,66.662,67.297,47.453,52.681,55.292,57.716,62.612,64.766,67.123,69.81,72.244,74.647,77.045,78.623,55.565,58.033,60.47,64.624,67.712,69.343,71.309,74.174,75.19,76.156,76.904,77.588,55.928,59.489,62.094,63.87,65.421,66.099,66.983,67.926,69.292,70.265,71.028,71.993,42.138,45.047,47.747,48.492,49.767,52.208,55.078,57.18,59.685,55.558,44.593,42.592,38.48,39.486,40.502,41.536,42.614,43.764,44.852,46.027,40.802,42.221,43.753,45.678,42.723,45.289,47.808,50.227,52.773,57.442,62.155,66.234,68.755,71.555,72.737,73.952,36.681,38.865,40.848,42.881,44.851,46.881,48.969,49.35,52.214,54.978,57.286,59.443,36.256,37.207,38.41,39.487,41.766,43.767,45.642,47.457,49.42,47.495,45.009,48.303,48.463,52.102,55.737,59.371,63.01,65.256,68.0,69.5,70.693,71.938,73.044,74.241,33.685,35.307,36.936,38.487,39.977,41.714,43.916,46.364,48.388,49.903,51.818,54.467,40.543,42.338,44.248,46.289,48.437,50.852,53.599,56.145,58.333,60.43,62.247,64.164,50.986,58.089,60.246,61.557,62.944,64.93,66.711,68.74,69.745,70.736,71.954,72.801,50.789,55.19,58.299,60.11,62.361,65.032,67.405,69.498,71.455,73.67,74.902,76.195,42.244,45.248,48.251,51.253,53.754,55.491,57.489,60.222,61.271,63.625,65.033,66.803,59.164,61.448,63.728,67.178,70.636,73.066,74.101,74.865,75.435,75.445,73.981,74.543,42.873,45.423,47.924,50.335,52.862,55.73,59.65,62.677,65.393,67.66,69.615,71.164,31.286,33.779,36.161,38.113,40.328,42.495,42.795,42.861,44.284,46.344,44.026,42.082,36.319,41.905,45.108,49.379,53.07,56.059,58.056,58.339,59.32,60.328,59.908,62.069,41.725,45.226,48.386,51.159,53.867,56.437,58.968,60.835,61.999,58.909,51.479,52.906,36.157,37.686,39.393,41.472,43.971,46.748,49.594,52.537,55.727,59.426,61.34,63.785,72.13,72.99,73.23,73.82,73.75,75.24,76.05,76.83,77.42,78.03,78.53,79.762,69.39,70.26,71.24,71.52,71.89,72.22,73.84,74.32,76.33,77.55,79.11,80.204,42.314,45.432,48.632,51.884,55.151,57.47,59.298,62.008,65.843,68.426,70.836,72.899,37.444,38.598,39.487,40.118,40.546,41.291,42.598,44.555,47.391,51.313,54.496,56.867,36.324,37.802,39.36,41.04,42.821,44.514,45.826,46.886,47.472,47.464,46.608,46.859,72.67,73.44,73.47,74.08,74.34,75.37,75.97,75.89,77.32,78.32,79.05,80.196,37.578,40.08,43.165,46.988,52.143,57.367,62.728,67.734,71.197,72.499,74.193,75.64,43.436,45.557,47.67,49.8,51.929,54.043,56.158,58.245,60.838,61.818,63.61,65.483,55.191,59.201,61.817,64.071,66.216,68.681,70.472,71.523,72.462,73.738,74.712,75.537,62.649,63.196,64.361,64.951,65.815,66.353,66.874,67.378,68.225,69.4,70.755,71.752,43.902,46.263,49.096,51.445,55.448,58.447,61.406,64.134,66.458,68.386,69.906,71.421,47.752,51.334,54.757,56.393,58.065,60.06,62.082,64.151,66.458,68.564,70.303,71.688,61.31,65.77,67.64,69.61,70.85,70.67,71.32,70.98,70.99,72.75,74.67,75.563,59.82,61.51,64.39,66.6,69.26,70.41,72.77,74.06,74.86,75.97,77.29,78.098,64.28,68.54,69.62,71.1,72.16,73.44,73.75,74.63,73.911,74.917,77.778,78.746,52.724,55.09,57.666,60.542,64.274,67.064,69.885,71.913,73.615,74.772,75.744,76.442,61.05,64.1,66.8,66.8,69.21,69.46,69.66,69.53,69.36,69.72,71.322,72.476,40.0,41.5,43.0,44.1,44.6,45.0,46.218,44.02,23.599,36.087,43.413,46.242,46.471,48.945,51.893,54.425,56.48,58.55,60.351,61.728,62.742,63.306,64.337,65.528,39.875,42.868,45.914,49.901,53.886,58.69,63.012,66.295,68.768,70.533,71.626,72.777,37.278,39.329,41.454,43.563,45.815,48.879,52.379,55.769,58.196,60.187,61.6,63.062,57.996,61.685,64.531,66.914,68.7,70.3,70.162,71.218,71.659,72.232,73.213,74.002,30.331,31.57,32.767,34.113,35.4,36.788,38.445,40.006,38.333,39.897,41.012,42.568,60.396,63.179,65.798,67.946,69.521,70.795,71.76,73.56,75.788,77.158,78.77,79.972,64.36,67.45,70.33,70.98,70.35,70.45,70.8,71.08,71.38,72.71,73.8,74.663,65.57,67.85,69.15,69.18,69.82,70.97,71.063,72.25,73.64,75.13,76.66,77.926,32.978,34.977,36.981,38.977,40.973,41.974,42.955,44.501,39.658,43.795,45.936,48.159,45.009,47.985,49.951,51.927,53.696,55.527,58.161,60.834,61.888,60.236,53.365,49.339,64.94,66.66,69.69,71.44,73.06,74.39,76.3,76.9,77.57,78.77,79.78,80.941,57.593,61.456,62.192,64.266,65.042,65.949,68.757,69.011,70.379,70.457,70.815,72.396,38.635,39.624,40.87,42.858,45.083,47.8,50.338,51.744,53.556,55.373,56.369,58.556,41.407,43.424,44.992,46.633,49.552,52.537,55.561,57.678,58.474,54.289,43.869,39.613,71.86,72.49,73.37,74.16,74.72,75.44,76.42,77.19,78.16,79.39,80.04,80.884,69.62,70.56,71.32,72.77,73.78,75.39,76.21,77.41,78.03,79.37,80.62,81.701,45.883,48.284,50.305,53.655,57.296,61.195,64.59,66.974,69.249,71.527,73.053,74.143,58.5,62.4,65.2,67.5,69.39,70.59,72.16,73.4,74.26,75.25,76.99,78.4,41.215,42.974,44.246,45.757,47.62,49.919,50.608,51.535,50.44,48.466,49.651,52.517,50.848,53.63,56.061,58.285,60.405,62.494,64.597,66.084,67.298,67.521,68.564,70.616,38.596,41.208,43.922,46.769,49.759,52.887,55.471,56.941,58.061,58.39,57.561,58.42,59.1,61.8,64.9,65.4,65.9,68.3,68.832,69.582,69.862,69.465,68.976,69.819,44.6,47.1,49.579,52.053,55.602,59.837,64.048,66.894,70.001,71.973,73.042,73.923,43.585,48.079,52.098,54.336,57.005,59.507,61.036,63.108,66.146,68.835,70.845,71.777,39.978,42.571,45.344,48.051,51.016,50.35,49.849,51.509,48.825,44.578,47.813,51.542,69.18,70.42,70.76,71.36,72.01,72.76,74.04,75.007,76.42,77.218,78.471,79.425,68.44,69.49,70.21,70.76,71.34,73.38,74.65,75.02,76.09,76.81,77.31,78.242,66.071,67.044,68.253,68.468,68.673,69.481,70.805,71.918,72.752,74.223,75.307,76.384,55.088,57.907,60.77,63.479,65.712,67.456,68.557,70.19,71.15,72.146,72.766,73.747,40.412,42.887,45.363,47.838,50.254,55.764,58.816,62.82,67.662,70.672,73.017,74.249,43.16,45.671,48.127,51.631,56.532,60.765,64.406,67.046,69.718,71.096,72.37,73.422,32.548,33.97,35.18,36.984,39.848,44.175,49.113,52.922,55.599,58.02,60.308,62.698,42.038,44.077,46.023,47.768,50.107,51.386,51.821,50.821,46.1,40.238,39.193,42.384,48.451,50.469,52.358,53.995,55.635,57.674,60.363,62.351,60.377,46.809,39.989,43.487],\n",
       "\"pop\":[8425333.0,9240934.0,1.0267083E7,1.1537966E7,1.307946E7,1.4880372E7,1.2881816E7,1.3867957E7,1.6317921E7,2.2227415E7,2.5268405E7,3.1889923E7,1282697.0,1476505.0,1728137.0,1984060.0,2263554.0,2509048.0,2780097.0,3075321.0,3326498.0,3428038.0,3508512.0,3600523.0,9279525.0,1.0270856E7,1.1000948E7,1.2760499E7,1.4760787E7,1.7152804E7,2.0033753E7,2.3254956E7,2.6298373E7,2.9072015E7,3.1287142E7,3.3333216E7,4232095.0,4561361.0,4826015.0,5247469.0,5894858.0,6162675.0,7016384.0,7874230.0,8735988.0,9875024.0,1.0866106E7,1.2420476E7,1.7876956E7,1.9610538E7,2.1283783E7,2.2934225E7,2.4779799E7,2.6983828E7,2.9341374E7,3.1620918E7,3.3958947E7,3.6203463E7,3.8331121E7,4.0301927E7,8691212.0,9712569.0,1.0794968E7,1.1872264E7,1.3177E7,1.40741E7,1.51842E7,1.6257249E7,1.7481977E7,1.8565243E7,1.9546792E7,2.0434176E7,6927772.0,6965860.0,7129864.0,7376998.0,7544201.0,7568430.0,7574613.0,7578903.0,7914969.0,8069876.0,8148312.0,8199783.0,120447.0,138655.0,171863.0,202182.0,230800.0,297410.0,377967.0,454612.0,529491.0,598561.0,656397.0,708573.0,4.6886859E7,5.1365468E7,5.6839289E7,6.2821884E7,7.0759295E7,8.0428306E7,9.3074406E7,1.03764241E8,1.13704579E8,1.23315288E8,1.3565679E8,1.50448339E8,8730405.0,8989111.0,9218400.0,9556500.0,9709100.0,9821800.0,9856303.0,9870200.0,1.0045622E7,1.0199787E7,1.031197E7,1.0392226E7,1738315.0,1925173.0,2151895.0,2427334.0,2761407.0,3168267.0,3641603.0,4243788.0,4981671.0,6066080.0,7026113.0,8078314.0,2883315.0,3211738.0,3593918.0,4040665.0,4565872.0,5079716.0,5642224.0,6156369.0,6893451.0,7693188.0,8445134.0,9119152.0,2791000.0,3076000.0,3349000.0,3585000.0,3819000.0,4086000.0,4172693.0,4338977.0,4256013.0,3607000.0,4165416.0,4552198.0,442308.0,474639.0,512764.0,553541.0,619351.0,781472.0,970347.0,1151184.0,1342614.0,1536536.0,1630347.0,1639131.0,5.660256E7,6.5551171E7,7.603939E7,8.8049823E7,1.00840058E8,1.14313951E8,1.28962939E8,1.42938076E8,1.55975974E8,1.68546719E8,1.79914212E8,1.90010647E8,7274900.0,7651254.0,8012946.0,8310226.0,8576200.0,8797022.0,8892098.0,8971958.0,8658506.0,8066057.0,7661799.0,7322858.0,4469979.0,4713416.0,4919632.0,5127935.0,5433886.0,5889574.0,6634596.0,7586551.0,8878303.0,1.0352843E7,1.2251209E7,1.4326203E7,2445618.0,2667518.0,2961915.0,3330989.0,3529983.0,3834415.0,4580410.0,5126023.0,5809236.0,6121610.0,7021078.0,8390505.0,4693836.0,5322536.0,6083619.0,6960067.0,7450606.0,6978607.0,7272485.0,8371791.0,1.0150094E7,1.1782962E7,1.2926707E7,1.4131858E7,5009067.0,5359923.0,5793633.0,6335506.0,7021028.0,7959865.0,9250831.0,1.0780667E7,1.2467171E7,1.4195809E7,1.5929988E7,1.7696293E7,1.4785584E7,1.7010154E7,1.8985849E7,2.0819767E7,2.22845E7,2.37964E7,2.52019E7,2.65497E7,2.8523502E7,3.0305843E7,3.1902268E7,3.3390141E7,1291695.0,1392284.0,1523478.0,1733638.0,1927260.0,2167533.0,2476971.0,2840009.0,3265124.0,3696513.0,4048013.0,4369038.0,2682462.0,2894855.0,3150417.0,3495967.0,3899068.0,4388260.0,4875118.0,5498955.0,6429417.0,7562011.0,8835739.0,1.0238807E7,6377619.0,7048426.0,7961258.0,8858908.0,9717524.0,1.0599793E7,1.1487112E7,1.2463354E7,1.3572994E7,1.4599929E7,1.5497046E7,1.6284741E7,5.56263527E8,6.37408E8,6.6577E8,7.5455E8,8.6203E8,9.43455E8,1.000281E9,1.084035E9,1.16497E9,1.230075E9,1.2804E9,1.318683096E9,1.2350771E7,1.4485993E7,1.7009885E7,1.9764027E7,2.254289E7,2.5094412E7,2.7764644E7,3.0964245E7,3.4202721E7,3.765783E7,4.1008227E7,4.422755E7,153936.0,170928.0,191689.0,217378.0,250027.0,304739.0,348643.0,395114.0,454429.0,527982.0,614382.0,710960.0,1.4100005E7,1.5577932E7,1.7486434E7,1.9941073E7,2.3007669E7,2.648087E7,3.0646495E7,3.5481645E7,4.1672143E7,4.7798986E7,5.5379852E7,6.4606759E7,854885.0,940458.0,1047924.0,1179760.0,1340458.0,1536769.0,1774735.0,2064095.0,2409073.0,2800947.0,3328795.0,3800610.0,926317.0,1112300.0,1345187.0,1588717.0,1834796.0,2108457.0,2424367.0,2799811.0,3173216.0,3518107.0,3834934.0,4133884.0,2977019.0,3300000.0,3832408.0,4744870.0,6071696.0,7459574.0,9025951.0,1.0761098E7,1.2772596E7,1.4625967E7,1.6252726E7,1.8013409E7,3882229.0,3991242.0,4076557.0,4174366.0,4225310.0,4318673.0,4413368.0,4484310.0,4494013.0,4444595.0,4481020.0,4493312.0,6007797.0,6640752.0,7254373.0,8139332.0,8831348.0,9537988.0,9789224.0,1.0239839E7,1.072326E7,1.0983007E7,1.1226999E7,1.1416987E7,9125183.0,9513758.0,9620282.0,9835109.0,9862158.0,1.0161915E7,1.0303704E7,1.0311597E7,1.0315702E7,1.0300707E7,1.0256295E7,1.0228744E7,4334000.0,4487831.0,4646899.0,4838800.0,4991596.0,5088419.0,5117810.0,5127024.0,5171393.0,5283663.0,5374693.0,5468120.0,63149.0,71851.0,89898.0,127617.0,178848.0,228694.0,305991.0,311025.0,384156.0,417908.0,447416.0,496374.0,2491346.0,2923186.0,3453434.0,4049146.0,4671329.0,5302800.0,5968349.0,6655297.0,7351181.0,7992357.0,8650322.0,9319622.0,3548753.0,4058385.0,4681707.0,5432424.0,6298651.0,7278866.0,8365850.0,9545158.0,1.0748394E7,1.1911819E7,1.2921234E7,1.375568E7,2.2223309E7,2.5009741E7,2.8173309E7,3.1681188E7,3.4807417E7,3.8783863E7,4.5681811E7,5.2799062E7,5.9402198E7,6.6134291E7,7.3312559E7,8.0264543E7,2042865.0,2355805.0,2747687.0,3232927.0,3790903.0,4282586.0,4474873.0,4842194.0,5274649.0,5783439.0,6353681.0,6939688.0,216964.0,232922.0,249220.0,259864.0,277603.0,192675.0,285483.0,341244.0,387838.0,439971.0,495627.0,551201.0,1438760.0,1542611.0,1666618.0,1820319.0,2260187.0,2512642.0,2637297.0,2915959.0,3668440.0,4058319.0,4414865.0,4906585.0,2.0860941E7,2.2815614E7,2.5145372E7,2.7860297E7,3.0770372E7,3.4617799E7,3.8111756E7,4.299953E7,5.2088559E7,5.9861301E7,6.7946797E7,7.6511887E7,4090500.0,4324000.0,4491443.0,4605744.0,4639657.0,4738902.0,4826933.0,4931729.0,5041039.0,5134406.0,5193039.0,5238460.0,4.2459667E7,4.4310863E7,4.7124E7,4.9569E7,5.1732E7,5.3165019E7,5.4433565E7,5.56301E7,5.7374179E7,5.8623428E7,5.9925035E7,6.1083916E7,420702.0,434904.0,455661.0,489004.0,537977.0,706367.0,753874.0,880397.0,985739.0,1126189.0,1299304.0,1454867.0,284320.0,323150.0,374020.0,439593.0,517101.0,608274.0,715523.0,848406.0,1025384.0,1235767.0,1457766.0,1688359.0,6.9145952E7,7.1019069E7,7.3739117E7,7.6368453E7,7.8717088E7,7.8160773E7,7.8335266E7,7.7718298E7,8.0597764E7,8.2011073E7,8.2350671E7,8.2400996E7,5581001.0,6391288.0,7355248.0,8490213.0,9354120.0,1.0538093E7,1.1400338E7,1.4168101E7,1.6278738E7,1.8418288E7,2.0550751E7,2.2873338E7,7733250.0,8096218.0,8448233.0,8716441.0,8888628.0,9308479.0,9786480.0,9974490.0,1.0325429E7,1.0502372E7,1.0603863E7,1.070629E7,3146381.0,3640876.0,4208858.0,4690773.0,5149581.0,5703430.0,6395630.0,7326406.0,8486949.0,9803875.0,1.117865E7,1.2572928E7,2664249.0,2876726.0,3140003.0,3451418.0,3811387.0,4227026.0,4710497.0,5650262.0,6990574.0,8048834.0,8807818.0,9947814.0,580653.0,601095.0,627820.0,601287.0,625361.0,745228.0,825987.0,927524.0,1050938.0,1193708.0,1332459.0,1472041.0,3201488.0,3507701.0,3880130.0,4318137.0,4698301.0,4908554.0,5198399.0,5756203.0,6326682.0,6913545.0,7607651.0,8502814.0,1517453.0,1770390.0,2090162.0,2500689.0,2965146.0,3055235.0,3669448.0,4372203.0,5077347.0,5867957.0,6677328.0,7483763.0,2125900.0,2736300.0,3305200.0,3722800.0,4115700.0,4583700.0,5264500.0,5584510.0,5829696.0,6495918.0,6762476.0,6980412.0,9504000.0,9839000.0,1.0063E7,1.0223422E7,1.0394091E7,1.0637171E7,1.0705535E7,1.061274E7,1.0348684E7,1.0244684E7,1.0083313E7,9956108.0,147962.0,165110.0,182053.0,198676.0,209275.0,221823.0,233997.0,244676.0,259012.0,271192.0,288030.0,301931.0,3.72E8,4.09E8,4.54E8,5.06E8,5.67E8,6.34E8,7.08E8,7.88E8,8.72E8,9.59E8,1.034172547E9,1.110396331E9,8.2052E7,9.0124E7,9.9028E7,1.09343E8,1.21282E8,1.36725E8,1.53343E8,1.69276E8,1.84816E8,1.99278E8,2.1106E8,2.23547E8,1.7272E7,1.9792E7,2.2874E7,2.6538E7,3.0614E7,3.5480679E7,4.3072751E7,5.1889696E7,6.0397973E7,6.3327987E7,6.6907826E7,6.945357E7,5441766.0,6248643.0,7240260.0,8519282.0,1.0061506E7,1.1882916E7,1.4173318E7,1.6543189E7,1.7861905E7,2.0775703E7,2.4001816E7,2.7499638E7,2952156.0,2878220.0,2830000.0,2900100.0,3024400.0,3271900.0,3480000.0,3539900.0,3557761.0,3667233.0,3879155.0,4109086.0,1620914.0,1944401.0,2310904.0,2693585.0,3095893.0,3495918.0,3858421.0,4203148.0,4936550.0,5531387.0,6029529.0,6426679.0,4.7666E7,4.9182E7,5.08432E7,5.26671E7,5.4365564E7,5.6059245E7,5.6535636E7,5.6729703E7,5.6840847E7,5.7479469E7,5.7926999E7,5.8147733E7,1426095.0,1535090.0,1665128.0,1861096.0,1997616.0,2156814.0,2298309.0,2326606.0,2378618.0,2531311.0,2664659.0,2780132.0,8.6459025E7,9.1563009E7,9.5831757E7,1.00825279E8,1.07188273E8,1.13872473E8,1.18454974E8,1.22091325E8,1.24329269E8,1.25956499E8,1.27065841E8,1.27467972E8,607914.0,746559.0,933559.0,1255058.0,1613551.0,1937652.0,2347031.0,2820042.0,3867409.0,4526235.0,5307470.0,6053193.0,6464046.0,7454779.0,8678557.0,1.0191512E7,1.2044785E7,1.4500404E7,1.7661452E7,2.1198082E7,2.5020539E7,2.8263827E7,3.1386842E7,3.5610177E7,8865488.0,9411381.0,1.0917494E7,1.2617009E7,1.4781241E7,1.632532E7,1.7647518E7,1.9067554E7,2.0711375E7,2.1585105E7,2.2215365E7,2.3301725E7,2.0947571E7,2.2611552E7,2.6420307E7,3.0131E7,3.3505E7,3.6436E7,3.9326E7,4.1622E7,4.380545E7,4.6173816E7,4.796915E7,4.904479E7,160000.0,212846.0,358266.0,575003.0,841934.0,1140357.0,1497494.0,1891487.0,1418095.0,1765345.0,2111561.0,2505559.0,1439529.0,1647412.0,1886848.0,2186894.0,2680018.0,3115787.0,3086876.0,3089353.0,3219994.0,3430388.0,3677780.0,3921278.0,748747.0,813338.0,893143.0,996380.0,1116779.0,1251524.0,1411807.0,1599200.0,1803195.0,1982823.0,2046772.0,2012649.0,863308.0,975950.0,1112796.0,1279406.0,1482628.0,1703617.0,1956875.0,2269414.0,1912974.0,2200725.0,2814651.0,3193942.0,1019729.0,1201578.0,1441863.0,1759224.0,2183877.0,2721783.0,3344074.0,3799845.0,4364501.0,4759670.0,5368585.0,6036914.0,4762912.0,5181679.0,5703324.0,6334556.0,7082430.0,8007166.0,9171477.0,1.0568642E7,1.2210395E7,1.4165114E7,1.6473477E7,1.9167654E7,2917802.0,3221238.0,3628608.0,4147252.0,4730997.0,5637246.0,6502825.0,7824747.0,1.0014249E7,1.0419991E7,1.1824495E7,1.3327079E7,6748378.0,7739235.0,8906385.0,1.0154878E7,1.1441462E7,1.2845381E7,1.4441916E7,1.6331785E7,1.8319502E7,2.0476091E7,2.2662365E7,2.4821286E7,3838168.0,4241884.0,4690372.0,5212416.0,5828158.0,6491649.0,6998256.0,7634008.0,8416215.0,9384984.0,1.0580176E7,1.2031795E7,1022556.0,1076852.0,1146757.0,1230542.0,1332786.0,1456688.0,1622136.0,1841240.0,2119465.0,2444741.0,2828858.0,3270065.0,516556.0,609816.0,701016.0,789309.0,851334.0,913025.0,992040.0,1042663.0,1096202.0,1149818.0,1200206.0,1250882.0,3.0144317E7,3.5015548E7,4.1121485E7,4.7995559E7,5.5984294E7,6.3759976E7,7.1640904E7,8.0122492E7,8.811103E7,9.5895146E7,1.02479927E8,1.08700891E8,800663.0,882134.0,1010280.0,1149500.0,1320500.0,1528000.0,1756032.0,2015133.0,2312802.0,2494803.0,2674234.0,2874127.0,413834.0,442829.0,474528.0,501035.0,527678.0,560073.0,562548.0,569473.0,621621.0,692651.0,720230.0,684736.0,9939217.0,1.140635E7,1.3056604E7,1.4770296E7,1.666067E7,1.8396941E7,2.019873E7,2.2987397E7,2.5798239E7,2.8529501E7,3.1167783E7,3.3757175E7,6446316.0,7038035.0,7788944.0,8680909.0,9809596.0,1.1127868E7,1.2587223E7,1.2891952E7,1.3160731E7,1.6603334E7,1.847378E7,1.9951656E7,2.0092996E7,2.1731844E7,2.3634436E7,2.5870271E7,2.846639E7,3.1528087E7,3.4680442E7,3.8028578E7,4.0546538E7,4.3247867E7,4.5598081E7,4.776198E7,485831.0,548080.0,621392.0,706640.0,821782.0,977026.0,1099010.0,1278184.0,1554253.0,1774766.0,1972153.0,2055080.0,9182536.0,9682338.0,1.0332057E7,1.126169E7,1.2412593E7,1.3933198E7,1.5796314E7,1.791718E7,2.0326209E7,2.3001113E7,2.5873917E7,2.890179E7,1.0381988E7,1.1026383E7,1.1805689E7,1.2596822E7,1.3329874E7,1.3852989E7,1.4310401E7,1.4665278E7,1.5174244E7,1.5604464E7,1.612283E7,1.6570613E7,1994794.0,2229407.0,2488550.0,2728150.0,2929100.0,3164900.0,3210650.0,3317166.0,3437674.0,3676187.0,3908037.0,4115771.0,1165790.0,1358828.0,1590597.0,1865490.0,2182908.0,2554598.0,2979423.0,3344353.0,4017939.0,4609572.0,5146848.0,5675356.0,3379468.0,3692184.0,4076008.0,4534062.0,5060262.0,5682086.0,6437188.0,7332638.0,8392818.0,9666252.0,1.1140655E7,1.2894865E7,3.3119096E7,3.717334E7,4.1871351E7,4.7287752E7,5.3740085E7,6.2209173E7,7.3039376E7,8.155152E7,9.3364244E7,1.06207839E8,1.19901274E8,1.35031164E8,3327728.0,3491938.0,3638919.0,3786019.0,3933004.0,4043205.0,4114787.0,4186147.0,4286357.0,4405672.0,4535591.0,4627926.0,507833.0,561977.0,628164.0,714775.0,829050.0,1004533.0,1301048.0,1593882.0,1915208.0,2283635.0,2713462.0,3204897.0,4.134656E7,4.6679944E7,5.3100671E7,6.0641899E7,6.9325921E7,7.8152686E7,9.1462088E7,1.05186881E8,1.20065004E8,1.35564834E8,1.53403524E8,1.69270617E8,940080.0,1063506.0,1215725.0,1405486.0,1616384.0,1839782.0,2036305.0,2253639.0,2484997.0,2734531.0,2990875.0,3242173.0,1555876.0,1770902.0,2009813.0,2287985.0,2614104.0,2984494.0,3366439.0,3886512.0,4483945.0,5154123.0,5884491.0,6667147.0,8025700.0,9146100.0,1.05165E7,1.21322E7,1.39547E7,1.5990099E7,1.8125129E7,2.0195924E7,2.2430449E7,2.4748122E7,2.6769436E7,2.8674757E7,2.2438691E7,2.6072194E7,3.0325264E7,3.53566E7,4.0850141E7,4.6850962E7,5.3456774E7,6.0017788E7,6.7185766E7,7.5012988E7,8.2995088E7,9.1077287E7,2.5730551E7,2.8235346E7,3.0329617E7,3.1785378E7,3.3039545E7,3.4621254E7,3.6227381E7,3.774071E7,3.8370697E7,3.8654957E7,3.8625976E7,3.8518241E7,8526050.0,8817650.0,9019800.0,9103000.0,8970450.0,9662600.0,9859650.0,9915289.0,9927680.0,1.0156415E7,1.0433867E7,1.0642836E7,2227000.0,2260000.0,2448046.0,2648961.0,2847132.0,3080828.0,3279001.0,3444468.0,3585176.0,3759430.0,3859606.0,3942491.0,257700.0,308700.0,358900.0,414024.0,461633.0,492095.0,517810.0,562035.0,622191.0,684810.0,743981.0,798094.0,1.663E7,1.7829327E7,1.8680721E7,1.9284814E7,2.0662648E7,2.1658597E7,2.2356726E7,2.2686371E7,2.2797027E7,2.2562458E7,2.2404337E7,2.2276056E7,2534927.0,2822082.0,3051242.0,3451079.0,3992121.0,4657072.0,5507565.0,6349365.0,7290203.0,7212583.0,7852401.0,8860588.0,60011.0,61325.0,65345.0,70787.0,76595.0,86796.0,98593.0,110812.0,125911.0,145608.0,170372.0,199579.0,4005677.0,4419650.0,4943029.0,5618198.0,6472756.0,8128505.0,1.1254672E7,1.4619745E7,1.6945857E7,2.1229759E7,2.450153E7,2.7601038E7,2755589.0,3054547.0,3430243.0,3965841.0,4588696.0,5260855.0,6147783.0,7171347.0,8307920.0,9535314.0,1.0870037E7,1.2267493E7,6860147.0,7271135.0,7616060.0,7971222.0,8313288.0,8686367.0,9032824.0,9230783.0,9826397.0,1.0336594E7,1.0111559E7,1.0150265E7,2143249.0,2295678.0,2467895.0,2662190.0,2879013.0,3140897.0,3464522.0,3868905.0,4260884.0,4578212.0,5359092.0,6144562.0,1127000.0,1445929.0,1750200.0,1977600.0,2152400.0,2325300.0,2651869.0,2794552.0,3235865.0,3802309.0,4197776.0,4553009.0,3558137.0,3844277.0,4237384.0,4442238.0,4593433.0,4827803.0,5048043.0,5199318.0,5302888.0,5383010.0,5410052.0,5447502.0,1489518.0,1533070.0,1582962.0,1646912.0,1694510.0,1746919.0,1861252.0,1945870.0,1999210.0,2011612.0,2011497.0,2009245.0,2526994.0,2780415.0,3080153.0,3428839.0,3840161.0,4353666.0,5828892.0,6921858.0,6099799.0,6633514.0,7753310.0,9118773.0,1.4264935E7,1.6151549E7,1.8356657E7,2.0997321E7,2.393581E7,2.7129932E7,3.1140029E7,3.5933379E7,3.9964159E7,4.2835005E7,4.4433622E7,4.3997828E7,2.854987E7,2.9841614E7,3.1158061E7,3.2850275E7,3.4513161E7,3.6439E7,3.798331E7,3.8880702E7,3.9549438E7,3.9855442E7,4.0152517E7,4.0448191E7,7982342.0,9128546.0,1.0421936E7,1.1737396E7,1.3016733E7,1.4116836E7,1.5410151E7,1.6495304E7,1.758706E7,1.8698655E7,1.9576783E7,2.0378239E7,8504667.0,9753392.0,1.1183227E7,1.2716129E7,1.4597019E7,1.7104986E7,2.0367053E7,2.472596E7,2.8227588E7,3.2160729E7,3.7090298E7,4.2292929E7,290243.0,326741.0,370006.0,420690.0,480105.0,551425.0,649901.0,779348.0,962344.0,1054486.0,1130269.0,1133066.0,7124673.0,7363802.0,7561588.0,7867931.0,8122293.0,8251648.0,8325260.0,8421403.0,8718867.0,8897619.0,8954175.0,9031088.0,4815000.0,5126000.0,5666000.0,6063000.0,6401400.0,6316424.0,6468126.0,6649942.0,6995447.0,7193761.0,7361757.0,7554661.0,3661549.0,4149908.0,4834621.0,5680812.0,6701172.0,7932503.0,9410494.0,1.1242847E7,1.3219062E7,1.5081016E7,1.7155814E7,1.9314747E7,8550362.0,1.0164215E7,1.1918938E7,1.3648692E7,1.5226039E7,1.6785196E7,1.850139E7,1.9757799E7,2.0686918E7,2.1628605E7,2.2454239E7,2.3174294E7,8322925.0,9452826.0,1.0863958E7,1.2607312E7,1.4706593E7,1.7129565E7,1.9844382E7,2.304063E7,2.6605473E7,3.0686889E7,3.4593779E7,3.813964E7,2.1289402E7,2.5041917E7,2.9263397E7,3.4024249E7,3.9276153E7,4.4148285E7,4.882716E7,5.2910342E7,5.6667095E7,6.0216677E7,6.2806748E7,6.5068149E7,1219113.0,1357445.0,1528098.0,1735550.0,2056351.0,2308582.0,2644765.0,3154264.0,3747553.0,4320890.0,4977378.0,5701579.0,662850.0,764900.0,887498.0,960155.0,975199.0,1039009.0,1116479.0,1191336.0,1183669.0,1138101.0,1101832.0,1056608.0,3647735.0,3950849.0,4286552.0,4786986.0,5303507.0,6005061.0,6734098.0,7724976.0,8523077.0,9231669.0,9770575.0,1.0276158E7,2.2235677E7,2.5670939E7,2.9788695E7,3.3411317E7,3.7492953E7,4.2404033E7,4.7328791E7,5.2881328E7,5.8179144E7,6.3047647E7,6.7308928E7,7.1158647E7,5824797.0,6675501.0,7688797.0,8900294.0,1.0190285E7,1.1457758E7,1.29394E7,1.528305E7,1.825219E7,2.1210254E7,2.4739869E7,2.9170398E7,5.043E7,5.143E7,5.3292E7,5.4959E7,5.6079E7,5.6179E7,5.6339704E7,5.698162E7,5.7866349E7,5.8808266E7,5.9912431E7,6.0776238E7,1.57553E8,1.71984E8,1.86538E8,1.98712E8,2.09896E8,2.20239E8,2.32187835E8,2.42803533E8,2.56894189E8,2.7291176E8,2.87675526E8,3.01139947E8,2252965.0,2424959.0,2598466.0,2748579.0,2829526.0,2873520.0,2953997.0,3045153.0,3149262.0,3262838.0,3363085.0,3447496.0,5439568.0,6702668.0,8143375.0,9709552.0,1.1515649E7,1.3503563E7,1.5620766E7,1.7910182E7,2.0265563E7,2.2374398E7,2.428767E7,2.6084662E7,2.6246839E7,2.8998543E7,3.379614E7,3.946391E7,4.4655014E7,5.0533506E7,5.6142181E7,6.2826491E7,6.9940728E7,7.6048996E7,8.0908147E7,8.5262356E7,1030585.0,1070439.0,1133134.0,1142636.0,1089572.0,1261091.0,1425876.0,1691210.0,2104779.0,2826046.0,3389578.0,4018332.0,4963829.0,5498090.0,6120081.0,6740785.0,7407075.0,8403990.0,9657618.0,1.121934E7,1.3367997E7,1.5826497E7,1.8701257E7,2.2211743E7,2672000.0,3016000.0,3421000.0,3900000.0,4506497.0,5216550.0,6100407.0,7272406.0,8381163.0,9417789.0,1.0595811E7,1.1746035E7,3080907.0,3646340.0,4277736.0,4995432.0,5861135.0,6642107.0,7636524.0,9216418.0,1.070434E7,1.1404948E7,1.1926563E7,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,820.8530296,853.10071,836.1971382,739.9811058,786.11336,978.0114388,852.3959448,649.3413952,635.341351,726.7340548,974.5803384,1601.056136,1942.284244,2312.888958,2760.196931,3313.422188,3533.00391,3630.880722,3738.932735,2497.437901,3193.054604,4604.211737,5937.029526,2449.008185,3013.976023,2550.81688,3246.991771,4182.663766,4910.416756,5745.160213,5681.358539,5023.216647,4797.295051,5288.040382,6223.367465,3520.610273,3827.940465,4269.276742,5522.776375,5473.288005,3008.647355,2756.953672,2430.208311,2627.845685,2277.140884,2773.287312,4797.231267,5911.315053,6856.856212,7133.166023,8052.953021,9443.038526,10079.02674,8997.897412,9139.671389,9308.41871,10967.28195,8797.640716,12779.37964,10039.59564,10949.64959,12217.22686,14526.12465,16788.62948,18334.19751,19477.00928,21888.88903,23424.76683,26997.93657,30687.75473,34435.36744,6137.076492,8842.59803,10750.72111,12834.6024,16661.6256,19749.4223,21597.08362,23687.82607,27042.01868,29095.92066,32417.60769,36126.4927,9867.084765,11635.79945,12753.27514,14804.6727,18268.65839,19340.10196,19211.14731,18524.02406,19035.57917,20292.01679,23403.55927,29796.04834,684.2441716,661.6374577,686.3415538,721.1860862,630.2336265,659.8772322,676.9818656,751.9794035,837.8101643,972.7700352,1136.39043,1391.253792,8343.105127,9714.960623,10991.20676,13149.04119,16672.14356,19117.97448,20979.84589,22525.56308,25575.57069,27561.19663,30485.88375,33692.60508,1062.7522,959.6010805,949.4990641,1035.831411,1085.796879,1029.161251,1277.897616,1225.85601,1191.207681,1232.975292,1372.877931,1441.284873,2677.326347,2127.686326,2180.972546,2586.886053,2980.331339,3548.097832,3156.510452,2753.69149,2961.699694,3326.143191,3413.26269,3822.137084,973.5331948,1353.989176,1709.683679,2172.352423,2860.16975,3528.481305,4126.613157,4314.114757,2546.781445,4766.355904,6018.975239,7446.298803,851.2411407,918.2325349,983.6539764,1214.709294,2263.611114,3214.857818,4551.14215,6205.88385,7954.111645,8647.142313,11003.60508,12569.85177,2108.944355,2487.365989,3336.585802,3429.864357,4985.711467,6660.118654,7030.835878,7807.095818,6950.283021,7957.980824,8131.212843,9065.800825,2444.286648,3008.670727,4254.337839,5577.0028,6597.494398,7612.240438,8224.191647,8239.854824,6302.623438,5970.38876,7696.777725,10680.79282,543.2552413,617.1834648,722.5120206,794.8265597,854.7359763,743.3870368,807.1985855,912.0631417,931.7527731,946.2949618,1037.645221,1217.032994,339.2964587,379.5646281,355.2032273,412.9775136,464.0995039,556.1032651,559.603231,621.8188189,631.6998778,463.1151478,446.4035126,430.0706916,368.4692856,434.0383364,496.9136476,523.4323142,421.6240257,524.9721832,624.4754784,683.8955732,682.3031755,734.28517,896.2260153,1713.778686,1172.667655,1313.048099,1399.607441,1508.453148,1684.146528,1783.432873,2367.983282,2602.664206,1793.163278,1694.337469,1934.011449,2042.09524,11367.16112,12489.95006,13462.48555,16076.58803,18970.57086,22090.88306,22898.79214,26626.51503,26342.88426,28954.92589,33328.96507,36319.23501,1071.310713,1190.844328,1193.068753,1136.056615,1070.013275,1109.374338,956.7529907,844.8763504,747.9055252,740.5063317,738.6906068,706.016537,1178.665927,1308.495577,1389.817618,1196.810565,1104.103987,1133.98495,797.9081006,952.386129,1058.0643,1004.961353,1156.18186,1704.063724,3939.978789,4315.622723,4519.094331,5106.654313,5494.024437,4756.763836,5095.665738,5547.063754,7596.125964,10118.05318,10778.78385,13171.63885,400.448611,575.9870009,487.6740183,612.7056934,676.9000921,741.2374699,962.4213805,1378.904018,1655.784158,2289.234136,3119.280896,4959.114854,2144.115096,2323.805581,2492.351109,2678.729839,3264.660041,3815.80787,4397.575659,4903.2191,5444.648617,6117.361746,5755.259962,7006.580419,1102.990936,1211.148548,1406.648278,1876.029643,1937.577675,1172.603047,1267.100083,1315.980812,1246.90737,1173.618235,1075.811558,986.1478792,780.5423257,905.8602303,896.3146335,861.5932424,904.8960685,795.757282,673.7478181,672.774812,457.7191807,312.188423,241.1658765,277.5518587,2125.621418,2315.056572,2464.783157,2677.939642,3213.152683,3259.178978,4879.507522,4201.194937,4016.239529,3484.164376,3484.06197,3632.557798,2627.009471,2990.010802,3460.937025,4161.727834,5118.146939,5926.876967,5262.734751,5629.915318,6160.416317,6677.045314,7723.447195,9645.06142,1388.594732,1500.895925,1728.869428,2052.050473,2378.201111,2517.736547,2602.710169,2156.956069,1648.073791,1786.265407,1648.800823,1544.750112,3119.23652,4338.231617,5477.890018,6960.297861,9164.090127,11305.38517,13221.82184,13822.58394,8447.794873,9875.604515,11628.38895,14619.22272,5586.53878,6092.174359,5180.75591,5690.268015,5305.445256,6380.494966,7316.918107,7532.924763,5592.843963,5431.990415,6340.646683,8948.102923,6876.14025,8256.343918,10136.86713,11399.44489,13108.4536,14800.16062,15377.22855,16310.4434,14297.02122,16048.51424,17596.21022,22833.30851,9692.385245,11099.65935,13583.31351,15937.21123,18866.20721,20422.9015,21688.04048,25116.17581,26406.73985,29804.34567,32166.50006,35278.41874,2669.529475,2864.969076,3020.989263,3020.050513,3694.212352,3081.761022,2879.468067,2880.102568,2377.156192,1895.016984,1908.260867,2082.481567,1397.717137,1544.402995,1662.137359,1653.723003,2189.874499,2681.9889,2861.092386,2899.842175,3044.214214,3614.101285,4563.808154,6025.374752,3522.110717,3780.546651,4086.114078,4579.074215,5280.99471,6679.62326,7213.791267,6481.776993,7103.702595,7429.455877,5773.044512,6873.262326,1418.822445,1458.915272,1693.335853,1814.880728,2024.008147,2785.493582,3503.729636,3885.46071,3794.755195,4173.181797,4754.604414,5581.180998,3048.3029,3421.523218,3776.803627,4358.595393,4520.246008,5138.922374,4098.344175,4140.442097,4444.2317,5154.825496,5351.568666,5728.353514,375.6431231,426.0964081,582.8419714,915.5960025,672.4122571,958.5668124,927.8253427,966.8968149,1132.055034,2814.480755,7703.4959,12154.08975,328.9405571,344.1618859,380.9958433,468.7949699,514.3242082,505.7538077,524.8758493,521.1341333,582.8585102,913.47079,765.3500015,641.3695236,362.1462796,378.9041632,419.4564161,516.1186438,566.2439442,556.8083834,577.8607471,573.7413142,421.3534653,515.8894013,530.0535319,690.8055759,6424.519071,7545.415386,9371.842561,10921.63626,14358.8759,15605.42283,18533.15761,21141.01223,20647.16499,23723.9502,28204.59057,33207.0844,7029.809327,8662.834898,10560.48553,12999.91766,16107.19171,18292.63514,20293.89746,22066.44214,24703.79615,25889.78487,28926.03234,30470.0167,4293.476475,4976.198099,6631.459222,8358.761987,11401.94841,21745.57328,15113.36194,11864.40844,13522.15752,14722.84188,12521.71392,13206.48452,485.2306591,520.9267111,599.650276,734.7829124,756.0868363,884.7552507,835.8096108,611.6588611,665.6244126,653.7301704,660.5855997,752.7497265,7144.114393,10187.82665,12902.46291,14745.62561,18016.18027,20512.92123,22031.53274,24639.18566,26505.30317,27788.88416,30035.80198,32170.37442,911.2989371,1043.561537,1190.041118,1125.69716,1178.223708,993.2239571,876.032569,847.0061135,925.060154,1005.245812,1111.984578,1327.60891,3530.690067,4916.299889,6017.190733,8513.097016,12724.82957,14195.52428,15268.42089,16120.52839,17541.49634,18747.69814,22514.2548,27538.41188,2428.237769,2617.155967,2750.364446,3242.531147,4031.408271,4879.992748,4820.49479,4246.485974,4439.45084,4684.313807,4858.347495,5186.050003,510.1964923,576.2670245,686.3736739,708.7595409,741.6662307,874.6858643,857.2503577,805.5724718,794.3484384,869.4497668,945.5835837,942.6542111,299.850319,431.7904566,522.0343725,715.5806402,820.2245876,764.7259628,838.1239671,736.4153921,745.5398706,796.6644681,575.7047176,579.231743,1840.366939,1726.887882,1796.589032,1452.057666,1654.456946,1874.298931,2011.159549,1823.015995,1456.309517,1341.726931,1270.364932,1201.637154,2194.926204,2220.487682,2291.156835,2538.269358,2529.842345,3203.208066,3121.760794,3023.096699,3081.694603,3160.454906,3099.72866,3548.330846,3054.421209,3629.076457,4692.648272,6197.962814,8315.928145,11186.14125,14560.53051,20038.47269,24757.60301,28377.63219,30209.01516,39724.97867,5263.673816,6040.180011,7550.359877,9326.64467,10168.65611,11674.83737,12545.99066,12986.47998,10535.62855,11712.7768,14843.93556,18008.94444,7267.688428,9244.001412,10350.15906,13319.89568,15798.06362,19654.96247,23269.6075,26923.20628,25144.39201,28061.09966,31163.20196,36180.78919,546.5657493,590.061996,658.3471509,700.7706107,724.032527,813.337323,855.7235377,976.5126756,1164.406809,1458.817442,1746.769454,2452.210407,749.6816546,858.9002707,849.2897701,762.4317721,1111.107907,1382.702056,1516.872988,1748.356961,2383.140898,3119.335603,2873.91287,3540.651564,3035.326002,3290.257643,4187.329802,5906.731805,9613.818607,11888.59508,7608.334602,6642.881371,7235.653188,8263.590301,9240.761975,11605.71449,4129.766056,6229.333562,8341.737815,8931.459811,9576.037596,14688.23507,14517.90711,11643.57268,3745.640687,3076.239795,4390.717312,4471.061906,5210.280328,5599.077872,6631.597314,7655.568963,9530.772896,11150.98113,12618.32141,13872.86652,17558.81555,24521.94713,34077.04939,40675.99635,4086.522128,5385.278451,7105.630706,8393.741404,12786.93223,13306.61921,15367.0292,17122.47986,18051.52254,20896.60924,21905.59514,25523.2771,4931.404155,6248.656232,8243.58234,10022.40131,12269.27378,14255.98475,16537.4835,19207.23482,22013.64486,24675.02446,27968.09817,28569.7197,2898.530881,4756.525781,5246.107524,6124.703451,7433.889293,6650.195573,6068.05135,6351.237495,7404.923685,7121.924704,6994.774861,7320.880262,3216.956347,4317.694365,6576.649461,9847.788607,14778.78636,16610.37701,19384.10571,22375.94189,26824.89511,28816.58499,28604.5919,31656.06806,1546.907807,1886.080591,2348.009158,2741.796252,2110.856309,2852.351568,4161.415959,4448.679912,3431.593647,3645.379572,3844.917194,4519.461171,853.540919,944.4383152,896.9663732,1056.736457,1222.359968,1267.613204,1348.225791,1361.936856,1341.921721,1360.485021,1287.514732,1463.249282,1088.277758,1571.134655,1621.693598,2143.540609,3701.621503,4106.301249,4106.525293,4106.492315,3726.063507,1690.756814,1646.758151,1593.06548,1030.592226,1487.593537,1536.344387,2029.228142,3030.87665,4657.22102,5622.942464,8533.088805,12104.27872,15993.52796,19233.98818,23348.13973,108382.3529,113523.1329,95458.11176,80894.88326,109347.867,59265.47714,31354.03573,28118.42998,34932.91959,40300.61996,35110.10566,47306.98978,4834.804067,6089.786934,5714.560611,6006.983042,7486.384341,8659.696836,7640.519521,5377.091329,6890.806854,8754.96385,9313.93883,10461.05868,298.8462121,335.9971151,411.8006266,498.6390265,496.5815922,745.3695408,797.2631074,773.9932141,977.4862725,1186.147994,1275.184575,1569.331442,575.5729961,620.9699901,634.1951625,713.6036483,803.0054535,640.3224383,572.1995694,506.1138573,636.6229191,609.1739508,531.4823679,414.5073415,2387.54806,3448.284395,6757.030816,18772.75169,21011.49721,21951.21176,17364.27538,11770.5898,9640.138501,9467.446056,9534.677467,12057.49928,1443.011715,1589.20275,1643.38711,1634.047282,1748.562982,1544.228586,1302.878658,1155.441948,1040.67619,986.2958956,894.6370822,1044.770126,369.1650802,416.3698064,427.9010856,495.5147806,584.6219709,663.2236766,632.8039209,635.5173634,563.2000145,692.2758103,665.4231186,759.3499101,1831.132894,1810.066992,2036.884944,2277.742396,2849.09478,3827.921571,4920.355951,5249.802653,7277.912802,10132.90964,10206.97794,12451.6558,452.3369807,490.3821867,496.1743428,545.0098873,581.3688761,686.3952693,618.0140641,684.1715576,739.014375,790.2579846,951.4097518,1042.581557,743.1159097,846.1202613,1055.896036,1421.145193,1586.851781,1497.492223,1481.150189,1421.603576,1361.369784,1483.136136,1579.019543,1803.151496,1967.955707,2034.037981,2529.067487,2475.387562,2575.484158,3710.982963,3688.037739,4783.586903,6058.253846,7425.705295,9021.815894,10956.99112,3478.125529,4131.546641,4581.609385,5754.733883,6809.40669,7674.929108,9611.147541,8688.156003,9472.384295,9767.29753,10742.44053,11977.57496,786.5668575,912.6626085,1056.353958,1226.04113,1421.741975,1647.511665,2000.603139,2338.008304,1785.402016,1902.2521,2140.739323,3095.772271,2647.585601,3682.259903,4649.593785,5907.850937,7778.414017,9595.929905,11222.58762,11732.51017,7003.339037,6465.613349,6557.194282,9253.896111,1688.20357,1642.002314,1566.353493,1711.04477,1930.194975,2370.619976,2702.620356,2755.046991,2948.047252,2982.101858,3258.495584,3820.17523,468.5260381,495.5868333,556.6863539,566.6691539,724.9178037,502.3197334,462.2114149,389.8761846,410.8968239,472.3460771,633.6179466,823.6856205,331.0,350.0,388.0,349.0,357.0,371.0,424.0,385.0,347.0,415.0,611.0,944.0,2423.780443,2621.448058,3173.215595,3793.694753,3746.080948,3876.485958,4191.100511,3693.731337,3804.537999,3899.52426,4072.324751,4811.060429,545.8657229,597.9363558,652.3968593,676.4422254,674.7881296,694.1124398,718.3730947,775.6324501,897.7403604,1010.892138,1057.206311,1091.359778,8941.571858,11276.19344,12790.84956,15363.25136,18794.74567,21209.0592,21399.46046,23651.32361,26790.94961,30246.13063,33724.75778,36797.93332,10556.57566,12247.39532,13175.678,14463.91893,16046.03728,16233.7177,17632.4104,19007.19129,18363.32494,21050.41377,23189.80135,25185.00911,3112.363948,3457.415947,3634.364406,4643.393534,4688.593267,5486.371089,3470.338156,2955.984375,2170.151724,2253.023004,2474.548819,2749.320965,761.879376,835.5234025,997.7661127,1054.384891,954.2092363,808.8970728,909.7221354,668.3000228,581.182725,580.3052092,601.0745012,619.6768924,1077.281856,1100.592563,1150.927478,1014.514104,1698.388838,1981.951806,1576.97375,1385.029563,1619.848217,1624.941275,1615.286395,2013.977305,10095.42172,11653.97304,13450.40151,16361.87647,18965.05551,23311.34939,26298.63531,31540.9748,33965.66115,41283.16433,44683.97525,49357.19017,1828.230307,2242.746551,2924.638113,4720.942687,10618.03855,11848.34392,12954.79101,18115.22313,18616.70691,19702.05581,19774.83687,22316.19287,684.5971438,747.0835292,803.3427418,942.4082588,1049.938981,1175.921193,1443.429832,1704.686583,1971.829464,2049.350521,2092.712441,2605.94758,2480.380334,2961.800905,3536.540301,4421.009084,5364.249663,5351.912144,7009.601598,7034.779161,6618.74305,7113.692252,7356.031934,9809.185636,1952.308701,2046.154706,2148.027146,2299.376311,2523.337977,3248.373311,4258.503604,3998.875695,4196.411078,4247.400261,3783.674243,4172.838464,3758.523437,4245.256698,4957.037982,5788.09333,5937.827283,6281.290855,6434.501797,6360.943444,4446.380924,5838.347657,5909.020073,7408.905561,1272.880995,1547.944844,1649.552153,1814.12743,1989.37407,2373.204287,2603.273765,2189.634995,2279.324017,2536.534925,2650.921068,3190.481016,4029.329699,4734.253019,5338.752143,6557.152776,8006.506993,9508.141454,8451.531004,9082.351172,7738.881247,10159.58368,12002.23908,15389.92468,3068.319867,3774.571743,4727.954889,6361.517993,9022.247417,10172.48572,11753.84291,13039.30876,16207.26663,17641.03156,19970.90787,20509.64777,3081.959785,3907.156189,5108.34463,6929.277714,9123.041742,9770.524921,10330.98915,12281.34191,14641.58711,16999.4333,18855.60618,19328.70901,2718.885295,2769.451844,3173.72334,4021.175739,5047.658563,4319.804067,5267.219353,5303.377488,6101.255823,6071.941411,6316.1652,7670.122558,3144.613186,3943.370225,4734.997586,6470.866545,8011.414402,9356.39724,9605.314053,9696.273295,6598.409903,7346.547557,7885.360081,10808.47561,493.3238752,540.2893983,597.4730727,510.9637142,590.5806638,670.0806011,881.5706467,847.991217,737.0685949,589.9445051,785.6537648,863.0884639,879.5835855,860.7369026,1071.551119,1384.840593,1532.985254,1737.561657,1890.218117,1516.525457,1428.777814,1339.076036,1353.09239,1598.435089,6459.554823,8157.591248,11626.41975,16903.04886,24837.42865,34167.7626,33693.17525,21198.26136,24841.61777,20586.69019,19014.54118,21654.83194,1450.356983,1567.653006,1654.988723,1612.404632,1597.712056,1561.769116,1518.479984,1441.72072,1367.899369,1392.368347,1519.635262,1712.472136,3581.459448,4981.090891,6289.629157,7991.707066,10522.06749,12980.66956,15181.0927,15870.87851,9325.068238,7914.320304,7236.075251,9786.534714,879.7877358,1004.484437,1116.639877,1206.043465,1353.759762,1348.285159,1465.010784,1294.447788,1068.696278,574.6481576,699.489713,862.5407561,2315.138227,2843.104409,3674.735572,4977.41854,8597.756202,11210.08948,15169.16112,18861.53081,24769.8912,33519.4766,36023.1054,47143.17964,5074.659104,6093.26298,7481.107598,8412.902397,9674.167626,10922.66404,11348.54585,12037.26758,9498.467723,12126.23065,13638.77837,18678.31435,4215.041741,5862.276629,7402.303395,9405.489397,12383.4862,15277.03017,17866.72175,18678.53492,14214.71681,17161.10735,20660.01936,25768.25759,1135.749842,1258.147413,1369.488336,1284.73318,1254.576127,1450.992513,1176.807031,1093.244963,926.9602964,930.5964284,882.0818218,926.1410683,4725.295531,5487.104219,5768.729717,7114.477971,7765.962636,8028.651439,8568.266228,7825.823398,7225.069258,7479.188244,7710.946444,9269.657808,3834.034742,4564.80241,5693.843879,7993.512294,10638.75131,13236.92117,13926.16997,15764.98313,18603.06452,20445.29896,24835.47166,28821.0637,1083.53203,1072.546602,1074.47196,1135.514326,1213.39553,1348.775651,1648.079789,1876.766827,2153.739222,2664.477257,3015.378833,3970.095407,1615.991129,1770.337074,1959.593767,1687.997641,1659.652775,2202.988423,1895.544073,1507.819159,1492.197043,1632.210764,1993.398314,2602.394995,1148.376626,1244.708364,1856.182125,2613.101665,3364.836625,3781.410618,3895.384018,3984.839812,3553.0224,3876.76846,4128.116943,4513.480643,8527.844662,9911.878226,12329.44192,15258.29697,17832.02464,18855.72521,20667.38125,23586.92927,23880.01683,25266.59499,29341.63093,33859.74835,14734.23275,17909.48973,20431.0927,22966.14432,27195.11304,26982.29052,28397.71512,30281.70459,31871.5303,32135.32301,34480.95771,37506.41907,1643.485354,2117.234893,2193.037133,1881.923632,2571.423014,3195.484582,3761.837715,3116.774285,3340.542768,4014.238972,4090.925331,4184.548089,1206.947913,1507.86129,1822.879028,2643.858681,4062.523897,5596.519826,7426.354774,11054.56175,15215.6579,20206.82098,23235.42329,28718.27684,716.6500721,698.5356073,722.0038073,848.2186575,915.9850592,962.4922932,874.2426069,831.8220794,825.682454,789.1862231,899.0742111,1107.482182,757.7974177,793.5774148,1002.199172,1295.46066,1524.358936,1961.224635,2393.219781,2982.653773,4616.896545,5852.625497,5913.187529,7458.396327,859.8086567,925.9083202,1067.53481,1477.59676,1649.660188,1532.776998,1344.577953,1202.201361,1034.298904,982.2869243,886.2205765,882.9699438,3023.271928,4100.3934,4997.523971,5621.368472,6619.551419,7899.554209,9119.528607,7388.597823,7370.990932,8792.573126,11460.60023,18008.50924,1468.475631,1395.232468,1660.30321,1932.360167,2753.285994,3120.876811,3560.233174,3810.419296,4332.720164,4876.798614,5722.895655,7092.923025,1969.10098,2218.754257,2322.869908,2826.356387,3450.69638,4269.122326,4241.356344,5089.043686,5678.348271,6601.429915,6508.085718,8458.276384,734.753484,774.3710692,767.2717398,908.9185217,950.735869,843.7331372,682.2662268,617.7244065,644.1707969,816.559081,927.7210018,1056.380121,9979.508487,11283.17795,12477.17707,14142.85089,15895.11641,17428.74846,18232.42452,21664.78767,22705.09254,26074.53136,29478.99919,33203.26128,13990.48208,14847.12712,16173.14586,19530.36557,21806.03594,24072.63213,25009.55914,29884.35041,32003.93224,35767.43303,39097.09955,42951.65309,5716.766744,6150.772969,5603.357717,5444.61962,5703.408898,6504.339663,6920.223051,7452.398969,8137.004775,9230.240708,7727.002004,10611.46299,7689.799761,9802.466526,8422.974165,9541.474188,10505.25966,13143.95095,11152.41011,9883.584648,10733.92631,10165.49518,8605.047831,11415.80569,605.0664917,676.2854478,772.0491602,637.1232887,699.5016441,713.5371196,707.2357863,820.7994449,989.0231487,1385.896769,1764.456677,2441.576404,1515.592329,1827.067742,2198.956312,2649.715007,3133.409277,3682.831494,4336.032082,5107.197384,6017.654756,7110.667619,4515.487575,3025.349798,781.7175761,804.8304547,825.6232006,862.4421463,1265.047031,1829.765177,1977.55701,1971.741538,1879.496673,2117.484526,2234.820827,2280.769906,1147.388831,1311.956766,1452.725766,1777.077318,1773.498265,1588.688299,1408.678565,1213.315116,1210.884633,1071.353818,1071.613938,1271.211593,406.8841148,518.7642681,527.2721818,569.7950712,799.3621758,685.5876821,788.8550411,706.1573059,693.4207856,792.4499603,672.0386227,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"grey\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"breaks\":[1000.0,10000.0,25000.0,50000.0,100000.0],\n",
       "\"labels\":[\"$1K\",\"$10K\",\"$25K\",\"$50K\",\"$100K\"],\n",
       "\"trans\":\"log10\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"egXfeh\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b16490>"
      ]
     },
     "execution_count": 80,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             ) +\n",
    "            #  add country name to hover\n",
    "        geom_point(alpha=0.5) +\n",
    "        scale_x_log10(\n",
    "            breaks = [1000, 10000, 25000, 50000, 100000],\n",
    "            labels = [f'${nz.numerize(x)}' for x in [1000, 10000, 25000, 50000, 100000]]\n",
    "            ) +\n",
    "        theme_grey()       \n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Fix the labels"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Finally, add some lables to change the default variable names. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 81,
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    },
    "tags": [
     "r-fit-text"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"yzLXfp\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,30.332,31.997,34.02,36.088,38.438,39.854,40.822,41.674,41.763,42.129,43.828,55.23,59.28,64.82,66.22,67.69,68.93,70.42,72.0,71.581,72.95,75.651,76.423,43.077,45.685,48.303,51.407,54.518,58.014,61.368,65.799,67.744,69.152,70.994,72.301,30.015,31.999,34.0,35.985,37.928,39.483,39.942,39.906,40.647,40.963,41.003,42.731,62.485,64.399,65.142,65.634,67.065,68.481,69.942,70.774,71.868,73.275,74.34,75.32,69.12,70.33,70.93,71.1,71.93,73.49,74.74,76.32,77.56,78.83,80.37,81.235,66.8,67.48,69.54,70.14,70.63,72.17,73.18,74.94,76.04,77.51,78.98,79.829,50.939,53.832,56.923,59.923,63.3,65.593,69.052,70.75,72.601,73.925,74.795,75.635,37.484,39.348,41.216,43.453,45.252,46.923,50.009,52.819,56.018,59.412,62.013,64.062,68.0,69.24,70.25,70.94,71.44,72.8,73.93,75.35,76.46,77.53,78.32,79.441,38.223,40.358,42.618,44.885,47.014,49.19,50.904,52.337,53.919,54.777,54.406,56.728,40.414,41.89,43.428,45.032,46.714,50.023,53.859,57.251,59.957,62.05,63.883,65.554,53.82,58.45,61.93,64.79,67.45,69.86,70.69,71.14,72.178,73.244,74.09,74.852,47.622,49.618,51.52,53.298,56.024,59.319,61.484,63.622,62.745,52.556,46.634,50.728,50.917,53.285,55.665,57.632,59.504,61.489,63.336,65.205,67.057,69.388,71.006,72.39,59.6,66.61,69.51,70.42,70.9,70.81,71.08,71.34,71.19,70.32,72.14,73.005,31.975,34.906,37.814,40.697,43.591,46.137,48.122,49.557,50.26,50.324,50.65,52.295,39.031,40.533,42.045,43.548,44.057,45.91,47.471,48.211,44.736,45.326,47.36,49.58,39.417,41.366,43.415,45.415,40.317,31.22,50.957,53.914,55.803,56.534,56.752,59.723,38.523,40.428,42.643,44.799,47.049,49.355,52.961,54.985,54.314,52.199,49.856,50.43,68.75,69.96,71.3,72.13,72.88,74.21,75.76,76.86,77.95,78.61,79.77,80.653,35.463,37.464,39.475,41.478,43.457,46.775,48.295,50.485,49.396,46.066,43.308,44.741,38.092,39.881,41.716,43.601,45.569,47.383,49.517,51.051,51.724,51.573,50.525,50.651,54.745,56.074,57.924,60.523,63.441,67.052,70.565,72.492,74.126,75.816,77.86,78.553,44.0,50.54896,44.50136,58.38112,63.11888,63.96736,65.525,67.274,68.69,70.426,72.028,72.961,50.643,55.118,57.863,59.963,61.623,63.837,66.653,67.768,68.421,70.313,71.682,72.889,40.715,42.46,44.467,46.472,48.944,50.939,52.933,54.926,57.939,60.66,62.974,65.152,39.143,40.652,42.122,44.056,45.989,47.804,47.784,47.412,45.548,42.587,44.966,46.462,42.111,45.053,48.435,52.04,54.907,55.625,56.695,57.47,56.433,52.962,52.97,55.322,57.206,60.026,62.842,65.424,67.849,70.75,73.45,74.752,75.713,77.26,78.123,78.782,40.477,42.469,44.93,47.35,49.801,52.374,53.983,54.655,52.044,47.991,46.832,48.328,61.21,64.77,67.13,68.5,69.61,70.64,70.46,71.52,72.527,73.68,74.876,75.748,59.421,62.325,65.246,68.29,70.723,72.649,73.717,74.174,74.414,76.151,77.158,78.273,66.87,69.03,69.9,70.38,70.29,70.71,70.96,71.58,72.4,74.01,75.51,76.486,70.78,71.81,72.35,72.96,73.47,74.69,74.63,74.8,75.33,76.11,77.18,78.332,34.812,37.328,39.693,42.074,44.366,46.519,48.812,50.04,51.604,53.157,53.373,54.791,45.928,49.828,53.459,56.751,59.631,61.788,63.727,66.046,68.457,69.957,70.847,72.235,48.357,51.356,54.64,56.678,58.796,61.31,64.342,67.231,69.613,72.312,74.173,74.994,41.893,44.444,46.992,49.293,51.137,53.319,56.006,59.797,63.674,67.217,69.806,71.338,45.262,48.57,52.307,55.855,58.207,56.696,56.604,63.154,66.798,69.535,70.734,71.878,34.482,35.983,37.485,38.987,40.516,42.024,43.662,45.664,47.545,48.245,49.348,51.579,35.928,38.047,40.158,42.189,44.142,44.535,43.89,46.453,49.991,53.378,55.24,58.04,34.078,36.667,40.059,42.115,43.515,44.51,44.916,46.684,48.091,49.402,50.725,52.947,66.55,67.49,68.75,69.83,70.87,72.52,74.55,74.83,75.7,77.13,78.37,79.313,67.41,68.93,70.51,71.55,72.38,73.83,74.89,76.34,77.46,78.64,79.59,80.657,37.003,38.999,40.489,44.598,48.69,52.79,56.564,60.19,61.366,60.461,56.761,56.735,30.0,32.065,33.896,35.857,38.308,41.842,45.58,49.265,52.644,55.861,58.041,59.448,67.5,69.1,70.3,70.8,71.0,72.5,73.8,74.847,76.07,77.34,78.67,79.406,43.149,44.779,46.452,48.072,49.875,51.756,53.744,55.729,57.501,58.556,58.453,60.022,65.86,67.86,69.51,71.0,72.34,73.68,75.24,76.67,77.03,77.869,78.256,79.483,42.023,44.142,46.954,50.016,53.738,56.029,58.137,60.782,63.373,66.322,68.978,70.259,33.609,34.558,35.753,37.197,38.842,40.762,42.891,45.552,48.576,51.455,53.676,56.007,32.5,33.489,34.488,35.492,36.486,37.465,39.327,41.245,43.266,44.873,45.504,46.388,37.579,40.696,43.59,46.243,48.042,49.923,51.461,53.636,55.089,56.671,58.137,60.916,41.912,44.665,48.041,50.924,53.884,57.402,60.909,64.492,66.399,67.659,68.565,70.198,60.96,64.75,67.65,70.0,72.0,73.6,75.45,76.2,77.601,80.0,81.495,82.208,64.03,66.41,67.96,69.5,69.76,69.95,69.39,69.58,69.17,71.04,72.59,73.338,72.49,73.47,73.68,73.73,74.46,76.11,76.99,77.23,78.77,78.95,80.5,81.757,37.373,40.249,43.605,47.193,50.651,54.208,56.596,58.553,60.223,61.765,62.879,64.698,37.468,39.918,42.518,45.964,49.203,52.702,56.159,60.137,62.681,66.041,68.588,70.65,44.869,47.181,49.325,52.469,55.234,57.702,59.62,63.04,65.742,68.042,69.451,70.964,45.32,48.437,51.457,54.459,56.95,60.413,62.038,65.044,59.461,58.811,57.046,59.545,66.91,68.9,70.29,71.08,71.28,72.03,73.1,74.36,75.467,76.122,77.783,78.885,65.39,67.84,69.39,70.75,71.63,73.06,74.45,75.6,76.93,78.269,79.696,80.745,65.94,67.81,69.24,71.06,72.19,73.48,74.98,76.42,77.44,78.82,80.24,80.546,58.53,62.61,65.61,67.51,69.0,70.11,71.21,71.77,71.766,72.262,72.047,72.567,63.03,65.5,68.73,71.43,73.42,75.38,77.11,78.67,79.36,80.69,82.0,82.603,43.158,45.669,48.126,51.629,56.528,61.134,63.739,65.869,68.015,69.772,71.263,72.535,42.27,44.686,47.949,50.654,53.559,56.155,58.766,59.339,59.285,54.407,50.992,54.11,50.056,54.081,56.656,59.942,63.983,67.159,69.1,70.647,69.978,67.727,66.662,67.297,47.453,52.681,55.292,57.716,62.612,64.766,67.123,69.81,72.244,74.647,77.045,78.623,55.565,58.033,60.47,64.624,67.712,69.343,71.309,74.174,75.19,76.156,76.904,77.588,55.928,59.489,62.094,63.87,65.421,66.099,66.983,67.926,69.292,70.265,71.028,71.993,42.138,45.047,47.747,48.492,49.767,52.208,55.078,57.18,59.685,55.558,44.593,42.592,38.48,39.486,40.502,41.536,42.614,43.764,44.852,46.027,40.802,42.221,43.753,45.678,42.723,45.289,47.808,50.227,52.773,57.442,62.155,66.234,68.755,71.555,72.737,73.952,36.681,38.865,40.848,42.881,44.851,46.881,48.969,49.35,52.214,54.978,57.286,59.443,36.256,37.207,38.41,39.487,41.766,43.767,45.642,47.457,49.42,47.495,45.009,48.303,48.463,52.102,55.737,59.371,63.01,65.256,68.0,69.5,70.693,71.938,73.044,74.241,33.685,35.307,36.936,38.487,39.977,41.714,43.916,46.364,48.388,49.903,51.818,54.467,40.543,42.338,44.248,46.289,48.437,50.852,53.599,56.145,58.333,60.43,62.247,64.164,50.986,58.089,60.246,61.557,62.944,64.93,66.711,68.74,69.745,70.736,71.954,72.801,50.789,55.19,58.299,60.11,62.361,65.032,67.405,69.498,71.455,73.67,74.902,76.195,42.244,45.248,48.251,51.253,53.754,55.491,57.489,60.222,61.271,63.625,65.033,66.803,59.164,61.448,63.728,67.178,70.636,73.066,74.101,74.865,75.435,75.445,73.981,74.543,42.873,45.423,47.924,50.335,52.862,55.73,59.65,62.677,65.393,67.66,69.615,71.164,31.286,33.779,36.161,38.113,40.328,42.495,42.795,42.861,44.284,46.344,44.026,42.082,36.319,41.905,45.108,49.379,53.07,56.059,58.056,58.339,59.32,60.328,59.908,62.069,41.725,45.226,48.386,51.159,53.867,56.437,58.968,60.835,61.999,58.909,51.479,52.906,36.157,37.686,39.393,41.472,43.971,46.748,49.594,52.537,55.727,59.426,61.34,63.785,72.13,72.99,73.23,73.82,73.75,75.24,76.05,76.83,77.42,78.03,78.53,79.762,69.39,70.26,71.24,71.52,71.89,72.22,73.84,74.32,76.33,77.55,79.11,80.204,42.314,45.432,48.632,51.884,55.151,57.47,59.298,62.008,65.843,68.426,70.836,72.899,37.444,38.598,39.487,40.118,40.546,41.291,42.598,44.555,47.391,51.313,54.496,56.867,36.324,37.802,39.36,41.04,42.821,44.514,45.826,46.886,47.472,47.464,46.608,46.859,72.67,73.44,73.47,74.08,74.34,75.37,75.97,75.89,77.32,78.32,79.05,80.196,37.578,40.08,43.165,46.988,52.143,57.367,62.728,67.734,71.197,72.499,74.193,75.64,43.436,45.557,47.67,49.8,51.929,54.043,56.158,58.245,60.838,61.818,63.61,65.483,55.191,59.201,61.817,64.071,66.216,68.681,70.472,71.523,72.462,73.738,74.712,75.537,62.649,63.196,64.361,64.951,65.815,66.353,66.874,67.378,68.225,69.4,70.755,71.752,43.902,46.263,49.096,51.445,55.448,58.447,61.406,64.134,66.458,68.386,69.906,71.421,47.752,51.334,54.757,56.393,58.065,60.06,62.082,64.151,66.458,68.564,70.303,71.688,61.31,65.77,67.64,69.61,70.85,70.67,71.32,70.98,70.99,72.75,74.67,75.563,59.82,61.51,64.39,66.6,69.26,70.41,72.77,74.06,74.86,75.97,77.29,78.098,64.28,68.54,69.62,71.1,72.16,73.44,73.75,74.63,73.911,74.917,77.778,78.746,52.724,55.09,57.666,60.542,64.274,67.064,69.885,71.913,73.615,74.772,75.744,76.442,61.05,64.1,66.8,66.8,69.21,69.46,69.66,69.53,69.36,69.72,71.322,72.476,40.0,41.5,43.0,44.1,44.6,45.0,46.218,44.02,23.599,36.087,43.413,46.242,46.471,48.945,51.893,54.425,56.48,58.55,60.351,61.728,62.742,63.306,64.337,65.528,39.875,42.868,45.914,49.901,53.886,58.69,63.012,66.295,68.768,70.533,71.626,72.777,37.278,39.329,41.454,43.563,45.815,48.879,52.379,55.769,58.196,60.187,61.6,63.062,57.996,61.685,64.531,66.914,68.7,70.3,70.162,71.218,71.659,72.232,73.213,74.002,30.331,31.57,32.767,34.113,35.4,36.788,38.445,40.006,38.333,39.897,41.012,42.568,60.396,63.179,65.798,67.946,69.521,70.795,71.76,73.56,75.788,77.158,78.77,79.972,64.36,67.45,70.33,70.98,70.35,70.45,70.8,71.08,71.38,72.71,73.8,74.663,65.57,67.85,69.15,69.18,69.82,70.97,71.063,72.25,73.64,75.13,76.66,77.926,32.978,34.977,36.981,38.977,40.973,41.974,42.955,44.501,39.658,43.795,45.936,48.159,45.009,47.985,49.951,51.927,53.696,55.527,58.161,60.834,61.888,60.236,53.365,49.339,64.94,66.66,69.69,71.44,73.06,74.39,76.3,76.9,77.57,78.77,79.78,80.941,57.593,61.456,62.192,64.266,65.042,65.949,68.757,69.011,70.379,70.457,70.815,72.396,38.635,39.624,40.87,42.858,45.083,47.8,50.338,51.744,53.556,55.373,56.369,58.556,41.407,43.424,44.992,46.633,49.552,52.537,55.561,57.678,58.474,54.289,43.869,39.613,71.86,72.49,73.37,74.16,74.72,75.44,76.42,77.19,78.16,79.39,80.04,80.884,69.62,70.56,71.32,72.77,73.78,75.39,76.21,77.41,78.03,79.37,80.62,81.701,45.883,48.284,50.305,53.655,57.296,61.195,64.59,66.974,69.249,71.527,73.053,74.143,58.5,62.4,65.2,67.5,69.39,70.59,72.16,73.4,74.26,75.25,76.99,78.4,41.215,42.974,44.246,45.757,47.62,49.919,50.608,51.535,50.44,48.466,49.651,52.517,50.848,53.63,56.061,58.285,60.405,62.494,64.597,66.084,67.298,67.521,68.564,70.616,38.596,41.208,43.922,46.769,49.759,52.887,55.471,56.941,58.061,58.39,57.561,58.42,59.1,61.8,64.9,65.4,65.9,68.3,68.832,69.582,69.862,69.465,68.976,69.819,44.6,47.1,49.579,52.053,55.602,59.837,64.048,66.894,70.001,71.973,73.042,73.923,43.585,48.079,52.098,54.336,57.005,59.507,61.036,63.108,66.146,68.835,70.845,71.777,39.978,42.571,45.344,48.051,51.016,50.35,49.849,51.509,48.825,44.578,47.813,51.542,69.18,70.42,70.76,71.36,72.01,72.76,74.04,75.007,76.42,77.218,78.471,79.425,68.44,69.49,70.21,70.76,71.34,73.38,74.65,75.02,76.09,76.81,77.31,78.242,66.071,67.044,68.253,68.468,68.673,69.481,70.805,71.918,72.752,74.223,75.307,76.384,55.088,57.907,60.77,63.479,65.712,67.456,68.557,70.19,71.15,72.146,72.766,73.747,40.412,42.887,45.363,47.838,50.254,55.764,58.816,62.82,67.662,70.672,73.017,74.249,43.16,45.671,48.127,51.631,56.532,60.765,64.406,67.046,69.718,71.096,72.37,73.422,32.548,33.97,35.18,36.984,39.848,44.175,49.113,52.922,55.599,58.02,60.308,62.698,42.038,44.077,46.023,47.768,50.107,51.386,51.821,50.821,46.1,40.238,39.193,42.384,48.451,50.469,52.358,53.995,55.635,57.674,60.363,62.351,60.377,46.809,39.989,43.487],\n",
       "\"pop\":[8425333.0,9240934.0,1.0267083E7,1.1537966E7,1.307946E7,1.4880372E7,1.2881816E7,1.3867957E7,1.6317921E7,2.2227415E7,2.5268405E7,3.1889923E7,1282697.0,1476505.0,1728137.0,1984060.0,2263554.0,2509048.0,2780097.0,3075321.0,3326498.0,3428038.0,3508512.0,3600523.0,9279525.0,1.0270856E7,1.1000948E7,1.2760499E7,1.4760787E7,1.7152804E7,2.0033753E7,2.3254956E7,2.6298373E7,2.9072015E7,3.1287142E7,3.3333216E7,4232095.0,4561361.0,4826015.0,5247469.0,5894858.0,6162675.0,7016384.0,7874230.0,8735988.0,9875024.0,1.0866106E7,1.2420476E7,1.7876956E7,1.9610538E7,2.1283783E7,2.2934225E7,2.4779799E7,2.6983828E7,2.9341374E7,3.1620918E7,3.3958947E7,3.6203463E7,3.8331121E7,4.0301927E7,8691212.0,9712569.0,1.0794968E7,1.1872264E7,1.3177E7,1.40741E7,1.51842E7,1.6257249E7,1.7481977E7,1.8565243E7,1.9546792E7,2.0434176E7,6927772.0,6965860.0,7129864.0,7376998.0,7544201.0,7568430.0,7574613.0,7578903.0,7914969.0,8069876.0,8148312.0,8199783.0,120447.0,138655.0,171863.0,202182.0,230800.0,297410.0,377967.0,454612.0,529491.0,598561.0,656397.0,708573.0,4.6886859E7,5.1365468E7,5.6839289E7,6.2821884E7,7.0759295E7,8.0428306E7,9.3074406E7,1.03764241E8,1.13704579E8,1.23315288E8,1.3565679E8,1.50448339E8,8730405.0,8989111.0,9218400.0,9556500.0,9709100.0,9821800.0,9856303.0,9870200.0,1.0045622E7,1.0199787E7,1.031197E7,1.0392226E7,1738315.0,1925173.0,2151895.0,2427334.0,2761407.0,3168267.0,3641603.0,4243788.0,4981671.0,6066080.0,7026113.0,8078314.0,2883315.0,3211738.0,3593918.0,4040665.0,4565872.0,5079716.0,5642224.0,6156369.0,6893451.0,7693188.0,8445134.0,9119152.0,2791000.0,3076000.0,3349000.0,3585000.0,3819000.0,4086000.0,4172693.0,4338977.0,4256013.0,3607000.0,4165416.0,4552198.0,442308.0,474639.0,512764.0,553541.0,619351.0,781472.0,970347.0,1151184.0,1342614.0,1536536.0,1630347.0,1639131.0,5.660256E7,6.5551171E7,7.603939E7,8.8049823E7,1.00840058E8,1.14313951E8,1.28962939E8,1.42938076E8,1.55975974E8,1.68546719E8,1.79914212E8,1.90010647E8,7274900.0,7651254.0,8012946.0,8310226.0,8576200.0,8797022.0,8892098.0,8971958.0,8658506.0,8066057.0,7661799.0,7322858.0,4469979.0,4713416.0,4919632.0,5127935.0,5433886.0,5889574.0,6634596.0,7586551.0,8878303.0,1.0352843E7,1.2251209E7,1.4326203E7,2445618.0,2667518.0,2961915.0,3330989.0,3529983.0,3834415.0,4580410.0,5126023.0,5809236.0,6121610.0,7021078.0,8390505.0,4693836.0,5322536.0,6083619.0,6960067.0,7450606.0,6978607.0,7272485.0,8371791.0,1.0150094E7,1.1782962E7,1.2926707E7,1.4131858E7,5009067.0,5359923.0,5793633.0,6335506.0,7021028.0,7959865.0,9250831.0,1.0780667E7,1.2467171E7,1.4195809E7,1.5929988E7,1.7696293E7,1.4785584E7,1.7010154E7,1.8985849E7,2.0819767E7,2.22845E7,2.37964E7,2.52019E7,2.65497E7,2.8523502E7,3.0305843E7,3.1902268E7,3.3390141E7,1291695.0,1392284.0,1523478.0,1733638.0,1927260.0,2167533.0,2476971.0,2840009.0,3265124.0,3696513.0,4048013.0,4369038.0,2682462.0,2894855.0,3150417.0,3495967.0,3899068.0,4388260.0,4875118.0,5498955.0,6429417.0,7562011.0,8835739.0,1.0238807E7,6377619.0,7048426.0,7961258.0,8858908.0,9717524.0,1.0599793E7,1.1487112E7,1.2463354E7,1.3572994E7,1.4599929E7,1.5497046E7,1.6284741E7,5.56263527E8,6.37408E8,6.6577E8,7.5455E8,8.6203E8,9.43455E8,1.000281E9,1.084035E9,1.16497E9,1.230075E9,1.2804E9,1.318683096E9,1.2350771E7,1.4485993E7,1.7009885E7,1.9764027E7,2.254289E7,2.5094412E7,2.7764644E7,3.0964245E7,3.4202721E7,3.765783E7,4.1008227E7,4.422755E7,153936.0,170928.0,191689.0,217378.0,250027.0,304739.0,348643.0,395114.0,454429.0,527982.0,614382.0,710960.0,1.4100005E7,1.5577932E7,1.7486434E7,1.9941073E7,2.3007669E7,2.648087E7,3.0646495E7,3.5481645E7,4.1672143E7,4.7798986E7,5.5379852E7,6.4606759E7,854885.0,940458.0,1047924.0,1179760.0,1340458.0,1536769.0,1774735.0,2064095.0,2409073.0,2800947.0,3328795.0,3800610.0,926317.0,1112300.0,1345187.0,1588717.0,1834796.0,2108457.0,2424367.0,2799811.0,3173216.0,3518107.0,3834934.0,4133884.0,2977019.0,3300000.0,3832408.0,4744870.0,6071696.0,7459574.0,9025951.0,1.0761098E7,1.2772596E7,1.4625967E7,1.6252726E7,1.8013409E7,3882229.0,3991242.0,4076557.0,4174366.0,4225310.0,4318673.0,4413368.0,4484310.0,4494013.0,4444595.0,4481020.0,4493312.0,6007797.0,6640752.0,7254373.0,8139332.0,8831348.0,9537988.0,9789224.0,1.0239839E7,1.072326E7,1.0983007E7,1.1226999E7,1.1416987E7,9125183.0,9513758.0,9620282.0,9835109.0,9862158.0,1.0161915E7,1.0303704E7,1.0311597E7,1.0315702E7,1.0300707E7,1.0256295E7,1.0228744E7,4334000.0,4487831.0,4646899.0,4838800.0,4991596.0,5088419.0,5117810.0,5127024.0,5171393.0,5283663.0,5374693.0,5468120.0,63149.0,71851.0,89898.0,127617.0,178848.0,228694.0,305991.0,311025.0,384156.0,417908.0,447416.0,496374.0,2491346.0,2923186.0,3453434.0,4049146.0,4671329.0,5302800.0,5968349.0,6655297.0,7351181.0,7992357.0,8650322.0,9319622.0,3548753.0,4058385.0,4681707.0,5432424.0,6298651.0,7278866.0,8365850.0,9545158.0,1.0748394E7,1.1911819E7,1.2921234E7,1.375568E7,2.2223309E7,2.5009741E7,2.8173309E7,3.1681188E7,3.4807417E7,3.8783863E7,4.5681811E7,5.2799062E7,5.9402198E7,6.6134291E7,7.3312559E7,8.0264543E7,2042865.0,2355805.0,2747687.0,3232927.0,3790903.0,4282586.0,4474873.0,4842194.0,5274649.0,5783439.0,6353681.0,6939688.0,216964.0,232922.0,249220.0,259864.0,277603.0,192675.0,285483.0,341244.0,387838.0,439971.0,495627.0,551201.0,1438760.0,1542611.0,1666618.0,1820319.0,2260187.0,2512642.0,2637297.0,2915959.0,3668440.0,4058319.0,4414865.0,4906585.0,2.0860941E7,2.2815614E7,2.5145372E7,2.7860297E7,3.0770372E7,3.4617799E7,3.8111756E7,4.299953E7,5.2088559E7,5.9861301E7,6.7946797E7,7.6511887E7,4090500.0,4324000.0,4491443.0,4605744.0,4639657.0,4738902.0,4826933.0,4931729.0,5041039.0,5134406.0,5193039.0,5238460.0,4.2459667E7,4.4310863E7,4.7124E7,4.9569E7,5.1732E7,5.3165019E7,5.4433565E7,5.56301E7,5.7374179E7,5.8623428E7,5.9925035E7,6.1083916E7,420702.0,434904.0,455661.0,489004.0,537977.0,706367.0,753874.0,880397.0,985739.0,1126189.0,1299304.0,1454867.0,284320.0,323150.0,374020.0,439593.0,517101.0,608274.0,715523.0,848406.0,1025384.0,1235767.0,1457766.0,1688359.0,6.9145952E7,7.1019069E7,7.3739117E7,7.6368453E7,7.8717088E7,7.8160773E7,7.8335266E7,7.7718298E7,8.0597764E7,8.2011073E7,8.2350671E7,8.2400996E7,5581001.0,6391288.0,7355248.0,8490213.0,9354120.0,1.0538093E7,1.1400338E7,1.4168101E7,1.6278738E7,1.8418288E7,2.0550751E7,2.2873338E7,7733250.0,8096218.0,8448233.0,8716441.0,8888628.0,9308479.0,9786480.0,9974490.0,1.0325429E7,1.0502372E7,1.0603863E7,1.070629E7,3146381.0,3640876.0,4208858.0,4690773.0,5149581.0,5703430.0,6395630.0,7326406.0,8486949.0,9803875.0,1.117865E7,1.2572928E7,2664249.0,2876726.0,3140003.0,3451418.0,3811387.0,4227026.0,4710497.0,5650262.0,6990574.0,8048834.0,8807818.0,9947814.0,580653.0,601095.0,627820.0,601287.0,625361.0,745228.0,825987.0,927524.0,1050938.0,1193708.0,1332459.0,1472041.0,3201488.0,3507701.0,3880130.0,4318137.0,4698301.0,4908554.0,5198399.0,5756203.0,6326682.0,6913545.0,7607651.0,8502814.0,1517453.0,1770390.0,2090162.0,2500689.0,2965146.0,3055235.0,3669448.0,4372203.0,5077347.0,5867957.0,6677328.0,7483763.0,2125900.0,2736300.0,3305200.0,3722800.0,4115700.0,4583700.0,5264500.0,5584510.0,5829696.0,6495918.0,6762476.0,6980412.0,9504000.0,9839000.0,1.0063E7,1.0223422E7,1.0394091E7,1.0637171E7,1.0705535E7,1.061274E7,1.0348684E7,1.0244684E7,1.0083313E7,9956108.0,147962.0,165110.0,182053.0,198676.0,209275.0,221823.0,233997.0,244676.0,259012.0,271192.0,288030.0,301931.0,3.72E8,4.09E8,4.54E8,5.06E8,5.67E8,6.34E8,7.08E8,7.88E8,8.72E8,9.59E8,1.034172547E9,1.110396331E9,8.2052E7,9.0124E7,9.9028E7,1.09343E8,1.21282E8,1.36725E8,1.53343E8,1.69276E8,1.84816E8,1.99278E8,2.1106E8,2.23547E8,1.7272E7,1.9792E7,2.2874E7,2.6538E7,3.0614E7,3.5480679E7,4.3072751E7,5.1889696E7,6.0397973E7,6.3327987E7,6.6907826E7,6.945357E7,5441766.0,6248643.0,7240260.0,8519282.0,1.0061506E7,1.1882916E7,1.4173318E7,1.6543189E7,1.7861905E7,2.0775703E7,2.4001816E7,2.7499638E7,2952156.0,2878220.0,2830000.0,2900100.0,3024400.0,3271900.0,3480000.0,3539900.0,3557761.0,3667233.0,3879155.0,4109086.0,1620914.0,1944401.0,2310904.0,2693585.0,3095893.0,3495918.0,3858421.0,4203148.0,4936550.0,5531387.0,6029529.0,6426679.0,4.7666E7,4.9182E7,5.08432E7,5.26671E7,5.4365564E7,5.6059245E7,5.6535636E7,5.6729703E7,5.6840847E7,5.7479469E7,5.7926999E7,5.8147733E7,1426095.0,1535090.0,1665128.0,1861096.0,1997616.0,2156814.0,2298309.0,2326606.0,2378618.0,2531311.0,2664659.0,2780132.0,8.6459025E7,9.1563009E7,9.5831757E7,1.00825279E8,1.07188273E8,1.13872473E8,1.18454974E8,1.22091325E8,1.24329269E8,1.25956499E8,1.27065841E8,1.27467972E8,607914.0,746559.0,933559.0,1255058.0,1613551.0,1937652.0,2347031.0,2820042.0,3867409.0,4526235.0,5307470.0,6053193.0,6464046.0,7454779.0,8678557.0,1.0191512E7,1.2044785E7,1.4500404E7,1.7661452E7,2.1198082E7,2.5020539E7,2.8263827E7,3.1386842E7,3.5610177E7,8865488.0,9411381.0,1.0917494E7,1.2617009E7,1.4781241E7,1.632532E7,1.7647518E7,1.9067554E7,2.0711375E7,2.1585105E7,2.2215365E7,2.3301725E7,2.0947571E7,2.2611552E7,2.6420307E7,3.0131E7,3.3505E7,3.6436E7,3.9326E7,4.1622E7,4.380545E7,4.6173816E7,4.796915E7,4.904479E7,160000.0,212846.0,358266.0,575003.0,841934.0,1140357.0,1497494.0,1891487.0,1418095.0,1765345.0,2111561.0,2505559.0,1439529.0,1647412.0,1886848.0,2186894.0,2680018.0,3115787.0,3086876.0,3089353.0,3219994.0,3430388.0,3677780.0,3921278.0,748747.0,813338.0,893143.0,996380.0,1116779.0,1251524.0,1411807.0,1599200.0,1803195.0,1982823.0,2046772.0,2012649.0,863308.0,975950.0,1112796.0,1279406.0,1482628.0,1703617.0,1956875.0,2269414.0,1912974.0,2200725.0,2814651.0,3193942.0,1019729.0,1201578.0,1441863.0,1759224.0,2183877.0,2721783.0,3344074.0,3799845.0,4364501.0,4759670.0,5368585.0,6036914.0,4762912.0,5181679.0,5703324.0,6334556.0,7082430.0,8007166.0,9171477.0,1.0568642E7,1.2210395E7,1.4165114E7,1.6473477E7,1.9167654E7,2917802.0,3221238.0,3628608.0,4147252.0,4730997.0,5637246.0,6502825.0,7824747.0,1.0014249E7,1.0419991E7,1.1824495E7,1.3327079E7,6748378.0,7739235.0,8906385.0,1.0154878E7,1.1441462E7,1.2845381E7,1.4441916E7,1.6331785E7,1.8319502E7,2.0476091E7,2.2662365E7,2.4821286E7,3838168.0,4241884.0,4690372.0,5212416.0,5828158.0,6491649.0,6998256.0,7634008.0,8416215.0,9384984.0,1.0580176E7,1.2031795E7,1022556.0,1076852.0,1146757.0,1230542.0,1332786.0,1456688.0,1622136.0,1841240.0,2119465.0,2444741.0,2828858.0,3270065.0,516556.0,609816.0,701016.0,789309.0,851334.0,913025.0,992040.0,1042663.0,1096202.0,1149818.0,1200206.0,1250882.0,3.0144317E7,3.5015548E7,4.1121485E7,4.7995559E7,5.5984294E7,6.3759976E7,7.1640904E7,8.0122492E7,8.811103E7,9.5895146E7,1.02479927E8,1.08700891E8,800663.0,882134.0,1010280.0,1149500.0,1320500.0,1528000.0,1756032.0,2015133.0,2312802.0,2494803.0,2674234.0,2874127.0,413834.0,442829.0,474528.0,501035.0,527678.0,560073.0,562548.0,569473.0,621621.0,692651.0,720230.0,684736.0,9939217.0,1.140635E7,1.3056604E7,1.4770296E7,1.666067E7,1.8396941E7,2.019873E7,2.2987397E7,2.5798239E7,2.8529501E7,3.1167783E7,3.3757175E7,6446316.0,7038035.0,7788944.0,8680909.0,9809596.0,1.1127868E7,1.2587223E7,1.2891952E7,1.3160731E7,1.6603334E7,1.847378E7,1.9951656E7,2.0092996E7,2.1731844E7,2.3634436E7,2.5870271E7,2.846639E7,3.1528087E7,3.4680442E7,3.8028578E7,4.0546538E7,4.3247867E7,4.5598081E7,4.776198E7,485831.0,548080.0,621392.0,706640.0,821782.0,977026.0,1099010.0,1278184.0,1554253.0,1774766.0,1972153.0,2055080.0,9182536.0,9682338.0,1.0332057E7,1.126169E7,1.2412593E7,1.3933198E7,1.5796314E7,1.791718E7,2.0326209E7,2.3001113E7,2.5873917E7,2.890179E7,1.0381988E7,1.1026383E7,1.1805689E7,1.2596822E7,1.3329874E7,1.3852989E7,1.4310401E7,1.4665278E7,1.5174244E7,1.5604464E7,1.612283E7,1.6570613E7,1994794.0,2229407.0,2488550.0,2728150.0,2929100.0,3164900.0,3210650.0,3317166.0,3437674.0,3676187.0,3908037.0,4115771.0,1165790.0,1358828.0,1590597.0,1865490.0,2182908.0,2554598.0,2979423.0,3344353.0,4017939.0,4609572.0,5146848.0,5675356.0,3379468.0,3692184.0,4076008.0,4534062.0,5060262.0,5682086.0,6437188.0,7332638.0,8392818.0,9666252.0,1.1140655E7,1.2894865E7,3.3119096E7,3.717334E7,4.1871351E7,4.7287752E7,5.3740085E7,6.2209173E7,7.3039376E7,8.155152E7,9.3364244E7,1.06207839E8,1.19901274E8,1.35031164E8,3327728.0,3491938.0,3638919.0,3786019.0,3933004.0,4043205.0,4114787.0,4186147.0,4286357.0,4405672.0,4535591.0,4627926.0,507833.0,561977.0,628164.0,714775.0,829050.0,1004533.0,1301048.0,1593882.0,1915208.0,2283635.0,2713462.0,3204897.0,4.134656E7,4.6679944E7,5.3100671E7,6.0641899E7,6.9325921E7,7.8152686E7,9.1462088E7,1.05186881E8,1.20065004E8,1.35564834E8,1.53403524E8,1.69270617E8,940080.0,1063506.0,1215725.0,1405486.0,1616384.0,1839782.0,2036305.0,2253639.0,2484997.0,2734531.0,2990875.0,3242173.0,1555876.0,1770902.0,2009813.0,2287985.0,2614104.0,2984494.0,3366439.0,3886512.0,4483945.0,5154123.0,5884491.0,6667147.0,8025700.0,9146100.0,1.05165E7,1.21322E7,1.39547E7,1.5990099E7,1.8125129E7,2.0195924E7,2.2430449E7,2.4748122E7,2.6769436E7,2.8674757E7,2.2438691E7,2.6072194E7,3.0325264E7,3.53566E7,4.0850141E7,4.6850962E7,5.3456774E7,6.0017788E7,6.7185766E7,7.5012988E7,8.2995088E7,9.1077287E7,2.5730551E7,2.8235346E7,3.0329617E7,3.1785378E7,3.3039545E7,3.4621254E7,3.6227381E7,3.774071E7,3.8370697E7,3.8654957E7,3.8625976E7,3.8518241E7,8526050.0,8817650.0,9019800.0,9103000.0,8970450.0,9662600.0,9859650.0,9915289.0,9927680.0,1.0156415E7,1.0433867E7,1.0642836E7,2227000.0,2260000.0,2448046.0,2648961.0,2847132.0,3080828.0,3279001.0,3444468.0,3585176.0,3759430.0,3859606.0,3942491.0,257700.0,308700.0,358900.0,414024.0,461633.0,492095.0,517810.0,562035.0,622191.0,684810.0,743981.0,798094.0,1.663E7,1.7829327E7,1.8680721E7,1.9284814E7,2.0662648E7,2.1658597E7,2.2356726E7,2.2686371E7,2.2797027E7,2.2562458E7,2.2404337E7,2.2276056E7,2534927.0,2822082.0,3051242.0,3451079.0,3992121.0,4657072.0,5507565.0,6349365.0,7290203.0,7212583.0,7852401.0,8860588.0,60011.0,61325.0,65345.0,70787.0,76595.0,86796.0,98593.0,110812.0,125911.0,145608.0,170372.0,199579.0,4005677.0,4419650.0,4943029.0,5618198.0,6472756.0,8128505.0,1.1254672E7,1.4619745E7,1.6945857E7,2.1229759E7,2.450153E7,2.7601038E7,2755589.0,3054547.0,3430243.0,3965841.0,4588696.0,5260855.0,6147783.0,7171347.0,8307920.0,9535314.0,1.0870037E7,1.2267493E7,6860147.0,7271135.0,7616060.0,7971222.0,8313288.0,8686367.0,9032824.0,9230783.0,9826397.0,1.0336594E7,1.0111559E7,1.0150265E7,2143249.0,2295678.0,2467895.0,2662190.0,2879013.0,3140897.0,3464522.0,3868905.0,4260884.0,4578212.0,5359092.0,6144562.0,1127000.0,1445929.0,1750200.0,1977600.0,2152400.0,2325300.0,2651869.0,2794552.0,3235865.0,3802309.0,4197776.0,4553009.0,3558137.0,3844277.0,4237384.0,4442238.0,4593433.0,4827803.0,5048043.0,5199318.0,5302888.0,5383010.0,5410052.0,5447502.0,1489518.0,1533070.0,1582962.0,1646912.0,1694510.0,1746919.0,1861252.0,1945870.0,1999210.0,2011612.0,2011497.0,2009245.0,2526994.0,2780415.0,3080153.0,3428839.0,3840161.0,4353666.0,5828892.0,6921858.0,6099799.0,6633514.0,7753310.0,9118773.0,1.4264935E7,1.6151549E7,1.8356657E7,2.0997321E7,2.393581E7,2.7129932E7,3.1140029E7,3.5933379E7,3.9964159E7,4.2835005E7,4.4433622E7,4.3997828E7,2.854987E7,2.9841614E7,3.1158061E7,3.2850275E7,3.4513161E7,3.6439E7,3.798331E7,3.8880702E7,3.9549438E7,3.9855442E7,4.0152517E7,4.0448191E7,7982342.0,9128546.0,1.0421936E7,1.1737396E7,1.3016733E7,1.4116836E7,1.5410151E7,1.6495304E7,1.758706E7,1.8698655E7,1.9576783E7,2.0378239E7,8504667.0,9753392.0,1.1183227E7,1.2716129E7,1.4597019E7,1.7104986E7,2.0367053E7,2.472596E7,2.8227588E7,3.2160729E7,3.7090298E7,4.2292929E7,290243.0,326741.0,370006.0,420690.0,480105.0,551425.0,649901.0,779348.0,962344.0,1054486.0,1130269.0,1133066.0,7124673.0,7363802.0,7561588.0,7867931.0,8122293.0,8251648.0,8325260.0,8421403.0,8718867.0,8897619.0,8954175.0,9031088.0,4815000.0,5126000.0,5666000.0,6063000.0,6401400.0,6316424.0,6468126.0,6649942.0,6995447.0,7193761.0,7361757.0,7554661.0,3661549.0,4149908.0,4834621.0,5680812.0,6701172.0,7932503.0,9410494.0,1.1242847E7,1.3219062E7,1.5081016E7,1.7155814E7,1.9314747E7,8550362.0,1.0164215E7,1.1918938E7,1.3648692E7,1.5226039E7,1.6785196E7,1.850139E7,1.9757799E7,2.0686918E7,2.1628605E7,2.2454239E7,2.3174294E7,8322925.0,9452826.0,1.0863958E7,1.2607312E7,1.4706593E7,1.7129565E7,1.9844382E7,2.304063E7,2.6605473E7,3.0686889E7,3.4593779E7,3.813964E7,2.1289402E7,2.5041917E7,2.9263397E7,3.4024249E7,3.9276153E7,4.4148285E7,4.882716E7,5.2910342E7,5.6667095E7,6.0216677E7,6.2806748E7,6.5068149E7,1219113.0,1357445.0,1528098.0,1735550.0,2056351.0,2308582.0,2644765.0,3154264.0,3747553.0,4320890.0,4977378.0,5701579.0,662850.0,764900.0,887498.0,960155.0,975199.0,1039009.0,1116479.0,1191336.0,1183669.0,1138101.0,1101832.0,1056608.0,3647735.0,3950849.0,4286552.0,4786986.0,5303507.0,6005061.0,6734098.0,7724976.0,8523077.0,9231669.0,9770575.0,1.0276158E7,2.2235677E7,2.5670939E7,2.9788695E7,3.3411317E7,3.7492953E7,4.2404033E7,4.7328791E7,5.2881328E7,5.8179144E7,6.3047647E7,6.7308928E7,7.1158647E7,5824797.0,6675501.0,7688797.0,8900294.0,1.0190285E7,1.1457758E7,1.29394E7,1.528305E7,1.825219E7,2.1210254E7,2.4739869E7,2.9170398E7,5.043E7,5.143E7,5.3292E7,5.4959E7,5.6079E7,5.6179E7,5.6339704E7,5.698162E7,5.7866349E7,5.8808266E7,5.9912431E7,6.0776238E7,1.57553E8,1.71984E8,1.86538E8,1.98712E8,2.09896E8,2.20239E8,2.32187835E8,2.42803533E8,2.56894189E8,2.7291176E8,2.87675526E8,3.01139947E8,2252965.0,2424959.0,2598466.0,2748579.0,2829526.0,2873520.0,2953997.0,3045153.0,3149262.0,3262838.0,3363085.0,3447496.0,5439568.0,6702668.0,8143375.0,9709552.0,1.1515649E7,1.3503563E7,1.5620766E7,1.7910182E7,2.0265563E7,2.2374398E7,2.428767E7,2.6084662E7,2.6246839E7,2.8998543E7,3.379614E7,3.946391E7,4.4655014E7,5.0533506E7,5.6142181E7,6.2826491E7,6.9940728E7,7.6048996E7,8.0908147E7,8.5262356E7,1030585.0,1070439.0,1133134.0,1142636.0,1089572.0,1261091.0,1425876.0,1691210.0,2104779.0,2826046.0,3389578.0,4018332.0,4963829.0,5498090.0,6120081.0,6740785.0,7407075.0,8403990.0,9657618.0,1.121934E7,1.3367997E7,1.5826497E7,1.8701257E7,2.2211743E7,2672000.0,3016000.0,3421000.0,3900000.0,4506497.0,5216550.0,6100407.0,7272406.0,8381163.0,9417789.0,1.0595811E7,1.1746035E7,3080907.0,3646340.0,4277736.0,4995432.0,5861135.0,6642107.0,7636524.0,9216418.0,1.070434E7,1.1404948E7,1.1926563E7,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,820.8530296,853.10071,836.1971382,739.9811058,786.11336,978.0114388,852.3959448,649.3413952,635.341351,726.7340548,974.5803384,1601.056136,1942.284244,2312.888958,2760.196931,3313.422188,3533.00391,3630.880722,3738.932735,2497.437901,3193.054604,4604.211737,5937.029526,2449.008185,3013.976023,2550.81688,3246.991771,4182.663766,4910.416756,5745.160213,5681.358539,5023.216647,4797.295051,5288.040382,6223.367465,3520.610273,3827.940465,4269.276742,5522.776375,5473.288005,3008.647355,2756.953672,2430.208311,2627.845685,2277.140884,2773.287312,4797.231267,5911.315053,6856.856212,7133.166023,8052.953021,9443.038526,10079.02674,8997.897412,9139.671389,9308.41871,10967.28195,8797.640716,12779.37964,10039.59564,10949.64959,12217.22686,14526.12465,16788.62948,18334.19751,19477.00928,21888.88903,23424.76683,26997.93657,30687.75473,34435.36744,6137.076492,8842.59803,10750.72111,12834.6024,16661.6256,19749.4223,21597.08362,23687.82607,27042.01868,29095.92066,32417.60769,36126.4927,9867.084765,11635.79945,12753.27514,14804.6727,18268.65839,19340.10196,19211.14731,18524.02406,19035.57917,20292.01679,23403.55927,29796.04834,684.2441716,661.6374577,686.3415538,721.1860862,630.2336265,659.8772322,676.9818656,751.9794035,837.8101643,972.7700352,1136.39043,1391.253792,8343.105127,9714.960623,10991.20676,13149.04119,16672.14356,19117.97448,20979.84589,22525.56308,25575.57069,27561.19663,30485.88375,33692.60508,1062.7522,959.6010805,949.4990641,1035.831411,1085.796879,1029.161251,1277.897616,1225.85601,1191.207681,1232.975292,1372.877931,1441.284873,2677.326347,2127.686326,2180.972546,2586.886053,2980.331339,3548.097832,3156.510452,2753.69149,2961.699694,3326.143191,3413.26269,3822.137084,973.5331948,1353.989176,1709.683679,2172.352423,2860.16975,3528.481305,4126.613157,4314.114757,2546.781445,4766.355904,6018.975239,7446.298803,851.2411407,918.2325349,983.6539764,1214.709294,2263.611114,3214.857818,4551.14215,6205.88385,7954.111645,8647.142313,11003.60508,12569.85177,2108.944355,2487.365989,3336.585802,3429.864357,4985.711467,6660.118654,7030.835878,7807.095818,6950.283021,7957.980824,8131.212843,9065.800825,2444.286648,3008.670727,4254.337839,5577.0028,6597.494398,7612.240438,8224.191647,8239.854824,6302.623438,5970.38876,7696.777725,10680.79282,543.2552413,617.1834648,722.5120206,794.8265597,854.7359763,743.3870368,807.1985855,912.0631417,931.7527731,946.2949618,1037.645221,1217.032994,339.2964587,379.5646281,355.2032273,412.9775136,464.0995039,556.1032651,559.603231,621.8188189,631.6998778,463.1151478,446.4035126,430.0706916,368.4692856,434.0383364,496.9136476,523.4323142,421.6240257,524.9721832,624.4754784,683.8955732,682.3031755,734.28517,896.2260153,1713.778686,1172.667655,1313.048099,1399.607441,1508.453148,1684.146528,1783.432873,2367.983282,2602.664206,1793.163278,1694.337469,1934.011449,2042.09524,11367.16112,12489.95006,13462.48555,16076.58803,18970.57086,22090.88306,22898.79214,26626.51503,26342.88426,28954.92589,33328.96507,36319.23501,1071.310713,1190.844328,1193.068753,1136.056615,1070.013275,1109.374338,956.7529907,844.8763504,747.9055252,740.5063317,738.6906068,706.016537,1178.665927,1308.495577,1389.817618,1196.810565,1104.103987,1133.98495,797.9081006,952.386129,1058.0643,1004.961353,1156.18186,1704.063724,3939.978789,4315.622723,4519.094331,5106.654313,5494.024437,4756.763836,5095.665738,5547.063754,7596.125964,10118.05318,10778.78385,13171.63885,400.448611,575.9870009,487.6740183,612.7056934,676.9000921,741.2374699,962.4213805,1378.904018,1655.784158,2289.234136,3119.280896,4959.114854,2144.115096,2323.805581,2492.351109,2678.729839,3264.660041,3815.80787,4397.575659,4903.2191,5444.648617,6117.361746,5755.259962,7006.580419,1102.990936,1211.148548,1406.648278,1876.029643,1937.577675,1172.603047,1267.100083,1315.980812,1246.90737,1173.618235,1075.811558,986.1478792,780.5423257,905.8602303,896.3146335,861.5932424,904.8960685,795.757282,673.7478181,672.774812,457.7191807,312.188423,241.1658765,277.5518587,2125.621418,2315.056572,2464.783157,2677.939642,3213.152683,3259.178978,4879.507522,4201.194937,4016.239529,3484.164376,3484.06197,3632.557798,2627.009471,2990.010802,3460.937025,4161.727834,5118.146939,5926.876967,5262.734751,5629.915318,6160.416317,6677.045314,7723.447195,9645.06142,1388.594732,1500.895925,1728.869428,2052.050473,2378.201111,2517.736547,2602.710169,2156.956069,1648.073791,1786.265407,1648.800823,1544.750112,3119.23652,4338.231617,5477.890018,6960.297861,9164.090127,11305.38517,13221.82184,13822.58394,8447.794873,9875.604515,11628.38895,14619.22272,5586.53878,6092.174359,5180.75591,5690.268015,5305.445256,6380.494966,7316.918107,7532.924763,5592.843963,5431.990415,6340.646683,8948.102923,6876.14025,8256.343918,10136.86713,11399.44489,13108.4536,14800.16062,15377.22855,16310.4434,14297.02122,16048.51424,17596.21022,22833.30851,9692.385245,11099.65935,13583.31351,15937.21123,18866.20721,20422.9015,21688.04048,25116.17581,26406.73985,29804.34567,32166.50006,35278.41874,2669.529475,2864.969076,3020.989263,3020.050513,3694.212352,3081.761022,2879.468067,2880.102568,2377.156192,1895.016984,1908.260867,2082.481567,1397.717137,1544.402995,1662.137359,1653.723003,2189.874499,2681.9889,2861.092386,2899.842175,3044.214214,3614.101285,4563.808154,6025.374752,3522.110717,3780.546651,4086.114078,4579.074215,5280.99471,6679.62326,7213.791267,6481.776993,7103.702595,7429.455877,5773.044512,6873.262326,1418.822445,1458.915272,1693.335853,1814.880728,2024.008147,2785.493582,3503.729636,3885.46071,3794.755195,4173.181797,4754.604414,5581.180998,3048.3029,3421.523218,3776.803627,4358.595393,4520.246008,5138.922374,4098.344175,4140.442097,4444.2317,5154.825496,5351.568666,5728.353514,375.6431231,426.0964081,582.8419714,915.5960025,672.4122571,958.5668124,927.8253427,966.8968149,1132.055034,2814.480755,7703.4959,12154.08975,328.9405571,344.1618859,380.9958433,468.7949699,514.3242082,505.7538077,524.8758493,521.1341333,582.8585102,913.47079,765.3500015,641.3695236,362.1462796,378.9041632,419.4564161,516.1186438,566.2439442,556.8083834,577.8607471,573.7413142,421.3534653,515.8894013,530.0535319,690.8055759,6424.519071,7545.415386,9371.842561,10921.63626,14358.8759,15605.42283,18533.15761,21141.01223,20647.16499,23723.9502,28204.59057,33207.0844,7029.809327,8662.834898,10560.48553,12999.91766,16107.19171,18292.63514,20293.89746,22066.44214,24703.79615,25889.78487,28926.03234,30470.0167,4293.476475,4976.198099,6631.459222,8358.761987,11401.94841,21745.57328,15113.36194,11864.40844,13522.15752,14722.84188,12521.71392,13206.48452,485.2306591,520.9267111,599.650276,734.7829124,756.0868363,884.7552507,835.8096108,611.6588611,665.6244126,653.7301704,660.5855997,752.7497265,7144.114393,10187.82665,12902.46291,14745.62561,18016.18027,20512.92123,22031.53274,24639.18566,26505.30317,27788.88416,30035.80198,32170.37442,911.2989371,1043.561537,1190.041118,1125.69716,1178.223708,993.2239571,876.032569,847.0061135,925.060154,1005.245812,1111.984578,1327.60891,3530.690067,4916.299889,6017.190733,8513.097016,12724.82957,14195.52428,15268.42089,16120.52839,17541.49634,18747.69814,22514.2548,27538.41188,2428.237769,2617.155967,2750.364446,3242.531147,4031.408271,4879.992748,4820.49479,4246.485974,4439.45084,4684.313807,4858.347495,5186.050003,510.1964923,576.2670245,686.3736739,708.7595409,741.6662307,874.6858643,857.2503577,805.5724718,794.3484384,869.4497668,945.5835837,942.6542111,299.850319,431.7904566,522.0343725,715.5806402,820.2245876,764.7259628,838.1239671,736.4153921,745.5398706,796.6644681,575.7047176,579.231743,1840.366939,1726.887882,1796.589032,1452.057666,1654.456946,1874.298931,2011.159549,1823.015995,1456.309517,1341.726931,1270.364932,1201.637154,2194.926204,2220.487682,2291.156835,2538.269358,2529.842345,3203.208066,3121.760794,3023.096699,3081.694603,3160.454906,3099.72866,3548.330846,3054.421209,3629.076457,4692.648272,6197.962814,8315.928145,11186.14125,14560.53051,20038.47269,24757.60301,28377.63219,30209.01516,39724.97867,5263.673816,6040.180011,7550.359877,9326.64467,10168.65611,11674.83737,12545.99066,12986.47998,10535.62855,11712.7768,14843.93556,18008.94444,7267.688428,9244.001412,10350.15906,13319.89568,15798.06362,19654.96247,23269.6075,26923.20628,25144.39201,28061.09966,31163.20196,36180.78919,546.5657493,590.061996,658.3471509,700.7706107,724.032527,813.337323,855.7235377,976.5126756,1164.406809,1458.817442,1746.769454,2452.210407,749.6816546,858.9002707,849.2897701,762.4317721,1111.107907,1382.702056,1516.872988,1748.356961,2383.140898,3119.335603,2873.91287,3540.651564,3035.326002,3290.257643,4187.329802,5906.731805,9613.818607,11888.59508,7608.334602,6642.881371,7235.653188,8263.590301,9240.761975,11605.71449,4129.766056,6229.333562,8341.737815,8931.459811,9576.037596,14688.23507,14517.90711,11643.57268,3745.640687,3076.239795,4390.717312,4471.061906,5210.280328,5599.077872,6631.597314,7655.568963,9530.772896,11150.98113,12618.32141,13872.86652,17558.81555,24521.94713,34077.04939,40675.99635,4086.522128,5385.278451,7105.630706,8393.741404,12786.93223,13306.61921,15367.0292,17122.47986,18051.52254,20896.60924,21905.59514,25523.2771,4931.404155,6248.656232,8243.58234,10022.40131,12269.27378,14255.98475,16537.4835,19207.23482,22013.64486,24675.02446,27968.09817,28569.7197,2898.530881,4756.525781,5246.107524,6124.703451,7433.889293,6650.195573,6068.05135,6351.237495,7404.923685,7121.924704,6994.774861,7320.880262,3216.956347,4317.694365,6576.649461,9847.788607,14778.78636,16610.37701,19384.10571,22375.94189,26824.89511,28816.58499,28604.5919,31656.06806,1546.907807,1886.080591,2348.009158,2741.796252,2110.856309,2852.351568,4161.415959,4448.679912,3431.593647,3645.379572,3844.917194,4519.461171,853.540919,944.4383152,896.9663732,1056.736457,1222.359968,1267.613204,1348.225791,1361.936856,1341.921721,1360.485021,1287.514732,1463.249282,1088.277758,1571.134655,1621.693598,2143.540609,3701.621503,4106.301249,4106.525293,4106.492315,3726.063507,1690.756814,1646.758151,1593.06548,1030.592226,1487.593537,1536.344387,2029.228142,3030.87665,4657.22102,5622.942464,8533.088805,12104.27872,15993.52796,19233.98818,23348.13973,108382.3529,113523.1329,95458.11176,80894.88326,109347.867,59265.47714,31354.03573,28118.42998,34932.91959,40300.61996,35110.10566,47306.98978,4834.804067,6089.786934,5714.560611,6006.983042,7486.384341,8659.696836,7640.519521,5377.091329,6890.806854,8754.96385,9313.93883,10461.05868,298.8462121,335.9971151,411.8006266,498.6390265,496.5815922,745.3695408,797.2631074,773.9932141,977.4862725,1186.147994,1275.184575,1569.331442,575.5729961,620.9699901,634.1951625,713.6036483,803.0054535,640.3224383,572.1995694,506.1138573,636.6229191,609.1739508,531.4823679,414.5073415,2387.54806,3448.284395,6757.030816,18772.75169,21011.49721,21951.21176,17364.27538,11770.5898,9640.138501,9467.446056,9534.677467,12057.49928,1443.011715,1589.20275,1643.38711,1634.047282,1748.562982,1544.228586,1302.878658,1155.441948,1040.67619,986.2958956,894.6370822,1044.770126,369.1650802,416.3698064,427.9010856,495.5147806,584.6219709,663.2236766,632.8039209,635.5173634,563.2000145,692.2758103,665.4231186,759.3499101,1831.132894,1810.066992,2036.884944,2277.742396,2849.09478,3827.921571,4920.355951,5249.802653,7277.912802,10132.90964,10206.97794,12451.6558,452.3369807,490.3821867,496.1743428,545.0098873,581.3688761,686.3952693,618.0140641,684.1715576,739.014375,790.2579846,951.4097518,1042.581557,743.1159097,846.1202613,1055.896036,1421.145193,1586.851781,1497.492223,1481.150189,1421.603576,1361.369784,1483.136136,1579.019543,1803.151496,1967.955707,2034.037981,2529.067487,2475.387562,2575.484158,3710.982963,3688.037739,4783.586903,6058.253846,7425.705295,9021.815894,10956.99112,3478.125529,4131.546641,4581.609385,5754.733883,6809.40669,7674.929108,9611.147541,8688.156003,9472.384295,9767.29753,10742.44053,11977.57496,786.5668575,912.6626085,1056.353958,1226.04113,1421.741975,1647.511665,2000.603139,2338.008304,1785.402016,1902.2521,2140.739323,3095.772271,2647.585601,3682.259903,4649.593785,5907.850937,7778.414017,9595.929905,11222.58762,11732.51017,7003.339037,6465.613349,6557.194282,9253.896111,1688.20357,1642.002314,1566.353493,1711.04477,1930.194975,2370.619976,2702.620356,2755.046991,2948.047252,2982.101858,3258.495584,3820.17523,468.5260381,495.5868333,556.6863539,566.6691539,724.9178037,502.3197334,462.2114149,389.8761846,410.8968239,472.3460771,633.6179466,823.6856205,331.0,350.0,388.0,349.0,357.0,371.0,424.0,385.0,347.0,415.0,611.0,944.0,2423.780443,2621.448058,3173.215595,3793.694753,3746.080948,3876.485958,4191.100511,3693.731337,3804.537999,3899.52426,4072.324751,4811.060429,545.8657229,597.9363558,652.3968593,676.4422254,674.7881296,694.1124398,718.3730947,775.6324501,897.7403604,1010.892138,1057.206311,1091.359778,8941.571858,11276.19344,12790.84956,15363.25136,18794.74567,21209.0592,21399.46046,23651.32361,26790.94961,30246.13063,33724.75778,36797.93332,10556.57566,12247.39532,13175.678,14463.91893,16046.03728,16233.7177,17632.4104,19007.19129,18363.32494,21050.41377,23189.80135,25185.00911,3112.363948,3457.415947,3634.364406,4643.393534,4688.593267,5486.371089,3470.338156,2955.984375,2170.151724,2253.023004,2474.548819,2749.320965,761.879376,835.5234025,997.7661127,1054.384891,954.2092363,808.8970728,909.7221354,668.3000228,581.182725,580.3052092,601.0745012,619.6768924,1077.281856,1100.592563,1150.927478,1014.514104,1698.388838,1981.951806,1576.97375,1385.029563,1619.848217,1624.941275,1615.286395,2013.977305,10095.42172,11653.97304,13450.40151,16361.87647,18965.05551,23311.34939,26298.63531,31540.9748,33965.66115,41283.16433,44683.97525,49357.19017,1828.230307,2242.746551,2924.638113,4720.942687,10618.03855,11848.34392,12954.79101,18115.22313,18616.70691,19702.05581,19774.83687,22316.19287,684.5971438,747.0835292,803.3427418,942.4082588,1049.938981,1175.921193,1443.429832,1704.686583,1971.829464,2049.350521,2092.712441,2605.94758,2480.380334,2961.800905,3536.540301,4421.009084,5364.249663,5351.912144,7009.601598,7034.779161,6618.74305,7113.692252,7356.031934,9809.185636,1952.308701,2046.154706,2148.027146,2299.376311,2523.337977,3248.373311,4258.503604,3998.875695,4196.411078,4247.400261,3783.674243,4172.838464,3758.523437,4245.256698,4957.037982,5788.09333,5937.827283,6281.290855,6434.501797,6360.943444,4446.380924,5838.347657,5909.020073,7408.905561,1272.880995,1547.944844,1649.552153,1814.12743,1989.37407,2373.204287,2603.273765,2189.634995,2279.324017,2536.534925,2650.921068,3190.481016,4029.329699,4734.253019,5338.752143,6557.152776,8006.506993,9508.141454,8451.531004,9082.351172,7738.881247,10159.58368,12002.23908,15389.92468,3068.319867,3774.571743,4727.954889,6361.517993,9022.247417,10172.48572,11753.84291,13039.30876,16207.26663,17641.03156,19970.90787,20509.64777,3081.959785,3907.156189,5108.34463,6929.277714,9123.041742,9770.524921,10330.98915,12281.34191,14641.58711,16999.4333,18855.60618,19328.70901,2718.885295,2769.451844,3173.72334,4021.175739,5047.658563,4319.804067,5267.219353,5303.377488,6101.255823,6071.941411,6316.1652,7670.122558,3144.613186,3943.370225,4734.997586,6470.866545,8011.414402,9356.39724,9605.314053,9696.273295,6598.409903,7346.547557,7885.360081,10808.47561,493.3238752,540.2893983,597.4730727,510.9637142,590.5806638,670.0806011,881.5706467,847.991217,737.0685949,589.9445051,785.6537648,863.0884639,879.5835855,860.7369026,1071.551119,1384.840593,1532.985254,1737.561657,1890.218117,1516.525457,1428.777814,1339.076036,1353.09239,1598.435089,6459.554823,8157.591248,11626.41975,16903.04886,24837.42865,34167.7626,33693.17525,21198.26136,24841.61777,20586.69019,19014.54118,21654.83194,1450.356983,1567.653006,1654.988723,1612.404632,1597.712056,1561.769116,1518.479984,1441.72072,1367.899369,1392.368347,1519.635262,1712.472136,3581.459448,4981.090891,6289.629157,7991.707066,10522.06749,12980.66956,15181.0927,15870.87851,9325.068238,7914.320304,7236.075251,9786.534714,879.7877358,1004.484437,1116.639877,1206.043465,1353.759762,1348.285159,1465.010784,1294.447788,1068.696278,574.6481576,699.489713,862.5407561,2315.138227,2843.104409,3674.735572,4977.41854,8597.756202,11210.08948,15169.16112,18861.53081,24769.8912,33519.4766,36023.1054,47143.17964,5074.659104,6093.26298,7481.107598,8412.902397,9674.167626,10922.66404,11348.54585,12037.26758,9498.467723,12126.23065,13638.77837,18678.31435,4215.041741,5862.276629,7402.303395,9405.489397,12383.4862,15277.03017,17866.72175,18678.53492,14214.71681,17161.10735,20660.01936,25768.25759,1135.749842,1258.147413,1369.488336,1284.73318,1254.576127,1450.992513,1176.807031,1093.244963,926.9602964,930.5964284,882.0818218,926.1410683,4725.295531,5487.104219,5768.729717,7114.477971,7765.962636,8028.651439,8568.266228,7825.823398,7225.069258,7479.188244,7710.946444,9269.657808,3834.034742,4564.80241,5693.843879,7993.512294,10638.75131,13236.92117,13926.16997,15764.98313,18603.06452,20445.29896,24835.47166,28821.0637,1083.53203,1072.546602,1074.47196,1135.514326,1213.39553,1348.775651,1648.079789,1876.766827,2153.739222,2664.477257,3015.378833,3970.095407,1615.991129,1770.337074,1959.593767,1687.997641,1659.652775,2202.988423,1895.544073,1507.819159,1492.197043,1632.210764,1993.398314,2602.394995,1148.376626,1244.708364,1856.182125,2613.101665,3364.836625,3781.410618,3895.384018,3984.839812,3553.0224,3876.76846,4128.116943,4513.480643,8527.844662,9911.878226,12329.44192,15258.29697,17832.02464,18855.72521,20667.38125,23586.92927,23880.01683,25266.59499,29341.63093,33859.74835,14734.23275,17909.48973,20431.0927,22966.14432,27195.11304,26982.29052,28397.71512,30281.70459,31871.5303,32135.32301,34480.95771,37506.41907,1643.485354,2117.234893,2193.037133,1881.923632,2571.423014,3195.484582,3761.837715,3116.774285,3340.542768,4014.238972,4090.925331,4184.548089,1206.947913,1507.86129,1822.879028,2643.858681,4062.523897,5596.519826,7426.354774,11054.56175,15215.6579,20206.82098,23235.42329,28718.27684,716.6500721,698.5356073,722.0038073,848.2186575,915.9850592,962.4922932,874.2426069,831.8220794,825.682454,789.1862231,899.0742111,1107.482182,757.7974177,793.5774148,1002.199172,1295.46066,1524.358936,1961.224635,2393.219781,2982.653773,4616.896545,5852.625497,5913.187529,7458.396327,859.8086567,925.9083202,1067.53481,1477.59676,1649.660188,1532.776998,1344.577953,1202.201361,1034.298904,982.2869243,886.2205765,882.9699438,3023.271928,4100.3934,4997.523971,5621.368472,6619.551419,7899.554209,9119.528607,7388.597823,7370.990932,8792.573126,11460.60023,18008.50924,1468.475631,1395.232468,1660.30321,1932.360167,2753.285994,3120.876811,3560.233174,3810.419296,4332.720164,4876.798614,5722.895655,7092.923025,1969.10098,2218.754257,2322.869908,2826.356387,3450.69638,4269.122326,4241.356344,5089.043686,5678.348271,6601.429915,6508.085718,8458.276384,734.753484,774.3710692,767.2717398,908.9185217,950.735869,843.7331372,682.2662268,617.7244065,644.1707969,816.559081,927.7210018,1056.380121,9979.508487,11283.17795,12477.17707,14142.85089,15895.11641,17428.74846,18232.42452,21664.78767,22705.09254,26074.53136,29478.99919,33203.26128,13990.48208,14847.12712,16173.14586,19530.36557,21806.03594,24072.63213,25009.55914,29884.35041,32003.93224,35767.43303,39097.09955,42951.65309,5716.766744,6150.772969,5603.357717,5444.61962,5703.408898,6504.339663,6920.223051,7452.398969,8137.004775,9230.240708,7727.002004,10611.46299,7689.799761,9802.466526,8422.974165,9541.474188,10505.25966,13143.95095,11152.41011,9883.584648,10733.92631,10165.49518,8605.047831,11415.80569,605.0664917,676.2854478,772.0491602,637.1232887,699.5016441,713.5371196,707.2357863,820.7994449,989.0231487,1385.896769,1764.456677,2441.576404,1515.592329,1827.067742,2198.956312,2649.715007,3133.409277,3682.831494,4336.032082,5107.197384,6017.654756,7110.667619,4515.487575,3025.349798,781.7175761,804.8304547,825.6232006,862.4421463,1265.047031,1829.765177,1977.55701,1971.741538,1879.496673,2117.484526,2234.820827,2280.769906,1147.388831,1311.956766,1452.725766,1777.077318,1773.498265,1588.688299,1408.678565,1213.315116,1210.884633,1071.353818,1071.613938,1271.211593,406.8841148,518.7642681,527.2721818,569.7950712,799.3621758,685.5876821,788.8550411,706.1573059,693.4207856,792.4499603,672.0386227,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"breaks\":[1000.0,10000.0,25000.0,50000.0,100000.0],\n",
       "\"labels\":[\"$1K\",\"$10K\",\"$25K\",\"$50K\",\"$100K\"],\n",
       "\"trans\":\"log10\"\n",
       "},{\n",
       "\"name\":\"GDP per Capita\",\n",
       "\"aesthetic\":\"x\"\n",
       "},{\n",
       "\"name\":\"Life Expectancy\",\n",
       "\"aesthetic\":\"y\"\n",
       "},{\n",
       "\"name\":\"Continent\",\n",
       "\"aesthetic\":\"color\"\n",
       "},{\n",
       "\"name\":\"Population\",\n",
       "\"aesthetic\":\"size\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"yzLXfp\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b4d790>"
      ]
     },
     "execution_count": 81,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             ) +\n",
    "            #  add country name to hover\n",
    "        geom_point(alpha=0.5) +\n",
    "        scale_x_log10(\n",
    "            breaks = [1000, 10000, 25000, 50000, 100000],\n",
    "            labels = [f'${nz.numerize(x)}' for x in [1000, 10000, 25000, 50000, 100000]]\n",
    "            ) +\n",
    "        theme_minimal() +\n",
    "        labs(\n",
    "            # title = 'Life Expectancy vs. GDP per Capita', # Why could we do without this?\n",
    "            x = 'GDP per Capita',\n",
    "            y = 'Life Expectancy',\n",
    "            color = 'Continent',\n",
    "            size = 'Population' \n",
    "        )\n",
    "        \n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# 2. A few words on (tidy) data formats"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Untidy data"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Real-world data are often in a ghastly Excel format that is reasonable for humans but awful for computers. Behold [(source)](https://www.linkedin.com/pulse/untidy-government-data-assault-democracy-peter-king/): \n",
    "\n",
    "![Governments, investment banks, and consultancies are notorious for this](https://media.licdn.com/dms/image/C5112AQGpCucou5GlOA/article-cover_image-shrink_720_1280/0/1576703880301?e=2147483647&v=beta&t=w6aAfQaujgqUl1E0dJV3qwPh3LkPybgwojYtqAquKkA)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Another one ([source](https://github.com/andrewheiss/datavizs24.classes.andrewheiss.com/blob/main/slides/img/03/untidy-example.png)):\n",
    "\n",
    "![](https://github.com/andrewheiss/datavizs24.classes.andrewheiss.com/blob/main/slides/img/03/untidy-example.png?raw=true)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Tidy data"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Tidy data is also called 'long' data, and here's how you might rearrange the table above:  "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "![](https://github.com/andrewheiss/datavizs24.classes.andrewheiss.com/blob/main/slides/img/03/tidy-example.png?raw=true)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Here's how we might want to mess with the Gapminder dataset to make it untidy (or fit for human consumption): "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 82,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>country</th>\n",
       "      <th>continent</th>\n",
       "      <th>year</th>\n",
       "      <th>lifeExp</th>\n",
       "      <th>pop</th>\n",
       "      <th>gdpPercap</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>Asia</td>\n",
       "      <td>1952-01-01</td>\n",
       "      <td>28.801</td>\n",
       "      <td>8425333</td>\n",
       "      <td>779.445314</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>Asia</td>\n",
       "      <td>1957-01-01</td>\n",
       "      <td>30.332</td>\n",
       "      <td>9240934</td>\n",
       "      <td>820.853030</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>Asia</td>\n",
       "      <td>1962-01-01</td>\n",
       "      <td>31.997</td>\n",
       "      <td>10267083</td>\n",
       "      <td>853.100710</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>Asia</td>\n",
       "      <td>1967-01-01</td>\n",
       "      <td>34.020</td>\n",
       "      <td>11537966</td>\n",
       "      <td>836.197138</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>Asia</td>\n",
       "      <td>1972-01-01</td>\n",
       "      <td>36.088</td>\n",
       "      <td>13079460</td>\n",
       "      <td>739.981106</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "       country continent       year  lifeExp       pop   gdpPercap\n",
       "0  Afghanistan      Asia 1952-01-01   28.801   8425333  779.445314\n",
       "1  Afghanistan      Asia 1957-01-01   30.332   9240934  820.853030\n",
       "2  Afghanistan      Asia 1962-01-01   31.997  10267083  853.100710\n",
       "3  Afghanistan      Asia 1967-01-01   34.020  11537966  836.197138\n",
       "4  Afghanistan      Asia 1972-01-01   36.088  13079460  739.981106"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "<class 'pandas.core.frame.DataFrame'>\n",
      "RangeIndex: 1704 entries, 0 to 1703\n",
      "Data columns (total 6 columns):\n",
      " #   Column     Non-Null Count  Dtype         \n",
      "---  ------     --------------  -----         \n",
      " 0   country    1704 non-null   object        \n",
      " 1   continent  1704 non-null   object        \n",
      " 2   year       1704 non-null   datetime64[ns]\n",
      " 3   lifeExp    1704 non-null   float64       \n",
      " 4   pop        1704 non-null   int64         \n",
      " 5   gdpPercap  1704 non-null   float64       \n",
      "dtypes: datetime64[ns](1), float64(2), int64(1), object(2)\n",
      "memory usage: 80.0+ KB\n"
     ]
    }
   ],
   "source": [
    "# original (tidy) format\n",
    "display(gapminder.head())\n",
    "gapminder.info()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "💡 The function `pivot_table` might feel like an advanced step for some. Don't worry, we will practice it some more tomorrow!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 83,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th>continent</th>\n",
       "      <th>Africa</th>\n",
       "      <th>Americas</th>\n",
       "      <th>Asia</th>\n",
       "      <th>Europe</th>\n",
       "      <th>Oceania</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>year</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>1952-01-01</th>\n",
       "      <td>39.135500</td>\n",
       "      <td>53.27984</td>\n",
       "      <td>46.314394</td>\n",
       "      <td>64.408500</td>\n",
       "      <td>69.255</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1957-01-01</th>\n",
       "      <td>41.266346</td>\n",
       "      <td>55.96028</td>\n",
       "      <td>49.318544</td>\n",
       "      <td>66.703067</td>\n",
       "      <td>70.295</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1962-01-01</th>\n",
       "      <td>43.319442</td>\n",
       "      <td>58.39876</td>\n",
       "      <td>51.563223</td>\n",
       "      <td>68.539233</td>\n",
       "      <td>71.085</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1967-01-01</th>\n",
       "      <td>45.334538</td>\n",
       "      <td>60.41092</td>\n",
       "      <td>54.663640</td>\n",
       "      <td>69.737600</td>\n",
       "      <td>71.310</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1972-01-01</th>\n",
       "      <td>47.450942</td>\n",
       "      <td>62.39492</td>\n",
       "      <td>57.319269</td>\n",
       "      <td>70.775033</td>\n",
       "      <td>71.910</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "continent      Africa  Americas       Asia     Europe  Oceania\n",
       "year                                                          \n",
       "1952-01-01  39.135500  53.27984  46.314394  64.408500   69.255\n",
       "1957-01-01  41.266346  55.96028  49.318544  66.703067   70.295\n",
       "1962-01-01  43.319442  58.39876  51.563223  68.539233   71.085\n",
       "1967-01-01  45.334538  60.41092  54.663640  69.737600   71.310\n",
       "1972-01-01  47.450942  62.39492  57.319269  70.775033   71.910"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# pivot table format, group by continent and year, value is lifeExp\n",
    "gapminder_pivot_life_exp = gapminder.pivot_table(\n",
    "                        index='year', columns='continent', \n",
    "                        values='lifeExp', aggfunc='mean')\n",
    "display(gapminder_pivot_life_exp.head())"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 84,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th>country</th>\n",
       "      <th>Afghanistan</th>\n",
       "      <th>Albania</th>\n",
       "      <th>Algeria</th>\n",
       "      <th>Angola</th>\n",
       "      <th>Argentina</th>\n",
       "      <th>Australia</th>\n",
       "      <th>Austria</th>\n",
       "      <th>Bahrain</th>\n",
       "      <th>Bangladesh</th>\n",
       "      <th>Belgium</th>\n",
       "      <th>...</th>\n",
       "      <th>Uganda</th>\n",
       "      <th>United Kingdom</th>\n",
       "      <th>United States</th>\n",
       "      <th>Uruguay</th>\n",
       "      <th>Venezuela</th>\n",
       "      <th>Vietnam</th>\n",
       "      <th>West Bank and Gaza</th>\n",
       "      <th>Yemen, Rep.</th>\n",
       "      <th>Zambia</th>\n",
       "      <th>Zimbabwe</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>year</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>1952-01-01</th>\n",
       "      <td>779.445314</td>\n",
       "      <td>1601.056136</td>\n",
       "      <td>2449.008185</td>\n",
       "      <td>3520.610273</td>\n",
       "      <td>5911.315053</td>\n",
       "      <td>10039.59564</td>\n",
       "      <td>6137.076492</td>\n",
       "      <td>9867.084765</td>\n",
       "      <td>684.244172</td>\n",
       "      <td>8343.105127</td>\n",
       "      <td>...</td>\n",
       "      <td>734.753484</td>\n",
       "      <td>9979.508487</td>\n",
       "      <td>13990.48208</td>\n",
       "      <td>5716.766744</td>\n",
       "      <td>7689.799761</td>\n",
       "      <td>605.066492</td>\n",
       "      <td>1515.592329</td>\n",
       "      <td>781.717576</td>\n",
       "      <td>1147.388831</td>\n",
       "      <td>406.884115</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1957-01-01</th>\n",
       "      <td>820.853030</td>\n",
       "      <td>1942.284244</td>\n",
       "      <td>3013.976023</td>\n",
       "      <td>3827.940465</td>\n",
       "      <td>6856.856212</td>\n",
       "      <td>10949.64959</td>\n",
       "      <td>8842.598030</td>\n",
       "      <td>11635.799450</td>\n",
       "      <td>661.637458</td>\n",
       "      <td>9714.960623</td>\n",
       "      <td>...</td>\n",
       "      <td>774.371069</td>\n",
       "      <td>11283.177950</td>\n",
       "      <td>14847.12712</td>\n",
       "      <td>6150.772969</td>\n",
       "      <td>9802.466526</td>\n",
       "      <td>676.285448</td>\n",
       "      <td>1827.067742</td>\n",
       "      <td>804.830455</td>\n",
       "      <td>1311.956766</td>\n",
       "      <td>518.764268</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1962-01-01</th>\n",
       "      <td>853.100710</td>\n",
       "      <td>2312.888958</td>\n",
       "      <td>2550.816880</td>\n",
       "      <td>4269.276742</td>\n",
       "      <td>7133.166023</td>\n",
       "      <td>12217.22686</td>\n",
       "      <td>10750.721110</td>\n",
       "      <td>12753.275140</td>\n",
       "      <td>686.341554</td>\n",
       "      <td>10991.206760</td>\n",
       "      <td>...</td>\n",
       "      <td>767.271740</td>\n",
       "      <td>12477.177070</td>\n",
       "      <td>16173.14586</td>\n",
       "      <td>5603.357717</td>\n",
       "      <td>8422.974165</td>\n",
       "      <td>772.049160</td>\n",
       "      <td>2198.956312</td>\n",
       "      <td>825.623201</td>\n",
       "      <td>1452.725766</td>\n",
       "      <td>527.272182</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1967-01-01</th>\n",
       "      <td>836.197138</td>\n",
       "      <td>2760.196931</td>\n",
       "      <td>3246.991771</td>\n",
       "      <td>5522.776375</td>\n",
       "      <td>8052.953021</td>\n",
       "      <td>14526.12465</td>\n",
       "      <td>12834.602400</td>\n",
       "      <td>14804.672700</td>\n",
       "      <td>721.186086</td>\n",
       "      <td>13149.041190</td>\n",
       "      <td>...</td>\n",
       "      <td>908.918522</td>\n",
       "      <td>14142.850890</td>\n",
       "      <td>19530.36557</td>\n",
       "      <td>5444.619620</td>\n",
       "      <td>9541.474188</td>\n",
       "      <td>637.123289</td>\n",
       "      <td>2649.715007</td>\n",
       "      <td>862.442146</td>\n",
       "      <td>1777.077318</td>\n",
       "      <td>569.795071</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1972-01-01</th>\n",
       "      <td>739.981106</td>\n",
       "      <td>3313.422188</td>\n",
       "      <td>4182.663766</td>\n",
       "      <td>5473.288005</td>\n",
       "      <td>9443.038526</td>\n",
       "      <td>16788.62948</td>\n",
       "      <td>16661.625600</td>\n",
       "      <td>18268.658390</td>\n",
       "      <td>630.233627</td>\n",
       "      <td>16672.143560</td>\n",
       "      <td>...</td>\n",
       "      <td>950.735869</td>\n",
       "      <td>15895.116410</td>\n",
       "      <td>21806.03594</td>\n",
       "      <td>5703.408898</td>\n",
       "      <td>10505.259660</td>\n",
       "      <td>699.501644</td>\n",
       "      <td>3133.409277</td>\n",
       "      <td>1265.047031</td>\n",
       "      <td>1773.498265</td>\n",
       "      <td>799.362176</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>5 rows × 142 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "country     Afghanistan      Albania      Algeria       Angola    Argentina  \\\n",
       "year                                                                          \n",
       "1952-01-01   779.445314  1601.056136  2449.008185  3520.610273  5911.315053   \n",
       "1957-01-01   820.853030  1942.284244  3013.976023  3827.940465  6856.856212   \n",
       "1962-01-01   853.100710  2312.888958  2550.816880  4269.276742  7133.166023   \n",
       "1967-01-01   836.197138  2760.196931  3246.991771  5522.776375  8052.953021   \n",
       "1972-01-01   739.981106  3313.422188  4182.663766  5473.288005  9443.038526   \n",
       "\n",
       "country       Australia       Austria       Bahrain  Bangladesh       Belgium  \\\n",
       "year                                                                            \n",
       "1952-01-01  10039.59564   6137.076492   9867.084765  684.244172   8343.105127   \n",
       "1957-01-01  10949.64959   8842.598030  11635.799450  661.637458   9714.960623   \n",
       "1962-01-01  12217.22686  10750.721110  12753.275140  686.341554  10991.206760   \n",
       "1967-01-01  14526.12465  12834.602400  14804.672700  721.186086  13149.041190   \n",
       "1972-01-01  16788.62948  16661.625600  18268.658390  630.233627  16672.143560   \n",
       "\n",
       "country     ...      Uganda  United Kingdom  United States      Uruguay  \\\n",
       "year        ...                                                           \n",
       "1952-01-01  ...  734.753484     9979.508487    13990.48208  5716.766744   \n",
       "1957-01-01  ...  774.371069    11283.177950    14847.12712  6150.772969   \n",
       "1962-01-01  ...  767.271740    12477.177070    16173.14586  5603.357717   \n",
       "1967-01-01  ...  908.918522    14142.850890    19530.36557  5444.619620   \n",
       "1972-01-01  ...  950.735869    15895.116410    21806.03594  5703.408898   \n",
       "\n",
       "country        Venezuela     Vietnam  West Bank and Gaza  Yemen, Rep.  \\\n",
       "year                                                                    \n",
       "1952-01-01   7689.799761  605.066492         1515.592329   781.717576   \n",
       "1957-01-01   9802.466526  676.285448         1827.067742   804.830455   \n",
       "1962-01-01   8422.974165  772.049160         2198.956312   825.623201   \n",
       "1967-01-01   9541.474188  637.123289         2649.715007   862.442146   \n",
       "1972-01-01  10505.259660  699.501644         3133.409277  1265.047031   \n",
       "\n",
       "country          Zambia    Zimbabwe  \n",
       "year                                 \n",
       "1952-01-01  1147.388831  406.884115  \n",
       "1957-01-01  1311.956766  518.764268  \n",
       "1962-01-01  1452.725766  527.272182  \n",
       "1967-01-01  1777.077318  569.795071  \n",
       "1972-01-01  1773.498265  799.362176  \n",
       "\n",
       "[5 rows x 142 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# pivot table format, group by country and year, value is mean gdpPercap\n",
    "gapminder_pivot_gdp = gapminder.pivot_table(\n",
    "                        index='year', columns='country', \n",
    "                        values='gdpPercap', aggfunc='mean')\n",
    "display(gapminder_pivot_gdp.head())"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Moving from wide to long format"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "If you envounter some Excel table or a PDF report which emphasises human readability, you can use the `pd.melt()` function to convert it to the long format to then use it in your analysis and visualise it. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Melt is essentially a convenient setting around pivot_table\n",
    "gapminder_melt = gapminder_pivot_life_exp.melt(ignore_index=False).reset_index()\n",
    "        \n",
    "display(gapminder_melt.head())"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 86,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>year</th>\n",
       "      <th>continent</th>\n",
       "      <th>lifeExp</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>1952-01-01</td>\n",
       "      <td>Africa</td>\n",
       "      <td>39.135500</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>1957-01-01</td>\n",
       "      <td>Africa</td>\n",
       "      <td>41.266346</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>1962-01-01</td>\n",
       "      <td>Africa</td>\n",
       "      <td>43.319442</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>1967-01-01</td>\n",
       "      <td>Africa</td>\n",
       "      <td>45.334538</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>1972-01-01</td>\n",
       "      <td>Africa</td>\n",
       "      <td>47.450942</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "        year continent    lifeExp\n",
       "0 1952-01-01    Africa  39.135500\n",
       "1 1957-01-01    Africa  41.266346\n",
       "2 1962-01-01    Africa  43.319442\n",
       "3 1967-01-01    Africa  45.334538\n",
       "4 1972-01-01    Africa  47.450942"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "gapminder_melt_life_exp = gapminder_pivot_life_exp.reset_index() \\\n",
    "    .melt(id_vars='year', \n",
    "          var_name='continent', \n",
    "          value_name='lifeExp')\n",
    "    \n",
    "display(gapminder_melt_life_exp.head())"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 87,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>year</th>\n",
       "      <th>country</th>\n",
       "      <th>gdpPercap</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>1952-01-01</td>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>779.445314</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>1957-01-01</td>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>820.853030</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>1962-01-01</td>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>853.100710</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>1967-01-01</td>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>836.197138</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>1972-01-01</td>\n",
       "      <td>Afghanistan</td>\n",
       "      <td>739.981106</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "        year      country   gdpPercap\n",
       "0 1952-01-01  Afghanistan  779.445314\n",
       "1 1957-01-01  Afghanistan  820.853030\n",
       "2 1962-01-01  Afghanistan  853.100710\n",
       "3 1967-01-01  Afghanistan  836.197138\n",
       "4 1972-01-01  Afghanistan  739.981106"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>year</th>\n",
       "      <th>country</th>\n",
       "      <th>gdpPercap</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>1699</th>\n",
       "      <td>1987-01-01</td>\n",
       "      <td>Zimbabwe</td>\n",
       "      <td>706.157306</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1700</th>\n",
       "      <td>1992-01-01</td>\n",
       "      <td>Zimbabwe</td>\n",
       "      <td>693.420786</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1701</th>\n",
       "      <td>1997-01-01</td>\n",
       "      <td>Zimbabwe</td>\n",
       "      <td>792.449960</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1702</th>\n",
       "      <td>2002-01-01</td>\n",
       "      <td>Zimbabwe</td>\n",
       "      <td>672.038623</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1703</th>\n",
       "      <td>2007-01-01</td>\n",
       "      <td>Zimbabwe</td>\n",
       "      <td>469.709298</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "           year   country   gdpPercap\n",
       "1699 1987-01-01  Zimbabwe  706.157306\n",
       "1700 1992-01-01  Zimbabwe  693.420786\n",
       "1701 1997-01-01  Zimbabwe  792.449960\n",
       "1702 2002-01-01  Zimbabwe  672.038623\n",
       "1703 2007-01-01  Zimbabwe  469.709298"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "gapminder_melt_gdp = gapminder_pivot_gdp.reset_index() \\\n",
    "    .melt(id_vars='year', \n",
    "          var_name='country', \n",
    "          value_name='gdpPercap')\n",
    "    \n",
    "display(\n",
    "    gapminder_melt_gdp.head(),\n",
    "    gapminder_melt_gdp.tail()\n",
    "    )"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# 3. A few more examples: faceting"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### `mtcars` dataset"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 88,
   "metadata": {
    "tags": [
     "r-fit-text"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>mpg</th>\n",
       "      <th>cyl</th>\n",
       "      <th>disp</th>\n",
       "      <th>hp</th>\n",
       "      <th>drat</th>\n",
       "      <th>wt</th>\n",
       "      <th>qsec</th>\n",
       "      <th>vs</th>\n",
       "      <th>am</th>\n",
       "      <th>gear</th>\n",
       "      <th>carb</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>rownames</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>Mazda RX4</th>\n",
       "      <td>21.0</td>\n",
       "      <td>6</td>\n",
       "      <td>160.0</td>\n",
       "      <td>110</td>\n",
       "      <td>3.90</td>\n",
       "      <td>2.620</td>\n",
       "      <td>16.46</td>\n",
       "      <td>0</td>\n",
       "      <td>1</td>\n",
       "      <td>4</td>\n",
       "      <td>4</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>Mazda RX4 Wag</th>\n",
       "      <td>21.0</td>\n",
       "      <td>6</td>\n",
       "      <td>160.0</td>\n",
       "      <td>110</td>\n",
       "      <td>3.90</td>\n",
       "      <td>2.875</td>\n",
       "      <td>17.02</td>\n",
       "      <td>0</td>\n",
       "      <td>1</td>\n",
       "      <td>4</td>\n",
       "      <td>4</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>Datsun 710</th>\n",
       "      <td>22.8</td>\n",
       "      <td>4</td>\n",
       "      <td>108.0</td>\n",
       "      <td>93</td>\n",
       "      <td>3.85</td>\n",
       "      <td>2.320</td>\n",
       "      <td>18.61</td>\n",
       "      <td>1</td>\n",
       "      <td>1</td>\n",
       "      <td>4</td>\n",
       "      <td>1</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>Hornet 4 Drive</th>\n",
       "      <td>21.4</td>\n",
       "      <td>6</td>\n",
       "      <td>258.0</td>\n",
       "      <td>110</td>\n",
       "      <td>3.08</td>\n",
       "      <td>3.215</td>\n",
       "      <td>19.44</td>\n",
       "      <td>1</td>\n",
       "      <td>0</td>\n",
       "      <td>3</td>\n",
       "      <td>1</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>Hornet Sportabout</th>\n",
       "      <td>18.7</td>\n",
       "      <td>8</td>\n",
       "      <td>360.0</td>\n",
       "      <td>175</td>\n",
       "      <td>3.15</td>\n",
       "      <td>3.440</td>\n",
       "      <td>17.02</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>3</td>\n",
       "      <td>2</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "                    mpg  cyl   disp   hp  drat     wt   qsec  vs  am  gear  \\\n",
       "rownames                                                                     \n",
       "Mazda RX4          21.0    6  160.0  110  3.90  2.620  16.46   0   1     4   \n",
       "Mazda RX4 Wag      21.0    6  160.0  110  3.90  2.875  17.02   0   1     4   \n",
       "Datsun 710         22.8    4  108.0   93  3.85  2.320  18.61   1   1     4   \n",
       "Hornet 4 Drive     21.4    6  258.0  110  3.08  3.215  19.44   1   0     3   \n",
       "Hornet Sportabout  18.7    8  360.0  175  3.15  3.440  17.02   0   0     3   \n",
       "\n",
       "                   carb  \n",
       "rownames                 \n",
       "Mazda RX4             4  \n",
       "Mazda RX4 Wag         4  \n",
       "Datsun 710            1  \n",
       "Hornet 4 Drive        1  \n",
       "Hornet Sportabout     2  "
      ]
     },
     "execution_count": 88,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# !pip install statsmodels\n",
    "import statsmodels.api as sm\n",
    "mtcars = sm.datasets.get_rdataset(\"mtcars\", \"datasets\", cache=True).data\n",
    "mtcars = pd.DataFrame(mtcars)\n",
    "mtcars.head()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 89,
   "metadata": {
    "tags": [
     "r-fit-text"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"QwnxPF\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"mpg\":[21.0,21.0,22.8,21.4,18.7,18.1,14.3,24.4,22.8,19.2,17.8,16.4,17.3,15.2,10.4,10.4,14.7,32.4,30.4,33.9,21.5,15.5,15.2,13.3,19.2,27.3,26.0,30.4,15.8,19.7,15.0,21.4],\n",
       "\"hp\":[110.0,110.0,93.0,110.0,175.0,105.0,245.0,62.0,95.0,123.0,123.0,180.0,180.0,180.0,205.0,215.0,230.0,66.0,52.0,65.0,97.0,150.0,150.0,245.0,175.0,66.0,91.0,113.0,264.0,175.0,335.0,109.0],\n",
       "\"wt\":[2.62,2.875,2.32,3.215,3.44,3.46,3.57,3.19,3.15,3.44,3.44,4.07,3.73,3.78,5.25,5.424,5.345,2.2,1.615,1.835,2.465,3.52,3.435,3.84,3.845,1.935,2.14,1.513,3.17,2.77,3.57,2.78]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"wt\",\n",
       "\"y\":\"mpg\",\n",
       "\"color\":\"hp\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"smooth\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"method\":\"lm\",\n",
       "\"data\":{\n",
       "\"..ymin..\":[26.9637596243046,26.74821163097799,26.532293643118013,26.315979803952708,26.09924203158688,25.882049807548857,25.664369946436718,25.446166345898057,25.227399716523074,25.008027291740934,24.788002518534245,24.5672747307859,24.345788808417513,24.12348482725029,23.9002977068049,23.676156866145327,23.450985901439942,23.22470230320919,22.99721723624465,22.768435410814753,22.538255079768405,22.306568202054887,22.07326081827499,21.838213687127222,21.601303231647698,21.362402839329096,21.121384548815314,20.87812113640567,20.6324885872813,20.384368899708285,20.133653127878546,19.880244525139766,19.624061610801967,19.365040958315305,19.103139497753393,18.838336146062346,18.57063262492164,18.300053393465227,18.026644701908147,17.7504728499618,17.47162179868021,17.19019032705795,16.906288941258758,16.620036736014264,16.331558379857157,16.040981356000614,15.74843354658199,15.454041206047755,15.15792733394895,14.86021043043173,14.561003599531578,14.26041395508463,13.958542280095603,13.655482891018286,13.351323662010536,13.046146169501945,12.740025923372029,12.433032657000677,12.125230654002793,11.816679094370107,11.507432406928613,11.197540618482305,10.887049692806372,10.576001854855777,10.264435897257101,9.952387467439804,9.639889334716896,9.32697163731397,9.013662109828243,8.699986291923867,8.385967719274454,8.071628097880659,7.756987462942249,7.442064323470289,7.1268757937987965,6.811437713108534,6.495764754014763,6.179870521202979,5.863767641025417,5.54746784289919],\n",
       "\"..ymax..\":[31.434121731320616,31.120499387408785,30.807247038030322,30.494390539957188,30.181957975084575,29.869979861884158,29.558489385757856,29.247522649058077,28.93711894119462,28.62732102873832,28.318175464706567,28.00973291521647,27.702048500346418,27.3951821442752,27.08919892748215,26.784169430903283,26.480170058370227,26.177283319362537,25.875598049088637,25.575209537280102,25.276219531088003,24.97873607156308,24.68287311810454,24.388749912013864,24.096490030254955,23.806220085335116,23.51806803861045,23.23216111378166,22.948623325667583,22.667572676002166,22.389118110593465,22.113356376093805,21.840368953193163,21.570219268441384,21.302950391764856,21.038583406217462,20.77711659011973,20.5185254843377,20.26276383865634,20.009765353364248,19.759446067407403,19.51170720179122,19.266438250351968,19.02352011835802,18.782828137276688,18.544234823894797,18.30761229607498,18.072834299370776,17.839777834231136,17.60832440050991,17.37836089417163,17.14978020138014,16.922481539130725,16.696370590969593,16.47135948273892,16.247366638009062,16.024316546900533,15.80213947603345,15.580771141792892,15.360152364187131,15.140228714390192,14.920950165598066,14.702270754035553,14.484148254747707,14.26654387510795,14.049421967686799,13.83274976317126,13.616497123335758,13.400636313583039,13.185141794248974,12.969990029659947,12.755159313815309,12.540629611515271,12.326382413748798,12.11240060618185,11.898668349633665,11.685170971489002,11.471894867062346,11.258827410001468,11.045956870889254],\n",
       "\"wt\":[1.513,1.562506329113924,1.612012658227848,1.6615189873417722,1.711025316455696,1.7605316455696203,1.8100379746835442,1.8595443037974684,1.9090506329113923,1.9585569620253165,2.0080632911392406,2.0575696202531644,2.1070759493670885,2.1565822784810127,2.206088607594937,2.255594936708861,2.3051012658227847,2.354607594936709,2.404113924050633,2.453620253164557,2.503126582278481,2.552632911392405,2.6021392405063293,2.6516455696202534,2.701151898734177,2.7506582278481013,2.8001645569620255,2.849670886075949,2.899177215189874,2.9486835443037975,2.9981898734177217,3.047696202531646,3.0972025316455696,3.146708860759494,3.196215189873418,3.245721518987342,3.2952278481012662,3.34473417721519,3.394240506329114,3.4437468354430383,3.493253164556962,3.542759493670886,3.5922658227848103,3.6417721518987345,3.6912784810126587,3.7407848101265824,3.7902911392405065,3.8397974683544307,3.889303797468355,3.938810126582279,3.9883164556962027,4.0378227848101265,4.087329113924051,4.136835443037976,4.1863417721518985,4.235848101265823,4.285354430379748,4.3348607594936714,4.384367088607595,4.43387341772152,4.4833797468354435,4.532886075949367,4.582392405063292,4.6318987341772155,4.681405063291139,4.730911392405064,4.7804177215189885,4.829924050632911,4.879430379746836,4.9289367088607605,4.978443037974684,5.027949367088608,5.077455696202533,5.126962025316456,5.17646835443038,5.225974683544305,5.275481012658228,5.324987341772152,5.374493670886077,5.424],\n",
       "\"mpg\":[29.198940677812608,28.934355509193388,28.669770340574168,28.405185171954948,28.140600003335727,27.876014834716507,27.611429666097287,27.346844497478067,27.082259328858846,26.817674160239626,26.553088991620406,26.288503823001186,26.023918654381966,25.759333485762745,25.494748317143525,25.230163148524305,24.965577979905085,24.700992811285865,24.436407642666644,24.171822474047428,23.907237305428204,23.642652136808984,23.378066968189763,23.113481799570543,22.848896630951327,22.584311462332106,22.319726293712883,22.055141125093666,21.790555956474442,21.525970787855226,21.261385619236005,20.996800450616785,20.732215281997565,20.467630113378345,20.203044944759124,19.938459776139904,19.673874607520684,19.409289438901464,19.144704270282244,18.880119101663023,18.615533933043807,18.350948764424587,18.086363595805363,17.821778427186143,17.557193258566922,17.292608089947706,17.028022921328485,16.763437752709265,16.49885258409004,16.23426741547082,15.969682246851605,15.705097078232384,15.440511909613164,15.17592674099394,14.911341572374727,14.646756403755504,14.38217123513628,14.117586066517063,13.853000897897843,13.58841572927862,13.323830560659403,13.059245392040186,12.794660223420962,12.530075054801742,12.265489886182525,12.000904717563301,11.736319548944078,11.471734380324865,11.20714921170564,10.94256404308642,10.6779788744672,10.413393705847984,10.14880853722876,9.884223368609543,9.619638199990323,9.3550530313711,9.090467862751883,8.825882694132662,8.561297525513442,8.296712356894222],\n",
       "\"hp\":[146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875,146.6875]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"QwnxPF\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144bafb10>"
      ]
     },
     "execution_count": 89,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(\n",
    "        data = mtcars, \n",
    "        mapping = aes(\n",
    "            x = 'wt', \n",
    "            y = 'mpg', \n",
    "            color = 'hp'\n",
    "            )\n",
    "        ) +\n",
    "        geom_point() +\n",
    "        geom_smooth(method = 'lm') +\n",
    "        theme_minimal()\n",
    ")\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 90,
   "metadata": {
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "r-fit-text"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"mVdIqX\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"mpg\":[21.0,21.0,22.8,21.4,18.7,18.1,14.3,24.4,22.8,19.2,17.8,16.4,17.3,15.2,10.4,10.4,14.7,32.4,30.4,33.9,21.5,15.5,15.2,13.3,19.2,27.3,26.0,30.4,15.8,19.7,15.0,21.4],\n",
       "\"cyl\":[6.0,6.0,4.0,6.0,8.0,6.0,8.0,4.0,4.0,6.0,6.0,8.0,8.0,8.0,8.0,8.0,8.0,4.0,4.0,4.0,4.0,8.0,8.0,8.0,8.0,4.0,4.0,4.0,8.0,6.0,8.0,4.0],\n",
       "\"wt\":[2.62,2.875,2.32,3.215,3.44,3.46,3.57,3.19,3.15,3.44,3.44,4.07,3.73,3.78,5.25,5.424,5.345,2.2,1.615,1.835,2.465,3.52,3.435,3.84,3.845,1.935,2.14,1.513,3.17,2.77,3.57,2.78]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"wt\",\n",
       "\"y\":\"mpg\",\n",
       "\"color\":\"cyl\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"smooth\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"method\":\"lm\",\n",
       "\"data\":{\n",
       "\"..ymin..\":[26.9637596243046,26.74821163097799,26.532293643118013,26.315979803952708,26.09924203158688,25.882049807548857,25.664369946436718,25.446166345898057,25.227399716523074,25.008027291740934,24.788002518534245,24.5672747307859,24.345788808417513,24.12348482725029,23.9002977068049,23.676156866145327,23.450985901439942,23.22470230320919,22.99721723624465,22.768435410814753,22.538255079768405,22.306568202054887,22.07326081827499,21.838213687127222,21.601303231647698,21.362402839329096,21.121384548815314,20.87812113640567,20.6324885872813,20.384368899708285,20.133653127878546,19.880244525139766,19.624061610801967,19.365040958315305,19.103139497753393,18.838336146062346,18.57063262492164,18.300053393465227,18.026644701908147,17.7504728499618,17.47162179868021,17.19019032705795,16.906288941258758,16.620036736014264,16.331558379857157,16.040981356000614,15.74843354658199,15.454041206047755,15.15792733394895,14.86021043043173,14.561003599531578,14.26041395508463,13.958542280095603,13.655482891018286,13.351323662010536,13.046146169501945,12.740025923372029,12.433032657000677,12.125230654002793,11.816679094370107,11.507432406928613,11.197540618482305,10.887049692806372,10.576001854855777,10.264435897257101,9.952387467439804,9.639889334716896,9.32697163731397,9.013662109828243,8.699986291923867,8.385967719274454,8.071628097880659,7.756987462942249,7.442064323470289,7.1268757937987965,6.811437713108534,6.495764754014763,6.179870521202979,5.863767641025417,5.54746784289919],\n",
       "\"..ymax..\":[31.434121731320616,31.120499387408785,30.807247038030322,30.494390539957188,30.181957975084575,29.869979861884158,29.558489385757856,29.247522649058077,28.93711894119462,28.62732102873832,28.318175464706567,28.00973291521647,27.702048500346418,27.3951821442752,27.08919892748215,26.784169430903283,26.480170058370227,26.177283319362537,25.875598049088637,25.575209537280102,25.276219531088003,24.97873607156308,24.68287311810454,24.388749912013864,24.096490030254955,23.806220085335116,23.51806803861045,23.23216111378166,22.948623325667583,22.667572676002166,22.389118110593465,22.113356376093805,21.840368953193163,21.570219268441384,21.302950391764856,21.038583406217462,20.77711659011973,20.5185254843377,20.26276383865634,20.009765353364248,19.759446067407403,19.51170720179122,19.266438250351968,19.02352011835802,18.782828137276688,18.544234823894797,18.30761229607498,18.072834299370776,17.839777834231136,17.60832440050991,17.37836089417163,17.14978020138014,16.922481539130725,16.696370590969593,16.47135948273892,16.247366638009062,16.024316546900533,15.80213947603345,15.580771141792892,15.360152364187131,15.140228714390192,14.920950165598066,14.702270754035553,14.484148254747707,14.26654387510795,14.049421967686799,13.83274976317126,13.616497123335758,13.400636313583039,13.185141794248974,12.969990029659947,12.755159313815309,12.540629611515271,12.326382413748798,12.11240060618185,11.898668349633665,11.685170971489002,11.471894867062346,11.258827410001468,11.045956870889254],\n",
       "\"wt\":[1.513,1.562506329113924,1.612012658227848,1.6615189873417722,1.711025316455696,1.7605316455696203,1.8100379746835442,1.8595443037974684,1.9090506329113923,1.9585569620253165,2.0080632911392406,2.0575696202531644,2.1070759493670885,2.1565822784810127,2.206088607594937,2.255594936708861,2.3051012658227847,2.354607594936709,2.404113924050633,2.453620253164557,2.503126582278481,2.552632911392405,2.6021392405063293,2.6516455696202534,2.701151898734177,2.7506582278481013,2.8001645569620255,2.849670886075949,2.899177215189874,2.9486835443037975,2.9981898734177217,3.047696202531646,3.0972025316455696,3.146708860759494,3.196215189873418,3.245721518987342,3.2952278481012662,3.34473417721519,3.394240506329114,3.4437468354430383,3.493253164556962,3.542759493670886,3.5922658227848103,3.6417721518987345,3.6912784810126587,3.7407848101265824,3.7902911392405065,3.8397974683544307,3.889303797468355,3.938810126582279,3.9883164556962027,4.0378227848101265,4.087329113924051,4.136835443037976,4.1863417721518985,4.235848101265823,4.285354430379748,4.3348607594936714,4.384367088607595,4.43387341772152,4.4833797468354435,4.532886075949367,4.582392405063292,4.6318987341772155,4.681405063291139,4.730911392405064,4.7804177215189885,4.829924050632911,4.879430379746836,4.9289367088607605,4.978443037974684,5.027949367088608,5.077455696202533,5.126962025316456,5.17646835443038,5.225974683544305,5.275481012658228,5.324987341772152,5.374493670886077,5.424],\n",
       "\"mpg\":[29.198940677812608,28.934355509193388,28.669770340574168,28.405185171954948,28.140600003335727,27.876014834716507,27.611429666097287,27.346844497478067,27.082259328858846,26.817674160239626,26.553088991620406,26.288503823001186,26.023918654381966,25.759333485762745,25.494748317143525,25.230163148524305,24.965577979905085,24.700992811285865,24.436407642666644,24.171822474047428,23.907237305428204,23.642652136808984,23.378066968189763,23.113481799570543,22.848896630951327,22.584311462332106,22.319726293712883,22.055141125093666,21.790555956474442,21.525970787855226,21.261385619236005,20.996800450616785,20.732215281997565,20.467630113378345,20.203044944759124,19.938459776139904,19.673874607520684,19.409289438901464,19.144704270282244,18.880119101663023,18.615533933043807,18.350948764424587,18.086363595805363,17.821778427186143,17.557193258566922,17.292608089947706,17.028022921328485,16.763437752709265,16.49885258409004,16.23426741547082,15.969682246851605,15.705097078232384,15.440511909613164,15.17592674099394,14.911341572374727,14.646756403755504,14.38217123513628,14.117586066517063,13.853000897897843,13.58841572927862,13.323830560659403,13.059245392040186,12.794660223420962,12.530075054801742,12.265489886182525,12.000904717563301,11.736319548944078,11.471734380324865,11.20714921170564,10.94256404308642,10.6779788744672,10.413393705847984,10.14880853722876,9.884223368609543,9.619638199990323,9.3550530313711,9.090467862751883,8.825882694132662,8.561297525513442,8.296712356894222],\n",
       "\"cyl\":[6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999,6.187499999999999]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"mVdIqX\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b9f650>"
      ]
     },
     "execution_count": 90,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(\n",
    "        data = mtcars, \n",
    "        mapping = aes(\n",
    "            x = 'wt', \n",
    "            y = 'mpg', \n",
    "            color = 'cyl'\n",
    "            )\n",
    "        ) +\n",
    "        geom_point() +\n",
    "        geom_smooth(method = 'lm') +\n",
    "        theme_minimal()\n",
    ")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 91,
   "metadata": {
    "slideshow": {
     "slide_type": "subslide"
    },
    "tags": [
     "r-fit-text"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"s4mst1\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"mpg\":[21.0,21.0,22.8,21.4,18.7,18.1,14.3,24.4,22.8,19.2,17.8,16.4,17.3,15.2,10.4,10.4,14.7,32.4,30.4,33.9,21.5,15.5,15.2,13.3,19.2,27.3,26.0,30.4,15.8,19.7,15.0,21.4],\n",
       "\"disp\":[160.0,160.0,108.0,258.0,360.0,225.0,360.0,146.7,140.8,167.6,167.6,275.8,275.8,275.8,472.0,460.0,440.0,78.7,75.7,71.1,120.1,318.0,304.0,350.0,400.0,79.0,120.3,95.1,351.0,145.0,301.0,121.0],\n",
       "\"gear\":[4.0,4.0,4.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,4.0,5.0,5.0,5.0,5.0,5.0,4.0]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"disp\",\n",
       "\"y\":\"mpg\",\n",
       "\"color\":\"gear\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"color\",\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"smooth\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"method\":\"lm\",\n",
       "\"data\":{\n",
       "\"..ymin..\":[24.736251054196302,24.565665150326968,24.39459593487032,24.223013049990797,24.050884004824578,23.878174044757596,23.70484602109553,23.53086026380435,23.356174460728656,23.18074354754102,23.00451961363853,22.827451830271837,22.64948640834526,22.470566594520914,22.29063271543104,22.109622280856357,21.92747015753626,21.74410882567713,21.55946873002044,21.37347873630312,21.186066701860245,20.997160165779338,20.80668715927171,20.614577130747723,20.42076197260181,20.22517712827551,20.02776274935804,19.828464864120797,19.627236511953814,19.424038793725735,19.218841787069046,19.01162527865425,18.802379272860836,18.591104247513563,18.37781114159404,18.162521075657864,17.94526482143091,17.72608205108086,17.505020407595364,17.28213444465931,17.057484487098286,16.831135461591508,16.603155742643285,16.373616051699997,16.142588438856983,15.910145367794117,15.676358916207837,15.441300096633856,15.205038296504014,14.967640831667882,14.729172604390573,14.489695854860507,14.249269994296274,14.007951507600861,13.765793913956712,13.522847774591689,13.279160738014891,13.034777614198237,12.789740470372566,12.544088742254022,12.297859355576806,12.051086853760726,11.803803528377491,11.556039549797683,11.307823096007933,11.059180478093396,10.810136261295883,10.560713380894516,10.310933252424537,10.060815875961971,9.810379934366377,9.559642885499223,9.30862104852939,9.057329684505305,8.805783071420695,8.553994574032894,8.301976708711209,8.049741203602473,7.797299054402684,7.544660576020099],\n",
       "\"..ymax..\":[28.602668399423393,28.354946921189413,28.107708754542745,27.860984257318954,27.61480592038186,27.369208498345525,27.124229139904276,26.879907515092135,26.63628593606452,26.393409467148835,26.151326018948012,25.91008642021139,25.66974446003465,25.430356891755682,25.19198338874224,24.95468644121361,24.718531182430393,24.483585132186207,24.249917845739574,24.017600457353588,23.78670510969314,23.557304263670733,23.329469888075046,23.10327253449572,22.878780310538318,22.6560577727613,22.435164769575458,22.21615527270938,21.999076242773054,21.78396657889781,21.570856203451186,21.359765329762666,21.150703953452766,20.943671596696724,20.73865732051293,20.535640004345794,20.334588876469425,20.13546426471617,19.938218526098343,19.74279710693109,19.549139682388798,19.357181325792254,19.166853662637163,18.978085971477135,18.790806202216835,18.604941891176388,18.42042096065935,18.23717239813001,18.055126816156545,17.874216898889355,17.694377744063356,17.5155471114901,17.33766558995102,17.16067669454312,16.98452690608395,16.80916566334566,16.634545317819136,16.46062105953248,16.28735082125484,16.11469516727006,15.942617171843965,15.771082291556723,15.600058234836647,15.42951483131314,15.259423902999576,15.089759138810798,14.92049597350499,14.751611471803042,14.583084218169713,14.414894212528957,14.247022772021236,14.079452438785083,13.912166893651593,13.745150875572364,13.578390106553652,13.411871221838146,13.245581705056516,13.07950982806193,12.913644595158411,12.747975691437674],\n",
       "\"disp\":[71.1,76.17468354430379,81.24936708860758,86.32405063291138,91.39873417721518,96.47341772151898,101.54810126582278,106.62278481012657,111.69746835443037,116.77215189873417,121.84683544303796,126.92151898734176,131.99620253164557,137.07088607594937,142.14556962025316,147.22025316455694,152.29493670886075,157.36962025316456,162.44430379746834,167.51898734177212,172.59367088607593,177.66835443037974,182.74303797468355,187.81772151898733,192.8924050632911,197.96708860759492,203.04177215189873,208.1164556962025,213.19113924050632,218.2658227848101,223.3405063291139,228.4151898734177,233.4898734177215,238.5645569620253,243.6392405063291,248.7139240506329,253.78860759493668,258.86329113924046,263.93797468354427,269.0126582278481,274.08734177215183,279.1620253164557,284.23670886075945,289.31139240506326,294.38607594936707,299.4607594936708,304.5354430379747,309.61012658227844,314.68481012658225,319.75949367088606,324.8341772151898,329.9088607594937,334.98354430379743,340.0582278481012,345.13291139240505,350.2075949367088,355.28227848101267,360.3569620253164,365.4316455696202,370.50632911392404,375.5810126582278,380.65569620253166,385.7303797468354,390.80506329113916,395.87974683544303,400.9544303797468,406.02911392405065,411.1037974683544,416.17848101265815,421.253164556962,426.3278481012658,431.4025316455695,436.4772151898734,441.55189873417714,446.626582278481,451.70126582278476,456.7759493670885,461.8506329113924,466.92531645569613,472.0],\n",
       "\"mpg\":[26.669459726809848,26.46030603575819,26.251152344706533,26.041998653654876,25.832844962603218,25.62369127155156,25.414537580499903,25.205383889448242,24.99623019839659,24.787076507344928,24.57792281629327,24.368769125241613,24.159615434189956,23.9504617431383,23.74130805208664,23.532154361034983,23.323000669983326,23.11384697893167,22.904693287880008,22.695539596828354,22.486385905776693,22.277232214725036,22.06807852367338,21.85892483262172,21.649771141570064,21.440617450518406,21.23146375946675,21.022310068415088,20.813156377363434,20.604002686311773,20.394848995260116,20.18569530420846,19.9765416131568,19.767387922105144,19.558234231053486,19.34908054000183,19.139926848950168,18.930773157898514,18.721619466846853,18.5124657757952,18.303312084743542,18.09415839369188,17.885004702640224,17.675851011588566,17.46669732053691,17.25754362948525,17.048389938433594,16.839236247381933,16.63008255633028,16.42092886527862,16.211775174226965,16.002621483175304,15.793467792123646,15.58431410107199,15.37516041002033,15.166006718968674,14.956853027917013,14.747699336865358,14.538545645813702,14.329391954762041,14.120238263710386,13.911084572658725,13.701930881607069,13.492777190555412,13.283623499503754,13.074469808452097,12.865316117400436,12.656162426348779,12.447008735297125,12.237855044245464,12.028701353193807,11.819547662142153,11.610393971090492,11.401240280038834,11.192086588987173,10.98293289793552,10.773779206883862,10.564625515832201,10.355471824780548,10.146318133728887],\n",
       "\"gear\":[3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987,3.6874999999999987]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"s4mst1\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b9e710>"
      ]
     },
     "execution_count": 91,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "  ggplot(data = mtcars,\n",
    "       mapping = aes(x = 'disp',\n",
    "                     y = 'mpg',\n",
    "                     color = 'gear')) +\n",
    "    geom_point() +\n",
    "    geom_smooth(method = \"lm\") +\n",
    "    scale_color_viridis() \n",
    ")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 92,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"LyxgY0\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"mpg\":[21.0,21.0,22.8,21.4,18.7,18.1,14.3,24.4,22.8,19.2,17.8,16.4,17.3,15.2,10.4,10.4,14.7,32.4,30.4,33.9,21.5,15.5,15.2,13.3,19.2,27.3,26.0,30.4,15.8,19.7,15.0,21.4],\n",
       "\"disp\":[160.0,160.0,108.0,258.0,360.0,225.0,360.0,146.7,140.8,167.6,167.6,275.8,275.8,275.8,472.0,460.0,440.0,78.7,75.7,71.1,120.1,318.0,304.0,350.0,400.0,79.0,120.3,95.1,351.0,145.0,301.0,121.0],\n",
       "\"gear\":[4.0,4.0,4.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,4.0,5.0,5.0,5.0,5.0,5.0,4.0]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"disp\",\n",
       "\"y\":\"mpg\",\n",
       "\"color\":\"gear\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"facet\":{\n",
       "\"name\":\"wrap\",\n",
       "\"facets\":\"gear\",\n",
       "\"ncol\":1.0,\n",
       "\"order\":1.0,\n",
       "\"dir\":\"h\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"color\",\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"smooth\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[]\n",
       "},\n",
       "\"method\":\"lm\",\n",
       "\"data\":{\n",
       "\"..ymin..\":[18.110471212875474,18.055282738072687,17.999869530255523,17.944218807024544,17.888316855121165,17.832148950250065,17.775699269275947,17.718950794063353,17.661885206172315,17.604482771567685,17.54672221444906,17.488580579264564,17.430033079940074,17.371052935341318,17.311611189999045,17.251676519176048,17.191215017454446,17.130189970188678,17.068561607426457,17.006286840273894,16.94331898020551,16.87960744253519,16.81509743621812,16.74972964340082,16.683439893735972,16.61615884049476,16.5478116479995,16.478317702912722,16.407590365475343,16.33553678086279,16.262057775326504,16.187047866506997,16.110395421896484,16.031983003365113,15.951687938202596,15.86938315730634,15.784938337825697,15.698221379531658,15.609100230319289,15.51744505587064,15.423130721683112,15.326039523627545,15.226064068599621,15.12311017379106,15.017099626872586,14.907972635488948,14.795689797568807,14.680233446496343,14.56160826639115,14.439841128238198,14.314980160068446,14.187093124968696,14.056265230964748,13.922596530550756,13.7861990819478,13.64719403972004,13.505708822678628,13.361874477245124,13.215823320168953,13.067686910542323,12.91759437095986,12.765671053466136,12.61203752832302,12.456808862316446,12.300094147400305,12.141996238764571,11.982611662709724,11.822030657936521,11.660337318147631,11.497609808555906,11.333920633553431,11.16933693713552,11.003920821539468,10.837729672887376,10.67081648541222,10.503230178131917,10.335015899670093,10.1662153183672,9.996866895943162,9.827006143820459,28.231355556087774,28.12301331860439,28.014326518156963,27.905278534974745,27.79585182570608,27.68602787401537,27.57578713990086,27.465109008030943,27.353971735480908,27.242352399350672,27.130226844857958,27.017569634632245,26.90435400008326,26.790551795884706,26.676133458798876,26.56106797227031,26.445322838434233,26.32886405941498,26.21165613002499,26.093662044209044,25.97484331780003,25.855160030348745,25.734570888943274,25.61303331702357,25.49050357119976,25.366936888972067,25.242287669998234,25.116509693132457,24.989556370843356,24.86138104178706,24.731937301255048,24.601179367938094,24.46906248396841,24.33554334356408,24.20058054386865,24.064135049843895,23.926170663445113,23.786654485911704,23.645557360971104,23.502854286205935,23.35852477987405,23.212553191166005,23.064928943253168,22.915646700484338,22.764706453635345,22.612113520056965,22.457878458715623,22.302016903270925,22.144549319276038,21.98550069413499,21.82490017045797,21.662780634826344,21.499178274676602,21.33413211605425,21.167683554442345,20.999875889836247,20.830753875840497,20.660363290935646,20.488750538328315,20.31596227906617,20.142045101461136,19.967045228384336,19.791008262717128,19.61397897018539,19.436001097972074,19.25711722688577,19.07736865444053,18.896795305949738,18.715435670625542,18.533326759678246,18.350504083499473,18.16700164516614,17.98285194769814,17.798086012724333,17.612733408445347,17.426822285017295,17.24037941570979,17.053430242409465,16.86599892424262,16.678108388275668,19.352986248253586,19.304830378368145,19.254893412348622,19.20308958429367,19.14932906994715,19.093517904690323,19.035557923737144,18.975346729515714,18.912777691774025,18.847739986485394,18.780118680123557,18.709794866295262,18.636645862019307,18.56054547107835,18.481364321788806,18.3989702861776,18.313228986859684,18.22400439681973,18.131159535760624,18.03455726465198,17.93406117757437,17.82953658691941,17.7208515945196,17.607878237435685,17.4904936930632,17.368581524122117,17.242032940197127,17.110748049066757,16.97463706837889,16.833621466572108,16.687635001543367,16.53662462659802,16.380551235768504,16.21939022462776,16.053131848103778,15.881781363262622,15.705358952207819,15.523899427719726,15.337451731574328,15.146078242198435,14.94985391405508,14.748865275614381,14.543209315770408,14.33299229004923,14.118328477969847,13.899338921616083,13.67615017307524,13.448893075164928,13.217701596083595,12.98271173455695,12.744060507954764,12.501885031923688,12.256321696476043,12.007505440297061,11.755569122343967,11.500642987629234,11.242854222397083,10.98232659268141,10.719180159426603,10.45353106290072,10.185491368973778,9.915168969911345,9.642667532591188,9.368086487438262,9.091521051848423,8.813062282399164,8.532797150697505,8.250808638269064,7.967175846431927,7.681974117612232,7.395275165037749,7.107147208186213,6.817655111765168,6.526860526358124,6.234822029190186,5.941595263745805,5.64723307721531,5.351785654957569,5.055300651347226,4.7578233165289365],\n",
       "\"..ymax..\":[24.730598031739163,24.556201105421014,24.382028912117235,24.20809423422727,24.034410785009715,23.86099328875987,23.687857568613047,23.515020642704705,23.3425008294748,23.170317862958488,22.99849301895618,22.82704925301973,22.656011351223285,22.485406094701098,22.315262438922428,22.14561170862449,21.976487809225148,21.807927455369974,21.63997041701126,21.47265978304288,21.30604224199032,21.140168378539705,20.97509298373583,20.810875375432197,20.6475797239761,20.48527537609637,20.32403716747069,20.16394571143653,20.005087647752966,19.847555831244584,19.691449435659926,19.53687394335849,19.38394098684806,19.232768004258496,19.08347766830007,18.936197048075393,18.79105646643509,18.648188023608185,18.50772377169962,18.369793545027328,18.23452247809392,18.102028275028545,17.972418328935525,17.84578682262314,17.722211968420687,17.601753558683384,17.484450995482582,17.370321945434103,17.259361724418355,17.151543461450366,17.04681902849918,16.94512066247799,16.846363155360997,16.75044645465405,16.657258502136063,16.566678143242886,16.478577959163356,16.392826903475918,16.309292659431147,16.227843667936845,16.14835080639836,16.07068872277115,15.994736846793321,15.920380111678956,15.847509425474154,15.776021932988952,15.705821107922853,15.63681671157512,15.568924650243067,15.502066758713854,15.436170532595385,15.37116882789236,15.306999542367466,15.243605289898623,15.18093307625284,15.1189339824122,15.057562859753087,14.996778039935037,14.936541061238136,14.876816412239897,33.52506094432826,33.33483296608371,33.144949550803204,32.95542731825749,32.76628381179822,32.57753754776099,32.38920806614757,32.20131598228955,32.013883039111654,31.82693215951395,31.64048749827873,31.45457449277651,31.26921991159756,31.084451900068178,30.900300021426073,30.716795292226706,30.533970210334846,30.351858773626166,30.17049648728822,29.98992035737623,29.81016886805731,29.63128193978066,29.453300865458196,29.276268221649964,29.10022775174584,28.9252242182456,28.751303221491497,28.57851098262934,28.406894089190505,28.236499202518868,28.067372727322944,27.899560444911963,27.73310711315371,27.568056037830107,27.404448621797602,27.242323900094423,27.08171807076527,26.922664032570744,26.76519094178341,26.609323800820643,26.455083091424594,26.302484464404703,26.151538496589605,26.0022505236305,25.85462055475156,25.708643272602004,25.56430811821541,25.421599457932174,25.280496826199126,25.14097523561224,25.003005543561326,24.866554863465016,24.73158700788683,24.598062950781248,24.465941296665218,24.335178745543374,24.20573054381119,24.077550912988112,23.9505934498675,23.82481149340171,23.70015845527881,23.576588112627675,23.45405486256695,23.33251393937076,23.21192159585614,23.092235251214507,22.973413607931807,22.855416740694665,22.738206160290925,22.621744855510286,22.505997315961125,22.390929538566525,22.276509020306587,22.16270473955246,22.049487128103518,21.936828035803636,21.824700689383207,21.71307964695559,21.601940749394497,21.491261069633516,34.311479038260146,34.03068924176512,33.75168054140417,33.47453870307864,33.1993535510447,32.92621904992105,32.65523336449376,32.38649889233472,32.12012226369594,31.8562143026041,31.594889942585468,31.336268090033293,31.08047142792877,30.827626152489266,30.57786163539833,30.331310004629067,30.088105637566514,29.848384561226,29.612283755904635,29.3799403606328,29.151490781329947,28.92706970560443,28.70680903162377,28.490836722327217,28.27927560031923,28.072242102879844,27.869845020424357,27.672184245174265,27.479349559481655,27.291419494907974,27.108460293556238,26.930525002121122,26.75765272657016,26.589868071330436,26.427180781473947,26.269585599934626,26.117062344608968,25.96957620271658,25.82707823248152,25.689506055476933,25.556784717239818,25.428827689300046,25.305537982763543,25.186809342104258,25.072527487803164,24.962571377776463,24.85681445993683,24.755125891466673,24.657371704167538,24.56341589931371,24.473121459535427,24.386351269186033,24.30296893825321,24.222839528051715,24.145830179624344,24.0718106479586,24.000653746810286,23.932235710145484,23.86643647701983,23.803139907165235,23.7422339347117,23.683610667393662,23.627166438333347,23.572801817105805,23.520421586315173,23.46993468938396,23.421254154705153,23.374297000753124,23.32898412620979,23.28524018864901,23.242993474843022,23.202175765314088,23.16272219535466,23.12457111438123,23.0876639451687,23.05194504423261,23.017361564382632,22.983863320259907,22.95140265748978,22.9199343259276],\n",
       "\"disp\":[120.1,124.55443037974683,129.00886075949367,133.4632911392405,137.91772151898732,142.37215189873416,146.826582278481,151.28101265822784,155.73544303797468,160.18987341772151,164.64430379746835,169.0987341772152,173.55316455696203,178.00759493670887,182.46202531645568,186.91645569620252,191.37088607594936,195.8253164556962,200.27974683544304,204.73417721518985,209.18860759493668,213.64303797468352,218.09746835443036,222.5518987341772,227.00632911392404,231.46075949367088,235.91518987341772,240.36962025316456,244.8240506329114,249.2784810126582,253.73291139240504,258.18734177215185,262.64177215189875,267.09620253164553,271.5506329113924,276.0050632911392,280.4594936708861,284.9139240506329,289.3683544303797,293.82278481012656,298.2772151898734,302.73164556962024,307.1860759493671,311.6405063291139,316.0949367088607,320.5493670886076,325.0037974683544,329.4582278481013,333.91265822784806,338.36708860759495,342.82151898734173,347.27594936708863,351.7303797468354,356.18481012658225,360.6392405063291,365.0936708860759,369.54810126582277,374.0025316455696,378.45696202531644,382.9113924050632,387.3658227848101,391.8202531645569,396.2746835443038,400.7291139240506,405.1835443037975,409.63797468354426,414.09240506329115,418.54683544303793,423.00126582278483,427.4556962025316,431.9101265822785,436.3645569620253,440.8189873417722,445.27341772151897,449.72784810126575,454.18227848101264,458.6367088607594,463.0911392405063,467.5455696202531,472.0,71.1,72.32151898734176,73.54303797468354,74.76455696202531,75.98607594936708,77.20759493670886,78.42911392405063,79.65063291139239,80.87215189873417,82.09367088607594,83.31518987341772,84.53670886075949,85.75822784810126,86.97974683544304,88.2012658227848,89.42278481012659,90.64430379746835,91.86582278481012,93.08734177215189,94.30886075949367,95.53037974683544,96.75189873417722,97.97341772151898,99.19493670886075,100.41645569620252,101.6379746835443,102.85949367088607,104.08101265822785,105.30253164556962,106.52405063291138,107.74556962025316,108.96708860759493,110.18860759493671,111.41012658227848,112.63164556962025,113.85316455696201,115.0746835443038,116.29620253164558,117.51772151898734,118.73924050632911,119.96075949367088,121.18227848101264,122.40379746835443,123.62531645569621,124.84683544303797,126.06835443037974,127.28987341772151,128.5113924050633,129.73291139240507,130.95443037974684,132.1759493670886,133.39746835443037,134.61898734177214,135.8405063291139,137.06202531645567,138.28354430379747,139.50506329113924,140.726582278481,141.9481012658228,143.16962025316457,144.39113924050633,145.6126582278481,146.83417721518987,148.05569620253164,149.2772151898734,150.49873417721517,151.72025316455696,152.94177215189873,154.1632911392405,155.3848101265823,156.60632911392406,157.82784810126583,159.0493670886076,160.27088607594936,161.49240506329113,162.7139240506329,163.93544303797466,165.15696202531646,166.37848101265823,167.6,95.1,98.3392405063291,101.57848101265822,104.81772151898734,108.05696202531645,111.29620253164556,114.53544303797467,117.7746835443038,121.01392405063291,124.25316455696202,127.49240506329113,130.73164556962024,133.97088607594935,137.21012658227846,140.44936708860757,143.6886075949367,146.92784810126582,150.16708860759493,153.40632911392404,156.64556962025316,159.88481012658227,163.1240506329114,166.36329113924052,169.60253164556963,172.84177215189874,176.08101265822785,179.32025316455696,182.55949367088607,185.79873417721518,189.0379746835443,192.2772151898734,195.5164556962025,198.75569620253162,201.99493670886073,205.23417721518985,208.47341772151898,211.7126582278481,214.9518987341772,218.19113924050632,221.43037974683546,224.66962025316454,227.90886075949365,231.1481012658228,234.3873417721519,237.626582278481,240.86582278481012,244.10506329113923,247.34430379746834,250.58354430379745,253.82278481012656,257.0620253164557,260.3012658227848,263.5405063291139,266.779746835443,270.0189873417721,273.2582278481012,276.49746835443034,279.73670886075945,282.97594936708856,286.21518987341767,289.45443037974684,292.69367088607595,295.93291139240506,299.17215189873417,302.4113924050633,305.6506329113924,308.8898734177215,312.1291139240506,315.3683544303797,318.6075949367089,321.846835443038,325.0860759493671,328.3253164556962,331.56455696202534,334.80379746835445,338.04303797468356,341.28227848101267,344.5215189873418,347.7607594936709,351.0],\n",
       "\"mpg\":[21.42053462230732,21.30574192174685,21.19094922118638,21.076156520625908,20.96136382006544,20.84657111950497,20.731778418944497,20.61698571838403,20.502193017823558,20.387400317263086,20.27260761670262,20.157814916142147,20.04302221558168,19.928229515021208,19.813436814460736,19.69864411390027,19.583851413339797,19.469058712779326,19.354266012218858,19.239473311658386,19.124680611097915,19.009887910537447,18.895095209976976,18.780302509416508,18.665509808856036,18.550717108295565,18.435924407735094,18.321131707174626,18.206339006614154,18.091546306053687,17.976753605493215,17.861960904932744,17.747168204372272,17.632375503811804,17.517582803251333,17.402790102690865,17.287997402130394,17.173204701569922,17.058412001009454,16.943619300448983,16.828826599888515,16.714033899328044,16.599241198767572,16.4844484982071,16.369655797646637,16.254863097086165,16.140070396525694,16.025277695965222,15.910484995404753,15.795692294844281,15.680899594283813,15.566106893723342,15.451314193162872,15.336521492602403,15.221728792041931,15.106936091481462,14.992143390920992,14.87735069036052,14.762557989800051,14.647765289239583,14.53297258867911,14.418179888118642,14.30338718755817,14.188594486997701,14.07380178643723,13.959009085876762,13.844216385316289,13.72942368475582,13.61463098419535,13.49983828363488,13.385045583074408,13.27025288251394,13.155460181953467,13.040667481393,12.92587478083253,12.811082080272058,12.69628937971159,12.581496679151119,12.46670397859065,12.351911278030178,30.87820825020802,30.72892314234405,30.579638034480084,30.430352926616116,30.28106781875215,30.13178271088818,29.982497603024214,29.833212495160247,29.68392738729628,29.534642279432312,29.385357171568344,29.236072063704377,29.08678695584041,28.937501847976442,28.788216740112475,28.638931632248507,28.48964652438454,28.340361416520572,28.191076308656605,28.041791200792638,27.89250609292867,27.743220985064703,27.593935877200735,27.444650769336768,27.2953656614728,27.146080553608833,26.996795445744866,26.847510337880898,26.69822523001693,26.548940122152963,26.399655014288996,26.25036990642503,26.10108479856106,25.951799690697094,25.802514582833126,25.65322947496916,25.50394436710519,25.354659259241224,25.205374151377256,25.05608904351329,24.90680393564932,24.757518827785354,24.608233719921387,24.45894861205742,24.309663504193452,24.160378396329484,24.011093288465517,23.86180818060155,23.712523072737582,23.563237964873615,23.413952857009647,23.26466774914568,23.115382641281716,22.96609753341775,22.81681242555378,22.66752731768981,22.518242209825843,22.36895710196188,22.219671994097908,22.07038688623394,21.921101778369973,21.771816670506006,21.62253156264204,21.473246454778074,21.323961346914107,21.17467623905014,21.02539113118617,20.8761060233222,20.726820915458234,20.577535807594266,20.4282506997303,20.27896559186633,20.129680484002364,19.980395376138397,19.831110268274433,19.681825160410465,19.532540052546498,19.383254944682527,19.23396983681856,19.084684728954592,26.832232643256866,26.66775981006663,26.503286976876396,26.338814143686157,26.174341310495926,26.009868477305687,25.845395644115452,25.680922810925217,25.516449977734982,25.351977144544747,25.187504311354513,25.023031478164278,24.85855864497404,24.694085811783808,24.52961297859357,24.365140145403334,24.2006673122131,24.036194479022864,23.87172164583263,23.70724881264239,23.54277597945216,23.37830314626192,23.213830313071686,23.04935747988145,22.884884646691216,22.72041181350098,22.555938980310742,22.39146614712051,22.226993313930272,22.06252048074004,21.898047647549802,21.73357481435957,21.569101981169332,21.404629147979097,21.240156314788862,21.075683481598624,20.911210648408392,20.746737815218154,20.582264982027922,20.417792148837684,20.25331931564745,20.088846482457214,19.924373649266975,19.759900816076744,19.595427982886505,19.430955149696274,19.266482316506035,19.1020094833158,18.937536650125566,18.77306381693533,18.608590983745096,18.44411815055486,18.279645317364626,18.115172484174387,17.950699650984156,17.786226817793917,17.621753984603686,17.457281151413447,17.292808318223216,17.128335485032977,16.96386265184274,16.799389818652504,16.63491698546227,16.470444152272034,16.3059713190818,16.141498485891564,15.977025652701329,15.812552819511094,15.648079986320859,15.48360715313062,15.319134319940385,15.15466148675015,14.990188653559915,14.825715820369677,14.661242987179442,14.496770153989207,14.332297320798972,14.167824487608737,14.003351654418502,13.838878821228267],\n",
       "\"gear\":[3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"LyxgY0\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b9d3d0>"
      ]
     },
     "execution_count": 92,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = mtcars,\n",
    "       mapping = aes(x = 'disp',\n",
    "                     y = 'mpg',\n",
    "                     color = 'gear')) +\n",
    "        geom_point() +\n",
    "        geom_smooth(method = \"lm\") +\n",
    "        scale_color_viridis() +\n",
    "        facet_wrap('gear', ncol = 1) #<<\n",
    "\n",
    ")\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 93,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"aUoTmv\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"mpg\":[21.0,21.0,22.8,21.4,18.7,18.1,14.3,24.4,22.8,19.2,17.8,16.4,17.3,15.2,10.4,10.4,14.7,32.4,30.4,33.9,21.5,15.5,15.2,13.3,19.2,27.3,26.0,30.4,15.8,19.7,15.0,21.4],\n",
       "\"disp\":[160.0,160.0,108.0,258.0,360.0,225.0,360.0,146.7,140.8,167.6,167.6,275.8,275.8,275.8,472.0,460.0,440.0,78.7,75.7,71.1,120.1,318.0,304.0,350.0,400.0,79.0,120.3,95.1,351.0,145.0,301.0,121.0],\n",
       "\"hp\":[110.0,110.0,93.0,110.0,175.0,105.0,245.0,62.0,95.0,123.0,123.0,180.0,180.0,180.0,205.0,215.0,230.0,66.0,52.0,65.0,97.0,150.0,150.0,245.0,175.0,66.0,91.0,113.0,264.0,175.0,335.0,109.0],\n",
       "\"gear\":[4.0,4.0,4.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,4.0,5.0,5.0,5.0,5.0,5.0,4.0]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"disp\",\n",
       "\"y\":\"mpg\",\n",
       "\"color\":\"hp\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"facet\":{\n",
       "\"name\":\"wrap\",\n",
       "\"facets\":\"gear\",\n",
       "\"ncol\":1.0,\n",
       "\"order\":1.0,\n",
       "\"dir\":\"h\"\n",
       "},\n",
       "\"ggtitle\":{\n",
       "\"text\":\"Heavier cars get lower mileage\",\n",
       "\"subtitle\":\"Displacement indicates weight(?)\"\n",
       "},\n",
       "\"caption\":{\n",
       "\"text\":\"I know nothing about cars\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"color\",\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "},{\n",
       "\"name\":\"Displacement\",\n",
       "\"aesthetic\":\"x\"\n",
       "},{\n",
       "\"name\":\"Highway MPG\",\n",
       "\"aesthetic\":\"y\"\n",
       "},{\n",
       "\"name\":\"Horsepower\",\n",
       "\"aesthetic\":\"color\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"smooth\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[]\n",
       "},\n",
       "\"method\":\"lm\",\n",
       "\"data\":{\n",
       "\"..ymin..\":[18.110471212875474,18.055282738072687,17.999869530255523,17.944218807024544,17.888316855121165,17.832148950250065,17.775699269275947,17.718950794063353,17.661885206172315,17.604482771567685,17.54672221444906,17.488580579264564,17.430033079940074,17.371052935341318,17.311611189999045,17.251676519176048,17.191215017454446,17.130189970188678,17.068561607426457,17.006286840273894,16.94331898020551,16.87960744253519,16.81509743621812,16.74972964340082,16.683439893735972,16.61615884049476,16.5478116479995,16.478317702912722,16.407590365475343,16.33553678086279,16.262057775326504,16.187047866506997,16.110395421896484,16.031983003365113,15.951687938202596,15.86938315730634,15.784938337825697,15.698221379531658,15.609100230319289,15.51744505587064,15.423130721683112,15.326039523627545,15.226064068599621,15.12311017379106,15.017099626872586,14.907972635488948,14.795689797568807,14.680233446496343,14.56160826639115,14.439841128238198,14.314980160068446,14.187093124968696,14.056265230964748,13.922596530550756,13.7861990819478,13.64719403972004,13.505708822678628,13.361874477245124,13.215823320168953,13.067686910542323,12.91759437095986,12.765671053466136,12.61203752832302,12.456808862316446,12.300094147400305,12.141996238764571,11.982611662709724,11.822030657936521,11.660337318147631,11.497609808555906,11.333920633553431,11.16933693713552,11.003920821539468,10.837729672887376,10.67081648541222,10.503230178131917,10.335015899670093,10.1662153183672,9.996866895943162,9.827006143820459,28.231355556087774,28.12301331860439,28.014326518156963,27.905278534974745,27.79585182570608,27.68602787401537,27.57578713990086,27.465109008030943,27.353971735480908,27.242352399350672,27.130226844857958,27.017569634632245,26.90435400008326,26.790551795884706,26.676133458798876,26.56106797227031,26.445322838434233,26.32886405941498,26.21165613002499,26.093662044209044,25.97484331780003,25.855160030348745,25.734570888943274,25.61303331702357,25.49050357119976,25.366936888972067,25.242287669998234,25.116509693132457,24.989556370843356,24.86138104178706,24.731937301255048,24.601179367938094,24.46906248396841,24.33554334356408,24.20058054386865,24.064135049843895,23.926170663445113,23.786654485911704,23.645557360971104,23.502854286205935,23.35852477987405,23.212553191166005,23.064928943253168,22.915646700484338,22.764706453635345,22.612113520056965,22.457878458715623,22.302016903270925,22.144549319276038,21.98550069413499,21.82490017045797,21.662780634826344,21.499178274676602,21.33413211605425,21.167683554442345,20.999875889836247,20.830753875840497,20.660363290935646,20.488750538328315,20.31596227906617,20.142045101461136,19.967045228384336,19.791008262717128,19.61397897018539,19.436001097972074,19.25711722688577,19.07736865444053,18.896795305949738,18.715435670625542,18.533326759678246,18.350504083499473,18.16700164516614,17.98285194769814,17.798086012724333,17.612733408445347,17.426822285017295,17.24037941570979,17.053430242409465,16.86599892424262,16.678108388275668,19.352986248253586,19.304830378368145,19.254893412348622,19.20308958429367,19.14932906994715,19.093517904690323,19.035557923737144,18.975346729515714,18.912777691774025,18.847739986485394,18.780118680123557,18.709794866295262,18.636645862019307,18.56054547107835,18.481364321788806,18.3989702861776,18.313228986859684,18.22400439681973,18.131159535760624,18.03455726465198,17.93406117757437,17.82953658691941,17.7208515945196,17.607878237435685,17.4904936930632,17.368581524122117,17.242032940197127,17.110748049066757,16.97463706837889,16.833621466572108,16.687635001543367,16.53662462659802,16.380551235768504,16.21939022462776,16.053131848103778,15.881781363262622,15.705358952207819,15.523899427719726,15.337451731574328,15.146078242198435,14.94985391405508,14.748865275614381,14.543209315770408,14.33299229004923,14.118328477969847,13.899338921616083,13.67615017307524,13.448893075164928,13.217701596083595,12.98271173455695,12.744060507954764,12.501885031923688,12.256321696476043,12.007505440297061,11.755569122343967,11.500642987629234,11.242854222397083,10.98232659268141,10.719180159426603,10.45353106290072,10.185491368973778,9.915168969911345,9.642667532591188,9.368086487438262,9.091521051848423,8.813062282399164,8.532797150697505,8.250808638269064,7.967175846431927,7.681974117612232,7.395275165037749,7.107147208186213,6.817655111765168,6.526860526358124,6.234822029190186,5.941595263745805,5.64723307721531,5.351785654957569,5.055300651347226,4.7578233165289365],\n",
       "\"..ymax..\":[24.730598031739163,24.556201105421014,24.382028912117235,24.20809423422727,24.034410785009715,23.86099328875987,23.687857568613047,23.515020642704705,23.3425008294748,23.170317862958488,22.99849301895618,22.82704925301973,22.656011351223285,22.485406094701098,22.315262438922428,22.14561170862449,21.976487809225148,21.807927455369974,21.63997041701126,21.47265978304288,21.30604224199032,21.140168378539705,20.97509298373583,20.810875375432197,20.6475797239761,20.48527537609637,20.32403716747069,20.16394571143653,20.005087647752966,19.847555831244584,19.691449435659926,19.53687394335849,19.38394098684806,19.232768004258496,19.08347766830007,18.936197048075393,18.79105646643509,18.648188023608185,18.50772377169962,18.369793545027328,18.23452247809392,18.102028275028545,17.972418328935525,17.84578682262314,17.722211968420687,17.601753558683384,17.484450995482582,17.370321945434103,17.259361724418355,17.151543461450366,17.04681902849918,16.94512066247799,16.846363155360997,16.75044645465405,16.657258502136063,16.566678143242886,16.478577959163356,16.392826903475918,16.309292659431147,16.227843667936845,16.14835080639836,16.07068872277115,15.994736846793321,15.920380111678956,15.847509425474154,15.776021932988952,15.705821107922853,15.63681671157512,15.568924650243067,15.502066758713854,15.436170532595385,15.37116882789236,15.306999542367466,15.243605289898623,15.18093307625284,15.1189339824122,15.057562859753087,14.996778039935037,14.936541061238136,14.876816412239897,33.52506094432826,33.33483296608371,33.144949550803204,32.95542731825749,32.76628381179822,32.57753754776099,32.38920806614757,32.20131598228955,32.013883039111654,31.82693215951395,31.64048749827873,31.45457449277651,31.26921991159756,31.084451900068178,30.900300021426073,30.716795292226706,30.533970210334846,30.351858773626166,30.17049648728822,29.98992035737623,29.81016886805731,29.63128193978066,29.453300865458196,29.276268221649964,29.10022775174584,28.9252242182456,28.751303221491497,28.57851098262934,28.406894089190505,28.236499202518868,28.067372727322944,27.899560444911963,27.73310711315371,27.568056037830107,27.404448621797602,27.242323900094423,27.08171807076527,26.922664032570744,26.76519094178341,26.609323800820643,26.455083091424594,26.302484464404703,26.151538496589605,26.0022505236305,25.85462055475156,25.708643272602004,25.56430811821541,25.421599457932174,25.280496826199126,25.14097523561224,25.003005543561326,24.866554863465016,24.73158700788683,24.598062950781248,24.465941296665218,24.335178745543374,24.20573054381119,24.077550912988112,23.9505934498675,23.82481149340171,23.70015845527881,23.576588112627675,23.45405486256695,23.33251393937076,23.21192159585614,23.092235251214507,22.973413607931807,22.855416740694665,22.738206160290925,22.621744855510286,22.505997315961125,22.390929538566525,22.276509020306587,22.16270473955246,22.049487128103518,21.936828035803636,21.824700689383207,21.71307964695559,21.601940749394497,21.491261069633516,34.311479038260146,34.03068924176512,33.75168054140417,33.47453870307864,33.1993535510447,32.92621904992105,32.65523336449376,32.38649889233472,32.12012226369594,31.8562143026041,31.594889942585468,31.336268090033293,31.08047142792877,30.827626152489266,30.57786163539833,30.331310004629067,30.088105637566514,29.848384561226,29.612283755904635,29.3799403606328,29.151490781329947,28.92706970560443,28.70680903162377,28.490836722327217,28.27927560031923,28.072242102879844,27.869845020424357,27.672184245174265,27.479349559481655,27.291419494907974,27.108460293556238,26.930525002121122,26.75765272657016,26.589868071330436,26.427180781473947,26.269585599934626,26.117062344608968,25.96957620271658,25.82707823248152,25.689506055476933,25.556784717239818,25.428827689300046,25.305537982763543,25.186809342104258,25.072527487803164,24.962571377776463,24.85681445993683,24.755125891466673,24.657371704167538,24.56341589931371,24.473121459535427,24.386351269186033,24.30296893825321,24.222839528051715,24.145830179624344,24.0718106479586,24.000653746810286,23.932235710145484,23.86643647701983,23.803139907165235,23.7422339347117,23.683610667393662,23.627166438333347,23.572801817105805,23.520421586315173,23.46993468938396,23.421254154705153,23.374297000753124,23.32898412620979,23.28524018864901,23.242993474843022,23.202175765314088,23.16272219535466,23.12457111438123,23.0876639451687,23.05194504423261,23.017361564382632,22.983863320259907,22.95140265748978,22.9199343259276],\n",
       "\"disp\":[120.1,124.55443037974683,129.00886075949367,133.4632911392405,137.91772151898732,142.37215189873416,146.826582278481,151.28101265822784,155.73544303797468,160.18987341772151,164.64430379746835,169.0987341772152,173.55316455696203,178.00759493670887,182.46202531645568,186.91645569620252,191.37088607594936,195.8253164556962,200.27974683544304,204.73417721518985,209.18860759493668,213.64303797468352,218.09746835443036,222.5518987341772,227.00632911392404,231.46075949367088,235.91518987341772,240.36962025316456,244.8240506329114,249.2784810126582,253.73291139240504,258.18734177215185,262.64177215189875,267.09620253164553,271.5506329113924,276.0050632911392,280.4594936708861,284.9139240506329,289.3683544303797,293.82278481012656,298.2772151898734,302.73164556962024,307.1860759493671,311.6405063291139,316.0949367088607,320.5493670886076,325.0037974683544,329.4582278481013,333.91265822784806,338.36708860759495,342.82151898734173,347.27594936708863,351.7303797468354,356.18481012658225,360.6392405063291,365.0936708860759,369.54810126582277,374.0025316455696,378.45696202531644,382.9113924050632,387.3658227848101,391.8202531645569,396.2746835443038,400.7291139240506,405.1835443037975,409.63797468354426,414.09240506329115,418.54683544303793,423.00126582278483,427.4556962025316,431.9101265822785,436.3645569620253,440.8189873417722,445.27341772151897,449.72784810126575,454.18227848101264,458.6367088607594,463.0911392405063,467.5455696202531,472.0,71.1,72.32151898734176,73.54303797468354,74.76455696202531,75.98607594936708,77.20759493670886,78.42911392405063,79.65063291139239,80.87215189873417,82.09367088607594,83.31518987341772,84.53670886075949,85.75822784810126,86.97974683544304,88.2012658227848,89.42278481012659,90.64430379746835,91.86582278481012,93.08734177215189,94.30886075949367,95.53037974683544,96.75189873417722,97.97341772151898,99.19493670886075,100.41645569620252,101.6379746835443,102.85949367088607,104.08101265822785,105.30253164556962,106.52405063291138,107.74556962025316,108.96708860759493,110.18860759493671,111.41012658227848,112.63164556962025,113.85316455696201,115.0746835443038,116.29620253164558,117.51772151898734,118.73924050632911,119.96075949367088,121.18227848101264,122.40379746835443,123.62531645569621,124.84683544303797,126.06835443037974,127.28987341772151,128.5113924050633,129.73291139240507,130.95443037974684,132.1759493670886,133.39746835443037,134.61898734177214,135.8405063291139,137.06202531645567,138.28354430379747,139.50506329113924,140.726582278481,141.9481012658228,143.16962025316457,144.39113924050633,145.6126582278481,146.83417721518987,148.05569620253164,149.2772151898734,150.49873417721517,151.72025316455696,152.94177215189873,154.1632911392405,155.3848101265823,156.60632911392406,157.82784810126583,159.0493670886076,160.27088607594936,161.49240506329113,162.7139240506329,163.93544303797466,165.15696202531646,166.37848101265823,167.6,95.1,98.3392405063291,101.57848101265822,104.81772151898734,108.05696202531645,111.29620253164556,114.53544303797467,117.7746835443038,121.01392405063291,124.25316455696202,127.49240506329113,130.73164556962024,133.97088607594935,137.21012658227846,140.44936708860757,143.6886075949367,146.92784810126582,150.16708860759493,153.40632911392404,156.64556962025316,159.88481012658227,163.1240506329114,166.36329113924052,169.60253164556963,172.84177215189874,176.08101265822785,179.32025316455696,182.55949367088607,185.79873417721518,189.0379746835443,192.2772151898734,195.5164556962025,198.75569620253162,201.99493670886073,205.23417721518985,208.47341772151898,211.7126582278481,214.9518987341772,218.19113924050632,221.43037974683546,224.66962025316454,227.90886075949365,231.1481012658228,234.3873417721519,237.626582278481,240.86582278481012,244.10506329113923,247.34430379746834,250.58354430379745,253.82278481012656,257.0620253164557,260.3012658227848,263.5405063291139,266.779746835443,270.0189873417721,273.2582278481012,276.49746835443034,279.73670886075945,282.97594936708856,286.21518987341767,289.45443037974684,292.69367088607595,295.93291139240506,299.17215189873417,302.4113924050633,305.6506329113924,308.8898734177215,312.1291139240506,315.3683544303797,318.6075949367089,321.846835443038,325.0860759493671,328.3253164556962,331.56455696202534,334.80379746835445,338.04303797468356,341.28227848101267,344.5215189873418,347.7607594936709,351.0],\n",
       "\"mpg\":[21.42053462230732,21.30574192174685,21.19094922118638,21.076156520625908,20.96136382006544,20.84657111950497,20.731778418944497,20.61698571838403,20.502193017823558,20.387400317263086,20.27260761670262,20.157814916142147,20.04302221558168,19.928229515021208,19.813436814460736,19.69864411390027,19.583851413339797,19.469058712779326,19.354266012218858,19.239473311658386,19.124680611097915,19.009887910537447,18.895095209976976,18.780302509416508,18.665509808856036,18.550717108295565,18.435924407735094,18.321131707174626,18.206339006614154,18.091546306053687,17.976753605493215,17.861960904932744,17.747168204372272,17.632375503811804,17.517582803251333,17.402790102690865,17.287997402130394,17.173204701569922,17.058412001009454,16.943619300448983,16.828826599888515,16.714033899328044,16.599241198767572,16.4844484982071,16.369655797646637,16.254863097086165,16.140070396525694,16.025277695965222,15.910484995404753,15.795692294844281,15.680899594283813,15.566106893723342,15.451314193162872,15.336521492602403,15.221728792041931,15.106936091481462,14.992143390920992,14.87735069036052,14.762557989800051,14.647765289239583,14.53297258867911,14.418179888118642,14.30338718755817,14.188594486997701,14.07380178643723,13.959009085876762,13.844216385316289,13.72942368475582,13.61463098419535,13.49983828363488,13.385045583074408,13.27025288251394,13.155460181953467,13.040667481393,12.92587478083253,12.811082080272058,12.69628937971159,12.581496679151119,12.46670397859065,12.351911278030178,30.87820825020802,30.72892314234405,30.579638034480084,30.430352926616116,30.28106781875215,30.13178271088818,29.982497603024214,29.833212495160247,29.68392738729628,29.534642279432312,29.385357171568344,29.236072063704377,29.08678695584041,28.937501847976442,28.788216740112475,28.638931632248507,28.48964652438454,28.340361416520572,28.191076308656605,28.041791200792638,27.89250609292867,27.743220985064703,27.593935877200735,27.444650769336768,27.2953656614728,27.146080553608833,26.996795445744866,26.847510337880898,26.69822523001693,26.548940122152963,26.399655014288996,26.25036990642503,26.10108479856106,25.951799690697094,25.802514582833126,25.65322947496916,25.50394436710519,25.354659259241224,25.205374151377256,25.05608904351329,24.90680393564932,24.757518827785354,24.608233719921387,24.45894861205742,24.309663504193452,24.160378396329484,24.011093288465517,23.86180818060155,23.712523072737582,23.563237964873615,23.413952857009647,23.26466774914568,23.115382641281716,22.96609753341775,22.81681242555378,22.66752731768981,22.518242209825843,22.36895710196188,22.219671994097908,22.07038688623394,21.921101778369973,21.771816670506006,21.62253156264204,21.473246454778074,21.323961346914107,21.17467623905014,21.02539113118617,20.8761060233222,20.726820915458234,20.577535807594266,20.4282506997303,20.27896559186633,20.129680484002364,19.980395376138397,19.831110268274433,19.681825160410465,19.532540052546498,19.383254944682527,19.23396983681856,19.084684728954592,26.832232643256866,26.66775981006663,26.503286976876396,26.338814143686157,26.174341310495926,26.009868477305687,25.845395644115452,25.680922810925217,25.516449977734982,25.351977144544747,25.187504311354513,25.023031478164278,24.85855864497404,24.694085811783808,24.52961297859357,24.365140145403334,24.2006673122131,24.036194479022864,23.87172164583263,23.70724881264239,23.54277597945216,23.37830314626192,23.213830313071686,23.04935747988145,22.884884646691216,22.72041181350098,22.555938980310742,22.39146614712051,22.226993313930272,22.06252048074004,21.898047647549802,21.73357481435957,21.569101981169332,21.404629147979097,21.240156314788862,21.075683481598624,20.911210648408392,20.746737815218154,20.582264982027922,20.417792148837684,20.25331931564745,20.088846482457214,19.924373649266975,19.759900816076744,19.595427982886505,19.430955149696274,19.266482316506035,19.1020094833158,18.937536650125566,18.77306381693533,18.608590983745096,18.44411815055486,18.279645317364626,18.115172484174387,17.950699650984156,17.786226817793917,17.621753984603686,17.457281151413447,17.292808318223216,17.128335485032977,16.96386265184274,16.799389818652504,16.63491698546227,16.470444152272034,16.3059713190818,16.141498485891564,15.977025652701329,15.812552819511094,15.648079986320859,15.48360715313062,15.319134319940385,15.15466148675015,14.990188653559915,14.825715820369677,14.661242987179442,14.496770153989207,14.332297320798972,14.167824487608737,14.003351654418502,13.838878821228267],\n",
       "\"hp\":[176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6],\n",
       "\"gear\":[3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"aUoTmv\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x14443e450>"
      ]
     },
     "execution_count": 93,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "     ggplot(data = mtcars,\n",
    "          mapping = aes(x = 'disp',\n",
    "                         y = 'mpg',\n",
    "                         color = 'hp')) +\n",
    "          geom_point() +\n",
    "          geom_smooth(method = \"lm\") +\n",
    "          scale_color_viridis() +\n",
    "          facet_wrap('gear', ncol = 1) +\n",
    "          labs(x = \"Displacement\", y = \"Highway MPG\",  #<<\n",
    "               color = \"Horsepower\",   #<<\n",
    "               title = \"Heavier cars get lower mileage\",  #<<\n",
    "               subtitle = \"Displacement indicates weight(?)\",  #<<\n",
    "               caption = \"I know nothing about cars\")\n",
    ")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 94,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"HrrX9k\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"mpg\":[21.0,21.0,22.8,21.4,18.7,18.1,14.3,24.4,22.8,19.2,17.8,16.4,17.3,15.2,10.4,10.4,14.7,32.4,30.4,33.9,21.5,15.5,15.2,13.3,19.2,27.3,26.0,30.4,15.8,19.7,15.0,21.4],\n",
       "\"disp\":[160.0,160.0,108.0,258.0,360.0,225.0,360.0,146.7,140.8,167.6,167.6,275.8,275.8,275.8,472.0,460.0,440.0,78.7,75.7,71.1,120.1,318.0,304.0,350.0,400.0,79.0,120.3,95.1,351.0,145.0,301.0,121.0],\n",
       "\"hp\":[110.0,110.0,93.0,110.0,175.0,105.0,245.0,62.0,95.0,123.0,123.0,180.0,180.0,180.0,205.0,215.0,230.0,66.0,52.0,65.0,97.0,150.0,150.0,245.0,175.0,66.0,91.0,113.0,264.0,175.0,335.0,109.0],\n",
       "\"gear\":[4.0,4.0,4.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,4.0,5.0,5.0,5.0,5.0,5.0,4.0]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"disp\",\n",
       "\"y\":\"mpg\",\n",
       "\"color\":\"hp\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"facet\":{\n",
       "\"name\":\"wrap\",\n",
       "\"facets\":\"gear\",\n",
       "\"ncol\":1.0,\n",
       "\"order\":1.0,\n",
       "\"format\":\"{} gears\",\n",
       "\"dir\":\"h\"\n",
       "},\n",
       "\"ggtitle\":{\n",
       "\"text\":\"Heavier cars get lower mileage\",\n",
       "\"subtitle\":\"Displacement indicates weight(?)\"\n",
       "},\n",
       "\"caption\":{\n",
       "\"text\":\"I know nothing about cars\"\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"bw\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"color\",\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "},{\n",
       "\"name\":\"Displacement\",\n",
       "\"aesthetic\":\"x\"\n",
       "},{\n",
       "\"name\":\"Highway MPG\",\n",
       "\"aesthetic\":\"y\"\n",
       "},{\n",
       "\"name\":\"Horsepower\",\n",
       "\"aesthetic\":\"color\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"smooth\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[]\n",
       "},\n",
       "\"method\":\"lm\",\n",
       "\"data\":{\n",
       "\"..ymin..\":[18.110471212875474,18.055282738072687,17.999869530255523,17.944218807024544,17.888316855121165,17.832148950250065,17.775699269275947,17.718950794063353,17.661885206172315,17.604482771567685,17.54672221444906,17.488580579264564,17.430033079940074,17.371052935341318,17.311611189999045,17.251676519176048,17.191215017454446,17.130189970188678,17.068561607426457,17.006286840273894,16.94331898020551,16.87960744253519,16.81509743621812,16.74972964340082,16.683439893735972,16.61615884049476,16.5478116479995,16.478317702912722,16.407590365475343,16.33553678086279,16.262057775326504,16.187047866506997,16.110395421896484,16.031983003365113,15.951687938202596,15.86938315730634,15.784938337825697,15.698221379531658,15.609100230319289,15.51744505587064,15.423130721683112,15.326039523627545,15.226064068599621,15.12311017379106,15.017099626872586,14.907972635488948,14.795689797568807,14.680233446496343,14.56160826639115,14.439841128238198,14.314980160068446,14.187093124968696,14.056265230964748,13.922596530550756,13.7861990819478,13.64719403972004,13.505708822678628,13.361874477245124,13.215823320168953,13.067686910542323,12.91759437095986,12.765671053466136,12.61203752832302,12.456808862316446,12.300094147400305,12.141996238764571,11.982611662709724,11.822030657936521,11.660337318147631,11.497609808555906,11.333920633553431,11.16933693713552,11.003920821539468,10.837729672887376,10.67081648541222,10.503230178131917,10.335015899670093,10.1662153183672,9.996866895943162,9.827006143820459,28.231355556087774,28.12301331860439,28.014326518156963,27.905278534974745,27.79585182570608,27.68602787401537,27.57578713990086,27.465109008030943,27.353971735480908,27.242352399350672,27.130226844857958,27.017569634632245,26.90435400008326,26.790551795884706,26.676133458798876,26.56106797227031,26.445322838434233,26.32886405941498,26.21165613002499,26.093662044209044,25.97484331780003,25.855160030348745,25.734570888943274,25.61303331702357,25.49050357119976,25.366936888972067,25.242287669998234,25.116509693132457,24.989556370843356,24.86138104178706,24.731937301255048,24.601179367938094,24.46906248396841,24.33554334356408,24.20058054386865,24.064135049843895,23.926170663445113,23.786654485911704,23.645557360971104,23.502854286205935,23.35852477987405,23.212553191166005,23.064928943253168,22.915646700484338,22.764706453635345,22.612113520056965,22.457878458715623,22.302016903270925,22.144549319276038,21.98550069413499,21.82490017045797,21.662780634826344,21.499178274676602,21.33413211605425,21.167683554442345,20.999875889836247,20.830753875840497,20.660363290935646,20.488750538328315,20.31596227906617,20.142045101461136,19.967045228384336,19.791008262717128,19.61397897018539,19.436001097972074,19.25711722688577,19.07736865444053,18.896795305949738,18.715435670625542,18.533326759678246,18.350504083499473,18.16700164516614,17.98285194769814,17.798086012724333,17.612733408445347,17.426822285017295,17.24037941570979,17.053430242409465,16.86599892424262,16.678108388275668,19.352986248253586,19.304830378368145,19.254893412348622,19.20308958429367,19.14932906994715,19.093517904690323,19.035557923737144,18.975346729515714,18.912777691774025,18.847739986485394,18.780118680123557,18.709794866295262,18.636645862019307,18.56054547107835,18.481364321788806,18.3989702861776,18.313228986859684,18.22400439681973,18.131159535760624,18.03455726465198,17.93406117757437,17.82953658691941,17.7208515945196,17.607878237435685,17.4904936930632,17.368581524122117,17.242032940197127,17.110748049066757,16.97463706837889,16.833621466572108,16.687635001543367,16.53662462659802,16.380551235768504,16.21939022462776,16.053131848103778,15.881781363262622,15.705358952207819,15.523899427719726,15.337451731574328,15.146078242198435,14.94985391405508,14.748865275614381,14.543209315770408,14.33299229004923,14.118328477969847,13.899338921616083,13.67615017307524,13.448893075164928,13.217701596083595,12.98271173455695,12.744060507954764,12.501885031923688,12.256321696476043,12.007505440297061,11.755569122343967,11.500642987629234,11.242854222397083,10.98232659268141,10.719180159426603,10.45353106290072,10.185491368973778,9.915168969911345,9.642667532591188,9.368086487438262,9.091521051848423,8.813062282399164,8.532797150697505,8.250808638269064,7.967175846431927,7.681974117612232,7.395275165037749,7.107147208186213,6.817655111765168,6.526860526358124,6.234822029190186,5.941595263745805,5.64723307721531,5.351785654957569,5.055300651347226,4.7578233165289365],\n",
       "\"..ymax..\":[24.730598031739163,24.556201105421014,24.382028912117235,24.20809423422727,24.034410785009715,23.86099328875987,23.687857568613047,23.515020642704705,23.3425008294748,23.170317862958488,22.99849301895618,22.82704925301973,22.656011351223285,22.485406094701098,22.315262438922428,22.14561170862449,21.976487809225148,21.807927455369974,21.63997041701126,21.47265978304288,21.30604224199032,21.140168378539705,20.97509298373583,20.810875375432197,20.6475797239761,20.48527537609637,20.32403716747069,20.16394571143653,20.005087647752966,19.847555831244584,19.691449435659926,19.53687394335849,19.38394098684806,19.232768004258496,19.08347766830007,18.936197048075393,18.79105646643509,18.648188023608185,18.50772377169962,18.369793545027328,18.23452247809392,18.102028275028545,17.972418328935525,17.84578682262314,17.722211968420687,17.601753558683384,17.484450995482582,17.370321945434103,17.259361724418355,17.151543461450366,17.04681902849918,16.94512066247799,16.846363155360997,16.75044645465405,16.657258502136063,16.566678143242886,16.478577959163356,16.392826903475918,16.309292659431147,16.227843667936845,16.14835080639836,16.07068872277115,15.994736846793321,15.920380111678956,15.847509425474154,15.776021932988952,15.705821107922853,15.63681671157512,15.568924650243067,15.502066758713854,15.436170532595385,15.37116882789236,15.306999542367466,15.243605289898623,15.18093307625284,15.1189339824122,15.057562859753087,14.996778039935037,14.936541061238136,14.876816412239897,33.52506094432826,33.33483296608371,33.144949550803204,32.95542731825749,32.76628381179822,32.57753754776099,32.38920806614757,32.20131598228955,32.013883039111654,31.82693215951395,31.64048749827873,31.45457449277651,31.26921991159756,31.084451900068178,30.900300021426073,30.716795292226706,30.533970210334846,30.351858773626166,30.17049648728822,29.98992035737623,29.81016886805731,29.63128193978066,29.453300865458196,29.276268221649964,29.10022775174584,28.9252242182456,28.751303221491497,28.57851098262934,28.406894089190505,28.236499202518868,28.067372727322944,27.899560444911963,27.73310711315371,27.568056037830107,27.404448621797602,27.242323900094423,27.08171807076527,26.922664032570744,26.76519094178341,26.609323800820643,26.455083091424594,26.302484464404703,26.151538496589605,26.0022505236305,25.85462055475156,25.708643272602004,25.56430811821541,25.421599457932174,25.280496826199126,25.14097523561224,25.003005543561326,24.866554863465016,24.73158700788683,24.598062950781248,24.465941296665218,24.335178745543374,24.20573054381119,24.077550912988112,23.9505934498675,23.82481149340171,23.70015845527881,23.576588112627675,23.45405486256695,23.33251393937076,23.21192159585614,23.092235251214507,22.973413607931807,22.855416740694665,22.738206160290925,22.621744855510286,22.505997315961125,22.390929538566525,22.276509020306587,22.16270473955246,22.049487128103518,21.936828035803636,21.824700689383207,21.71307964695559,21.601940749394497,21.491261069633516,34.311479038260146,34.03068924176512,33.75168054140417,33.47453870307864,33.1993535510447,32.92621904992105,32.65523336449376,32.38649889233472,32.12012226369594,31.8562143026041,31.594889942585468,31.336268090033293,31.08047142792877,30.827626152489266,30.57786163539833,30.331310004629067,30.088105637566514,29.848384561226,29.612283755904635,29.3799403606328,29.151490781329947,28.92706970560443,28.70680903162377,28.490836722327217,28.27927560031923,28.072242102879844,27.869845020424357,27.672184245174265,27.479349559481655,27.291419494907974,27.108460293556238,26.930525002121122,26.75765272657016,26.589868071330436,26.427180781473947,26.269585599934626,26.117062344608968,25.96957620271658,25.82707823248152,25.689506055476933,25.556784717239818,25.428827689300046,25.305537982763543,25.186809342104258,25.072527487803164,24.962571377776463,24.85681445993683,24.755125891466673,24.657371704167538,24.56341589931371,24.473121459535427,24.386351269186033,24.30296893825321,24.222839528051715,24.145830179624344,24.0718106479586,24.000653746810286,23.932235710145484,23.86643647701983,23.803139907165235,23.7422339347117,23.683610667393662,23.627166438333347,23.572801817105805,23.520421586315173,23.46993468938396,23.421254154705153,23.374297000753124,23.32898412620979,23.28524018864901,23.242993474843022,23.202175765314088,23.16272219535466,23.12457111438123,23.0876639451687,23.05194504423261,23.017361564382632,22.983863320259907,22.95140265748978,22.9199343259276],\n",
       "\"disp\":[120.1,124.55443037974683,129.00886075949367,133.4632911392405,137.91772151898732,142.37215189873416,146.826582278481,151.28101265822784,155.73544303797468,160.18987341772151,164.64430379746835,169.0987341772152,173.55316455696203,178.00759493670887,182.46202531645568,186.91645569620252,191.37088607594936,195.8253164556962,200.27974683544304,204.73417721518985,209.18860759493668,213.64303797468352,218.09746835443036,222.5518987341772,227.00632911392404,231.46075949367088,235.91518987341772,240.36962025316456,244.8240506329114,249.2784810126582,253.73291139240504,258.18734177215185,262.64177215189875,267.09620253164553,271.5506329113924,276.0050632911392,280.4594936708861,284.9139240506329,289.3683544303797,293.82278481012656,298.2772151898734,302.73164556962024,307.1860759493671,311.6405063291139,316.0949367088607,320.5493670886076,325.0037974683544,329.4582278481013,333.91265822784806,338.36708860759495,342.82151898734173,347.27594936708863,351.7303797468354,356.18481012658225,360.6392405063291,365.0936708860759,369.54810126582277,374.0025316455696,378.45696202531644,382.9113924050632,387.3658227848101,391.8202531645569,396.2746835443038,400.7291139240506,405.1835443037975,409.63797468354426,414.09240506329115,418.54683544303793,423.00126582278483,427.4556962025316,431.9101265822785,436.3645569620253,440.8189873417722,445.27341772151897,449.72784810126575,454.18227848101264,458.6367088607594,463.0911392405063,467.5455696202531,472.0,71.1,72.32151898734176,73.54303797468354,74.76455696202531,75.98607594936708,77.20759493670886,78.42911392405063,79.65063291139239,80.87215189873417,82.09367088607594,83.31518987341772,84.53670886075949,85.75822784810126,86.97974683544304,88.2012658227848,89.42278481012659,90.64430379746835,91.86582278481012,93.08734177215189,94.30886075949367,95.53037974683544,96.75189873417722,97.97341772151898,99.19493670886075,100.41645569620252,101.6379746835443,102.85949367088607,104.08101265822785,105.30253164556962,106.52405063291138,107.74556962025316,108.96708860759493,110.18860759493671,111.41012658227848,112.63164556962025,113.85316455696201,115.0746835443038,116.29620253164558,117.51772151898734,118.73924050632911,119.96075949367088,121.18227848101264,122.40379746835443,123.62531645569621,124.84683544303797,126.06835443037974,127.28987341772151,128.5113924050633,129.73291139240507,130.95443037974684,132.1759493670886,133.39746835443037,134.61898734177214,135.8405063291139,137.06202531645567,138.28354430379747,139.50506329113924,140.726582278481,141.9481012658228,143.16962025316457,144.39113924050633,145.6126582278481,146.83417721518987,148.05569620253164,149.2772151898734,150.49873417721517,151.72025316455696,152.94177215189873,154.1632911392405,155.3848101265823,156.60632911392406,157.82784810126583,159.0493670886076,160.27088607594936,161.49240506329113,162.7139240506329,163.93544303797466,165.15696202531646,166.37848101265823,167.6,95.1,98.3392405063291,101.57848101265822,104.81772151898734,108.05696202531645,111.29620253164556,114.53544303797467,117.7746835443038,121.01392405063291,124.25316455696202,127.49240506329113,130.73164556962024,133.97088607594935,137.21012658227846,140.44936708860757,143.6886075949367,146.92784810126582,150.16708860759493,153.40632911392404,156.64556962025316,159.88481012658227,163.1240506329114,166.36329113924052,169.60253164556963,172.84177215189874,176.08101265822785,179.32025316455696,182.55949367088607,185.79873417721518,189.0379746835443,192.2772151898734,195.5164556962025,198.75569620253162,201.99493670886073,205.23417721518985,208.47341772151898,211.7126582278481,214.9518987341772,218.19113924050632,221.43037974683546,224.66962025316454,227.90886075949365,231.1481012658228,234.3873417721519,237.626582278481,240.86582278481012,244.10506329113923,247.34430379746834,250.58354430379745,253.82278481012656,257.0620253164557,260.3012658227848,263.5405063291139,266.779746835443,270.0189873417721,273.2582278481012,276.49746835443034,279.73670886075945,282.97594936708856,286.21518987341767,289.45443037974684,292.69367088607595,295.93291139240506,299.17215189873417,302.4113924050633,305.6506329113924,308.8898734177215,312.1291139240506,315.3683544303797,318.6075949367089,321.846835443038,325.0860759493671,328.3253164556962,331.56455696202534,334.80379746835445,338.04303797468356,341.28227848101267,344.5215189873418,347.7607594936709,351.0],\n",
       "\"mpg\":[21.42053462230732,21.30574192174685,21.19094922118638,21.076156520625908,20.96136382006544,20.84657111950497,20.731778418944497,20.61698571838403,20.502193017823558,20.387400317263086,20.27260761670262,20.157814916142147,20.04302221558168,19.928229515021208,19.813436814460736,19.69864411390027,19.583851413339797,19.469058712779326,19.354266012218858,19.239473311658386,19.124680611097915,19.009887910537447,18.895095209976976,18.780302509416508,18.665509808856036,18.550717108295565,18.435924407735094,18.321131707174626,18.206339006614154,18.091546306053687,17.976753605493215,17.861960904932744,17.747168204372272,17.632375503811804,17.517582803251333,17.402790102690865,17.287997402130394,17.173204701569922,17.058412001009454,16.943619300448983,16.828826599888515,16.714033899328044,16.599241198767572,16.4844484982071,16.369655797646637,16.254863097086165,16.140070396525694,16.025277695965222,15.910484995404753,15.795692294844281,15.680899594283813,15.566106893723342,15.451314193162872,15.336521492602403,15.221728792041931,15.106936091481462,14.992143390920992,14.87735069036052,14.762557989800051,14.647765289239583,14.53297258867911,14.418179888118642,14.30338718755817,14.188594486997701,14.07380178643723,13.959009085876762,13.844216385316289,13.72942368475582,13.61463098419535,13.49983828363488,13.385045583074408,13.27025288251394,13.155460181953467,13.040667481393,12.92587478083253,12.811082080272058,12.69628937971159,12.581496679151119,12.46670397859065,12.351911278030178,30.87820825020802,30.72892314234405,30.579638034480084,30.430352926616116,30.28106781875215,30.13178271088818,29.982497603024214,29.833212495160247,29.68392738729628,29.534642279432312,29.385357171568344,29.236072063704377,29.08678695584041,28.937501847976442,28.788216740112475,28.638931632248507,28.48964652438454,28.340361416520572,28.191076308656605,28.041791200792638,27.89250609292867,27.743220985064703,27.593935877200735,27.444650769336768,27.2953656614728,27.146080553608833,26.996795445744866,26.847510337880898,26.69822523001693,26.548940122152963,26.399655014288996,26.25036990642503,26.10108479856106,25.951799690697094,25.802514582833126,25.65322947496916,25.50394436710519,25.354659259241224,25.205374151377256,25.05608904351329,24.90680393564932,24.757518827785354,24.608233719921387,24.45894861205742,24.309663504193452,24.160378396329484,24.011093288465517,23.86180818060155,23.712523072737582,23.563237964873615,23.413952857009647,23.26466774914568,23.115382641281716,22.96609753341775,22.81681242555378,22.66752731768981,22.518242209825843,22.36895710196188,22.219671994097908,22.07038688623394,21.921101778369973,21.771816670506006,21.62253156264204,21.473246454778074,21.323961346914107,21.17467623905014,21.02539113118617,20.8761060233222,20.726820915458234,20.577535807594266,20.4282506997303,20.27896559186633,20.129680484002364,19.980395376138397,19.831110268274433,19.681825160410465,19.532540052546498,19.383254944682527,19.23396983681856,19.084684728954592,26.832232643256866,26.66775981006663,26.503286976876396,26.338814143686157,26.174341310495926,26.009868477305687,25.845395644115452,25.680922810925217,25.516449977734982,25.351977144544747,25.187504311354513,25.023031478164278,24.85855864497404,24.694085811783808,24.52961297859357,24.365140145403334,24.2006673122131,24.036194479022864,23.87172164583263,23.70724881264239,23.54277597945216,23.37830314626192,23.213830313071686,23.04935747988145,22.884884646691216,22.72041181350098,22.555938980310742,22.39146614712051,22.226993313930272,22.06252048074004,21.898047647549802,21.73357481435957,21.569101981169332,21.404629147979097,21.240156314788862,21.075683481598624,20.911210648408392,20.746737815218154,20.582264982027922,20.417792148837684,20.25331931564745,20.088846482457214,19.924373649266975,19.759900816076744,19.595427982886505,19.430955149696274,19.266482316506035,19.1020094833158,18.937536650125566,18.77306381693533,18.608590983745096,18.44411815055486,18.279645317364626,18.115172484174387,17.950699650984156,17.786226817793917,17.621753984603686,17.457281151413447,17.292808318223216,17.128335485032977,16.96386265184274,16.799389818652504,16.63491698546227,16.470444152272034,16.3059713190818,16.141498485891564,15.977025652701329,15.812552819511094,15.648079986320859,15.48360715313062,15.319134319940385,15.15466148675015,14.990188653559915,14.825715820369677,14.661242987179442,14.496770153989207,14.332297320798972,14.167824487608737,14.003351654418502,13.838878821228267],\n",
       "\"hp\":[176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6],\n",
       "\"gear\":[3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"HrrX9k\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b91810>"
      ]
     },
     "execution_count": 94,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = mtcars,\n",
    "          mapping = aes(x = 'disp',\n",
    "                     y = 'mpg',\n",
    "                     color = 'hp')\n",
    "                     ) +\n",
    "     geom_point() +\n",
    "     geom_smooth(method = \"lm\") +\n",
    "     scale_color_viridis() +\n",
    "     facet_wrap('gear', ncol = 1, \n",
    "                    format = '{} gears') +#<<               \n",
    "     labs(x = \"Displacement\", y = \"Highway MPG\",  #<<\n",
    "          color = \"Horsepower\",   #<<\n",
    "          title = \"Heavier cars get lower mileage\",  #<<\n",
    "          subtitle = \"Displacement indicates weight(?)\",  #<<\n",
    "          caption = \"I know nothing about cars\") +\n",
    "     theme_bw() #<<\n",
    ") "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 95,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"N31hOr\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"mpg\":[21.0,21.0,22.8,21.4,18.7,18.1,14.3,24.4,22.8,19.2,17.8,16.4,17.3,15.2,10.4,10.4,14.7,32.4,30.4,33.9,21.5,15.5,15.2,13.3,19.2,27.3,26.0,30.4,15.8,19.7,15.0,21.4],\n",
       "\"disp\":[160.0,160.0,108.0,258.0,360.0,225.0,360.0,146.7,140.8,167.6,167.6,275.8,275.8,275.8,472.0,460.0,440.0,78.7,75.7,71.1,120.1,318.0,304.0,350.0,400.0,79.0,120.3,95.1,351.0,145.0,301.0,121.0],\n",
       "\"hp\":[110.0,110.0,93.0,110.0,175.0,105.0,245.0,62.0,95.0,123.0,123.0,180.0,180.0,180.0,205.0,215.0,230.0,66.0,52.0,65.0,97.0,150.0,150.0,245.0,175.0,66.0,91.0,113.0,264.0,175.0,335.0,109.0],\n",
       "\"gear\":[4.0,4.0,4.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,3.0,3.0,3.0,3.0,3.0,4.0,5.0,5.0,5.0,5.0,5.0,4.0]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"disp\",\n",
       "\"y\":\"mpg\",\n",
       "\"color\":\"hp\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"facet\":{\n",
       "\"name\":\"wrap\",\n",
       "\"facets\":\"gear\",\n",
       "\"ncol\":1.0,\n",
       "\"order\":1.0,\n",
       "\"format\":\"{} gears\",\n",
       "\"dir\":\"h\"\n",
       "},\n",
       "\"ggtitle\":{\n",
       "\"text\":\"Heavier cars get lower mileage\",\n",
       "\"subtitle\":\"Displacement indicates weight(?)\"\n",
       "},\n",
       "\"caption\":{\n",
       "\"text\":\"I know nothing about cars\"\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"bw\",\n",
       "\"legend_position\":\"bottom\",\n",
       "\"plot_title\":{\n",
       "\"face\":\"bold\",\n",
       "\"blank\":false\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"color\",\n",
       "\"breaks\":[100.0,200.0,300.0],\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "},{\n",
       "\"name\":\"Displacement\",\n",
       "\"aesthetic\":\"x\"\n",
       "},{\n",
       "\"name\":\"Highway MPG\",\n",
       "\"aesthetic\":\"y\"\n",
       "},{\n",
       "\"name\":\"Horsepower\",\n",
       "\"aesthetic\":\"color\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"smooth\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[]\n",
       "},\n",
       "\"method\":\"lm\",\n",
       "\"data\":{\n",
       "\"..ymin..\":[18.110471212875474,18.055282738072687,17.999869530255523,17.944218807024544,17.888316855121165,17.832148950250065,17.775699269275947,17.718950794063353,17.661885206172315,17.604482771567685,17.54672221444906,17.488580579264564,17.430033079940074,17.371052935341318,17.311611189999045,17.251676519176048,17.191215017454446,17.130189970188678,17.068561607426457,17.006286840273894,16.94331898020551,16.87960744253519,16.81509743621812,16.74972964340082,16.683439893735972,16.61615884049476,16.5478116479995,16.478317702912722,16.407590365475343,16.33553678086279,16.262057775326504,16.187047866506997,16.110395421896484,16.031983003365113,15.951687938202596,15.86938315730634,15.784938337825697,15.698221379531658,15.609100230319289,15.51744505587064,15.423130721683112,15.326039523627545,15.226064068599621,15.12311017379106,15.017099626872586,14.907972635488948,14.795689797568807,14.680233446496343,14.56160826639115,14.439841128238198,14.314980160068446,14.187093124968696,14.056265230964748,13.922596530550756,13.7861990819478,13.64719403972004,13.505708822678628,13.361874477245124,13.215823320168953,13.067686910542323,12.91759437095986,12.765671053466136,12.61203752832302,12.456808862316446,12.300094147400305,12.141996238764571,11.982611662709724,11.822030657936521,11.660337318147631,11.497609808555906,11.333920633553431,11.16933693713552,11.003920821539468,10.837729672887376,10.67081648541222,10.503230178131917,10.335015899670093,10.1662153183672,9.996866895943162,9.827006143820459,28.231355556087774,28.12301331860439,28.014326518156963,27.905278534974745,27.79585182570608,27.68602787401537,27.57578713990086,27.465109008030943,27.353971735480908,27.242352399350672,27.130226844857958,27.017569634632245,26.90435400008326,26.790551795884706,26.676133458798876,26.56106797227031,26.445322838434233,26.32886405941498,26.21165613002499,26.093662044209044,25.97484331780003,25.855160030348745,25.734570888943274,25.61303331702357,25.49050357119976,25.366936888972067,25.242287669998234,25.116509693132457,24.989556370843356,24.86138104178706,24.731937301255048,24.601179367938094,24.46906248396841,24.33554334356408,24.20058054386865,24.064135049843895,23.926170663445113,23.786654485911704,23.645557360971104,23.502854286205935,23.35852477987405,23.212553191166005,23.064928943253168,22.915646700484338,22.764706453635345,22.612113520056965,22.457878458715623,22.302016903270925,22.144549319276038,21.98550069413499,21.82490017045797,21.662780634826344,21.499178274676602,21.33413211605425,21.167683554442345,20.999875889836247,20.830753875840497,20.660363290935646,20.488750538328315,20.31596227906617,20.142045101461136,19.967045228384336,19.791008262717128,19.61397897018539,19.436001097972074,19.25711722688577,19.07736865444053,18.896795305949738,18.715435670625542,18.533326759678246,18.350504083499473,18.16700164516614,17.98285194769814,17.798086012724333,17.612733408445347,17.426822285017295,17.24037941570979,17.053430242409465,16.86599892424262,16.678108388275668,19.352986248253586,19.304830378368145,19.254893412348622,19.20308958429367,19.14932906994715,19.093517904690323,19.035557923737144,18.975346729515714,18.912777691774025,18.847739986485394,18.780118680123557,18.709794866295262,18.636645862019307,18.56054547107835,18.481364321788806,18.3989702861776,18.313228986859684,18.22400439681973,18.131159535760624,18.03455726465198,17.93406117757437,17.82953658691941,17.7208515945196,17.607878237435685,17.4904936930632,17.368581524122117,17.242032940197127,17.110748049066757,16.97463706837889,16.833621466572108,16.687635001543367,16.53662462659802,16.380551235768504,16.21939022462776,16.053131848103778,15.881781363262622,15.705358952207819,15.523899427719726,15.337451731574328,15.146078242198435,14.94985391405508,14.748865275614381,14.543209315770408,14.33299229004923,14.118328477969847,13.899338921616083,13.67615017307524,13.448893075164928,13.217701596083595,12.98271173455695,12.744060507954764,12.501885031923688,12.256321696476043,12.007505440297061,11.755569122343967,11.500642987629234,11.242854222397083,10.98232659268141,10.719180159426603,10.45353106290072,10.185491368973778,9.915168969911345,9.642667532591188,9.368086487438262,9.091521051848423,8.813062282399164,8.532797150697505,8.250808638269064,7.967175846431927,7.681974117612232,7.395275165037749,7.107147208186213,6.817655111765168,6.526860526358124,6.234822029190186,5.941595263745805,5.64723307721531,5.351785654957569,5.055300651347226,4.7578233165289365],\n",
       "\"..ymax..\":[24.730598031739163,24.556201105421014,24.382028912117235,24.20809423422727,24.034410785009715,23.86099328875987,23.687857568613047,23.515020642704705,23.3425008294748,23.170317862958488,22.99849301895618,22.82704925301973,22.656011351223285,22.485406094701098,22.315262438922428,22.14561170862449,21.976487809225148,21.807927455369974,21.63997041701126,21.47265978304288,21.30604224199032,21.140168378539705,20.97509298373583,20.810875375432197,20.6475797239761,20.48527537609637,20.32403716747069,20.16394571143653,20.005087647752966,19.847555831244584,19.691449435659926,19.53687394335849,19.38394098684806,19.232768004258496,19.08347766830007,18.936197048075393,18.79105646643509,18.648188023608185,18.50772377169962,18.369793545027328,18.23452247809392,18.102028275028545,17.972418328935525,17.84578682262314,17.722211968420687,17.601753558683384,17.484450995482582,17.370321945434103,17.259361724418355,17.151543461450366,17.04681902849918,16.94512066247799,16.846363155360997,16.75044645465405,16.657258502136063,16.566678143242886,16.478577959163356,16.392826903475918,16.309292659431147,16.227843667936845,16.14835080639836,16.07068872277115,15.994736846793321,15.920380111678956,15.847509425474154,15.776021932988952,15.705821107922853,15.63681671157512,15.568924650243067,15.502066758713854,15.436170532595385,15.37116882789236,15.306999542367466,15.243605289898623,15.18093307625284,15.1189339824122,15.057562859753087,14.996778039935037,14.936541061238136,14.876816412239897,33.52506094432826,33.33483296608371,33.144949550803204,32.95542731825749,32.76628381179822,32.57753754776099,32.38920806614757,32.20131598228955,32.013883039111654,31.82693215951395,31.64048749827873,31.45457449277651,31.26921991159756,31.084451900068178,30.900300021426073,30.716795292226706,30.533970210334846,30.351858773626166,30.17049648728822,29.98992035737623,29.81016886805731,29.63128193978066,29.453300865458196,29.276268221649964,29.10022775174584,28.9252242182456,28.751303221491497,28.57851098262934,28.406894089190505,28.236499202518868,28.067372727322944,27.899560444911963,27.73310711315371,27.568056037830107,27.404448621797602,27.242323900094423,27.08171807076527,26.922664032570744,26.76519094178341,26.609323800820643,26.455083091424594,26.302484464404703,26.151538496589605,26.0022505236305,25.85462055475156,25.708643272602004,25.56430811821541,25.421599457932174,25.280496826199126,25.14097523561224,25.003005543561326,24.866554863465016,24.73158700788683,24.598062950781248,24.465941296665218,24.335178745543374,24.20573054381119,24.077550912988112,23.9505934498675,23.82481149340171,23.70015845527881,23.576588112627675,23.45405486256695,23.33251393937076,23.21192159585614,23.092235251214507,22.973413607931807,22.855416740694665,22.738206160290925,22.621744855510286,22.505997315961125,22.390929538566525,22.276509020306587,22.16270473955246,22.049487128103518,21.936828035803636,21.824700689383207,21.71307964695559,21.601940749394497,21.491261069633516,34.311479038260146,34.03068924176512,33.75168054140417,33.47453870307864,33.1993535510447,32.92621904992105,32.65523336449376,32.38649889233472,32.12012226369594,31.8562143026041,31.594889942585468,31.336268090033293,31.08047142792877,30.827626152489266,30.57786163539833,30.331310004629067,30.088105637566514,29.848384561226,29.612283755904635,29.3799403606328,29.151490781329947,28.92706970560443,28.70680903162377,28.490836722327217,28.27927560031923,28.072242102879844,27.869845020424357,27.672184245174265,27.479349559481655,27.291419494907974,27.108460293556238,26.930525002121122,26.75765272657016,26.589868071330436,26.427180781473947,26.269585599934626,26.117062344608968,25.96957620271658,25.82707823248152,25.689506055476933,25.556784717239818,25.428827689300046,25.305537982763543,25.186809342104258,25.072527487803164,24.962571377776463,24.85681445993683,24.755125891466673,24.657371704167538,24.56341589931371,24.473121459535427,24.386351269186033,24.30296893825321,24.222839528051715,24.145830179624344,24.0718106479586,24.000653746810286,23.932235710145484,23.86643647701983,23.803139907165235,23.7422339347117,23.683610667393662,23.627166438333347,23.572801817105805,23.520421586315173,23.46993468938396,23.421254154705153,23.374297000753124,23.32898412620979,23.28524018864901,23.242993474843022,23.202175765314088,23.16272219535466,23.12457111438123,23.0876639451687,23.05194504423261,23.017361564382632,22.983863320259907,22.95140265748978,22.9199343259276],\n",
       "\"disp\":[120.1,124.55443037974683,129.00886075949367,133.4632911392405,137.91772151898732,142.37215189873416,146.826582278481,151.28101265822784,155.73544303797468,160.18987341772151,164.64430379746835,169.0987341772152,173.55316455696203,178.00759493670887,182.46202531645568,186.91645569620252,191.37088607594936,195.8253164556962,200.27974683544304,204.73417721518985,209.18860759493668,213.64303797468352,218.09746835443036,222.5518987341772,227.00632911392404,231.46075949367088,235.91518987341772,240.36962025316456,244.8240506329114,249.2784810126582,253.73291139240504,258.18734177215185,262.64177215189875,267.09620253164553,271.5506329113924,276.0050632911392,280.4594936708861,284.9139240506329,289.3683544303797,293.82278481012656,298.2772151898734,302.73164556962024,307.1860759493671,311.6405063291139,316.0949367088607,320.5493670886076,325.0037974683544,329.4582278481013,333.91265822784806,338.36708860759495,342.82151898734173,347.27594936708863,351.7303797468354,356.18481012658225,360.6392405063291,365.0936708860759,369.54810126582277,374.0025316455696,378.45696202531644,382.9113924050632,387.3658227848101,391.8202531645569,396.2746835443038,400.7291139240506,405.1835443037975,409.63797468354426,414.09240506329115,418.54683544303793,423.00126582278483,427.4556962025316,431.9101265822785,436.3645569620253,440.8189873417722,445.27341772151897,449.72784810126575,454.18227848101264,458.6367088607594,463.0911392405063,467.5455696202531,472.0,71.1,72.32151898734176,73.54303797468354,74.76455696202531,75.98607594936708,77.20759493670886,78.42911392405063,79.65063291139239,80.87215189873417,82.09367088607594,83.31518987341772,84.53670886075949,85.75822784810126,86.97974683544304,88.2012658227848,89.42278481012659,90.64430379746835,91.86582278481012,93.08734177215189,94.30886075949367,95.53037974683544,96.75189873417722,97.97341772151898,99.19493670886075,100.41645569620252,101.6379746835443,102.85949367088607,104.08101265822785,105.30253164556962,106.52405063291138,107.74556962025316,108.96708860759493,110.18860759493671,111.41012658227848,112.63164556962025,113.85316455696201,115.0746835443038,116.29620253164558,117.51772151898734,118.73924050632911,119.96075949367088,121.18227848101264,122.40379746835443,123.62531645569621,124.84683544303797,126.06835443037974,127.28987341772151,128.5113924050633,129.73291139240507,130.95443037974684,132.1759493670886,133.39746835443037,134.61898734177214,135.8405063291139,137.06202531645567,138.28354430379747,139.50506329113924,140.726582278481,141.9481012658228,143.16962025316457,144.39113924050633,145.6126582278481,146.83417721518987,148.05569620253164,149.2772151898734,150.49873417721517,151.72025316455696,152.94177215189873,154.1632911392405,155.3848101265823,156.60632911392406,157.82784810126583,159.0493670886076,160.27088607594936,161.49240506329113,162.7139240506329,163.93544303797466,165.15696202531646,166.37848101265823,167.6,95.1,98.3392405063291,101.57848101265822,104.81772151898734,108.05696202531645,111.29620253164556,114.53544303797467,117.7746835443038,121.01392405063291,124.25316455696202,127.49240506329113,130.73164556962024,133.97088607594935,137.21012658227846,140.44936708860757,143.6886075949367,146.92784810126582,150.16708860759493,153.40632911392404,156.64556962025316,159.88481012658227,163.1240506329114,166.36329113924052,169.60253164556963,172.84177215189874,176.08101265822785,179.32025316455696,182.55949367088607,185.79873417721518,189.0379746835443,192.2772151898734,195.5164556962025,198.75569620253162,201.99493670886073,205.23417721518985,208.47341772151898,211.7126582278481,214.9518987341772,218.19113924050632,221.43037974683546,224.66962025316454,227.90886075949365,231.1481012658228,234.3873417721519,237.626582278481,240.86582278481012,244.10506329113923,247.34430379746834,250.58354430379745,253.82278481012656,257.0620253164557,260.3012658227848,263.5405063291139,266.779746835443,270.0189873417721,273.2582278481012,276.49746835443034,279.73670886075945,282.97594936708856,286.21518987341767,289.45443037974684,292.69367088607595,295.93291139240506,299.17215189873417,302.4113924050633,305.6506329113924,308.8898734177215,312.1291139240506,315.3683544303797,318.6075949367089,321.846835443038,325.0860759493671,328.3253164556962,331.56455696202534,334.80379746835445,338.04303797468356,341.28227848101267,344.5215189873418,347.7607594936709,351.0],\n",
       "\"mpg\":[21.42053462230732,21.30574192174685,21.19094922118638,21.076156520625908,20.96136382006544,20.84657111950497,20.731778418944497,20.61698571838403,20.502193017823558,20.387400317263086,20.27260761670262,20.157814916142147,20.04302221558168,19.928229515021208,19.813436814460736,19.69864411390027,19.583851413339797,19.469058712779326,19.354266012218858,19.239473311658386,19.124680611097915,19.009887910537447,18.895095209976976,18.780302509416508,18.665509808856036,18.550717108295565,18.435924407735094,18.321131707174626,18.206339006614154,18.091546306053687,17.976753605493215,17.861960904932744,17.747168204372272,17.632375503811804,17.517582803251333,17.402790102690865,17.287997402130394,17.173204701569922,17.058412001009454,16.943619300448983,16.828826599888515,16.714033899328044,16.599241198767572,16.4844484982071,16.369655797646637,16.254863097086165,16.140070396525694,16.025277695965222,15.910484995404753,15.795692294844281,15.680899594283813,15.566106893723342,15.451314193162872,15.336521492602403,15.221728792041931,15.106936091481462,14.992143390920992,14.87735069036052,14.762557989800051,14.647765289239583,14.53297258867911,14.418179888118642,14.30338718755817,14.188594486997701,14.07380178643723,13.959009085876762,13.844216385316289,13.72942368475582,13.61463098419535,13.49983828363488,13.385045583074408,13.27025288251394,13.155460181953467,13.040667481393,12.92587478083253,12.811082080272058,12.69628937971159,12.581496679151119,12.46670397859065,12.351911278030178,30.87820825020802,30.72892314234405,30.579638034480084,30.430352926616116,30.28106781875215,30.13178271088818,29.982497603024214,29.833212495160247,29.68392738729628,29.534642279432312,29.385357171568344,29.236072063704377,29.08678695584041,28.937501847976442,28.788216740112475,28.638931632248507,28.48964652438454,28.340361416520572,28.191076308656605,28.041791200792638,27.89250609292867,27.743220985064703,27.593935877200735,27.444650769336768,27.2953656614728,27.146080553608833,26.996795445744866,26.847510337880898,26.69822523001693,26.548940122152963,26.399655014288996,26.25036990642503,26.10108479856106,25.951799690697094,25.802514582833126,25.65322947496916,25.50394436710519,25.354659259241224,25.205374151377256,25.05608904351329,24.90680393564932,24.757518827785354,24.608233719921387,24.45894861205742,24.309663504193452,24.160378396329484,24.011093288465517,23.86180818060155,23.712523072737582,23.563237964873615,23.413952857009647,23.26466774914568,23.115382641281716,22.96609753341775,22.81681242555378,22.66752731768981,22.518242209825843,22.36895710196188,22.219671994097908,22.07038688623394,21.921101778369973,21.771816670506006,21.62253156264204,21.473246454778074,21.323961346914107,21.17467623905014,21.02539113118617,20.8761060233222,20.726820915458234,20.577535807594266,20.4282506997303,20.27896559186633,20.129680484002364,19.980395376138397,19.831110268274433,19.681825160410465,19.532540052546498,19.383254944682527,19.23396983681856,19.084684728954592,26.832232643256866,26.66775981006663,26.503286976876396,26.338814143686157,26.174341310495926,26.009868477305687,25.845395644115452,25.680922810925217,25.516449977734982,25.351977144544747,25.187504311354513,25.023031478164278,24.85855864497404,24.694085811783808,24.52961297859357,24.365140145403334,24.2006673122131,24.036194479022864,23.87172164583263,23.70724881264239,23.54277597945216,23.37830314626192,23.213830313071686,23.04935747988145,22.884884646691216,22.72041181350098,22.555938980310742,22.39146614712051,22.226993313930272,22.06252048074004,21.898047647549802,21.73357481435957,21.569101981169332,21.404629147979097,21.240156314788862,21.075683481598624,20.911210648408392,20.746737815218154,20.582264982027922,20.417792148837684,20.25331931564745,20.088846482457214,19.924373649266975,19.759900816076744,19.595427982886505,19.430955149696274,19.266482316506035,19.1020094833158,18.937536650125566,18.77306381693533,18.608590983745096,18.44411815055486,18.279645317364626,18.115172484174387,17.950699650984156,17.786226817793917,17.621753984603686,17.457281151413447,17.292808318223216,17.128335485032977,16.96386265184274,16.799389818652504,16.63491698546227,16.470444152272034,16.3059713190818,16.141498485891564,15.977025652701329,15.812552819511094,15.648079986320859,15.48360715313062,15.319134319940385,15.15466148675015,14.990188653559915,14.825715820369677,14.661242987179442,14.496770153989207,14.332297320798972,14.167824487608737,14.003351654418502,13.838878821228267],\n",
       "\"hp\":[176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,176.1333333333333,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,89.49999999999999,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6,195.6],\n",
       "\"gear\":[3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,3.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,4.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0,5.0]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"N31hOr\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b92010>"
      ]
     },
     "execution_count": 95,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = mtcars,\n",
    "          mapping = aes(x = 'disp',\n",
    "                     y = 'mpg',\n",
    "                     color = 'hp')\n",
    "     ) +\n",
    "     geom_point() +\n",
    "     geom_smooth(method = \"lm\") +\n",
    "     scale_color_viridis(breaks = [100, 200, 300]) +\n",
    "     facet_wrap('gear', ncol = 1, format = '{} gears') +\n",
    "     labs(x = \"Displacement\", y = \"Highway MPG\",  #<<\n",
    "          color = \"Horsepower\",   #<<\n",
    "          title = \"Heavier cars get lower mileage\",  #<<\n",
    "          subtitle = \"Displacement indicates weight(?)\",  #<<\n",
    "          caption = \"I know nothing about cars\") +\n",
    "     theme_bw() + \n",
    "     theme(legend_position = \"bottom\", #<<\n",
    "        plot_title = element_text(face = \"bold\")) #<<\n",
    ") "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 96,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"LhODQg\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"lifeExp\":[28.801,43.828,55.23,76.423,43.077,72.301,30.015,42.731,62.485,75.32,69.12,81.235,66.8,79.829,50.939,75.635,37.484,64.062,68.0,79.441,38.223,56.728,40.414,65.554,53.82,74.852,47.622,50.728,50.917,72.39,59.6,73.005,31.975,52.295,39.031,49.58,39.417,59.723,38.523,50.43,68.75,80.653,35.463,44.741,38.092,50.651,54.745,78.553,44.0,72.961,50.643,72.889,40.715,65.152,39.143,46.462,42.111,55.322,57.206,78.782,40.477,48.328,61.21,75.748,59.421,78.273,66.87,76.486,70.78,78.332,34.812,54.791,45.928,72.235,48.357,74.994,41.893,71.338,45.262,71.878,34.482,51.579,35.928,58.04,34.078,52.947,66.55,79.313,67.41,80.657,37.003,56.735,30.0,59.448,67.5,79.406,43.149,60.022,65.86,79.483,42.023,70.259,33.609,56.007,32.5,46.388,37.579,60.916,41.912,70.198,60.96,82.208,64.03,73.338,72.49,81.757,37.373,64.698,37.468,70.65,44.869,70.964,45.32,59.545,66.91,78.885,65.39,80.745,65.94,80.546,58.53,72.567,63.03,82.603,43.158,72.535,42.27,54.11,50.056,67.297,47.453,78.623,55.565,77.588,55.928,71.993,42.138,42.592,38.48,45.678,42.723,73.952,36.681,59.443,36.256,48.303,48.463,74.241,33.685,54.467,40.543,64.164,50.986,72.801,50.789,76.195,42.244,66.803,59.164,74.543,42.873,71.164,31.286,42.082,36.319,62.069,41.725,52.906,36.157,63.785,72.13,79.762,69.39,80.204,42.314,72.899,37.444,56.867,36.324,46.859,72.67,80.196,37.578,75.64,43.436,65.483,55.191,75.537,62.649,71.752,43.902,71.421,47.752,71.688,61.31,75.563,59.82,78.098,64.28,78.746,52.724,76.442,61.05,72.476,40.0,46.242,46.471,65.528,39.875,72.777,37.278,63.062,57.996,74.002,30.331,42.568,60.396,79.972,64.36,74.663,65.57,77.926,32.978,48.159,45.009,49.339,64.94,80.941,57.593,72.396,38.635,58.556,41.407,39.613,71.86,80.884,69.62,81.701,45.883,74.143,58.5,78.4,41.215,52.517,50.848,70.616,38.596,58.42,59.1,69.819,44.6,73.923,43.585,71.777,39.978,51.542,69.18,79.425,68.44,78.242,66.071,76.384,55.088,73.747,40.412,74.249,43.16,73.422,32.548,62.698,42.038,42.384,48.451,43.487],\n",
       "\"pop\":[8425333.0,3.1889923E7,1282697.0,3600523.0,9279525.0,3.3333216E7,4232095.0,1.2420476E7,1.7876956E7,4.0301927E7,8691212.0,2.0434176E7,6927772.0,8199783.0,120447.0,708573.0,4.6886859E7,1.50448339E8,8730405.0,1.0392226E7,1738315.0,8078314.0,2883315.0,9119152.0,2791000.0,4552198.0,442308.0,1639131.0,5.660256E7,1.90010647E8,7274900.0,7322858.0,4469979.0,1.4326203E7,2445618.0,8390505.0,4693836.0,1.4131858E7,5009067.0,1.7696293E7,1.4785584E7,3.3390141E7,1291695.0,4369038.0,2682462.0,1.0238807E7,6377619.0,1.6284741E7,5.56263527E8,1.318683096E9,1.2350771E7,4.422755E7,153936.0,710960.0,1.4100005E7,6.4606759E7,854885.0,3800610.0,926317.0,4133884.0,2977019.0,1.8013409E7,3882229.0,4493312.0,6007797.0,1.1416987E7,9125183.0,1.0228744E7,4334000.0,5468120.0,63149.0,496374.0,2491346.0,9319622.0,3548753.0,1.375568E7,2.2223309E7,8.0264543E7,2042865.0,6939688.0,216964.0,551201.0,1438760.0,4906585.0,2.0860941E7,7.6511887E7,4090500.0,5238460.0,4.2459667E7,6.1083916E7,420702.0,1454867.0,284320.0,1688359.0,6.9145952E7,8.2400996E7,5581001.0,2.2873338E7,7733250.0,1.070629E7,3146381.0,1.2572928E7,2664249.0,9947814.0,580653.0,1472041.0,3201488.0,8502814.0,1517453.0,7483763.0,2125900.0,6980412.0,9504000.0,9956108.0,147962.0,301931.0,3.72E8,1.110396331E9,8.2052E7,2.23547E8,1.7272E7,6.945357E7,5441766.0,2.7499638E7,2952156.0,4109086.0,1620914.0,6426679.0,4.7666E7,5.8147733E7,1426095.0,2780132.0,8.6459025E7,1.27467972E8,607914.0,6053193.0,6464046.0,3.5610177E7,8865488.0,2.3301725E7,2.0947571E7,4.904479E7,160000.0,2505559.0,1439529.0,3921278.0,748747.0,2012649.0,863308.0,3193942.0,1019729.0,6036914.0,4762912.0,1.9167654E7,2917802.0,1.3327079E7,6748378.0,2.4821286E7,3838168.0,1.2031795E7,1022556.0,3270065.0,516556.0,1250882.0,3.0144317E7,1.08700891E8,800663.0,2874127.0,413834.0,684736.0,9939217.0,3.3757175E7,6446316.0,1.9951656E7,2.0092996E7,4.776198E7,485831.0,2055080.0,9182536.0,2.890179E7,1.0381988E7,1.6570613E7,1994794.0,4115771.0,1165790.0,5675356.0,3379468.0,1.2894865E7,3.3119096E7,1.35031164E8,3327728.0,4627926.0,507833.0,3204897.0,4.134656E7,1.69270617E8,940080.0,3242173.0,1555876.0,6667147.0,8025700.0,2.8674757E7,2.2438691E7,9.1077287E7,2.5730551E7,3.8518241E7,8526050.0,1.0642836E7,2227000.0,3942491.0,257700.0,798094.0,1.663E7,2.2276056E7,2534927.0,8860588.0,60011.0,199579.0,4005677.0,2.7601038E7,2755589.0,1.2267493E7,6860147.0,1.0150265E7,2143249.0,6144562.0,1127000.0,4553009.0,3558137.0,5447502.0,1489518.0,2009245.0,2526994.0,9118773.0,1.4264935E7,4.3997828E7,2.854987E7,4.0448191E7,7982342.0,2.0378239E7,8504667.0,4.2292929E7,290243.0,1133066.0,7124673.0,9031088.0,4815000.0,7554661.0,3661549.0,1.9314747E7,8550362.0,2.3174294E7,8322925.0,3.813964E7,2.1289402E7,6.5068149E7,1219113.0,5701579.0,662850.0,1056608.0,3647735.0,1.0276158E7,2.2235677E7,7.1158647E7,5824797.0,2.9170398E7,5.043E7,6.0776238E7,1.57553E8,3.01139947E8,2252965.0,3447496.0,5439568.0,2.6084662E7,2.6246839E7,8.5262356E7,1030585.0,4018332.0,4963829.0,2.2211743E7,2672000.0,1.1746035E7,3080907.0,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,974.5803384,1601.056136,5937.029526,2449.008185,6223.367465,3520.610273,4797.231267,5911.315053,12779.37964,10039.59564,34435.36744,6137.076492,36126.4927,9867.084765,29796.04834,684.2441716,1391.253792,8343.105127,33692.60508,1062.7522,1441.284873,2677.326347,3822.137084,973.5331948,7446.298803,851.2411407,12569.85177,2108.944355,9065.800825,2444.286648,10680.79282,543.2552413,1217.032994,339.2964587,430.0706916,368.4692856,1713.778686,1172.667655,2042.09524,11367.16112,36319.23501,1071.310713,706.016537,1178.665927,1704.063724,3939.978789,13171.63885,400.448611,4959.114854,2144.115096,7006.580419,1102.990936,986.1478792,780.5423257,277.5518587,2125.621418,3632.557798,2627.009471,9645.06142,1388.594732,1544.750112,3119.23652,14619.22272,5586.53878,8948.102923,6876.14025,22833.30851,9692.385245,35278.41874,2669.529475,2082.481567,1397.717137,6025.374752,3522.110717,6873.262326,1418.822445,5581.180998,3048.3029,5728.353514,375.6431231,12154.08975,328.9405571,641.3695236,362.1462796,690.8055759,6424.519071,33207.0844,7029.809327,30470.0167,4293.476475,13206.48452,485.2306591,752.7497265,7144.114393,32170.37442,911.2989371,1327.60891,3530.690067,27538.41188,2428.237769,5186.050003,510.1964923,942.6542111,299.850319,579.231743,1840.366939,1201.637154,2194.926204,3548.330846,3054.421209,39724.97867,5263.673816,18008.94444,7267.688428,36180.78919,546.5657493,2452.210407,749.6816546,3540.651564,3035.326002,11605.71449,4129.766056,4471.061906,5210.280328,40675.99635,4086.522128,25523.2771,4931.404155,28569.7197,2898.530881,7320.880262,3216.956347,31656.06806,1546.907807,4519.461171,853.540919,1463.249282,1088.277758,1593.06548,1030.592226,23348.13973,108382.3529,47306.98978,4834.804067,10461.05868,298.8462121,1569.331442,575.5729961,414.5073415,2387.54806,12057.49928,1443.011715,1044.770126,369.1650802,759.3499101,1831.132894,12451.6558,452.3369807,1042.581557,743.1159097,1803.151496,1967.955707,10956.99112,3478.125529,11977.57496,786.5668575,3095.772271,2647.585601,9253.896111,1688.20357,3820.17523,468.5260381,823.6856205,331.0,944.0,2423.780443,4811.060429,545.8657229,1091.359778,8941.571858,36797.93332,10556.57566,25185.00911,3112.363948,2749.320965,761.879376,619.6768924,1077.281856,2013.977305,10095.42172,49357.19017,1828.230307,22316.19287,684.5971438,2605.94758,2480.380334,9809.185636,1952.308701,4172.838464,3758.523437,7408.905561,1272.880995,3190.481016,4029.329699,15389.92468,3068.319867,20509.64777,3081.959785,19328.70901,2718.885295,7670.122558,3144.613186,10808.47561,493.3238752,863.0884639,879.5835855,1598.435089,6459.554823,21654.83194,1450.356983,1712.472136,3581.459448,9786.534714,879.7877358,862.5407561,2315.138227,47143.17964,5074.659104,18678.31435,4215.041741,25768.25759,1135.749842,926.1410683,4725.295531,9269.657808,3834.034742,28821.0637,1083.53203,3970.095407,1615.991129,2602.394995,1148.376626,4513.480643,8527.844662,33859.74835,14734.23275,37506.41907,1643.485354,4184.548089,1206.947913,28718.27684,716.6500721,1107.482182,757.7974177,7458.396327,859.8086567,882.9699438,3023.271928,18008.50924,1468.475631,7092.923025,1969.10098,8458.276384,734.753484,1056.380121,9979.508487,33203.26128,13990.48208,42951.65309,5716.766744,10611.46299,7689.799761,11415.80569,605.0664917,2441.576404,1515.592329,3025.349798,781.7175761,2280.769906,1147.388831,1271.211593,406.8841148,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"breaks\":[1000.0,10000.0,25000.0,50000.0,100000.0],\n",
       "\"labels\":[\"$1K\",\"$10K\",\"$25K\",\"$50K\",\"$100K\"],\n",
       "\"trans\":\"log10\"\n",
       "},{\n",
       "\"name\":\"GDP per Capita\",\n",
       "\"aesthetic\":\"x\"\n",
       "},{\n",
       "\"name\":\"Life Expectancy\",\n",
       "\"aesthetic\":\"y\"\n",
       "},{\n",
       "\"name\":\"Continent\",\n",
       "\"aesthetic\":\"color\"\n",
       "},{\n",
       "\"name\":\"Population\",\n",
       "\"aesthetic\":\"size\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"LhODQg\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144308310>"
      ]
     },
     "execution_count": 96,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# get 2007 and 1952 data\n",
    "_gapminder = gapminder[gapminder.year.isin([pd.to_datetime('2007', format='%Y'), pd.to_datetime('1952', format='%Y')])]\n",
    "\n",
    "(\n",
    "    ggplot(data = _gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "             ) +\n",
    "        geom_point(alpha=0.5) +\n",
    "        scale_x_log10(\n",
    "            breaks = [1000, 10000, 25000, 50000, 100000],\n",
    "            labels = [f'${nz.numerize(x)}' for x in [1000, 10000, 25000, 50000, 100000]]\n",
    "            ) +\n",
    "        theme_minimal() +\n",
    "        labs(\n",
    "            x = 'GDP per Capita',\n",
    "            y = 'Life Expectancy',\n",
    "            color = 'Continent',\n",
    "            size = 'Population' \n",
    "        )\n",
    "        \n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Gapminder faceting"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 97,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/var/folders/tk/3rj0dqn167qd5hxxfjtpq6q00000gn/T/ipykernel_328/3811636648.py:4: SettingWithCopyWarning:\n",
      "\n",
      "\n",
      "A value is trying to be set on a copy of a slice from a DataFrame.\n",
      "Try using .loc[row_indexer,col_indexer] = value instead\n",
      "\n",
      "See the caveats in the documentation: https://pandas.pydata.org/pandas-docs/stable/user_guide/indexing.html#returning-a-view-versus-a-copy\n",
      "\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "   <div id=\"AeQUxd\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Oceania\",\"Oceania\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Europe\",\"Europe\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Africa\",\"Africa\",\"Africa\",\"Africa\"],\n",
       "\"year\":[1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0,1952.0,2007.0],\n",
       "\"lifeExp\":[28.801,43.828,55.23,76.423,43.077,72.301,30.015,42.731,62.485,75.32,69.12,81.235,66.8,79.829,50.939,75.635,37.484,64.062,68.0,79.441,38.223,56.728,40.414,65.554,53.82,74.852,47.622,50.728,50.917,72.39,59.6,73.005,31.975,52.295,39.031,49.58,39.417,59.723,38.523,50.43,68.75,80.653,35.463,44.741,38.092,50.651,54.745,78.553,44.0,72.961,50.643,72.889,40.715,65.152,39.143,46.462,42.111,55.322,57.206,78.782,40.477,48.328,61.21,75.748,59.421,78.273,66.87,76.486,70.78,78.332,34.812,54.791,45.928,72.235,48.357,74.994,41.893,71.338,45.262,71.878,34.482,51.579,35.928,58.04,34.078,52.947,66.55,79.313,67.41,80.657,37.003,56.735,30.0,59.448,67.5,79.406,43.149,60.022,65.86,79.483,42.023,70.259,33.609,56.007,32.5,46.388,37.579,60.916,41.912,70.198,60.96,82.208,64.03,73.338,72.49,81.757,37.373,64.698,37.468,70.65,44.869,70.964,45.32,59.545,66.91,78.885,65.39,80.745,65.94,80.546,58.53,72.567,63.03,82.603,43.158,72.535,42.27,54.11,50.056,67.297,47.453,78.623,55.565,77.588,55.928,71.993,42.138,42.592,38.48,45.678,42.723,73.952,36.681,59.443,36.256,48.303,48.463,74.241,33.685,54.467,40.543,64.164,50.986,72.801,50.789,76.195,42.244,66.803,59.164,74.543,42.873,71.164,31.286,42.082,36.319,62.069,41.725,52.906,36.157,63.785,72.13,79.762,69.39,80.204,42.314,72.899,37.444,56.867,36.324,46.859,72.67,80.196,37.578,75.64,43.436,65.483,55.191,75.537,62.649,71.752,43.902,71.421,47.752,71.688,61.31,75.563,59.82,78.098,64.28,78.746,52.724,76.442,61.05,72.476,40.0,46.242,46.471,65.528,39.875,72.777,37.278,63.062,57.996,74.002,30.331,42.568,60.396,79.972,64.36,74.663,65.57,77.926,32.978,48.159,45.009,49.339,64.94,80.941,57.593,72.396,38.635,58.556,41.407,39.613,71.86,80.884,69.62,81.701,45.883,74.143,58.5,78.4,41.215,52.517,50.848,70.616,38.596,58.42,59.1,69.819,44.6,73.923,43.585,71.777,39.978,51.542,69.18,79.425,68.44,78.242,66.071,76.384,55.088,73.747,40.412,74.249,43.16,73.422,32.548,62.698,42.038,42.384,48.451,43.487],\n",
       "\"pop\":[8425333.0,3.1889923E7,1282697.0,3600523.0,9279525.0,3.3333216E7,4232095.0,1.2420476E7,1.7876956E7,4.0301927E7,8691212.0,2.0434176E7,6927772.0,8199783.0,120447.0,708573.0,4.6886859E7,1.50448339E8,8730405.0,1.0392226E7,1738315.0,8078314.0,2883315.0,9119152.0,2791000.0,4552198.0,442308.0,1639131.0,5.660256E7,1.90010647E8,7274900.0,7322858.0,4469979.0,1.4326203E7,2445618.0,8390505.0,4693836.0,1.4131858E7,5009067.0,1.7696293E7,1.4785584E7,3.3390141E7,1291695.0,4369038.0,2682462.0,1.0238807E7,6377619.0,1.6284741E7,5.56263527E8,1.318683096E9,1.2350771E7,4.422755E7,153936.0,710960.0,1.4100005E7,6.4606759E7,854885.0,3800610.0,926317.0,4133884.0,2977019.0,1.8013409E7,3882229.0,4493312.0,6007797.0,1.1416987E7,9125183.0,1.0228744E7,4334000.0,5468120.0,63149.0,496374.0,2491346.0,9319622.0,3548753.0,1.375568E7,2.2223309E7,8.0264543E7,2042865.0,6939688.0,216964.0,551201.0,1438760.0,4906585.0,2.0860941E7,7.6511887E7,4090500.0,5238460.0,4.2459667E7,6.1083916E7,420702.0,1454867.0,284320.0,1688359.0,6.9145952E7,8.2400996E7,5581001.0,2.2873338E7,7733250.0,1.070629E7,3146381.0,1.2572928E7,2664249.0,9947814.0,580653.0,1472041.0,3201488.0,8502814.0,1517453.0,7483763.0,2125900.0,6980412.0,9504000.0,9956108.0,147962.0,301931.0,3.72E8,1.110396331E9,8.2052E7,2.23547E8,1.7272E7,6.945357E7,5441766.0,2.7499638E7,2952156.0,4109086.0,1620914.0,6426679.0,4.7666E7,5.8147733E7,1426095.0,2780132.0,8.6459025E7,1.27467972E8,607914.0,6053193.0,6464046.0,3.5610177E7,8865488.0,2.3301725E7,2.0947571E7,4.904479E7,160000.0,2505559.0,1439529.0,3921278.0,748747.0,2012649.0,863308.0,3193942.0,1019729.0,6036914.0,4762912.0,1.9167654E7,2917802.0,1.3327079E7,6748378.0,2.4821286E7,3838168.0,1.2031795E7,1022556.0,3270065.0,516556.0,1250882.0,3.0144317E7,1.08700891E8,800663.0,2874127.0,413834.0,684736.0,9939217.0,3.3757175E7,6446316.0,1.9951656E7,2.0092996E7,4.776198E7,485831.0,2055080.0,9182536.0,2.890179E7,1.0381988E7,1.6570613E7,1994794.0,4115771.0,1165790.0,5675356.0,3379468.0,1.2894865E7,3.3119096E7,1.35031164E8,3327728.0,4627926.0,507833.0,3204897.0,4.134656E7,1.69270617E8,940080.0,3242173.0,1555876.0,6667147.0,8025700.0,2.8674757E7,2.2438691E7,9.1077287E7,2.5730551E7,3.8518241E7,8526050.0,1.0642836E7,2227000.0,3942491.0,257700.0,798094.0,1.663E7,2.2276056E7,2534927.0,8860588.0,60011.0,199579.0,4005677.0,2.7601038E7,2755589.0,1.2267493E7,6860147.0,1.0150265E7,2143249.0,6144562.0,1127000.0,4553009.0,3558137.0,5447502.0,1489518.0,2009245.0,2526994.0,9118773.0,1.4264935E7,4.3997828E7,2.854987E7,4.0448191E7,7982342.0,2.0378239E7,8504667.0,4.2292929E7,290243.0,1133066.0,7124673.0,9031088.0,4815000.0,7554661.0,3661549.0,1.9314747E7,8550362.0,2.3174294E7,8322925.0,3.813964E7,2.1289402E7,6.5068149E7,1219113.0,5701579.0,662850.0,1056608.0,3647735.0,1.0276158E7,2.2235677E7,7.1158647E7,5824797.0,2.9170398E7,5.043E7,6.0776238E7,1.57553E8,3.01139947E8,2252965.0,3447496.0,5439568.0,2.6084662E7,2.6246839E7,8.5262356E7,1030585.0,4018332.0,4963829.0,2.2211743E7,2672000.0,1.1746035E7,3080907.0,1.2311143E7],\n",
       "\"gdpPercap\":[779.4453145,974.5803384,1601.056136,5937.029526,2449.008185,6223.367465,3520.610273,4797.231267,5911.315053,12779.37964,10039.59564,34435.36744,6137.076492,36126.4927,9867.084765,29796.04834,684.2441716,1391.253792,8343.105127,33692.60508,1062.7522,1441.284873,2677.326347,3822.137084,973.5331948,7446.298803,851.2411407,12569.85177,2108.944355,9065.800825,2444.286648,10680.79282,543.2552413,1217.032994,339.2964587,430.0706916,368.4692856,1713.778686,1172.667655,2042.09524,11367.16112,36319.23501,1071.310713,706.016537,1178.665927,1704.063724,3939.978789,13171.63885,400.448611,4959.114854,2144.115096,7006.580419,1102.990936,986.1478792,780.5423257,277.5518587,2125.621418,3632.557798,2627.009471,9645.06142,1388.594732,1544.750112,3119.23652,14619.22272,5586.53878,8948.102923,6876.14025,22833.30851,9692.385245,35278.41874,2669.529475,2082.481567,1397.717137,6025.374752,3522.110717,6873.262326,1418.822445,5581.180998,3048.3029,5728.353514,375.6431231,12154.08975,328.9405571,641.3695236,362.1462796,690.8055759,6424.519071,33207.0844,7029.809327,30470.0167,4293.476475,13206.48452,485.2306591,752.7497265,7144.114393,32170.37442,911.2989371,1327.60891,3530.690067,27538.41188,2428.237769,5186.050003,510.1964923,942.6542111,299.850319,579.231743,1840.366939,1201.637154,2194.926204,3548.330846,3054.421209,39724.97867,5263.673816,18008.94444,7267.688428,36180.78919,546.5657493,2452.210407,749.6816546,3540.651564,3035.326002,11605.71449,4129.766056,4471.061906,5210.280328,40675.99635,4086.522128,25523.2771,4931.404155,28569.7197,2898.530881,7320.880262,3216.956347,31656.06806,1546.907807,4519.461171,853.540919,1463.249282,1088.277758,1593.06548,1030.592226,23348.13973,108382.3529,47306.98978,4834.804067,10461.05868,298.8462121,1569.331442,575.5729961,414.5073415,2387.54806,12057.49928,1443.011715,1044.770126,369.1650802,759.3499101,1831.132894,12451.6558,452.3369807,1042.581557,743.1159097,1803.151496,1967.955707,10956.99112,3478.125529,11977.57496,786.5668575,3095.772271,2647.585601,9253.896111,1688.20357,3820.17523,468.5260381,823.6856205,331.0,944.0,2423.780443,4811.060429,545.8657229,1091.359778,8941.571858,36797.93332,10556.57566,25185.00911,3112.363948,2749.320965,761.879376,619.6768924,1077.281856,2013.977305,10095.42172,49357.19017,1828.230307,22316.19287,684.5971438,2605.94758,2480.380334,9809.185636,1952.308701,4172.838464,3758.523437,7408.905561,1272.880995,3190.481016,4029.329699,15389.92468,3068.319867,20509.64777,3081.959785,19328.70901,2718.885295,7670.122558,3144.613186,10808.47561,493.3238752,863.0884639,879.5835855,1598.435089,6459.554823,21654.83194,1450.356983,1712.472136,3581.459448,9786.534714,879.7877358,862.5407561,2315.138227,47143.17964,5074.659104,18678.31435,4215.041741,25768.25759,1135.749842,926.1410683,4725.295531,9269.657808,3834.034742,28821.0637,1083.53203,3970.095407,1615.991129,2602.394995,1148.376626,4513.480643,8527.844662,33859.74835,14734.23275,37506.41907,1643.485354,4184.548089,1206.947913,28718.27684,716.6500721,1107.482182,757.7974177,7458.396327,859.8086567,882.9699438,3023.271928,18008.50924,1468.475631,7092.923025,1969.10098,8458.276384,734.753484,1056.380121,9979.508487,33203.26128,13990.48208,42951.65309,5716.766744,10611.46299,7689.799761,11415.80569,605.0664917,2441.576404,1515.592329,3025.349798,781.7175761,2280.769906,1147.388831,1271.211593,406.8841148,469.7092981]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"gdpPercap\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"color\":\"continent\",\n",
       "\"size\":\"pop\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"facet\":{\n",
       "\"name\":\"wrap\",\n",
       "\"facets\":\"year\",\n",
       "\"ncol\":1.0,\n",
       "\"order\":1.0,\n",
       "\"dir\":\"h\"\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"x\",\n",
       "\"breaks\":[1000.0,10000.0,25000.0,50000.0,100000.0],\n",
       "\"labels\":[\"$1K\",\"$10K\",\"$25K\",\"$50K\",\"$100K\"],\n",
       "\"trans\":\"log10\"\n",
       "},{\n",
       "\"name\":\"GDP per Capita\",\n",
       "\"aesthetic\":\"x\"\n",
       "},{\n",
       "\"name\":\"Life Expectancy\",\n",
       "\"aesthetic\":\"y\"\n",
       "},{\n",
       "\"name\":\"Continent\",\n",
       "\"aesthetic\":\"color\"\n",
       "},{\n",
       "\"name\":\"Population\",\n",
       "\"aesthetic\":\"size\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"AeQUxd\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144508610>"
      ]
     },
     "execution_count": 97,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# get 2007 and 1952 data\n",
    "_filt = [pd.to_datetime(x, format='%Y') for x in ['2007', '1952']]\n",
    "_gapminder = gapminder[gapminder.year.isin(_filt)]\n",
    "_gapminder.year = _gapminder.year.dt.year   \n",
    "\n",
    "(\n",
    "    ggplot(data = _gapminder, mapping = aes(\n",
    "                    x = 'gdpPercap', \n",
    "                    y = 'lifeExp', \n",
    "                    color = 'continent', \n",
    "                    size = 'pop')\n",
    "                    ) +\n",
    "            geom_point(alpha=0.5) +\n",
    "            scale_x_log10(\n",
    "                breaks = [1000, 10000, 25000, 50000, 100000],\n",
    "                labels = [f'${nz.numerize(x)}' for x in [1000, 10000, 25000, 50000, 100000]]\n",
    "                ) +\n",
    "            facet_wrap('year', ncol=1) + ## <<<<\n",
    "            theme_minimal() +\n",
    "            labs(\n",
    "                x = 'GDP per Capita',\n",
    "                y = 'Life Expectancy',\n",
    "                color = 'Continent',\n",
    "                size = 'Population' \n",
    "        )\n",
    "        \n",
    ")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 98,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"x9ypNn\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "       (function() {\n",
       "           var plotSpec={\n",
       "\"data\":{\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"continent\",\n",
       "\"y\":\"lifeExp\",\n",
       "\"fill\":\"continent\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"column\":\"year\",\n",
       "\"type\":\"datetime\"\n",
       "}]\n",
       "},\n",
       "\"guides\":{\n",
       "\"fill\":\"none\"\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"name\":\"Life Expectancy\",\n",
       "\"aesthetic\":\"y\"\n",
       "},{\n",
       "\"name\":\"Continent\",\n",
       "\"aesthetic\":\"x\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"violin\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "\"..quantile..\":[0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.25,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,0.75,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0],\n",
       "\"continent\":[\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Americas\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\",\"Oceania\"],\n",
       "\"lifeExp\":[28.801,28.906287671232874,29.01157534246575,29.11686301369863,29.222150684931506,29.327438356164382,29.43272602739726,29.538013698630134,29.64330136986301,29.74858904109589,29.853876712328766,29.959164383561642,30.06445205479452,30.169739726027395,30.27502739726027,30.38031506849315,30.485602739726026,30.590890410958902,30.69617808219178,30.801465753424655,30.90675342465753,31.01204109589041,31.117328767123286,31.222616438356162,31.32790410958904,31.433191780821915,31.538479452054794,31.64376712328767,31.749054794520546,31.854342465753422,31.9596301369863,32.06491780821918,32.17020547945205,32.27549315068493,32.38078082191781,32.48606849315068,32.59135616438356,32.696643835616435,32.801931506849314,32.90721917808219,33.012506849315066,33.117794520547946,33.22308219178082,33.3283698630137,33.43365753424657,33.53894520547945,33.64423287671232,33.7495205479452,33.85480821917808,33.960095890410955,34.065383561643834,34.170671232876714,34.27595890410959,34.381246575342466,34.48653424657534,34.59182191780822,34.69710958904109,34.80239726027397,34.90768493150685,35.01297260273972,35.1182602739726,35.223547945205475,35.328835616438354,35.43412328767123,35.53941095890411,35.644698630136986,35.74998630136986,35.85527397260274,35.96056164383562,36.06584931506849,36.17113698630137,36.27642465753424,36.38171232876712,36.486999999999995,36.592287671232874,36.697575342465754,36.80286301369863,36.908150684931506,37.01343835616438,37.11872602739726,37.22401369863013,37.32930136986301,37.43458904109589,37.53987671232876,37.64516438356164,37.75045205479452,37.855739726027394,37.961027397260274,38.06631506849315,38.171602739726026,38.2768904109589,38.38217808219178,38.48746575342466,38.59275342465753,38.69804109589041,38.80332876712328,38.90861643835616,39.013904109589035,39.119191780821915,39.224479452054794,39.32976712328767,39.435054794520546,39.540342465753426,39.6456301369863,39.75091780821918,39.85620547945205,39.96149315068493,40.0667808219178,40.17206849315068,40.27735616438356,40.382643835616435,40.487931506849314,40.59321917808219,40.698506849315066,40.80379452054794,40.90908219178082,41.0143698630137,41.11965753424657,41.22494520547945,41.33023287671233,41.4355205479452,41.54080821917808,41.646095890410955,41.751383561643834,41.85667123287671,41.961958904109586,42.067246575342466,42.17253424657534,42.27782191780822,42.38310958904109,42.48839726027397,42.59368493150684,42.69897260273972,42.8042602739726,42.909547945205475,43.014835616438354,43.120123287671234,43.22541095890411,43.330698630136986,43.43598630136986,43.54127397260274,43.64656164383561,43.75184931506849,43.85713698630137,43.96242465753424,44.06771232876712,44.172999999999995,44.278287671232874,44.38357534246575,44.48886301369863,44.594150684931506,44.69943835616438,44.80472602739726,44.91001369863014,45.01530136986301,45.12058904109588,45.22587671232876,45.33116438356164,45.436452054794515,45.541739726027394,45.647027397260274,45.75231506849315,45.85760273972602,45.962890410958906,46.06817808219178,46.17346575342465,46.27875342465753,46.38404109589041,46.48932876712328,46.59461643835616,46.69990410958904,46.805191780821914,46.91047945205479,47.01576712328767,47.121054794520546,47.22634246575342,47.3316301369863,47.43691780821918,47.54220547945205,47.64749315068492,47.75278082191781,47.85806849315068,47.963356164383555,48.068643835616435,48.173931506849314,48.27921917808219,48.384506849315066,48.489794520547946,48.59508219178082,48.70036986301369,48.80565753424657,48.91094520547945,49.01623287671232,49.1215205479452,49.22680821917808,49.332095890410955,49.43738356164383,49.542671232876714,49.647958904109586,49.75324657534246,49.85853424657534,49.96382191780822,50.06910958904109,50.17439726027397,50.27968493150685,50.38497260273972,50.490260273972595,50.595547945205475,50.700835616438354,50.80612328767123,50.911410958904106,51.016698630136986,51.12198630136986,51.22727397260273,51.22727397260273,51.33256164383562,51.43784931506849,51.54313698630136,51.64842465753424,51.75371232876712,51.858999999999995,51.964287671232874,52.069575342465754,52.174863013698626,52.2801506849315,52.38543835616438,52.49072602739726,52.59601369863013,52.70130136986301,52.80658904109589,52.91187671232876,53.017164383561635,53.12245205479452,53.227739726027394,53.33302739726027,53.43831506849315,53.543602739726026,53.6488904109589,53.75417808219178,53.85946575342466,53.96475342465753,54.0700410958904,54.17532876712328,54.28061643835616,54.385904109589035,54.491191780821914,54.596479452054794,54.70176712328767,54.80705479452054,54.912342465753426,55.0176301369863,55.12291780821917,55.22820547945205,55.33349315068493,55.4387808219178,55.54406849315068,55.64935616438356,55.754643835616434,55.85993150684931,55.96521917808219,56.070506849315066,56.17579452054794,56.28108219178082,56.3863698630137,56.49165753424657,56.59694520547944,56.70223287671233,56.8075205479452,56.912808219178075,57.018095890410954,57.123383561643834,57.22867123287671,57.333958904109586,57.439246575342466,57.54453424657534,57.64982191780821,57.75510958904109,57.86039726027397,57.96568493150684,58.07097260273972,58.1762602739726,58.281547945205475,58.38683561643835,58.492123287671234,58.597410958904106,58.70269863013698,58.80798630136986,58.91327397260274,59.01856164383561,59.12384931506849,59.22913698630137,59.33442465753424,59.439712328767115,59.544999999999995,59.650287671232874,59.75557534246575,59.860863013698626,59.966150684931506,60.07143835616438,60.17672602739725,60.28201369863014,60.38730136986301,60.49258904109588,60.59787671232876,60.70316438356164,60.808452054794515,60.91373972602739,61.019027397260274,61.124315068493146,61.22960273972602,61.334890410958906,61.334890410958906,61.44017808219178,61.54546575342465,61.65075342465752,61.75604109589041,61.86132876712328,61.966616438356155,62.07190410958904,62.177191780821914,62.28247945205479,62.387767123287674,62.493054794520546,62.59834246575342,62.70363013698629,62.80891780821918,62.91420547945205,63.01949315068492,63.12478082191781,63.23006849315068,63.335356164383555,63.44064383561643,63.545931506849314,63.65121917808219,63.75650684931506,63.861794520547946,63.96708219178082,64.07236986301369,64.17765753424658,64.28294520547945,64.38823287671232,64.4935205479452,64.59880821917808,64.70409589041095,64.80938356164383,64.91467123287671,65.01995890410959,65.12524657534246,65.23053424657533,65.33582191780822,65.44110958904109,65.54639726027396,65.65168493150685,65.75697260273972,65.8622602739726,65.96754794520548,66.07283561643835,66.17812328767123,66.2834109589041,66.38869863013699,66.49398630136986,66.59927397260273,66.70456164383562,66.80984931506849,66.91513698630136,67.02042465753424,67.12571232876712,67.231,67.33628767123287,67.44157534246575,67.54686301369863,67.6521506849315,67.75743835616439,67.86272602739726,67.96801369863013,68.073301369863,68.17858904109589,68.28387671232876,68.38916438356163,68.49445205479452,68.5997397260274,68.70502739726027,68.81031506849314,68.91560273972603,69.0208904109589,69.12617808219177,69.23146575342466,69.23146575342466,69.33675342465753,69.4420410958904,69.54732876712329,69.65261643835616,69.75790410958903,69.86319178082191,69.9684794520548,70.07376712328767,70.17905479452054,70.28434246575343,70.3896301369863,70.49491780821917,70.60020547945204,70.70549315068493,70.8107808219178,70.91606849315068,71.02135616438356,71.12664383561643,71.2319315068493,71.3372191780822,71.44250684931507,71.54779452054794,71.65308219178081,71.7583698630137,71.86365753424657,71.96894520547944,72.07423287671233,72.1795205479452,72.28480821917807,72.39009589041095,72.49538356164383,72.6006712328767,72.70595890410958,72.81124657534247,72.91653424657534,73.02182191780821,73.1271095890411,73.23239726027397,73.33768493150684,73.44297260273972,73.5482602739726,73.65354794520547,73.75883561643835,73.86412328767123,73.9694109589041,74.07469863013698,74.17998630136985,74.28527397260274,74.39056164383561,74.49584931506848,74.60113698630137,74.70642465753424,74.81171232876711,74.91699999999999,75.02228767123287,75.12757534246575,75.23286301369862,75.3381506849315,75.44343835616438,75.54872602739725,75.65401369863014,75.75930136986301,75.86458904109588,75.96987671232876,76.07516438356164,76.18045205479451,76.28573972602739,76.39102739726027,76.49631506849315,76.60160273972602,76.70689041095889,76.81217808219178,76.91746575342465,77.02275342465752,77.12804109589041,77.23332876712328,77.33861643835615,77.44390410958904,77.54919178082191,77.65447945205479,77.75976712328766,77.86505479452055,77.97034246575342,78.07563013698629,78.18091780821918,78.28620547945205,78.39149315068492,78.4967808219178,78.60206849315068,78.70735616438355,78.81264383561643,78.91793150684931,79.02321917808219,79.12850684931506,79.23379452054795,79.33908219178082,79.44436986301369,79.54965753424656,79.65494520547945,79.76023287671232,79.8655205479452,79.97080821917808,80.07609589041095,80.18138356164383,80.2866712328767,80.39195890410959,80.49724657534246,80.60253424657533,80.70782191780822,80.81310958904109,80.91839726027396,81.02368493150685,81.12897260273972,81.2342602739726,81.33954794520547,81.44483561643835,81.55012328767123,81.6554109589041,81.76069863013699,81.86598630136986,81.97127397260273,82.0765616438356,82.18184931506849,82.28713698630136,82.39242465753424,82.49771232876712,82.603,43.585,43.65970058708415,43.7344011741683,43.80910176125245,43.883802348336594,43.958502935420746,44.03320352250489,44.10790410958904,44.18260469667319,44.25730528375734,44.332005870841485,44.40670645792564,44.48140704500979,44.55610763209393,44.630808219178085,44.70550880626223,44.78020939334638,44.85490998043053,44.92961056751468,45.004311154598824,45.079011741682976,45.15371232876713,45.22841291585127,45.303113502935425,45.37781409001957,45.45251467710372,45.527215264187866,45.60191585127202,45.67661643835616,45.751317025440315,45.82601761252446,45.90071819960861,45.975418786692764,46.05011937377691,46.12481996086106,46.199520547945205,46.27422113502936,46.3489217221135,46.423622309197654,46.4983228962818,46.57302348336595,46.647724070450096,46.72242465753425,46.7971252446184,46.871825831702544,46.946526418786696,47.02122700587084,47.09592759295499,47.17062818003914,47.24532876712329,47.320029354207435,47.39472994129159,47.46943052837574,47.544131115459884,47.618831702544036,47.69353228962818,47.76823287671233,47.84293346379648,47.91763405088063,47.992334637964774,48.067035225048926,48.14173581213308,48.21643639921722,48.291136986301375,48.36583757338552,48.44053816046967,48.515238747553816,48.58993933463797,48.66463992172211,48.739340508806265,48.81404109589041,48.88874168297456,48.96344227005871,49.03814285714286,49.11284344422701,49.187544031311155,49.26224461839531,49.33694520547945,49.411645792563604,49.48634637964775,49.5610469667319,49.635747553816046,49.7104481409002,49.78514872798435,49.859849315068494,49.934549902152646,50.00925048923679,50.08395107632094,50.15865166340509,50.23335225048924,50.308052837573385,50.38275342465754,50.45745401174169,50.532154598825834,50.606855185909986,50.68155577299413,50.75625636007828,50.83095694716243,50.90565753424658,50.980358121330724,51.055058708414876,51.12975929549902,51.20445988258317,51.27916046966732,51.35386105675147,51.42856164383562,51.503262230919766,51.57796281800392,51.65266340508806,51.727363992172215,51.80206457925636,51.87676516634051,51.95146575342466,52.02616634050881,52.10086692759296,52.175567514677105,52.25026810176126,52.3249686888454,52.399669275929554,52.4743698630137,52.54907045009785,52.623771037181996,52.69847162426615,52.7731722113503,52.847872798434445,52.92257338551859,52.99727397260274,53.07197455968689,53.14667514677104,53.22137573385519,53.296076320939335,53.37077690802349,53.44547749510764,53.520178082191784,53.59487866927593,53.66957925636008,53.74427984344423,53.81898043052838,53.89368101761253,53.968381604696674,54.043082191780826,54.11778277886498,54.19248336594912,54.26718395303327,54.34188454011742,54.41658512720157,54.491285714285716,54.56598630136987,54.64068688845401,54.715387475538165,54.79008806262231,54.86478864970646,54.93948923679061,55.01418982387476,55.08889041095891,55.163590998043055,55.2382915851272,55.31299217221135,55.387692759295504,55.46239334637965,55.5370939334638,55.611794520547946,55.6864951076321,55.76119569471625,55.835896281800395,55.91059686888454,55.98529745596869,56.05999804305284,56.13469863013699,56.20939921722114,56.284099804305285,56.35880039138944,56.43350097847359,56.508201565557734,56.58290215264188,56.65760273972603,56.73230332681018,56.80700391389433,56.88170450097848,56.956405088062624,57.031105675146776,57.10580626223092,57.18050684931507,57.25520743639922,57.32990802348337,57.40460861056752,57.479309197651666,57.55400978473582,57.62871037181996,57.703410958904115,57.77811154598826,57.85281213307241,57.92751272015656,58.00221330724071,58.07691389432486,58.151614481409005,58.22631506849315,58.3010156555773,58.375716242661454,58.4504168297456,58.52511741682975,58.599818003913896,58.67451859099805,58.7492191780822,58.823919765166345,58.89862035225049,58.97332093933464,59.04802152641879,59.12272211350294,59.19742270058709,59.272123287671235,59.34682387475539,59.42152446183953,59.496225048923684,59.57092563600783,59.64562622309198,59.72032681017613,59.79502739726028,59.86972798434442,59.944428571428574,60.019129158512726,60.09382974559688,60.16853033268102,60.24323091976517,60.31793150684932,60.39263209393347,60.467332681017616,60.54203326810176,60.61673385518591,60.691434442270065,60.76613502935421,60.84083561643836,60.91553620352251,60.99023679060666,61.06493737769081,61.139637964774955,61.2143385518591,61.28903913894325,61.363739726027404,61.43844031311155,61.513140900195694,61.587841487279846,61.662542074364,61.73724266144815,61.811943248532295,61.88664383561644,61.96134442270059,62.03604500978474,62.11074559686889,62.18544618395303,62.260146771037185,62.33484735812134,62.40954794520549,62.484248532289634,62.55894911937378,62.63364970645793,62.70835029354208,62.78305088062623,62.85775146771037,62.932452054794524,63.007152641878676,63.08185322896282,63.15655381604697,63.23125440313112,63.30595499021527,63.38065557729942,63.455356164383566,63.53005675146771,63.60475733855186,63.679457925636015,63.75415851272016,63.828859099804305,63.90355968688846,63.97826027397261,64.05296086105676,64.12766144814091,64.20236203522505,64.2770626223092,64.35176320939335,64.42646379647749,64.50116438356164,64.5758649706458,64.65056555772995,64.7252661448141,64.79996673189825,64.87466731898239,64.94936790606654,65.0240684931507,65.09876908023483,65.17346966731898,65.24817025440314,65.32287084148729,65.39757142857144,65.47227201565559,65.54697260273973,65.62167318982388,65.69637377690803,65.77107436399217,65.84577495107632,65.92047553816047,65.99517612524463,66.06987671232878,66.14457729941292,66.21927788649707,66.29397847358122,66.36867906066537,66.44337964774951,66.51808023483366,66.59278082191781,66.66748140900197,66.74218199608612,66.81688258317025,66.8915831702544,66.96628375733856,67.04098434442271,67.11568493150685,67.190385518591,67.26508610567515,67.3397866927593,67.41448727984346,67.4891878669276,67.56388845401175,67.6385890410959,67.71328962818005,67.78799021526419,67.86269080234834,67.93739138943249,68.01209197651664,68.0867925636008,68.16149315068493,68.23619373776909,68.31089432485324,68.38559491193737,68.46029549902153,68.53499608610568,68.60969667318983,68.68439726027398,68.75909784735813,68.83379843444227,68.90849902152642,68.98319960861058,69.05790019569471,69.13260078277887,69.20730136986302,69.20730136986302,69.28200195694717,69.35670254403132,69.43140313111547,69.50610371819961,69.58080430528376,69.65550489236792,69.73020547945205,69.8049060665362,69.87960665362036,69.95430724070451,70.02900782778866,70.10370841487281,70.17840900195695,70.2531095890411,70.32781017612525,70.40251076320939,70.47721135029354,70.5519119373777,70.62661252446185,70.701313111546,70.77601369863015,70.85071428571429,70.92541487279844,71.0001154598826,71.07481604696673,71.14951663405088,71.22421722113504,71.29891780821919,71.37361839530334,71.44831898238748,71.52301956947163,71.59772015655578,71.67242074363993,71.74712133072407,71.82182191780822,71.89652250489237,71.97122309197653,72.04592367906068,72.12062426614482,72.19532485322897,72.19532485322897,72.27002544031312,72.34472602739727,72.41942661448141,72.49412720156556,72.56882778864971,72.64352837573387,72.71822896281802,72.79292954990215,72.8676301369863,72.94233072407046,73.0170313111546,73.09173189823875,73.1664324853229,73.24113307240705,73.3158336594912,73.39053424657536,73.4652348336595,73.53993542074365,73.6146360078278,73.68933659491194,73.76403718199609,73.83873776908024,73.91343835616439,73.98813894324854,74.0628395303327,74.13754011741683,74.21224070450099,74.28694129158514,74.36164187866927,74.43634246575343,74.51104305283758,74.58574363992173,74.66044422700588,74.73514481409003,74.80984540117417,74.88454598825832,74.95924657534248,75.03394716242661,75.10864774951077,75.18334833659492,75.25804892367907,75.33274951076322,75.40745009784737,75.48215068493151,75.48215068493151,75.55685127201566,75.6315518590998,75.70625244618395,75.7809530332681,75.85565362035226,75.93035420743641,76.00505479452056,76.07975538160471,76.15445596868885,76.229156555773,76.30385714285714,76.37855772994129,76.45325831702544,76.5279589041096,76.60265949119375,76.6773600782779,76.75206066536205,76.82676125244619,76.90146183953034,76.97616242661448,77.05086301369863,77.12556360078278,77.20026418786694,77.27496477495109,77.34966536203524,77.42436594911939,77.49906653620353,77.57376712328768,77.64846771037182,77.72316829745597,77.79786888454012,77.87256947162427,77.94727005870843,78.02197064579258,78.09667123287673,78.17137181996087,78.24607240704502,78.32077299412916,78.39547358121331,78.47017416829746,78.54487475538161,78.61957534246577,78.69427592954992,78.76897651663405,78.8436771037182,78.91837769080236,78.9930782778865,79.06777886497065,79.1424794520548,79.21718003913895,79.2918806262231,79.36658121330726,79.4412818003914,79.51598238747555,79.5906829745597,79.66538356164384,79.74008414872799,79.81478473581214,79.88948532289629,79.96418590998044,80.0388864970646,80.11358708414873,80.18828767123289,80.26298825831702,80.33768884540117,80.41238943248533,80.48709001956948,80.56179060665363,80.63649119373778,80.71119178082193,80.78589236790607,80.86059295499022,80.93529354207436,81.00999412915851,81.08469471624267,81.15939530332682,81.23409589041097,81.30879647749512,81.38349706457927,81.45819765166341,81.53289823874756,81.6075988258317,81.68229941291585,81.757,23.599,23.70241095890411,23.80582191780822,23.90923287671233,24.012643835616437,24.116054794520547,24.219465753424657,24.322876712328767,24.426287671232878,24.529698630136988,24.633109589041094,24.736520547945204,24.839931506849315,24.943342465753425,25.046753424657535,25.150164383561645,25.25357534246575,25.35698630136986,25.46039726027397,25.56380821917808,25.667219178082192,25.770630136986302,25.874041095890412,25.97745205479452,26.08086301369863,26.18427397260274,26.28768493150685,26.39109589041096,26.49450684931507,26.59791780821918,26.701328767123286,26.804739726027396,26.908150684931506,27.011561643835616,27.114972602739726,27.218383561643833,27.321794520547943,27.425205479452053,27.528616438356163,27.632027397260273,27.735438356164384,27.838849315068494,27.9422602739726,28.04567123287671,28.14908219178082,28.25249315068493,28.35590410958904,28.45931506849315,28.56272602739726,28.666136986301368,28.769547945205478,28.872958904109588,28.976369863013698,29.079780821917808,29.183191780821915,29.28660273972603,29.390013698630135,29.493424657534245,29.596835616438355,29.700246575342465,29.803657534246575,29.907068493150682,30.010479452054792,30.113890410958902,30.217301369863012,30.320712328767122,30.424123287671232,30.527534246575343,30.63094520547945,30.73435616438356,30.83776712328767,30.94117808219178,31.04458904109589,31.147999999999996,31.25141095890411,31.354821917808216,31.458232876712326,31.561643835616437,31.665054794520547,31.768465753424657,31.871876712328763,31.975287671232877,32.078698630136984,32.18210958904109,32.285520547945204,32.38893150684931,32.492342465753424,32.59575342465753,32.69916438356164,32.80257534246575,32.905986301369865,33.00939726027397,33.11280821917808,33.21621917808219,33.3196301369863,33.42304109589041,33.52645205479452,33.629863013698625,33.73327397260274,33.836684931506845,33.94009589041096,34.043506849315065,34.14691780821917,34.250328767123285,34.3537397260274,34.457150684931506,34.56056164383561,34.663972602739726,34.76738356164383,34.870794520547946,34.97420547945205,35.07761643835616,35.18102739726027,35.28443835616438,35.38784931506849,35.4912602739726,35.594671232876706,35.69808219178082,35.80149315068493,35.90490410958904,36.00831506849315,36.11172602739725,36.21513698630137,36.31854794520548,36.42195890410959,36.525369863013694,36.62878082191781,36.732191780821914,36.83560273972603,36.939013698630134,37.04242465753424,37.145835616438355,37.24924657534246,37.352657534246575,37.45606849315068,37.55947945205479,37.6628904109589,37.76630136986301,37.86971232876712,37.97312328767123,38.076534246575335,38.17994520547945,38.28335616438356,38.38676712328767,38.490178082191775,38.59358904109589,38.696999999999996,38.80041095890411,38.903821917808216,39.00723287671232,39.110643835616436,39.21405479452054,39.317465753424656,39.42087671232876,39.52428767123287,39.62769863013698,39.7311095890411,39.8345205479452,39.93793150684931,40.04134246575342,40.14475342465753,40.248164383561644,40.35157534246575,40.45498630136986,40.55839726027396,40.66180821917808,40.76521917808219,40.8686301369863,40.972041095890404,41.07545205479452,41.178863013698624,41.28227397260274,41.385684931506844,41.48909589041095,41.592506849315065,41.69591780821918,41.799328767123285,41.90273972602739,42.0061506849315,42.10956164383561,42.10956164383561,42.212972602739725,42.31638356164383,42.41979452054794,42.523205479452045,42.62661643835616,42.73002739726027,42.83343835616438,42.936849315068486,43.0402602739726,43.143671232876706,43.24708219178082,43.350493150684926,43.45390410958903,43.557315068493146,43.66072602739726,43.76413698630137,43.86754794520547,43.97095890410958,44.07436986301369,44.17778082191781,44.28119178082191,44.38460273972602,44.48801369863013,44.59142465753424,44.694835616438354,44.79824657534246,44.90165753424657,45.00506849315068,45.108479452054794,45.2118904109589,45.31530136986301,45.418712328767114,45.52212328767123,45.62553424657534,45.72894520547945,45.832356164383555,45.93576712328766,46.039178082191775,46.14258904109589,46.245999999999995,46.3494109589041,46.45282191780821,46.55623287671232,46.659643835616436,46.76305479452054,46.86646575342465,46.96987671232876,47.073287671232876,47.17669863013698,47.28010958904109,47.383520547945196,47.48693150684931,47.59034246575342,47.69375342465753,47.69375342465753,47.797164383561636,47.90057534246574,48.00398630136986,48.10739726027397,48.21080821917808,48.31421917808218,48.41763013698629,48.5210410958904,48.62445205479452,48.727863013698624,48.83127397260273,48.934684931506844,49.03809589041096,49.141506849315064,49.24491780821917,49.34832876712328,49.45173972602739,49.555150684931505,49.65856164383561,49.76197260273972,49.865383561643824,49.96879452054794,50.07220547945205,50.17561643835616,50.279027397260265,50.38243835616438,50.485849315068485,50.5892602739726,50.692671232876705,50.79608219178081,50.899493150684926,51.00290410958904,51.106315068493146,51.20972602739725,51.31313698630136,51.41654794520547,51.519958904109586,51.62336986301369,51.7267808219178,51.830191780821906,51.93360273972602,52.03701369863013,52.14042465753424,52.243835616438346,52.34724657534246,52.45065753424657,52.55406849315068,52.65747945205479,52.76089041095889,52.86430136986301,52.96771232876712,53.07112328767123,53.174534246575334,53.27794520547944,53.381356164383554,53.48476712328767,53.588178082191774,53.69158904109588,53.79499999999999,53.8984109589041,54.001821917808215,54.10523287671232,54.20864383561643,54.31205479452054,54.41546575342465,54.41546575342465,54.51887671232876,54.62228767123287,54.725698630136975,54.82910958904109,54.9325205479452,55.03593150684931,55.139342465753415,55.24275342465752,55.346164383561636,55.44957534246575,55.552986301369856,55.65639726027396,55.75980821917807,55.86321917808219,55.966630136986296,56.0700410958904,56.17345205479451,56.276863013698616,56.38027397260274,56.48368493150684,56.58709589041095,56.69050684931506,56.79391780821916,56.897328767123284,57.00073972602739,57.1041506849315,57.207561643835604,57.310972602739724,57.41438356164383,57.51779452054794,57.621205479452044,57.72461643835615,57.82802739726027,57.93143835616438,58.034849315068485,58.13826027397259,58.2416712328767,58.34508219178082,58.448493150684925,58.55190410958903,58.65531506849314,58.758726027397245,58.862136986301365,58.96554794520547,59.06895890410958,59.172369863013685,59.275780821917806,59.37919178082191,59.48260273972602,59.586013698630126,59.68942465753423,59.79283561643835,59.89624657534246,59.999657534246566,60.10306849315067,60.20647945205478,60.3098904109589,60.41330136986301,60.51671232876711,60.62012328767122,60.723534246575326,60.82694520547945,60.930356164383554,61.03376712328766,61.13717808219177,61.24058904109589,61.343999999999994,61.4474109589041,61.55082191780821,61.654232876712314,61.757643835616435,61.86105479452054,61.96446575342465,62.067876712328754,62.17128767123286,62.27469863013698,62.37810958904109,62.481520547945195,62.5849315068493,62.68834246575341,62.79175342465753,62.895164383561635,62.99857534246574,63.10198630136985,63.20539726027397,63.308808219178076,63.41221917808218,63.51563013698629,63.619041095890395,63.722452054794516,63.82586301369862,63.92927397260273,64.03268493150684,64.13609589041094,64.23950684931506,64.34291780821917,64.44632876712328,64.54973972602738,64.65315068493149,64.75656164383561,64.85997260273972,64.96338356164382,65.06679452054793,65.17020547945205,65.27361643835616,65.37702739726026,65.48043835616437,65.58384931506848,65.6872602739726,65.7906712328767,65.89408219178081,65.99749315068492,66.10090410958902,66.20431506849314,66.30772602739725,66.41113698630136,66.51454794520546,66.61795890410959,66.72136986301369,66.8247808219178,66.9281917808219,67.03160273972601,67.13501369863013,67.23842465753424,67.34183561643835,67.44524657534245,67.54865753424656,67.65206849315068,67.75547945205479,67.85889041095889,67.962301369863,68.0657123287671,68.16912328767123,68.27253424657533,68.37594520547944,68.47935616438355,68.58276712328767,68.68617808219177,68.78958904109588,68.89299999999999,68.9964109589041,69.09982191780821,69.20323287671232,69.30664383561643,69.41005479452053,69.51346575342464,69.61687671232876,69.72028767123287,69.82369863013697,69.92710958904108,70.03052054794519,70.13393150684931,70.23734246575341,70.34075342465752,70.44416438356163,70.54757534246575,70.65098630136985,70.75439726027396,70.85780821917807,70.96121917808217,71.0646301369863,71.1680410958904,71.27145205479451,71.37486301369862,71.47827397260272,71.58168493150684,71.68509589041095,71.78850684931506,71.89191780821916,71.99532876712327,72.09873972602739,72.2021506849315,72.3055616438356,72.40897260273971,72.51238356164383,72.61579452054794,72.71920547945204,72.82261643835615,72.92602739726026,73.02943835616438,73.13284931506848,73.23626027397259,73.3396712328767,73.4430821917808,73.54649315068492,73.64990410958903,73.75331506849314,73.85672602739724,73.96013698630135,74.06354794520547,74.16695890410958,74.27036986301368,74.37378082191779,74.47719178082191,74.58060273972602,74.68401369863012,74.78742465753423,74.89083561643834,74.99424657534246,75.09765753424657,75.20106849315067,75.30447945205478,75.40789041095888,75.511301369863,75.61471232876711,75.71812328767122,75.82153424657533,75.92494520547943,76.02835616438355,76.13176712328766,76.23517808219177,76.33858904109587,76.442,37.579,37.66329354207436,37.747587084148726,37.83188062622309,37.91617416829746,38.00046771037182,38.084761252446185,38.16905479452055,38.25334833659491,38.337641878669274,38.421935420743644,38.50622896281801,38.59052250489237,38.67481604696673,38.759109589041095,38.84340313111546,38.92769667318982,39.01199021526419,39.096283757338554,39.18057729941292,39.26487084148728,39.34916438356164,39.433457925636006,39.517751467710376,39.60204500978474,39.6863385518591,39.770632093933465,39.85492563600783,39.93921917808219,40.02351272015656,40.10780626223092,40.192099804305286,40.27639334637965,40.36068688845401,40.444980430528375,40.52927397260274,40.61356751467711,40.69786105675147,40.782154598825834,40.8664481409002,40.95074168297456,41.03503522504892,41.11932876712329,41.203622309197655,41.28791585127202,41.37220939334638,41.456502935420744,41.54079647749511,41.62509001956947,41.70938356164383,41.7936771037182,41.877970645792566,41.96226418786693,42.04655772994129,42.130851272015654,42.215144814090024,42.29943835616439,42.38373189823875,42.46802544031311,42.552318982387476,42.63661252446184,42.7209060665362,42.80519960861057,42.889493150684935,42.9737866927593,43.05808023483366,43.14237377690802,43.226667318982386,43.310960861056756,43.39525440313112,43.47954794520548,43.563841487279845,43.64813502935421,43.73242857142857,43.816722113502934,43.901015655577304,43.98530919765167,44.06960273972603,44.15389628180039,44.238189823874755,44.32248336594912,44.40677690802349,44.49107045009785,44.575363992172214,44.65965753424658,44.74395107632094,44.8282446183953,44.912538160469666,44.996831702544036,45.0811252446184,45.16541878669276,45.249712328767124,45.33400587084149,45.41829941291585,45.50259295499022,45.58688649706458,45.671180039138946,45.75547358121331,45.83976712328767,45.924060665362035,46.0083542074364,46.09264774951076,46.17694129158513,46.26123483365949,46.345528375733856,46.42982191780822,46.51411545988258,46.59840900195695,46.682702544031315,46.76699608610568,46.85128962818004,46.935583170254404,47.01987671232877,47.10417025440313,47.18846379647749,47.27275733855186,47.357050880626225,47.44134442270059,47.52563796477495,47.609931506849314,47.694225048923684,47.77851859099805,47.86281213307241,47.94710567514677,48.031399217221136,48.1156927592955,48.19998630136986,48.284279843444224,48.368573385518594,48.45286692759296,48.53716046966732,48.62145401174168,48.705747553816046,48.790041095890416,48.87433463796478,48.95862818003914,49.042921722113505,49.12721526418787,49.21150880626223,49.29580234833659,49.380095890410956,49.464389432485326,49.54868297455969,49.63297651663405,49.717270058708415,49.80156360078278,49.88585714285715,49.97015068493151,50.054444227005874,50.13873776908024,50.2230313111546,50.30732485322896,50.391618395303325,50.47591193737769,50.56020547945206,50.64449902152642,50.728792563600784,50.81308610567515,50.89737964774952,50.98167318982388,51.06596673189824,51.150260273972606,51.23455381604697,51.31884735812133,51.403140900195694,51.48743444227006,51.57172798434442,51.65602152641879,51.74031506849315,51.824608610567516,51.90890215264188,51.99319569471625,52.07748923679061,52.161782778864975,52.24607632093934,52.3303698630137,52.41466340508806,52.498956947162426,52.58325048923679,52.66754403131115,52.75183757338552,52.836131115459885,52.92042465753425,53.00471819960861,53.08901174168298,53.173305283757344,53.25759882583171,53.34189236790607,53.42618590998043,53.510479452054796,53.59477299412916,53.67906653620352,53.763360078277884,53.847653620352254,53.93194716242662,54.01624070450098,54.10053424657534,54.18482778864971,54.269121330724076,54.35341487279844,54.4377084148728,54.522001956947165,54.60629549902153,54.69058904109589,54.77488258317025,54.859176125244616,54.943469667318986,55.02776320939335,55.11205675146771,55.196350293542075,55.280643835616445,55.36493737769081,55.44923091976517,55.533524461839534,55.6178180039139,55.70211154598826,55.78640508806262,55.870698630136985,55.95499217221135,56.03928571428572,56.12357925636008,56.207872798434444,56.292166340508814,56.37645988258318,56.46075342465754,56.5450469667319,56.629340508806266,56.71363405088063,56.79792759295499,56.882221135029354,56.96651467710372,57.05080821917808,57.13510176125245,57.21939530332681,57.303688845401176,57.387982387475546,57.47227592954991,57.55656947162427,57.640863013698635,57.725156555773,57.80945009784736,57.89374363992172,57.978037181996086,58.06233072407045,58.14662426614481,58.23091780821918,58.315211350293545,58.39950489236791,58.39950489236791,58.48379843444228,58.56809197651664,58.652385518591004,58.73667906066537,58.82097260273973,58.90526614481409,58.989559686888455,59.07385322896282,59.15814677103718,59.242440313111544,59.326733855185914,59.41102739726028,59.49532093933464,59.57961448140901,59.66390802348337,59.748201565557736,59.8324951076321,59.91678864970646,60.001082191780824,60.08537573385519,60.16966927592955,60.25396281800391,60.338256360078276,60.422549902152646,60.50684344422701,60.59113698630137,60.67543052837574,60.759724070450105,60.84401761252447,60.92831115459883,61.01260469667319,61.096898238747556,61.18119178082192,61.26548532289628,61.349778864970645,61.43407240704501,61.51836594911938,61.60265949119374,61.686953033268104,61.771246575342474,61.85554011741684,61.9398336594912,62.02412720156556,62.108420743639925,62.19271428571429,62.27700782778865,62.361301369863014,62.44559491193738,62.52988845401174,62.61418199608611,62.69847553816047,62.782769080234836,62.867062622309206,62.95135616438357,63.03564970645793,63.119943248532294,63.20423679060666,63.28853033268102,63.37282387475538,63.457117416829746,63.54141095890411,63.62570450097847,63.70999804305284,63.794291585127205,63.87858512720157,63.96287866927594,64.0471722113503,64.13146575342466,64.21575929549903,64.30005283757339,64.38434637964775,64.46863992172212,64.55293346379648,64.63722700587084,64.7215205479452,64.80581409001957,64.89010763209393,64.97440117416829,65.05869471624267,65.14298825831703,65.2272818003914,65.31157534246576,65.39586888454012,65.48016242661448,65.56445596868885,65.64874951076321,65.73304305283757,65.81733659491194,65.90163013698631,65.98592367906068,66.07021722113504,66.1545107632094,66.23880430528376,66.32309784735813,66.40739138943249,66.40739138943249,66.49168493150685,66.57597847358122,66.66027201565558,66.74456555772994,66.8288590998043,66.91315264187867,66.99744618395303,67.0817397260274,67.16603326810176,67.25032681017613,67.3346203522505,67.41891389432486,67.50320743639922,67.58750097847359,67.67179452054795,67.75608806262231,67.84038160469667,67.92467514677104,68.0089686888454,68.09326223091978,68.17755577299414,68.2618493150685,68.34614285714287,68.43043639921723,68.51472994129159,68.59902348336595,68.68331702544032,68.76761056751468,68.85190410958904,68.9361976516634,69.02049119373777,69.10478473581213,69.1890782778865,69.27337181996086,69.35766536203522,69.4419589041096,69.52625244618396,69.61054598825832,69.69483953033269,69.77913307240705,69.86342661448141,69.94772015655577,70.03201369863014,70.11630724070451,70.20060078277888,70.28489432485324,70.3691878669276,70.45348140900197,70.53777495107633,70.62206849315069,70.70636203522506,70.79065557729942,70.87494911937378,70.95924266144814,71.0435362035225,71.12782974559687,71.21212328767123,71.2964168297456,71.38071037181996,71.46500391389432,71.54929745596868,71.63359099804305,71.63359099804305,71.71788454011741,71.80217808219179,71.88647162426615,71.97076516634051,72.05505870841488,72.13935225048924,72.2236457925636,72.30793933463798,72.39223287671234,72.4765264187867,72.56081996086107,72.64511350293543,72.7294070450098,72.81370058708416,72.89799412915852,72.98228767123288,73.06658121330724,73.15087475538161,73.23516829745597,73.31946183953033,73.4037553816047,73.48804892367906,73.57234246575342,73.65663600782779,73.74092954990215,73.82522309197651,73.90951663405089,73.99381017612525,74.07810371819961,74.16239726027398,74.24669080234834,74.3309843444227,74.41527788649707,74.49957142857144,74.5838649706458,74.66815851272017,74.75245205479453,74.8367455968689,74.92103913894326,75.00533268101762,75.08962622309198,75.17391976516635,75.25821330724071,75.34250684931507,75.42680039138943,75.5110939334638,75.59538747553816,75.67968101761252,75.76397455968689,75.84826810176125,75.93256164383561,76.01685518590998,76.10114872798435,76.18544227005872,76.26973581213308,76.35402935420744,76.4383228962818,76.52261643835617,76.60690998043053,76.6912035225049,76.77549706457927,76.85979060665363,76.944084148728,77.02837769080236,77.11267123287672,77.19696477495108,77.28125831702545,77.36555185909981,77.44984540117417,77.53413894324854,77.6184324853229,77.70272602739726,77.78701956947162,77.87131311154599,77.95560665362035,78.03990019569471,78.12419373776908,78.20848727984344,78.29278082191782,78.37707436399218,78.46136790606654,78.5456614481409,78.62995499021527,78.71424853228963,78.798542074364,78.88283561643837,78.96712915851273,79.0514227005871,79.13571624266146,79.22000978473582,79.30430332681019,79.38859686888455,79.47289041095891,79.55718395303327,79.64147749510764,79.725771037182,79.81006457925636,79.89435812133073,79.97865166340509,80.06294520547945,80.14723874755381,80.23153228962818,80.31582583170254,80.4001193737769,80.48441291585128,80.56870645792564,80.653,69.12,69.1437084148728,69.1674168297456,69.1911252446184,69.2148336594912,69.23854207436399,69.26225048923679,69.28595890410959,69.30966731898239,69.33337573385519,69.35708414872799,69.38079256360079,69.40450097847359,69.42820939334638,69.45191780821918,69.47562622309198,69.49933463796478,69.52304305283758,69.54675146771038,69.57045988258318,69.59416829745598,69.61787671232877,69.64158512720157,69.66529354207437,69.68900195694717,69.71271037181997,69.73641878669277,69.76012720156557,69.78383561643837,69.80754403131115,69.83125244618395,69.85496086105675,69.87866927592955,69.90237769080235,69.92608610567515,69.94979452054795,69.97350293542075,69.99721135029354,70.02091976516634,70.04462818003914,70.06833659491194,70.09204500978474,70.11575342465754,70.13946183953034,70.16317025440314,70.18687866927593,70.21058708414873,70.23429549902153,70.25800391389433,70.28171232876713,70.30542074363993,70.32912915851273,70.35283757338553,70.37654598825831,70.40025440313111,70.42396281800391,70.44767123287671,70.47137964774952,70.49508806262232,70.51879647749512,70.54250489236792,70.5662133072407,70.5899217221135,70.6136301369863,70.6373385518591,70.6610469667319,70.6847553816047,70.7084637964775,70.7321722113503,70.7558806262231,70.77958904109589,70.80329745596869,70.82700587084149,70.85071428571429,70.87442270058709,70.89813111545989,70.92183953033269,70.94554794520548,70.96925636007828,70.99296477495108,71.01667318982388,71.04038160469668,71.06409001956948,71.08779843444228,71.11150684931508,71.13521526418788,71.15892367906066,71.18263209393346,71.20634050880626,71.23004892367906,71.25375733855186,71.27746575342466,71.30117416829746,71.32488258317026,71.34859099804305,71.37229941291585,71.39600782778865,71.41971624266145,71.44342465753425,71.46713307240705,71.49084148727985,71.51454990215265,71.53825831702544,71.56196673189824,71.56196673189824,71.58567514677104,71.60938356164384,71.63309197651664,71.65680039138944,71.68050880626224,71.70421722113504,71.72792563600783,71.75163405088063,71.77534246575343,71.79905088062623,71.82275929549903,71.84646771037183,71.87017612524463,71.89388454011743,71.91759295499021,71.94130136986301,71.96500978473581,71.98871819960861,72.01242661448141,72.03613502935421,72.05984344422701,72.08355185909981,72.1072602739726,72.1309686888454,72.1546771037182,72.178385518591,72.2020939334638,72.2258023483366,72.2495107632094,72.2732191780822,72.29692759295499,72.32063600782779,72.34434442270059,72.36805283757339,72.39176125244619,72.41546966731899,72.43917808219179,72.46288649706459,72.48659491193737,72.51030332681017,72.53401174168297,72.55772015655577,72.58142857142857,72.60513698630137,72.62884540117417,72.65255381604698,72.67626223091978,72.69997064579256,72.72367906066536,72.74738747553816,72.77109589041096,72.79480430528376,72.81851272015656,72.84222113502936,72.86592954990216,72.88963796477495,72.91334637964775,72.93705479452055,72.96076320939335,72.98447162426615,73.00818003913895,73.03188845401175,73.05559686888455,73.07930528375734,73.10301369863014,73.12672211350294,73.15043052837574,73.17413894324854,73.19784735812134,73.22155577299414,73.24526418786694,73.26897260273972,73.29268101761252,73.31638943248532,73.34009784735812,73.36380626223092,73.38751467710372,73.41122309197652,73.43493150684932,73.45863992172211,73.48234833659491,73.50605675146771,73.52976516634051,73.55347358121331,73.57718199608611,73.60089041095891,73.62459882583171,73.6483072407045,73.6720156555773,73.6957240704501,73.7194324853229,73.7431409001957,73.7668493150685,73.7905577299413,73.8142661448141,73.83797455968688,73.86168297455968,73.88539138943248,73.90909980430528,73.90909980430528,73.93280821917809,73.95651663405089,73.98022504892369,74.00393346379649,74.02764187866927,74.05135029354207,74.07505870841487,74.09876712328767,74.12247553816047,74.14618395303327,74.16989236790607,74.19360078277887,74.21730919765167,74.24101761252446,74.26472602739726,74.28843444227006,74.31214285714286,74.33585127201566,74.35955968688846,74.38326810176126,74.40697651663405,74.43068493150685,74.45439334637965,74.47810176125245,74.50181017612525,74.52551859099805,74.54922700587085,74.57293542074365,74.59664383561645,74.62035225048923,74.64406066536203,74.66776908023483,74.69147749510763,74.71518590998043,74.73889432485323,74.76260273972603,74.78631115459883,74.81001956947162,74.83372798434442,74.85743639921722,74.88114481409002,74.90485322896282,74.92856164383562,74.95227005870842,74.97597847358122,74.99968688845401,75.02339530332681,75.04710371819961,75.07081213307241,75.09452054794521,75.11822896281801,75.14193737769081,75.16564579256361,75.1893542074364,75.2130626223092,75.236771037182,75.2604794520548,75.2841878669276,75.3078962818004,75.3316046966732,75.355313111546,75.37902152641878,75.40272994129158,75.42643835616438,75.45014677103718,75.47385518590998,75.49756360078278,75.52127201565558,75.54498043052838,75.56868884540117,75.59239726027397,75.61610567514677,75.63981409001957,75.66352250489237,75.68723091976517,75.71093933463797,75.73464774951077,75.75835616438357,75.78206457925636,75.80577299412916,75.82948140900196,75.85318982387476,75.87689823874756,75.90060665362036,75.92431506849316,75.94802348336594,75.97173189823874,75.99544031311154,76.01914872798434,76.04285714285714,76.06656555772994,76.09027397260274,76.11398238747555,76.13769080234835,76.16139921722113,76.18510763209393,76.20881604696673,76.23252446183953,76.25623287671233,76.27994129158513,76.30364970645793,76.32735812133072,76.35106653620352,76.37477495107632,76.39848336594912,76.42219178082192,76.44590019569472,76.46960861056752,76.49331702544032,76.51702544031312,76.5407338551859,76.5644422700587,76.5881506849315,76.6118590998043,76.6355675146771,76.6592759295499,76.6829843444227,76.7066927592955,76.73040117416829,76.7541095890411,76.7778180039139,76.8015264187867,76.8252348336595,76.8489432485323,76.8726516634051,76.8963600782779,76.92006849315068,76.94377690802348,76.96748532289628,76.99119373776908,77.01490215264188,77.03861056751468,77.06231898238748,77.08602739726028,77.10973581213307,77.13344422700587,77.15715264187867,77.18086105675147,77.20456947162427,77.22827788649707,77.22827788649707,77.25198630136987,77.27569471624267,77.29940313111547,77.32311154598825,77.34681996086105,77.37052837573385,77.39423679060666,77.41794520547946,77.44165362035226,77.46536203522506,77.48907045009784,77.51277886497064,77.53648727984344,77.56019569471624,77.58390410958904,77.60761252446184,77.63132093933464,77.65502935420744,77.67873776908024,77.70244618395303,77.72615459882583,77.74986301369863,77.77357142857143,77.79727984344423,77.82098825831703,77.84469667318983,77.86840508806262,77.89211350293542,77.91582191780822,77.93953033268102,77.96323874755382,77.98694716242662,78.01065557729942,78.03436399217222,78.05807240704502,78.0817808219178,78.1054892367906,78.1291976516634,78.1529060665362,78.176614481409,78.2003228962818,78.2240313111546,78.24773972602739,78.27144814090019,78.29515655577299,78.31886497064579,78.34257338551859,78.36628180039139,78.38999021526419,78.41369863013699,78.43740704500979,78.46111545988258,78.48482387475538,78.50853228962818,78.53224070450098,78.55594911937378,78.57965753424658,78.60336594911938,78.62707436399216,78.65078277886496,78.67449119373777,78.69819960861057,78.72190802348337,78.74561643835617,78.76932485322897,78.79303326810177,78.81674168297457,78.84045009784737,78.86415851272015,78.88786692759295,78.91157534246575,78.93528375733855,78.95899217221135,78.98270058708415,79.00640900195695,79.03011741682974,79.05382583170254,79.07753424657534,79.10124266144814,79.12495107632094,79.14865949119374,79.17236790606654,79.19607632093934,79.21978473581214,79.24349315068493,79.26720156555773,79.29090998043053,79.31461839530333,79.33832681017613,79.36203522504893,79.38574363992173,79.40945205479451,79.43316046966731,79.45686888454011,79.48057729941291,79.50428571428571,79.52799412915851,79.55170254403131,79.57541095890411,79.59911937377692,79.6228277886497,79.6465362035225,79.6702446183953,79.6939530332681,79.7176614481409,79.7413698630137,79.7650782778865,79.78878669275929,79.81249510763209,79.83620352250489,79.85991193737769,79.88362035225049,79.90732876712329,79.93103718199609,79.95474559686889,79.97845401174169,80.00216242661448,80.02587084148728,80.04957925636008,80.07328767123288,80.09699608610568,80.12070450097848,80.14441291585128,80.16812133072406,80.19182974559686,80.21553816046966,80.23924657534246,80.26295499021526,80.28666340508806,80.31037181996086,80.33408023483366,80.35778864970646,80.38149706457925,80.40520547945205,80.42891389432485,80.45262230919765,80.47633072407045,80.50003913894325,80.52374755381605,80.54745596868885,80.57116438356164,80.59487279843444,80.61858121330724,80.64228962818004,80.66599804305284,80.68970645792564,80.71341487279844,80.73712328767124,80.76083170254404,80.78454011741682,80.80824853228962,80.83195694716242,80.85566536203523,80.87937377690803,80.90308219178083,80.92679060665363,80.95049902152641,80.97420743639921,80.99791585127201,81.02162426614481,81.04533268101761,81.06904109589041,81.09274951076321,81.11645792563601,81.14016634050881,81.1638747553816,81.1875831702544,81.2112915851272,81.235],\n",
       "\"..violinwidth..\":[0.01516505500800416,0.015619556887190671,0.016080226098730624,0.016547021214148198,0.017019911854262357,0.01749887962500669,0.017983919004222425,0.018475038172385896,0.018972259780434354,0.019475621648105127,0.019985177386512728,0.020500996939050442,0.02102316703511514,0.021551791551617364,0.022086991777747676,0.022628906579023347,0.023177692457231204,0.023733523503512374,0.024296591242492668,0.024867104366050007,0.025445288356016716,0.026031384995837292,0.026625651771935863,0.02722836116628365,0.02783979984239065,0.028460267727672933,0.02909007699585667,0.029729550953771403,0.0303790228375482,0.031038834523868276,0.03170933516250087,0.03239087973691643,0.03308382756026103,0.033788540714425205,0.03450538244032688,0.03523471548785966,0.0359769004342184,0.03673229397951537,0.03750124722872946,0.038284103969092,0.039081198952008234,0.03989285618853377,0.04071938726728717,0.04156108970346543,0.04241824532736054,0.0432911187204416,0.04417995570667663,0.04508498190632958,0.04600640135897409,0.04694439522194066,0.04789912054983887,0.04887070916020141,0.04985926658967072,0.050864871144507905,0.05188757304854565,0.05292739369105212,0.05398432497630689,0.055058328776043323,0.05614933648526644,0.05725724868134068,0.05838193488563964,0.0595232334264846,0.060680951401567,0.061854864737548074,0.06304471834408124,0.06425022635908438,0.06547107248173156,0.06670691038931381,0.06795736423385297,0.06922202921413502,0.07050047221866652,0.07179223253493176,0.07309682262027097,0.07441372892966189,0.07574241279572261,0.07708231135630378,0.07843283852514968,0.07979338600123549,0.08116332431256194,0.08254200389038414,0.08392875617006804,0.08532289471501206,0.08672371636032816,0.08813050237323802,0.0895425196274246,0.09095902178885143,0.09237925051084545,0.09380243663651426,0.09522780140683189,0.0966545576729975,0.09808191111189894,0.09950906144375886,0.10093520365123877,0.1023595291994717,0.10378122725666146,0.1051994859150263,0.10661349341198734,0.10802243935158928,0.10942551592621103,0.11082191913865586,0.11221085002472932,0.11359151587638644,0.11496313146549539,0.1163249202681889,0.1176761156896834,0.11901596228932139,0.12034371700545528,0.12165865037961889,0.12296004777925608,0.12424721061806192,0.1255194575727819,0.1267761257950722,0.12801657211677742,0.1292401742467354,0.13044633195693775,0.131634468255625,0.13280403054461232,0.13395449175788313,0.13508535147822018,0.1361961370283957,0.1372864045331875,0.13835573994828063,0.1394037600518856,0.14043011339473158,0.1414344812039284,0.14241657823606083,0.14337615357478026,0.14431299136809878,0.14522691150056974,0.146117770195552,0.1469854605428317,0.14782991294696998,0.1486510954919273,0.14944901421770335,0.15022371330501164,0.1509752751643121,0.1517038204259016,0.15240950782816182,0.153092534001557,0.15375313314646524,0.15439157660351052,0.15500817231564612,0.1556032641818994,0.15617723130335517,0.1567304871226639,0.157263478459085,0.15777668444182436,0.15827061534518402,0.15874581132978152,0.15920284109487484,0.159642300447543,0.16006481079520646,0.16047101756864884,0.16086158858335636,0.16123721234759428,0.16159859632618181,0.16194646516942054,0.16228155891703971,0.16260463118736315,0.16291644736216,0.1632177827777933,0.16350942093337675,0.16379215172658743,0.1640667697276875,0.16433407250204957,0.16459485899115867,0.16484992796160947,0.16510007653108216,0.16534609877962944,0.16558878445386122,0.16582891777078448,0.1660672763271271,0.16630463011898147,0.16654174067552377,0.16677936030944246,0.16701823148551728,0.16725908630757053,0.16750264612276844,0.1677496212409686,0.16800071076555917,0.16825660253097105,0.16851797314080322,0.16878548809933497,0.16905980202803153,0.16934155895759348,0.16963139268510466,0.16992992718492994,0.17023777706121845,0.17055554802919018,0.1708838374118281,0.1712232346381752,0.1715743217291656,0.1719376737567854,0.17231385926238774,0.17270344062017237,0.17310697433218458,0.1735250112416887,0.1739580966524372,0.17440677034217175,0.17487156645966087,0.1753530132956822,0.17585163291961223,0.1763679406746393,0.1769024445261124,0.17745564425909835,0.17802803052289995,0.17862008372201307,0.17923227275477377,0.17986505360278748,0.18051886777604037,0.18119414062043554,0.18189127949629885,0.18261067183816387,0.1833526831078427,0.1833526831078427,0.18411765465440713,0.18490590149623648,0.18571771004167326,0.18655333576610944,0.1874130008644352,0.18829689189873847,0.18920515746192057,0.19013790587847293,0.19109520296406435,0.19207706986575607,0.19308348100465017,0.19411436214253525,0.19516958859364147,0.19624898360195728,0.1973523169036911,0.19847930349338258,0.19962960261091564,0.20080281696522845,0.20199849220889768,0.20321611667601108,0.204455121393821,0.20571488037664037,0.20699471120830729,0.20829387591732787,0.20961158214652503,0.21094698461670955,0.21229918688154834,0.2136672433684874,0.21505016169828844,0.21644690527348606,0.21785639612391322,0.21927751799535444,0.22070911966543164,0.22215001846899873,0.22359900401362964,0.22505484206429427,0.22651627857496248,0.227982043843746,0.22945085676724739,0.23092142916904265,0.23239247017672862,0.23386269062163523,0.23533080743525045,0.23679554801651848,0.23825565454452693,0.23970988821164912,0.2411570333529739,0.2425959014487718,0.24402533497790255,0.24544421110132686,0.24685144515634352,0.24824599394373958,0.2496268587917336,0.2509930883823972,0.2523437813281044,0.25367808848751416,0.25499521501257943,0.2562944221200905,0.2575750285832811,0.2588364119410712,0.2600780094244715,0.2612993186016504,0.26249989774504595,0.2636793659257138,0.26483740284181384,0.26597374838979887,0.2670882019883147,0.26818062166627094,0.26925092292773944,0.27029907740748316,0.2713251113318587,0.2723291038006695,0.27331118490619194,0.2742715337061026,0.2752103760673955,0.27612798239854225,0.27702466528722147,0.27790077706080674,0.27875670728654733,0.27959288022800627,0.2804097522737499,0.2812078093536656,0.28198756435748557,0.28274955456924056,0.2834943391303572,0.28422249654307896,0.28493462222473626,0.28563132612217595,0.28631323039441603,0.286980967170287,0.2876351763864905,0.2882765037101688,0.28890559854871567,0.28952311214825893,0.29012969578088543,0.2907259990194436,0.2907259990194436,0.29131266809749323,0.29189034435082445,0.29245966273585894,0.29302125041921584,0.2935757254318119,0.29412369538003413,0.294665756205803,0.2952024909867463,0.29573446876724097,0.2962622434107283,0.29678635246350793,0.2973073160201639,0.29782563558082603,0.29834179289074153,0.2988562487529485,0.29936944180539643,0.29988178725449055,0.30039367555783436,0.30090547104986126,0.30141751050509336,0.30193010163491885,0.30244352151506065,0.30295801494224756,0.3034737927200603,0.30399102987543064,0.30450986380883316,0.3050303923828341,0.3055526719552605,0.30607671536493364,0.3066024898794898,0.3071299151164396,0.30765886095016187,0.30818914541900144,0.3087205326480602,0.30925273080455973,0.3097853901038569,0.31031810088522377,0.310850391777439,0.3113817279749436,0.3119115096459173,0.31243907049398,0.31296367649541934,0.3134845248338208,0.3140007430537254,0.3145113884545049,0.3150154477449466,0.315511836978168,0.3159994017853386,0.31647691792538846,0.3169430921663153,0.3173965635119807,0.31783590478634355,0.3182596245849824,0.31866616960147326,0.31905392733377064,0.31942122917320753,0.3197663538760343,0.32008753141471186,0.3203829472033186,0.3206507466886052,0.3208890402953322,0.3210959087116719,0.321269408497608,0.3214075779964935,0.32150844352722435,0.3215700258319084,0.32159034675143783,0.3215674360990871,0.32149933870013875,0.3213841215636017,0.32121988115041894,0.3210047507010623,0.3207369075842379,0.3204145806274679,0.32003605738965857,0.32003605738965857,0.31959969133539357,0.3191039088706205,0.3185472161996148,0.3179282059636334,0.3172455636224953,0.3164980735414361,0.31568462474700754,0.31480421631745087,0.31385596237495006,0.3128390966493575,0.3117529765854301,0.31059708696825705,0.3093710430444272,0.30807459311948376,0.30670762061539286,0.3052701455750469,0.30376232560419203,0.3021844562446455,0.3005369707761338,0.29882043944761705,0.29703556814242343,0.29518319648498376,0.29326429540030996,0.2912799641406511,0.28923142679688846,0.2871200283152535,0.2849472300427697,0.28271460482747035,0.28042383170185864,0.278076690180309,0.2756750542030449,0.2732208857610615,0.2707162282378015,0.26816319950458295,0.2655639848076794,0.2629208294855908,0.2602360315554028,0.2575119342072205,0.2547509182454709,0.2519553945154516,0.2491277963527936,0.2462705720925901,0.24338617767378684,0.2404770693730743,0.23754569670096026,0.234594495490967,0.23162588121102531,0.22864224252408907,0.2256459351228666,0.22263927586130872,0.21962453720318653,0.2166039420057059,0.21357965865368586,0.21055379655741466,0.2075284020248452,0.2045054545163964,0.20148686328824028,0.1984744644276459,0.19547001828168797,0.19247520727845466,0.18949163413781966,0.18652082046686289,0.18356420573315615,0.18062314660740866,0.17769891666533674,0.17479270643715789,0.17190562379174984,0.16903869464133275,0.16619286395144361,0.16336899704005675,0.16056788114891063,0.1577902272694389,0.15503667220518094,0.1523077808521315,0.14960404867822277,0.14692590438294528,0.14427371271805342,0.14164777745034648,0.1390483444476329,0.1364756048692008,0.13392969844241864,0.13141071680743657,0.1289187069123951,0.12645367444201755,0.12401558726299954,0.12160437887017474,0.11921995181803857,0.1168621811228607,0.11453091762126509,0.11222599127185297,0.10994721438712902,0.10769438478371988,0.1054672888395835,0.10326570444763958,0.10108940385599235,0.0989381563856477,0.0968117310173643,0.09470989884002931,0.09263243535367767,0.09057912262102318,0.08854975126210336,0.08654412228738599,0.08456204876542023,0.08260335732185019,0.08066788946735626,0.07875550275281491,0.07686607175071132,0.07499948886256434,0.07315566495286399,0.07133452981074041,0.06953603244130582,0.0677601411893337,0.06600684369863866,0.06427614671121797,0.06256807571090486,0.060882674416943144,0.059220004133546285,0.057580142962124686,0.05596318488347145,0.05436923871776144,0.05279842697075523,0.051250884575105175,0.049726757536112255,0.04822620149170224,0.04674938019674901,0.045296463942194505,0.04386762791966648,0.00902063791047152,0.009006328884624541,0.008959052945207489,0.008879490936840899,0.008768707784147902,0.008628137732581429,0.00845956345840404,0.008265089616672766,0.008047111522879385,0.007808279765500428,0.007551461620021702,0.0072797001780716755,0.0069961721174234435,0.006704145020339662,0.006406935100792646,0.006107866128354704,0.005810230241862098,0.005517251233949523,0.005232050763442006,0.004957617821951045,0.004696781649512213,0.004452188167257642,0.00422627987808324,0.004021279083618181,0.0038391741813221542,0.003681708742100683,0.00355037302829436,0.003446397595028909,0.003370748624384905,0.0033241246702608138,0.003306954539781367,0.0033193961013864254,0.0033613358863486273,0.0034323894348899943,0.0035319024254390798,0.0036589527109022256,0.0038123534642202908,0.003990657702355002,0.004192164509120119,0.004414927309553006,0.0046567645592783605,0.004915273199975805,0.005187845196116242,0.005471687409147449,0.005763844984950287,0.006061228331334477,0.006360643648215592,0.0066588268483165755,0.006952480575776673,0.00723831389934713,0.007513084131481393,0.007773640110104011,0.008016966181351053,0.008240226043760618,0.008440805561122533,0.008616353625398419,0.008764820154629416,0.008884490344204049,0.008974014352687517,0.009032431693821234,0.009059189721360487,0.009054155729179489,0.009017622340749888,0.008950306024271392,0.008853338736595967,0.008728252864707178,0.008576959792099331,0.008401722563546443,0.008205123250691677,0.007990025728683963,0.007759534657799139,0.007516951521757389,0.0072657286055970586,0.007009421800929003,0.006751643106709262,0.006496013651812731,0.006246118004958503,0.006005460461807581,0.005777423912579026,0.0055652318006983404,0.005371913588072981,0.005200274049533273,0.005052866631186846,0.004931971027630381,0.004839575063038716,0.004777360902131678,0.004746695569027155,0.0047486257143029,0.0047838765417326625,0.004852854784041855,0.004955655599120813,0.0050920732416859325,0.005261615347631699,0.005463520646728918,0.005696779891782473,0.005960159757370088,0.006252229418114085,0.0065713894652310685,0.006915902761929643,0.0072839267750580755,0.007673546855073908,0.008082809872454466,0.008509757560184971,0.00895245886334477,0.00940904056253673,0.0098777154222129,0.0103568071216111,0.010844771258025786,0.011340211771502073,0.01184189222757717,0.012348741509872597,0.012859853615248084,0.013374481407520152,0.013892024366776017,0.014412010564220614,0.014934073290491474,0.015457922960967981,0.01598331510695652,0.01651001542891467,0.01703776302961681,0.01756623305464151,0.018095000039109573,0.018623503288943195,0.01915101560934563,0.019676616631796963,0.020199171884517166,0.020717318602803528,0.021229459089368158,0.021733762216808568,0.022228173421972086,0.02271043328355677,0.02317810450880938,0.023628606891880198,0.024059259554417196,0.024467329546971065,0.02485008568556227,0.025204856328028963,0.025529089664864977,0.0258204150129776,0.026076703560322833,0.026296127015240017,0.026477212665421423,0.02661889344524904,0.0267205517427918,0.026782055844054273,0.026803788106174897,0.026786664166628088,0.026732142725151745,0.026642225672026832,0.026519448573512384,0.02636686175602721,0.026188002448891325,0.025986858645552693,0.025767825520420208,0.025535655388717608,0.025295402317046082,0.02505236258038007,0.024812012215699886,0.024579942942962826,0.02436179771107355,0.024163207081214128,0.023989727584408815,0.02384678308734404,0.023739610073751638,0.023673207602211317,0.023652292539700755,0.023681260498721258,0.023764152729780576,0.023904629046052794,0.024105946688834787,0.024370944886539823,0.02470203472168145,0.025101193804389722,0.02556996516158495,0.02610945969127067,0.02672036150373402,0.027402935476814796,0.028157036390598553,0.02898211907630355,0.029877249111785097,0.03084111371763203,0.03187203264765918,0.03296796901899739,0.034126540182307985,0.03534502888368031,0.03662039510793887,0.03794928910995019,0.03932806622804405,0.040752804124737266,0.0422193231087229,0.04372321015435756,0.045259847148491905,0.04682444375949452,0.04841207514230643,0.05001772447140687,0.05163633003833353,0.053262836371883365,0.05489224854944585,0.05651968858092033,0.05814045247731323,0.05975006637994356,0.06134433993855625,0.06291941500197566,0.06447180763588509,0.06599844151910023,0.06749667089922803,0.06896429151401443,0.07039953820476473,0.07180106835717368,0.07316793079220532,0.07449952028023478,0.07579551844624377,0.07705582244954493,0.07828046343273207,0.07946951731390361,0.08062301101584672,0.08174082765858683,0.08282261456245239,0.08386769809581382,0.08487500943783123,0.08584302520037555,0.08676972655979989,0.08765258009047595,0.0884885428773639,0.08927409373094544,0.09000529145801385,0.09067786018549183,0.0912873007259852,0.09182902595110709,0.0922985171416732,0.09269149735296701,0.09300411700727591,0.09323314624053575,0.09337616801622953,0.09343176570250189,0.09339969870537841,0.09328105987146465,0.0930784087184122,0.09279587511294822,0.0924392287781399,0.09201591094981437,0.09153502558585506,0.0910072887251668,0.09044493585493683,0.08986158843258123,0.08927208197866172,0.08869225936620716,0.08813873403979469,0.08762862886775509,0.08717929713140819,0.08680803276074106,0.086531777317685,0.08636683139454306,0.08632857803202973,0.08643122547187869,0.08668757605310849,0.0871088273551974,0.087704410807705,0.08848187195117356,0.08944679537922524,0.0906027761503366,0.09195143816540179,0.09349249870040884,0.09522387699882812,0.09714184360123673,0.09924120595404684,0.1015155248263062,0.10395735520143734,0.10655850462373728,0.10931030148737125,0.11220386547344455,0.11523037227838205,0.11838130493850978,0.12164868443996384,0.12502527290251625,0.12850474342741566,0.13208181168407002,0.1357523254540163,0.13951330962387623,0.14336296548823782,0.147300624651219,0.15132665926178804,0.15544235174086196,0.1596497285151561,0.16395136352186548,0.1683501583493067,0.17284910679462762,0.1774510523178446,0.18215844732458578,0.18697312339713668,0.1918960815013453,0.19692731082024167,0.20206564420678852,0.20730865731972709,0.2126526173281333,0.2180924856703464,0.22362197776722684,0.2292336808608013,0.23491922932520068,0.2406695349297706,0.24647506767943833,0.2523261810709607,0.2582134739415221,0.2641281796017288,0.270062571688159,0.27601037518553023,0.28196717039241115,0.28793077726629823,0.29390160760320116,0.2998829728929157,0.3058813364420793,0.3119064994600869,0.3179717122339291,0.3240937032422785,0.33029262103215623,0.3365918858498636,0.3430179503210802,0.3495999708470157,0.3563693937550637,0.3633594625428922,0.3706046547153169,0.37814005866818634,0.3860007027634273,0.3942208501135195,0.40283327361107985,0.41186852637118726,0.42135422298456604,0.43131434680684905,0.4417685979440911,0.4527317956625466,0.46421334768838124,0.4762167973177089,0.4887394574854513,0.5017721390041257,0.5152989781462596,0.5292973666715112,0.5437379853540844,0.5585849401052239,0.5737959979584288,0.5893229185317591,0.6051118751308713,0.621103958425906,0.6372357546303784,0.6534399893260292,0.6534399893260292,0.6696462274994316,0.6857816199612855,0.701771686080559,0.7175411226518323,0.7330146286951257,0.7481177360343985,0.762777635590902,0.7769239894433755,0.7904897188401174,0.8034117584985172,0.8156317677038547,0.8270967889380239,0.8377598450534987,0.8475804663856435,0.8565251396973639,0.8645676715029036,0.8716894591478828,0.8778796640492379,0.8831352827326321,0.8874611127451957,0.8908696121564728,0.8933806531651532,0.8950211722665163,0.8958247214570522,0.8958309270004072,0.8950848642878714,0.893636359227513,0.8915392283195351,0.8888504710539464,0.8856294294399831,0.8819369302932064,0.8778344263274483,0.8733831520997841,0.8686433104294361,0.8636733040637508,0.8585290261205799,0.8532632212363888,0.8479249274467342,0.8425590066845668,0.8372057694754889,0.8372057694754889,0.8319006970151399,0.8266742614117097,0.821551842544093,0.8165537377956217,0.8116952589395798,0.8069869087301192,0.8024346283330749,0.7980401056447538,0.793801133808009,0.7897120088459596,0.7857639552827479,0.7819455688854471,0.7782432662082632,0.7746417314091528,0.7711243517930663,0.7676736346656305,0.7642715993048824,0.7609001391267991,0.7575413503857822,0.7541778249712202,0.7507929059996046,0.7473709059281133,0.7438972878083279,0.7403588110426609,0.7367436435941337,0.7330414430321948,0.729243409079292,0.7253423104668311,0.7213324889307507,0.7172098430957162,0.712971794834324,0.7086172404659695,0.7041464889016165,0.6995611885666144,0.6948642446631343,0.6900597280831893,0.6851527770659226,0.6801494925184167,0.6750568277939529,0.6698824736476326,0.6646347390654366,0.6593224286849272,0.6539547175868388,0.6485410243277081,0.6485410243277081,0.6430908831937898,0.637613816774475,0.6321192100674711,0.6266161874273027,0.6211134937429078,0.6156193812711137,0.61014150355401,0.604686817805761,0.5992614970665894,0.5938708532896095,0.5885192723532984,0.5832101617843328,0.5779459117400252,0.5727278695455096,0.5675563278184691,0.562430525953826,0.5573486644929112,0.5523079316758442,0.5473045412806329,0.5423337806948441,0.5373900680503001,0.532467017181105,0.5275575091405172,0.522653769031087,0.5177474469608562,0.5128297020304209,0.5078912883737619,0.5029226424113901,0.4979139706184496,0.4928553372536312,0.48773675162856117,0.4825482546136851,0.4772800041694439,0.47192235975583974,0.466465965506722,0.46090183205654395,0.4552214168783894,0.44941670293607866,0.44348027537503837,0.4374053958829387,0.431186074248911,0.42481713654753406,0.4182942892783522,0.41161417871099837,0.4047744446265059,0.397773767612539,0.39061190906773274,0.3832897431004807,0.3758092795705928,0.36817367761698744,0.36038724913813885,0.35245545183991767,0.3443848716324114,0.33618319433696786,0.3278591668505116,0.3194225480992217,0.3108840502916796,0.3022552711465341,0.293548617916541,0.28477722415560053,0.2759548602750843,0.26709583900870554,0.25821491695088034,0.2493271933525447,0.2404480073521305,0.23159283479040696,0.22277718570871444,0.21401650356440002,0.20532606711818527,0.19672089585941843,0.18821565973993234,0.17982459388861358,0.17156141887952306,0.16343926702861716,0.15547061509987753,0.1476672237120316,0.14004008365333595,0.13259936923449323,0.12535439873913035,0.11831360196742294,0.11148449481129358,0.10487366074895381,0.09848673910193072,0.09232841985893527,0.0029841285735518674,0.0030028360707133883,0.00301835448585351,0.0030310612924975082,0.0030413994199726796,0.003049877497536197,0.0030570696360992973,0.0030636147492683428,0.003070215419950035,0.003077636323031754,0.0030867022185978948,0.0030982955337383344,0.0031133535542175283,0.0031328652500862823,0.003157867761727927,0.003189442574843707,0.003228711414514493,0.003276831889752871,0.0033349929209127425,0.003404409982989538,0.003486320198262033,0.0035819773119369408,0.0036926465844983607,0.00381959963437076,0.003964109264307629,0.004127444304640421,0.0043108645061814155,0.0045156155151765,0.004742923962247682,0.004993992696742826,0.0052699961973009185,0.005572076188722218,0.005901337494372018,0.006258844152310077,0.006645615822087164,0.007062624507649157,0.0075107916200024445,0.007990985401191716,0.00850401872869879,0.009050647316573105,0.009631568326448523,0.010247419398091342,0.010898778105284373,0.011586161838713657,0.012310028113135264,0.013070775291523434,0.013868743714205916,0.014704217216266968,0.015577425011832876,0.016488543919349504,0.017437700897717512,0.018424975859277676,0.019450404722230308,0.020513982662233855,0.02161566752073786,0.02275538332614935,0.02393302388326008,0.025148456386532587,0.02640152501386456,0.027692054459347054,0.029019853366266536,0.030384717625150527,0.03178643350594892,0.03322478059840389,0.03469953454018401,0.036210469518325725,0.03775736053580593,0.03933998544150985,0.0409581267283179,0.042611573110336955,0.044300120896305785,0.046023575181737414,0.0477817508872869,0.04957447367500503,0.051401580777442585,0.05326292177688492,0.05515835937326781,0.05708777017944843,0.05905104558149448,0.061048092699453604,0.06307883548072536,0.06514321595369964,0.06724119566383599,0.06937275730791899,0.07153790657495254,0.07373667419420789,0.07596911818244168,0.0782353262734435,0.08053541850403692,0.08286954992161874,0.08523791336949008,0.08764074229778991,0.09007831353998272,0.09255094998776474,0.09505902309109807,0.09760295510504377,0.10018322100125293,0.10280034995956286,0.10545492635418996,0.10814759014962963,0.1108790366236364,0.11365001533853988,0.11646132828776008,0.11931382715160858,0.1222084096053266,0.1251460146327263,0.12812761681065016,0.1311542195426858,0.13422684723495126,0.13734653642221092,0.14051432586881246,0.14373124568584933,0.14699830552319457,0.15031648191248417,0.1536867048544036,0.15710984376051815,0.1605866928760625,0.16411795632531948,0.167704232935105,0.17134600100423186,0.17504360319725096,0.17879723174911047,0.1826069141732631,0.1864724996690375,0.1903936464245312,0.1943698100087074,0.19840023304070542,0.20248393631546713,0.20661971155268805,0.21080611592078924,0.2150414684692263,0.2193238485811216,0.22365109653420318,0.22802081623156603,0.23243038013528264,0.23687693640573906,0.24135741821818335,0.24586855519597964,0.2504068868678797,0.2549687780248921,0.2595504358216884,0.2641479284384102,0.2687572050919809,0.27337411716203,0.27799444017589775,0.2826138963803807,0.28722817761538944,0.2918329681967227,0.2964239675122113,0.30099691203752194,0.305547596485144,0.31007189381245565,0.31456577383214707,0.3190253201904109,0.32344674550488234,0.32782640448492967,0.3321608048908922,0.33644661622578387,0.34068067609207636,0.34485999418668734,0.34898175394851033,0.35304331191394234,0.35704219487598216,0.3609760949810275,0.3648428629334029,0.368640499510586,0.3723671456210128,0.3760210711609895,0.37960066294691774,0.3831044120134377,0.3865309005769695,0.3898787889671655,0.39314680282614445,0.39633372086684726,0.39943836346788036,0.4024595823628541,0.40539625165801274,0.4082472603832858,0.4110115067493994,0.41368789424794095,0.41368789424794095,0.4162753296930302,0.41877272326323267,0.4211789905612994,0.423493056668118,0.42571386212653073,0.42784037075142206,0.42987157912517115,0.4318065276031383,0.4336443126228086,0.4353841000831028,0.43702513953782496,0.43856677892939483,0.44000847957648076,0.44134983112187415,0.44259056614516373,0.44373057414840417,0.4447699146319069,0.4457088289913287,0.44654775098601207,0.4472873155517384,0.44792836575803385,0.44847195774058995,0.4489193634723694,0.44927207127212054,0.4495317839854279,0.44970041481060785,0.44978008077875303,0.44977309393363574,0.4496819502920353,0.4495093166980834,0.44925801571551915,0.448931008729162,0.44853137745076743,0.4480623040445855,0.4475270501040766,0.44692893472326817,0.44627131191405445,0.445557547624482,0.444790996612803,0.44397497942803393,0.44311275974027514,0.4422075222533952,0.441262351419324,0.44028021115753974,0.43926392576580603,0.4382161621893314,0.4371394137956875,0.43603598578249053,0.43490798232444355,0.4337572955461762,0.4325855963877696,0.4313943274111313,0.4301846975777115,0.4289576790115588,0.4289576790115588,0.4277140057464625,0.4264541744419741,0.42517844704032953,0.42388685532475406,0.4225792073289915,0.42125509553827817,0.41991390681292246,0.41855483395719567,0.4171768888480934,0.4157789170305234,0.4143596136775435,0.41291754080620496,0.4114511456313552,0.40995877993128776,0.40843872029057116,0.40688918907654686,0.40530837599729275,0.40369446008010845,0.40204563190129317,0.4003601158901678,0.39863619252330523,0.3968722202190526,0.395066656737846,0.39321807989100055,0.39132520735964443,0.3893869154267573,0.38740225642887216,0.38537047474025427,0.38329102111131724,0.3811635651947627,0.3789880061075096,0.37676448089376535,0.37449337077453276,0.37217530509123214,0.3698111628756875,0.3674020720051441,0.36494940592890457,0.36245477798214704,0.35992003333203704,0.35734723863087936,0.35473866948026017,0.3520967958383223,0.34942426552905026,0.3467238860371126,0.3439986047940128,0.3412514881805275,0.33848569948632806,0.33570447607993475,0.33291110605046337,0.3301089045868879,0.3273011903605903,0.3244912621728295,0.3216823761205428,0.31887772352174215,0.31608040982591434,0.31329343471569915,0.31051967358401344,0.30776186054625504,0.3050225731207381,0.30230421868263146,0.29960902276803847,0.29693901927595706,0.2942960425873862,0.29168172159327527,0.28909747559695187,0.28909747559695187,0.2865445120325297,0.2840238259190924,0.28153620095143844,0.2790822121122482,0.2766622296777881,0.27427642447990525,0.27192477428104334,0.26960707111631793,0.26732292945717784,0.2650717950545886,0.2628529543258034,0.2606655441572118,0.2585085620061502,0.2563808761964633,0.2542812363156088,0.25220828363471814,0.25016056148686167,0.248136525552358,0.24613455401294457,0.244152957548622,0.24218998916171536,0.24024385382189234,0.23831271793338923,0.23639471863134684,0.23448797291798595,0.23259058665124535,0.23070066339867748,0.22881631316782053,0.22693566102127746,0.22505685558039448,0.22317807741613507,0.22129754731965923,0.21941353443858327,0.2175243642582065,0.21562842640039198,0.21372418220661785,0.21181017206614947,0.20988502244560858,0.20794745257257016,0.20599628072338602,0.2040304300642826,0.20204893399501464,0.20005094094594605,0.19803571858239088,0.19600265737428246,0.19395127349466526,0.19188121101697078,0.18979224338839598,0.18768427416474343,0.18555733700063487,0.18341159489782954,0.18124733872326682,0.17906498501720683,0.1768650731202206,0.1746482616556405,0.17241532441120672,0.1701671456698958,0.1679047150451998,0.1656291218802715,0.1633415492733836,0.1610432677939438,0.15873562895392085,0.15642005849897384,0.1540980495818595,0.1517711558779757,0.14944098469919384,0.14710919015764934,0.14477746642597278,0.14244754113476976,0.14012116894209253,0.13780012530342184,0.13548620046441218,0.1331811936925302,0.13088690775788492,0.128605143668137,0.12633769565750563,0.12408634642567498,0.12185286261889074,0.11963899054281625,0.11744645209476993,0.11527694090183305,0.11313211865094296,0.11101361159743436,0.10892300723948929,0.10686185114750309,0.10483164393937329,0.10283383839503185,0.1008698367060706,0.09894098785887986,0.09704858515224016,0.09519386385262288,0.09337799899246127,0.09160210331825075,0.08986722539642508,0.08817434788548568,0.0865243859827857,0.08491818605365979,0.08335652444928292,0.081840106517723,0.08036956581023007,0.07894546348191604,0.07756828788274411,0.07623845433128124,0.07495630506007876,0.073722109317998,0.07253606361140195,0.07139829206305477,0.07030884686491214,0.06926770879889772,0.06827478779832812,0.06732992352197083,0.06643288591286602,0.06558337571504011,0.06478102492312526,0.0640253971426447,0.0633159878423004,0.06265222448394481,0.06203346652093531,0.06145900526115797,0.06092806359702839,0.06043979561109559,0.05999328607232409,0.05958754984455659,0.059221531234893696,0.058894103315609715,0.05860406725859804,0.05835015172605983,0.05813101236509421,0.057945231456894765,0.05779131777332793,0.05766770669468999,0.05757276064236762,0.057504769878950514,0.0574619537260646,0.05744246224684125,0.05744437843557127,0.057465720951774775,0.057504447429750444,0.057558458387749305,0.05762560175337114,0.057703678013732045,0.0577904459905313,0.05788362923149514,0.057980923000924126,0.058080001843359694,0.0581785276858387,0.058274158435946584,0.05836455702502499,0.05844740083854086,0.058520391468878934,0.05858126471976108,0.058627800786197,0.05865783452939646,0.058669265762476296,0.0586600694601146,0.058628305803581506,0.05857212997182482,0.05848980158953389,0.05837969374434641,0.05824030148760369,0.0580702497362858,0.05786830049795327,0.0576333593456562,0.05736448107580918,0.05706087448892264,0.056721906240770864,0.05634710371999729,0.05593615691722641,0.05548891926038244,0.05500540740100275,0.05448579994677016,0.053930435146149966,0.053339807541772394,0.05271456361991857,0.0520554964939935,0.051363539670068625,0.05063975995229069,0.04988534955504779,0.04910161749710375,0.04828998036033599,0.04745195250211007,0.046589135815584826,0.045703209136280835,0.044795917395974494,0.04386906062635748,0.042924482914893265,0.04196406141389689,0.04098969550109462,0.04000329618581228,0.03900677584958287,0.038002038403437945,0.03699096993657125,0.03597542992258222,0.034957243040260044,0.033938191656040506,0.03292000900502409,0.0319043730969831,0.030892901363281967,0.02988714605029071,0.02888859035485912,0.02789864528791086,0.02691864724338112,0.02594985624168343,0.024993454809790882,0.024050547453941737,0.023122160676007465,0.022209243480749836,0.021312668318552015,0.020433232406749047,0.019571659372369044,0.01872860115987488,0.01790464014930249,0.01710029143291608,0.017148101276453064,0.017747973887846647,0.018362591148052335,0.018992031895272588,0.019636356599740584,0.020295606306471353,0.020969801611877757,0.021658941681818245,0.022363003318595805,0.023081940084308535,0.02381568148777167,0.024564132241982457,0.025327171598791203,0.0261046527670651,0.02689640242020535,0.027702220298387672,0.028521878910360777,0.029355123339053265,0.030201671154612017,0.031061212437838506,0.03193340991629441,0.03281789921463947,0.033714289220033285,0.03462216256269637,0.03554107621098471,0.036470562179599444,0.037410128348829244,0.03835925939201883,0.039317417807781106,0.040284045052821106,0.04125856277063032,0.04224037411074632,0.04322886513274678,0.04422340628868379,0.04522335397724721,0.046228052162588865,0.0472368340504438,0.04824902381394445,0.0492639383613509,0.050280889137801044,0.05129918395312996,0.052318128827809354,0.0533370298491139,0.05435519502972962,0.055371936161179885,0.05638657065464256,0.057398423361978944,0.05840682837006768,0.059411130761849625,0.060410688337817126,0.06140487329203754,0.062393073837162395,0.06337469577325273,0.06434916399562632,0.06531592393731121,0.06627444294206325,0.06722421156426375,0.06816474479237075,0.06909558319291828,0.0700162939723858,0.0709264719545454,0.07182574047117023,0.0727137521642389,0.07359018969799778,0.07445476637945306,0.0753072266860491,0.07614734669946444,0.07697493444460718,0.07778983013303946,0.07859190631018871,0.07938106790584112,0.08015725218753349,0.08092042861659604,0.0816705986067386,0.08240779518522175,0.08313208255682684,0.08384355557102317,0.08454233909294602,0.08522858727903913,0.08590248275848411,0.08656423572184398,0.0872140829186841,0.08785228656630703,0.08847913317214584,0.08909493227280378,0.08970001509320313,0.09029473312981774,0.09087945666249547,0.09145457319994231,0.092020485864515,0.09257761172256972,0.09312638006721032,0.09366723066088713,0.09420061194589252,0.09472697923138118,0.09524679286610072,0.09576051640654852,0.09626861479075062,0.09677155252829998,0.09726979191766535,0.09776379130208888,0.09825400337562884,0.09874087355104577,0.0992248384012904,0.09970632418630725,0.10018574547672357,0.10066350388573062,0.10113998692010599,0.10161556696082001,0.1020906003830892,0.10256542682499395,0.1030403686129558,0.10351573035140557,0.10399179868291487,0.10446884222388898,0.10494711167965856,0.10542684014144263,0.1059082435662216,0.10639152143905126,0.10687685761578167,0.10736442134253797,0.10785436844667724,0.10834684269228914,0.10884197729164052,0.10933989656234887,0.10984071771844363,0.11034455278194558,0.11085151060009453,0.1113616989519694,0.11187522672694118,0.11239220615622472,0.11291275507774629,0.11343699921364912,0.11396507443901539,0.11449712901982255,0.11503332579776715,0.11557384429939567,0.11611888274699435,0.11666865994890191,0.11722341704732801,0.1177834191023893,0.1183489564919186,0.11892034610764383,0.11949793232957452,0.12008208776188109,0.1206732137151669,0.12127174042183447,0.12187812697319819,0.12249286096910203,0.12311645787302418,0.12374946006798729,0.12439243561102807,0.12504597668646644,0.12571069776075944,0.12638723344429717,0.12707623606805354,0.12777837298555705,0.12849432361313834,0.12922477622383607,0.12997042451267427,0.13073196395324369,0.13151008796758865,0.1323054839333295,0.1331188290536881,0.13395078611762928,0.13480199917867933,0.13567308918208712,0.13656464957087702,0.13747724190198304,0.13841139150403128,0.13936758320847373,0.14034625718564067,0.1413478049169049,0.14237256533350232,0.14342082115166827,0.14449279543262344,0.1455886483945823,0.14670847450237595,0.14785229985850196,0.14902007991744315,0.1502116975429522,0.15142696142570838,0.15266560487632633,0.15392728500616562,0.1552115823057624,0.15651800062802287,0.1578459675805891,0.1591948353290373,0.16056388180982825,0.16195231234921487,0.16335926168163917,0.16478379635855606,0.16622491753611324,0.16768156412770766,0.1691526163051728,0.1706368993302074,0.1721331876956796,0.17364020955462345,0.17515665141311385,0.17668116306174944,0.1782123627192231,0.1797488423603942,0.18128917320041982,0.18283191130585177,0.18437560330313874,0.18591879215473034,0.18746002297290418,0.18899784884157841,0.1905308366166777,0.19205757267610374,0.1935766685910255,0.19508676669099934,0.196586545496404,0.19807472499274192,0.1995500717225943,0.20101140367233453,0.20245759493210633,0.20388758010912866,0.20530035847592326,0.20669499783673956,0.2080706380971364,0.20942649452341652,0.2107618606803684,0.21207611103755858,0.2133687032361973,0.2146391800103926,0.2158871707583687,0.21711239276099442,0.21831465204668,0.21949384390339946,0.22064995304024446,0.2217830534025155,0.22289330764590307,0.2239809662768164,0.22504636646732717,0.22608993055455895,0.22711216423566488,0.2281136544707131,0.2290950671069674,0.23005714423908874,0.23100070132075862,0.23192662404411218,0.2328358650041626,0.2337294401660937,0.2346084251539376,0.23547395137963295,0.23632720203191712,0.23716940794481017,0.23716940794481017,0.2380018433656835,0.23882582164303567,0.23964269085412876,0.24045382939256915,0.2412606415357608,0.2420645530118826,0.24286700658570468,0.2436694576820859,0.24447337006547187,0.2452802115930754,0.24609145005869576,0.2469085491433589,0.24773296448805845,0.24856613990295687,0.2494095037263699,0.2502644653457957,0.25113241189211327,0.2520147051168955,0.25291267846156174,0.25382763432583316,0.25476084154167783,0.25571353305762035,0.25668690383697856,0.2576821089722714,0.25870026201672475,0.25974243353248694,0.2608096498538974,0.2619028920628763,0.2630230951722795,0.2641711475118832,0.26534789031052275,0.266554117466797,0.2677905754997821,0.2690579636701528,0.27035693426129376,0.27168809300909713,0.2730519996684358,0.27444916870361435,0.2758800700895234,0.27734513020971574,0.27884473283720995,0.2803792201835056,0.2819488940010359,0.28355401672415464,0.2851948126336647,0.2868714690299395,0.2885841373997854,0.29033293456238735,0.2921179437799731,0.29393921581917387,0.29579676994952075,0.2976905948660287,0.29962064952342016,0.30158686387022465,0.30358913947172467,0.305627350011551,0.3077013416626034,0.3098109333189296,0.31195591668121425,0.31413605618957674,0.31635108879853446,0.31860072359013886,0.3208846412225271,0.32320249321239114,0.325553901051187,0.3279384551562175,0.33035571365911015,0.33280520103558053,0.3352864065817801,0.33779878274392994,0.340341743309344,0.3429146614683504,0.34551686775799884,0.3481476478997899,0.35080624054498843,0.3534918349423587,0.3562035685443688,0.35894052456908,0.36170172953599994,0.36448615079517993,0.367292694069728,0.37012020103270293,0.3729674469400045,0.37583313834144816,0.378715910892603,0.38161432729022554,0.3845268753542634,0.3874519662793178,0.3903879330782748,0.3933330292404117,0.3962854276257441,0.39924321961663534,0.4022044145468225,0.405166939426872,0.4081286389839137,0.4081286389839137,0.4110872760320122,0.41404053218800363,0.4169860089458723,0.4199212291208999,0.4228436386727567,0.4257506089146396,0.42863943911327335,0.4315073594822965,0.4343515345691205,0.43716906703290526,0.43995700180877967,0.4427123306509164,0.4454319970445165,0.4481129014742863,0.45075190703448953,0.45334584536324524,0.45589152288142215,0.4583857273142375,0.4608252344715436,0.4632068152608184,0.4655272429050359,0.46778330033594967,0.4699717877318328,0.4720895301674604,0.474133385343035,0.47610025135793027,0.47798707449449807,0.47979085697678486,0.4815086646688791,0.48313763467767795,0.4846749828251945,0.4861180109560778,0.4874641140468322,0.48871078708419935,0.48985563168143204,0.4908963624025915,0.49183081276664026,0.49265694090490886,0.4933728348474585,0.49397671741599886,0.4944669507032282,0.4948420401208482,0.49510063800089243,0.495241546737563,0.4952637214592794,0.4951662722232642,0.49494846572754075,0.494609726537823,0.49414963782931554,0.49356794164591633,0.4928645386817629,0.4920394875923805,0.49109300384493015,0.4900254581191713,0.4888373742727386,0.4875294268861838,0.4861024384048962,0.4845573758966119,0.48289534744450635,0.4811175981971411,0.4792255060975005,0.47722057731423856,0.47722057731423856,0.47510444139892144,0.4728788461935544,0.4705456525130349,0.46810682862733166,0.46556444456824136,0.4629206662854323,0.46017774967623987,0.4573380345133002,0.4544039382935991,0.4513779500319283,0.44826262402105177,0.4450605735801083,0.441774464811957,0.4384070103892829,0.43496096338835893,0.4314391111884032,0.42784426945351417,0.42417927621317786,0.42044698605637576,0.4166502644533671,0.4127919822182695,0.4088750101246653,0.4049022136855549,0.4008764481081695,0.39680055343330867,0.3926773498681351,0.388509633320618,0.3843001711431347,0.3800516980920855,0.37576691250977906,0.37144847273424625,0.3670989937420932,0.36272104402896294,0.3583171427316535,0.3538897569954301,0.349441299589538,0.34497412677342554,0.3404905364156353,0.3359927663667735,0.3314829930873944,0.3269633305310201,0.3224358292818799,0.31790247594626314,0.31336519279565844,0.30882583765908184,0.30428620406117884,0.29974802160183245,0.29521295657210755,0.29068261280042135,0.2861585327218578,0.28164219866254303,0.27713503432997844,0.27263840649918075,0.2681536268834577,0.2636819541775846,0.2592245962601624,0.254782712540921,0.25035741643779486,0.24594977796770107,0.2415608264341134,0.23719155319378177,0.23284291448426186,0.2285158342933862,0.2242112072513259,0.21992990152558217,0.21567276169904095,0.21144061161116154,0.20723425714246135,0.2030544889226874,0.19890208494345638,0.19477781305668834,0.19068243334085513,0.18661670031791688,0.18258136500481845,0.17857717678456234,0.17460488508315294,0.1706652408401146,0.16675899776180872,0.16288691334840366,0.15904974968707183,0.1552482740057742,0.15148325898386517,0.14775548281763162,0.14406572904081769,0.14041478610211525,0.13680344670352823,0.13323250690541694,0.12970276500587177,0.12621502020387504,0.12277007105739673,0.11936871374920198,0.11601174017464336,0.11269993586709368,0.10943407777791789,0.10621493192897685,0.1030432509565934,0.09991977156668441,0.09684521192136286,0.09382026897774144,0.09084561579991648,0.08792189886518278,0.08504973538542333,0.08222971066433851,0.07946237551073132,0.07674824372745451,0.07408778969486325,0.0714814460667007,0.6053356821158181,0.6116791122431183,0.6180166450005945,0.624346854379884,0.6306683062069655,0.6369795587596206,0.6432791633954558,0.6495656651901132,0.6558376035854229,0.6620935130471088,0.6683319237317109,0.6745513621623717,0.6807503519131004,0.6869274143011287,0.6930810690869867,0.6992098351818178,0.7053122313615997,0.711386776987766,0.7174319927338103,0.7234464013174116,0.7294285282376024,0.7353769025165056,0.7412900574451591,0.7471665313328775,0.7530048682597112,0.758803618831419,0.7645613409364523,0.770276600504397,0.775947972265332,0.7815740405095334,0.787153399846988,0.7926846559660806,0.7981664263909534,0.8035973412368873,0.808976043963147,0.8143011921226734,0.8195714581080286,0.8247855298929834,0.8299421117691493,0.8350399250769981,0.8400777089307154,0.8450542209362207,0.8499682379017549,0.8548185565404129,0.8596039941640001,0.8643233893675955,0.8689756027042186,0.8735595173489422,0.8780740397519081,0.8825181002795789,0.8868906538436585,0.8911906805170706,0.8954171861364129,0.899569202890298,0.9036457898930202,0.9076460337429536,0.9115690490651627,0.9154139790376511,0.9191799959007292,0.922866301448966,0.9264721275052298,0.9299967363763043,0.9334394212896221,0.9367995068106119,0.9400763492402471,0.9432693369923394,0.9463778909501586,0.9494014648019979,0.9523395453552709,0.9551916528288227,0.9579573411230687,0.9606361980676832,0.9632278456464921,0.9657319401993409,0.9681481726006487,0.9704762684144238,0.9727159880255418,0.9748671267470908,0.9769295149036341,0.9789030178902378,0.9807875362071713,0.9825830054701853,0.9842893963963176,0.9859067147651749,0.98743500135571,0.988874331858493,0.9902248167635341,0.9914866012237323,0.9926598648940365,0.9937448217464724,0.9947417198611573,0.9956508411935157,0.9964725013178747,0.9972070491476979,0.9978548666326985,0.9984163684331343,0.9988920015715891,0.9992822450625765,0.9995876095203426,0.9998086367452386,0.9999458992890911,1.0,0.999971571547022,0.9998612759252322,0.9998612759252322,0.9996698039416577,0.9993978746826176,0.9990462349630151,0.9986156587581495,0.9981069466186349,0.9975209250690297,0.9968584459908085,0.9961203859903044,0.9953076457522917,0.9944211493798684,0.9934618437213351,0.9924306976847608,0.991328701540955,0.9901568662155583,0.9889162225709984,0.9876078206790341,0.98623272908466,0.9847920340621092,0.983286838863722,0.9817182629624573,0.9800874412888042,0.9783955234628727,0.9766436730224425,0.9748330666477307,0.9729648933836772,0.9710403538604896,0.9690606595132389,0.9670270318012605,0.9649407014281188,0.9628029075628968,0.9606148970635437,0.958377923703017,0.9560932473989678,0.9537621334476508,0.951385851762785,0.948965676120058,0.9465028834079352,0.9439987528854524,0.9414545654476365,0.938871602899167,0.9362511472369343,0.9335944799420334,0.9309028812818262,0.9281776296225845,0.9254200007532851,0.9226312672210493,0.9198126976787347,0.9169655562451534,0.9140911018783469,0.911190587762385,0.9082652607080448,0.9053163605677836,0.902345119665352,0.8993527622403703,0.89634050390819,0.8933095511353061,0.8902611007305835,0.8871963393525427,0.8841164430328803,0.8810225767164311,0.8779158938177184,0.8747975357942225,0.8716686317364711,0.8685302979750411,0.8653836377045068,0.8622297406244042,0.8590696825971746,0.8559045253231023,0.8527353160321988,0.8495630871929635,0.8463888562379528,0.843213625306037,0.8400383810012184,0.8368640941678821,0.8336917196822808,0.8305221962600899,0.8273564462798167,0.8241953756218428,0.8210398735228541,0.8178908124454091,0.8147490479623526,0.8116154186558221,0.8084907460304993,0.8053758344408244,0.8022714710318328,0.7991784256932709,0.7960974510266497,0.7930292823248695,0.789974637564038,0.7869342174071356,0.7839087052191017,0.7808987670929827,0.7779050518867311,0.7749281912702658,0.7719687997823784,0.7690274748970887,0.7661047970990312,0.7632013299674851,0.7603176202686059,0.7603176202686059,0.7574541980554815,0.754611576775586,0.7517902533852382,0.7489907084706576,0.7462134063752222,0.7434587953325329,0.7407273076049108,0.738019359626922,0.735335352153576,0.732675670412819,0.7300406842619677,0.7274307483477306,0.7248462022694719,0.7222873707453913,0.7197545637812816,0.7172480768415802,0.7147681910223745,0.7123151732261025,0.7098892763376465,0.7074907394015651,0.7051197878002022,0.7027766334324204,0.7004614748927472,0.6981744976506906,0.6959158742300301,0.6936857643878865,0.6914843152933852,0.6893116617057449,0.6871679261516352,0.6850532191016571,0.6829676391458082,0.6809112731678324,0.6788841965183146,0.6768864731864533,0.6749181559704072,0.6729792866461548,0.6710698961347938,0.6691900046682403,0.667339621953273,0.6655187473339116,0.6637273699520858,0.6619654689065992,0.6602330134103773,0.6585299629460127,0.6568562674196132,0.6552118673129828,0.6535966938341512,0.6520106690663108,0.6504537061151754,0.648925709254828,0.6474265740721011,0.6459561876095506,0.6445144285070847,0.6431011671423098,0.6417162657696647,0.6403595786584186,0.6390309522295969,0.6377302251919154,0.6364572286767993,0.635211786372566,0.6339937146578399,0.6328028227342883,0.6316389127587422,0.630501779974793,0.6293912128439173,0.628306993176222,0.6272488962608648,0.6262166909962229,0.6252101400198707,0.6242289998384285,0.6232730209573313,0.6223419480105816,0.6214355198905205,0.6205534698776668,0.6196955257706611,0.6188614100163456,0.6180508398400083,0.6172635273758146,0.6164991797974363,0.6157574994488966,0.6150381839756306,0.6143409264557607,0.613665415531578,0.613011335541221,0.6123783666505256,0.6117661849850264,0.611174462762074,0.6106028684230355,0.6100510667655287,0.6095187190756477,0.6090054832601197,0.6085110139783416,0.6080349627742201,0.6075769782077555,0.6071367059862912,0.6067137890953459,0.6063078679289514,0.6059185804194057,0.6055455621663456,0.6051884465650539,0.6048468649338941,0.6045204466407765,0.6042088192285517,0.6039116085392273,0.6036284388368963,0.6033589329292761,0.6031027122877424,0.6028593971657483,0.6026286067155238,0.602409959102936,0.6022030716204119,0.6020075607978003,0.6018230425110808,0.6016491320887996,0.6014854444161382,0.6013315940365084,0.601187195250574,0.6010518622126088,0.6009252090240909,0.6008068498244523,0.6006963988788947,0.600593470663195,0.6004976799454226,0.6004086418645029,0.6003259720055596,0.6002492864719803,0.6001782019541492,0.6001123357948076,0.6000513060509959,0.5999947315525497,0.5999422319571215,0.5998934278017113,0.5998479405506945,0.5998053926403444,0.5997654075198523,0.5997276096888567,0.5996916247315058,0.5996570793470751,0.5996236013771781,0.599590819829618,0.599590819829618,0.599558364898924,0.5995258679836405,0.5994929617004298,0.5994592798950708,0.5994244576504316,0.599388131291511,0.5993499383876463,0.5993095177519946,0.5992665094384031,0.5992205547357864,0.5991712961601421,0.5991183774443389,0.5990614435258177,0.5990001405323558,0.5989341157660457,0.5988630176856535,0.598786495887515,0.5987042010851445,0.5986157850877349,0.5985209007777204,0.5984192020875938,0.5983103439761642,0.5981939824044448,0.5980697743113645,0.5979373775895067,0.5977964510610653,0.5976466544542272,0.5974876483801791,0.5973190943109433,0.5971406545582464,0.5969519922536267,0.5967527713299805,0.5965426565047527,0.5963213132649742,0.5960884078543429,0.5958436072625499,0.5955865792170418,0.5953169921774164,0.595034515332636,0.5947388186012458,0.594429572634777,0.5941064488245115,0.5937691193117752,0.5934172570019294,0.5930505355822185,0.5926686295436223,0.5922712142068648,0.5918579657527128,0.5914285612567014,0.5909826787284032,0.5905199971553624,0.5900401965517968,0.5895429580121668,0.5890279637697022,0.5884948972599633,0.587943443189509,0.58737328760973,0.5867841179958995,0.5861756233314813,0.5855474941977202,0.5848994228685434,0.5842311034107706,0.5835422317896376,0.582832505979616,0.5821016260805086,0.5813492944387793,0.5805752157740769,0.5797790973108903,0.5789606489152704,0.5781195832365325,0.5772556158538581,0.576368465427683,0.5754578538557668,0.5745235064338149,0.5735651520205237,0.5725825232068994,0.5715753564896952,0.5705433924488077,0.5694863759284483,0.5684040562219093,0.5672961872597301,0.5661625278010576,0.565002841627989,0.5638168977426752,0.562604470566956,0.5613653401442825,0.5600992923436964,0.5588061190655939,0.5574856184490271,0.5561375950802748,0.5547618602024059,0.5533582319255606,0.5519265354376612,0.5504666032152763,0.5489782752343264,0.5474613991803502,0.5459158306580231,0.5443414333996285,0.5427380794721712,0.5411056494828319,0.5394440327824455,0.5377531276666966,0.5360328415747252,0.5342830912848217,0.5325038031069077,0.5306949130714916,0.528856367114788,0.5269881212596984,0.5250901417923423,0.5231624054338512,0.5212048995071117,0.5192176220981737,0.5172005822120341,0.5151537999225099,0.5130773065159205,0.5109711446283114,0.5088353683759477,0.5066700434788148,0.5044752473768904,0.5022510693389177,0.49999761056346265,0.49771498427201877,0.49540331579394065,0.4930627426429989,0.49069341458534466,0.48829549369871755,0.4858691544226844,0.4834145835997639,0.48093198050726627,0.4784215568797042,0.47588353692163743,0.47331815731082527,0.47072566719158004,0.46810632815820497,0.46546041422845763,0.46278821180692997,0.46009001963830326,0.45736614875042164,0.4546169223871463,0.4518426759309659,0.4490437568153567,0.4462205244268783,0.4433733499970519,0.44050261648401084,0.43760871844399146,0.43469206189271037,0.4317530641566945,0.4287921537146464,0.42580977002893794,0.42280636336734007,0.4197823946150978,0.41673833507750735,0.4136746662731052,0.41059187971765065,0.40749047669905936,0.40437096804347017,0.40123387387263754,0.3980797233528405,0.3949090544355508,0.3917224135900459,0.3885203555282288,0.38530344292188967,0.3820722461126632,0.3788273428149461,0.37556931781204755,0.3722987626458536,0.3690162753002855,0.36572245987887525,0.36241792627672625]\n",
       "}\n",
       "},{\n",
       "\"geom\":\"boxplot\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"alpha\":0.5,\n",
       "\"data\":{\n",
       "\"..middle..\":[61.7915,72.241,47.792,67.048,73.66499999999999],\n",
       "\"..lower..\":[51.3955,69.56,42.361000000000004,58.373000000000005,71.16999999999999],\n",
       "\"..upper..\":[69.51050000000001,75.45599999999999,54.416,71.717,77.555],\n",
       "\"..ymin..\":[28.801,61.036,30.0,40.414,69.12],\n",
       "\"..ymax..\":[82.603,81.757,72.301,80.653,81.235],\n",
       "\"continent\":[\"Asia\",\"Europe\",\"Africa\",\"Americas\",\"Oceania\"]\n",
       "}\n",
       "},{\n",
       "\"geom\":\"point\",\n",
       "\"stat\":\"boxplot_outlier\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"show_legend\":false,\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "\"..middle..\":[61.7915,72.241,72.241,72.241,72.241,72.241,72.241,72.241,72.241,72.241,72.241,72.241,72.241,72.241,72.241,47.792,47.792,47.792,47.792,47.792,47.792,47.792,47.792,47.792,47.792,67.048,73.66499999999999],\n",
       "\"..lower..\":[51.3955,69.56,69.56,69.56,69.56,69.56,69.56,69.56,69.56,69.56,69.56,69.56,69.56,69.56,69.56,42.361000000000004,42.361000000000004,42.361000000000004,42.361000000000004,42.361000000000004,42.361000000000004,42.361000000000004,42.361000000000004,42.361000000000004,42.361000000000004,58.373000000000005,71.16999999999999],\n",
       "\"..upper..\":[69.51050000000001,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,75.45599999999999,54.416,54.416,54.416,54.416,54.416,54.416,54.416,54.416,54.416,54.416,71.717,77.555],\n",
       "\"..ymin..\":[28.801,61.036,61.036,61.036,61.036,61.036,61.036,61.036,61.036,61.036,61.036,61.036,61.036,61.036,61.036,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,40.414,69.12],\n",
       "\"..ymax..\":[82.603,81.757,81.757,81.757,81.757,81.757,81.757,81.757,81.757,81.757,81.757,81.757,81.757,81.757,81.757,72.301,72.301,72.301,72.301,72.301,72.301,72.301,72.301,72.301,72.301,80.653,81.235],\n",
       "\"continent\":[\"Asia\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Europe\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Africa\",\"Americas\",\"Oceania\"],\n",
       "\"lifeExp\":[NaN,55.23,59.28,53.82,58.45,59.6,59.164,59.82,57.996,43.585,48.079,52.098,54.336,57.005,59.507,72.737,73.952,72.801,73.615,74.772,75.744,76.442,23.599,73.042,73.923,37.579,NaN]\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[]\n",
       "};\n",
       "           var plotContainer = document.getElementById(\"x9ypNn\");\n",
       "           window.letsPlotCall(function() {{\n",
       "               LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer);\n",
       "           }});\n",
       "       })();\n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x144b93f10>"
      ]
     },
     "execution_count": 98,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "    ggplot(data = gapminder, \n",
    "       mapping = aes(x = 'continent',\n",
    "                     y = 'lifeExp',\n",
    "                     fill = 'continent')\n",
    "       ) +\n",
    "        geom_violin(alpha=0.5) +\n",
    "        geom_boxplot(alpha = 0.5) +\n",
    "        guides(fill = 'none')  +# Turn off legend\n",
    "        labs(\n",
    "            # title = 'Life Expectancy by Continent',\n",
    "            y = 'Life Expectancy',\n",
    "            # x is nothing\n",
    "            x = 'Continent'\n",
    "        ) \n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# 4. Getting fancier: `plotly`, dashboards, and animations"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 99,
   "metadata": {
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
         "hovertext": [
          "Afghanistan",
          "Bahrain",
          "Bangladesh",
          "Cambodia",
          "China",
          "Hong Kong, China",
          "India",
          "Indonesia",
          "Iran",
          "Iraq",
          "Israel",
          "Japan",
          "Jordan",
          "Korea, Dem. Rep.",
          "Korea, Rep.",
          "Kuwait",
          "Lebanon",
          "Malaysia",
          "Mongolia",
          "Myanmar",
          "Nepal",
          "Oman",
          "Pakistan",
          "Philippines",
          "Saudi Arabia",
          "Singapore",
          "Sri Lanka",
          "Syria",
          "Taiwan",
          "Thailand",
          "Vietnam",
          "West Bank and Gaza",
          "Yemen, Rep."
         ],
         "ids": [
          "Afghanistan",
          "Bahrain",
          "Bangladesh",
          "Cambodia",
          "China",
          "Hong Kong, China",
          "India",
          "Indonesia",
          "Iran",
          "Iraq",
          "Israel",
          "Japan",
          "Jordan",
          "Korea, Dem. Rep.",
          "Korea, Rep.",
          "Kuwait",
          "Lebanon",
          "Malaysia",
          "Mongolia",
          "Myanmar",
          "Nepal",
          "Oman",
          "Pakistan",
          "Philippines",
          "Saudi Arabia",
          "Singapore",
          "Sri Lanka",
          "Syria",
          "Taiwan",
          "Thailand",
          "Vietnam",
          "West Bank and Gaza",
          "Yemen, Rep."
         ],
         "legendgroup": "Asia",
         "marker": {
          "color": "#636efa",
          "size": [
           8425333,
           120447,
           46886859,
           4693836,
           556263527,
           2125900,
           372000000,
           82052000,
           17272000,
           5441766,
           1620914,
           86459025,
           607914,
           8865488,
           20947571,
           160000,
           1439529,
           6748378,
           800663,
           20092996,
           9182536,
           507833,
           41346560,
           22438691,
           4005677,
           1127000,
           7982342,
           3661549,
           8550362,
           21289402,
           26246839,
           1030585,
           4963829
          ],
          "sizemode": "area",
          "sizeref": 435928.2961983471,
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Asia",
         "orientation": "v",
         "showlegend": true,
         "type": "scatter",
         "x": [
          779.4453145,
          9867.084765,
          684.2441716,
          368.4692856,
          400.448611,
          3054.421209,
          546.5657493,
          749.6816546,
          3035.326002,
          4129.766056,
          4086.522128,
          3216.956347,
          1546.907807,
          1088.277758,
          1030.592226,
          108382.3529,
          4834.804067,
          1831.132894,
          786.5668575,
          331,
          545.8657229,
          1828.230307,
          684.5971438,
          1272.880995,
          6459.554823,
          2315.138227,
          1083.53203,
          1643.485354,
          1206.947913,
          757.7974177,
          605.0664917,
          1515.592329,
          781.7175761
         ],
         "xaxis": "x",
         "y": [
          28.801,
          50.939,
          37.484,
          39.417,
          44,
          60.96,
          37.373,
          37.468,
          44.869,
          45.32,
          65.39,
          63.03,
          43.158,
          50.056,
          47.453,
          55.565,
          55.928,
          48.463,
          42.244,
          36.319,
          36.157,
          37.578,
          43.436,
          47.752,
          39.875,
          60.396,
          57.593,
          45.883,
          58.5,
          50.848,
          40.412,
          43.16,
          32.548
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
         "hovertext": [
          "Albania",
          "Austria",
          "Belgium",
          "Bosnia and Herzegovina",
          "Bulgaria",
          "Croatia",
          "Czech Republic",
          "Denmark",
          "Finland",
          "France",
          "Germany",
          "Greece",
          "Hungary",
          "Iceland",
          "Ireland",
          "Italy",
          "Montenegro",
          "Netherlands",
          "Norway",
          "Poland",
          "Portugal",
          "Romania",
          "Serbia",
          "Slovak Republic",
          "Slovenia",
          "Spain",
          "Sweden",
          "Switzerland",
          "Turkey",
          "United Kingdom"
         ],
         "ids": [
          "Albania",
          "Austria",
          "Belgium",
          "Bosnia and Herzegovina",
          "Bulgaria",
          "Croatia",
          "Czech Republic",
          "Denmark",
          "Finland",
          "France",
          "Germany",
          "Greece",
          "Hungary",
          "Iceland",
          "Ireland",
          "Italy",
          "Montenegro",
          "Netherlands",
          "Norway",
          "Poland",
          "Portugal",
          "Romania",
          "Serbia",
          "Slovak Republic",
          "Slovenia",
          "Spain",
          "Sweden",
          "Switzerland",
          "Turkey",
          "United Kingdom"
         ],
         "legendgroup": "Europe",
         "marker": {
          "color": "#EF553B",
          "size": [
           1282697,
           6927772,
           8730405,
           2791000,
           7274900,
           3882229,
           9125183,
           4334000,
           4090500,
           42459667,
           69145952,
           7733250,
           9504000,
           147962,
           2952156,
           47666000,
           413834,
           10381988,
           3327728,
           25730551,
           8526050,
           16630000,
           6860147,
           3558137,
           1489518,
           28549870,
           7124673,
           4815000,
           22235677,
           50430000
          ],
          "sizemode": "area",
          "sizeref": 435928.2961983471,
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Europe",
         "orientation": "v",
         "showlegend": true,
         "type": "scatter",
         "x": [
          1601.056136,
          6137.076492,
          8343.105127,
          973.5331948,
          2444.286648,
          3119.23652,
          6876.14025,
          9692.385245,
          6424.519071,
          7029.809327,
          7144.114393,
          3530.690067,
          5263.673816,
          7267.688428,
          5210.280328,
          4931.404155,
          2647.585601,
          8941.571858,
          10095.42172,
          4029.329699,
          3068.319867,
          3144.613186,
          3581.459448,
          5074.659104,
          4215.041741,
          3834.034742,
          8527.844662,
          14734.23275,
          1969.10098,
          9979.508487
         ],
         "xaxis": "x",
         "y": [
          55.23,
          66.8,
          68,
          53.82,
          59.6,
          61.21,
          66.87,
          70.78,
          66.55,
          67.41,
          67.5,
          65.86,
          64.03,
          72.49,
          66.91,
          65.94,
          59.164,
          72.13,
          72.67,
          61.31,
          59.82,
          61.05,
          57.996,
          64.36,
          65.57,
          64.94,
          71.86,
          69.62,
          43.585,
          69.18
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
         "hovertext": [
          "Algeria",
          "Angola",
          "Benin",
          "Botswana",
          "Burkina Faso",
          "Burundi",
          "Cameroon",
          "Central African Republic",
          "Chad",
          "Comoros",
          "Congo, Dem. Rep.",
          "Congo, Rep.",
          "Cote d'Ivoire",
          "Djibouti",
          "Egypt",
          "Equatorial Guinea",
          "Eritrea",
          "Ethiopia",
          "Gabon",
          "Gambia",
          "Ghana",
          "Guinea",
          "Guinea-Bissau",
          "Kenya",
          "Lesotho",
          "Liberia",
          "Libya",
          "Madagascar",
          "Malawi",
          "Mali",
          "Mauritania",
          "Mauritius",
          "Morocco",
          "Mozambique",
          "Namibia",
          "Niger",
          "Nigeria",
          "Reunion",
          "Rwanda",
          "Sao Tome and Principe",
          "Senegal",
          "Sierra Leone",
          "Somalia",
          "South Africa",
          "Sudan",
          "Swaziland",
          "Tanzania",
          "Togo",
          "Tunisia",
          "Uganda",
          "Zambia",
          "Zimbabwe"
         ],
         "ids": [
          "Algeria",
          "Angola",
          "Benin",
          "Botswana",
          "Burkina Faso",
          "Burundi",
          "Cameroon",
          "Central African Republic",
          "Chad",
          "Comoros",
          "Congo, Dem. Rep.",
          "Congo, Rep.",
          "Cote d'Ivoire",
          "Djibouti",
          "Egypt",
          "Equatorial Guinea",
          "Eritrea",
          "Ethiopia",
          "Gabon",
          "Gambia",
          "Ghana",
          "Guinea",
          "Guinea-Bissau",
          "Kenya",
          "Lesotho",
          "Liberia",
          "Libya",
          "Madagascar",
          "Malawi",
          "Mali",
          "Mauritania",
          "Mauritius",
          "Morocco",
          "Mozambique",
          "Namibia",
          "Niger",
          "Nigeria",
          "Reunion",
          "Rwanda",
          "Sao Tome and Principe",
          "Senegal",
          "Sierra Leone",
          "Somalia",
          "South Africa",
          "Sudan",
          "Swaziland",
          "Tanzania",
          "Togo",
          "Tunisia",
          "Uganda",
          "Zambia",
          "Zimbabwe"
         ],
         "legendgroup": "Africa",
         "marker": {
          "color": "#00cc96",
          "size": [
           9279525,
           4232095,
           1738315,
           442308,
           4469979,
           2445618,
           5009067,
           1291695,
           2682462,
           153936,
           14100005,
           854885,
           2977019,
           63149,
           22223309,
           216964,
           1438760,
           20860941,
           420702,
           284320,
           5581001,
           2664249,
           580653,
           6464046,
           748747,
           863308,
           1019729,
           4762912,
           2917802,
           3838168,
           1022556,
           516556,
           9939217,
           6446316,
           485831,
           3379468,
           33119096,
           257700,
           2534927,
           60011,
           2755589,
           2143249,
           2526994,
           14264935,
           8504667,
           290243,
           8322925,
           1219113,
           3647735,
           5824797,
           2672000,
           3080907
          ],
          "sizemode": "area",
          "sizeref": 435928.2961983471,
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Africa",
         "orientation": "v",
         "showlegend": true,
         "type": "scatter",
         "x": [
          2449.008185,
          3520.610273,
          1062.7522,
          851.2411407,
          543.2552413,
          339.2964587,
          1172.667655,
          1071.310713,
          1178.665927,
          1102.990936,
          780.5423257,
          2125.621418,
          1388.594732,
          2669.529475,
          1418.822445,
          375.6431231,
          328.9405571,
          362.1462796,
          4293.476475,
          485.2306591,
          911.2989371,
          510.1964923,
          299.850319,
          853.540919,
          298.8462121,
          575.5729961,
          2387.54806,
          1443.011715,
          369.1650802,
          452.3369807,
          743.1159097,
          1967.955707,
          1688.20357,
          468.5260381,
          2423.780443,
          761.879376,
          1077.281856,
          2718.885295,
          493.3238752,
          879.5835855,
          1450.356983,
          879.7877358,
          1135.749842,
          4725.295531,
          1615.991129,
          1148.376626,
          716.6500721,
          859.8086567,
          1468.475631,
          734.753484,
          1147.388831,
          406.8841148
         ],
         "xaxis": "x",
         "y": [
          43.077,
          30.015,
          38.223,
          47.622,
          31.975,
          39.031,
          38.523,
          35.463,
          38.092,
          40.715,
          39.143,
          42.111,
          40.477,
          34.812,
          41.893,
          34.482,
          35.928,
          34.078,
          37.003,
          30,
          43.149,
          33.609,
          32.5,
          42.27,
          42.138,
          38.48,
          42.723,
          36.681,
          36.256,
          33.685,
          40.543,
          50.986,
          42.873,
          31.286,
          41.725,
          37.444,
          36.324,
          52.724,
          40,
          46.471,
          37.278,
          30.331,
          32.978,
          45.009,
          38.635,
          41.407,
          41.215,
          38.596,
          44.6,
          39.978,
          42.038,
          48.451
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
         "hovertext": [
          "Argentina",
          "Bolivia",
          "Brazil",
          "Canada",
          "Chile",
          "Colombia",
          "Costa Rica",
          "Cuba",
          "Dominican Republic",
          "Ecuador",
          "El Salvador",
          "Guatemala",
          "Haiti",
          "Honduras",
          "Jamaica",
          "Mexico",
          "Nicaragua",
          "Panama",
          "Paraguay",
          "Peru",
          "Puerto Rico",
          "Trinidad and Tobago",
          "United States",
          "Uruguay",
          "Venezuela"
         ],
         "ids": [
          "Argentina",
          "Bolivia",
          "Brazil",
          "Canada",
          "Chile",
          "Colombia",
          "Costa Rica",
          "Cuba",
          "Dominican Republic",
          "Ecuador",
          "El Salvador",
          "Guatemala",
          "Haiti",
          "Honduras",
          "Jamaica",
          "Mexico",
          "Nicaragua",
          "Panama",
          "Paraguay",
          "Peru",
          "Puerto Rico",
          "Trinidad and Tobago",
          "United States",
          "Uruguay",
          "Venezuela"
         ],
         "legendgroup": "Americas",
         "marker": {
          "color": "#ab63fa",
          "size": [
           17876956,
           2883315,
           56602560,
           14785584,
           6377619,
           12350771,
           926317,
           6007797,
           2491346,
           3548753,
           2042865,
           3146381,
           3201488,
           1517453,
           1426095,
           30144317,
           1165790,
           940080,
           1555876,
           8025700,
           2227000,
           662850,
           157553000,
           2252965,
           5439568
          ],
          "sizemode": "area",
          "sizeref": 435928.2961983471,
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Americas",
         "orientation": "v",
         "showlegend": true,
         "type": "scatter",
         "x": [
          5911.315053,
          2677.326347,
          2108.944355,
          11367.16112,
          3939.978789,
          2144.115096,
          2627.009471,
          5586.53878,
          1397.717137,
          3522.110717,
          3048.3029,
          2428.237769,
          1840.366939,
          2194.926204,
          2898.530881,
          3478.125529,
          3112.363948,
          2480.380334,
          1952.308701,
          3758.523437,
          3081.959785,
          3023.271928,
          13990.48208,
          5716.766744,
          7689.799761
         ],
         "xaxis": "x",
         "y": [
          62.485,
          40.414,
          50.917,
          68.75,
          54.745,
          50.643,
          57.206,
          59.421,
          45.928,
          48.357,
          45.262,
          42.023,
          37.579,
          41.912,
          58.53,
          50.789,
          42.314,
          55.191,
          62.649,
          43.902,
          64.28,
          59.1,
          68.44,
          66.071,
          55.088
         ],
         "yaxis": "y"
        },
        {
         "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
         "hovertext": [
          "Australia",
          "New Zealand"
         ],
         "ids": [
          "Australia",
          "New Zealand"
         ],
         "legendgroup": "Oceania",
         "marker": {
          "color": "#FFA15A",
          "size": [
           8691212,
           1994794
          ],
          "sizemode": "area",
          "sizeref": 435928.2961983471,
          "symbol": "circle"
         },
         "mode": "markers",
         "name": "Oceania",
         "orientation": "v",
         "showlegend": true,
         "type": "scatter",
         "x": [
          10039.59564,
          10556.57566
         ],
         "xaxis": "x",
         "y": [
          69.12,
          69.39
         ],
         "yaxis": "y"
        }
       ],
       "frames": [
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             8425333,
             120447,
             46886859,
             4693836,
             556263527,
             2125900,
             372000000,
             82052000,
             17272000,
             5441766,
             1620914,
             86459025,
             607914,
             8865488,
             20947571,
             160000,
             1439529,
             6748378,
             800663,
             20092996,
             9182536,
             507833,
             41346560,
             22438691,
             4005677,
             1127000,
             7982342,
             3661549,
             8550362,
             21289402,
             26246839,
             1030585,
             4963829
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            779.4453145,
            9867.084765,
            684.2441716,
            368.4692856,
            400.448611,
            3054.421209,
            546.5657493,
            749.6816546,
            3035.326002,
            4129.766056,
            4086.522128,
            3216.956347,
            1546.907807,
            1088.277758,
            1030.592226,
            108382.3529,
            4834.804067,
            1831.132894,
            786.5668575,
            331,
            545.8657229,
            1828.230307,
            684.5971438,
            1272.880995,
            6459.554823,
            2315.138227,
            1083.53203,
            1643.485354,
            1206.947913,
            757.7974177,
            605.0664917,
            1515.592329,
            781.7175761
           ],
           "xaxis": "x",
           "y": [
            28.801,
            50.939,
            37.484,
            39.417,
            44,
            60.96,
            37.373,
            37.468,
            44.869,
            45.32,
            65.39,
            63.03,
            43.158,
            50.056,
            47.453,
            55.565,
            55.928,
            48.463,
            42.244,
            36.319,
            36.157,
            37.578,
            43.436,
            47.752,
            39.875,
            60.396,
            57.593,
            45.883,
            58.5,
            50.848,
            40.412,
            43.16,
            32.548
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             1282697,
             6927772,
             8730405,
             2791000,
             7274900,
             3882229,
             9125183,
             4334000,
             4090500,
             42459667,
             69145952,
             7733250,
             9504000,
             147962,
             2952156,
             47666000,
             413834,
             10381988,
             3327728,
             25730551,
             8526050,
             16630000,
             6860147,
             3558137,
             1489518,
             28549870,
             7124673,
             4815000,
             22235677,
             50430000
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            1601.056136,
            6137.076492,
            8343.105127,
            973.5331948,
            2444.286648,
            3119.23652,
            6876.14025,
            9692.385245,
            6424.519071,
            7029.809327,
            7144.114393,
            3530.690067,
            5263.673816,
            7267.688428,
            5210.280328,
            4931.404155,
            2647.585601,
            8941.571858,
            10095.42172,
            4029.329699,
            3068.319867,
            3144.613186,
            3581.459448,
            5074.659104,
            4215.041741,
            3834.034742,
            8527.844662,
            14734.23275,
            1969.10098,
            9979.508487
           ],
           "xaxis": "x",
           "y": [
            55.23,
            66.8,
            68,
            53.82,
            59.6,
            61.21,
            66.87,
            70.78,
            66.55,
            67.41,
            67.5,
            65.86,
            64.03,
            72.49,
            66.91,
            65.94,
            59.164,
            72.13,
            72.67,
            61.31,
            59.82,
            61.05,
            57.996,
            64.36,
            65.57,
            64.94,
            71.86,
            69.62,
            43.585,
            69.18
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             9279525,
             4232095,
             1738315,
             442308,
             4469979,
             2445618,
             5009067,
             1291695,
             2682462,
             153936,
             14100005,
             854885,
             2977019,
             63149,
             22223309,
             216964,
             1438760,
             20860941,
             420702,
             284320,
             5581001,
             2664249,
             580653,
             6464046,
             748747,
             863308,
             1019729,
             4762912,
             2917802,
             3838168,
             1022556,
             516556,
             9939217,
             6446316,
             485831,
             3379468,
             33119096,
             257700,
             2534927,
             60011,
             2755589,
             2143249,
             2526994,
             14264935,
             8504667,
             290243,
             8322925,
             1219113,
             3647735,
             5824797,
             2672000,
             3080907
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            2449.008185,
            3520.610273,
            1062.7522,
            851.2411407,
            543.2552413,
            339.2964587,
            1172.667655,
            1071.310713,
            1178.665927,
            1102.990936,
            780.5423257,
            2125.621418,
            1388.594732,
            2669.529475,
            1418.822445,
            375.6431231,
            328.9405571,
            362.1462796,
            4293.476475,
            485.2306591,
            911.2989371,
            510.1964923,
            299.850319,
            853.540919,
            298.8462121,
            575.5729961,
            2387.54806,
            1443.011715,
            369.1650802,
            452.3369807,
            743.1159097,
            1967.955707,
            1688.20357,
            468.5260381,
            2423.780443,
            761.879376,
            1077.281856,
            2718.885295,
            493.3238752,
            879.5835855,
            1450.356983,
            879.7877358,
            1135.749842,
            4725.295531,
            1615.991129,
            1148.376626,
            716.6500721,
            859.8086567,
            1468.475631,
            734.753484,
            1147.388831,
            406.8841148
           ],
           "xaxis": "x",
           "y": [
            43.077,
            30.015,
            38.223,
            47.622,
            31.975,
            39.031,
            38.523,
            35.463,
            38.092,
            40.715,
            39.143,
            42.111,
            40.477,
            34.812,
            41.893,
            34.482,
            35.928,
            34.078,
            37.003,
            30,
            43.149,
            33.609,
            32.5,
            42.27,
            42.138,
            38.48,
            42.723,
            36.681,
            36.256,
            33.685,
            40.543,
            50.986,
            42.873,
            31.286,
            41.725,
            37.444,
            36.324,
            52.724,
            40,
            46.471,
            37.278,
            30.331,
            32.978,
            45.009,
            38.635,
            41.407,
            41.215,
            38.596,
            44.6,
            39.978,
            42.038,
            48.451
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             17876956,
             2883315,
             56602560,
             14785584,
             6377619,
             12350771,
             926317,
             6007797,
             2491346,
             3548753,
             2042865,
             3146381,
             3201488,
             1517453,
             1426095,
             30144317,
             1165790,
             940080,
             1555876,
             8025700,
             2227000,
             662850,
             157553000,
             2252965,
             5439568
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            5911.315053,
            2677.326347,
            2108.944355,
            11367.16112,
            3939.978789,
            2144.115096,
            2627.009471,
            5586.53878,
            1397.717137,
            3522.110717,
            3048.3029,
            2428.237769,
            1840.366939,
            2194.926204,
            2898.530881,
            3478.125529,
            3112.363948,
            2480.380334,
            1952.308701,
            3758.523437,
            3081.959785,
            3023.271928,
            13990.48208,
            5716.766744,
            7689.799761
           ],
           "xaxis": "x",
           "y": [
            62.485,
            40.414,
            50.917,
            68.75,
            54.745,
            50.643,
            57.206,
            59.421,
            45.928,
            48.357,
            45.262,
            42.023,
            37.579,
            41.912,
            58.53,
            50.789,
            42.314,
            55.191,
            62.649,
            43.902,
            64.28,
            59.1,
            68.44,
            66.071,
            55.088
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1952-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             8691212,
             1994794
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            10039.59564,
            10556.57566
           ],
           "xaxis": "x",
           "y": [
            69.12,
            69.39
           ],
           "yaxis": "y"
          }
         ],
         "name": "1952-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1957-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             9240934,
             138655,
             51365468,
             5322536,
             637408000,
             2736300,
             409000000,
             90124000,
             19792000,
             6248643,
             1944401,
             91563009,
             746559,
             9411381,
             22611552,
             212846,
             1647412,
             7739235,
             882134,
             21731844,
             9682338,
             561977,
             46679944,
             26072194,
             4419650,
             1445929,
             9128546,
             4149908,
             10164215,
             25041917,
             28998543,
             1070439,
             5498090
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            820.8530296,
            11635.79945,
            661.6374577,
            434.0383364,
            575.9870009,
            3629.076457,
            590.061996,
            858.9002707,
            3290.257643,
            6229.333562,
            5385.278451,
            4317.694365,
            1886.080591,
            1571.134655,
            1487.593537,
            113523.1329,
            6089.786934,
            1810.066992,
            912.6626085,
            350,
            597.9363558,
            2242.746551,
            747.0835292,
            1547.944844,
            8157.591248,
            2843.104409,
            1072.546602,
            2117.234893,
            1507.86129,
            793.5774148,
            676.2854478,
            1827.067742,
            804.8304547
           ],
           "xaxis": "x",
           "y": [
            30.332,
            53.832,
            39.348,
            41.366,
            50.54896,
            64.75,
            40.249,
            39.918,
            47.181,
            48.437,
            67.84,
            65.5,
            45.669,
            54.081,
            52.681,
            58.033,
            59.489,
            52.102,
            45.248,
            41.905,
            37.686,
            40.08,
            45.557,
            51.334,
            42.868,
            63.179,
            61.456,
            48.284,
            62.4,
            53.63,
            42.887,
            45.671,
            33.97
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1957-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             1476505,
             6965860,
             8989111,
             3076000,
             7651254,
             3991242,
             9513758,
             4487831,
             4324000,
             44310863,
             71019069,
             8096218,
             9839000,
             165110,
             2878220,
             49182000,
             442829,
             11026383,
             3491938,
             28235346,
             8817650,
             17829327,
             7271135,
             3844277,
             1533070,
             29841614,
             7363802,
             5126000,
             25670939,
             51430000
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            1942.284244,
            8842.59803,
            9714.960623,
            1353.989176,
            3008.670727,
            4338.231617,
            8256.343918,
            11099.65935,
            7545.415386,
            8662.834898,
            10187.82665,
            4916.299889,
            6040.180011,
            9244.001412,
            5599.077872,
            6248.656232,
            3682.259903,
            11276.19344,
            11653.97304,
            4734.253019,
            3774.571743,
            3943.370225,
            4981.090891,
            6093.26298,
            5862.276629,
            4564.80241,
            9911.878226,
            17909.48973,
            2218.754257,
            11283.17795
           ],
           "xaxis": "x",
           "y": [
            59.28,
            67.48,
            69.24,
            58.45,
            66.61,
            64.77,
            69.03,
            71.81,
            67.49,
            68.93,
            69.1,
            67.86,
            66.41,
            73.47,
            68.9,
            67.81,
            61.448,
            72.99,
            73.44,
            65.77,
            61.51,
            64.1,
            61.685,
            67.45,
            67.85,
            66.66,
            72.49,
            70.56,
            48.079,
            70.42
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1957-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             10270856,
             4561361,
             1925173,
             474639,
             4713416,
             2667518,
             5359923,
             1392284,
             2894855,
             170928,
             15577932,
             940458,
             3300000,
             71851,
             25009741,
             232922,
             1542611,
             22815614,
             434904,
             323150,
             6391288,
             2876726,
             601095,
             7454779,
             813338,
             975950,
             1201578,
             5181679,
             3221238,
             4241884,
             1076852,
             609816,
             11406350,
             7038035,
             548080,
             3692184,
             37173340,
             308700,
             2822082,
             61325,
             3054547,
             2295678,
             2780415,
             16151549,
             9753392,
             326741,
             9452826,
             1357445,
             3950849,
             6675501,
             3016000,
             3646340
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            3013.976023,
            3827.940465,
            959.6010805,
            918.2325349,
            617.1834648,
            379.5646281,
            1313.048099,
            1190.844328,
            1308.495577,
            1211.148548,
            905.8602303,
            2315.056572,
            1500.895925,
            2864.969076,
            1458.915272,
            426.0964081,
            344.1618859,
            378.9041632,
            4976.198099,
            520.9267111,
            1043.561537,
            576.2670245,
            431.7904566,
            944.4383152,
            335.9971151,
            620.9699901,
            3448.284395,
            1589.20275,
            416.3698064,
            490.3821867,
            846.1202613,
            2034.037981,
            1642.002314,
            495.5868333,
            2621.448058,
            835.5234025,
            1100.592563,
            2769.451844,
            540.2893983,
            860.7369026,
            1567.653006,
            1004.484437,
            1258.147413,
            5487.104219,
            1770.337074,
            1244.708364,
            698.5356073,
            925.9083202,
            1395.232468,
            774.3710692,
            1311.956766,
            518.7642681
           ],
           "xaxis": "x",
           "y": [
            45.685,
            31.999,
            40.358,
            49.618,
            34.906,
            40.533,
            40.428,
            37.464,
            39.881,
            42.46,
            40.652,
            45.053,
            42.469,
            37.328,
            44.444,
            35.983,
            38.047,
            36.667,
            38.999,
            32.065,
            44.779,
            34.558,
            33.489,
            44.686,
            45.047,
            39.486,
            45.289,
            38.865,
            37.207,
            35.307,
            42.338,
            58.089,
            45.423,
            33.779,
            45.226,
            38.598,
            37.802,
            55.09,
            41.5,
            48.945,
            39.329,
            31.57,
            34.977,
            47.985,
            39.624,
            43.424,
            42.974,
            41.208,
            47.1,
            42.571,
            44.077,
            50.469
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1957-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             19610538,
             3211738,
             65551171,
             17010154,
             7048426,
             14485993,
             1112300,
             6640752,
             2923186,
             4058385,
             2355805,
             3640876,
             3507701,
             1770390,
             1535090,
             35015548,
             1358828,
             1063506,
             1770902,
             9146100,
             2260000,
             764900,
             171984000,
             2424959,
             6702668
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            6856.856212,
            2127.686326,
            2487.365989,
            12489.95006,
            4315.622723,
            2323.805581,
            2990.010802,
            6092.174359,
            1544.402995,
            3780.546651,
            3421.523218,
            2617.155967,
            1726.887882,
            2220.487682,
            4756.525781,
            4131.546641,
            3457.415947,
            2961.800905,
            2046.154706,
            4245.256698,
            3907.156189,
            4100.3934,
            14847.12712,
            6150.772969,
            9802.466526
           ],
           "xaxis": "x",
           "y": [
            64.399,
            41.89,
            53.285,
            69.96,
            56.074,
            55.118,
            60.026,
            62.325,
            49.828,
            51.356,
            48.57,
            44.142,
            40.696,
            44.665,
            62.61,
            55.19,
            45.432,
            59.201,
            63.196,
            46.263,
            68.54,
            61.8,
            69.49,
            67.044,
            57.907
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1957-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             9712569,
             2229407
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            10949.64959,
            12247.39532
           ],
           "xaxis": "x",
           "y": [
            70.33,
            70.26
           ],
           "yaxis": "y"
          }
         ],
         "name": "1957-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1962-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             10267083,
             171863,
             56839289,
             6083619,
             665770000,
             3305200,
             454000000,
             99028000,
             22874000,
             7240260,
             2310904,
             95831757,
             933559,
             10917494,
             26420307,
             358266,
             1886848,
             8906385,
             1010280,
             23634436,
             10332057,
             628164,
             53100671,
             30325264,
             4943029,
             1750200,
             10421936,
             4834621,
             11918938,
             29263397,
             33796140,
             1133134,
             6120081
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            853.10071,
            12753.27514,
            686.3415538,
            496.9136476,
            487.6740183,
            4692.648272,
            658.3471509,
            849.2897701,
            4187.329802,
            8341.737815,
            7105.630706,
            6576.649461,
            2348.009158,
            1621.693598,
            1536.344387,
            95458.11176,
            5714.560611,
            2036.884944,
            1056.353958,
            388,
            652.3968593,
            2924.638113,
            803.3427418,
            1649.552153,
            11626.41975,
            3674.735572,
            1074.47196,
            2193.037133,
            1822.879028,
            1002.199172,
            772.0491602,
            2198.956312,
            825.6232006
           ],
           "xaxis": "x",
           "y": [
            31.997,
            56.923,
            41.216,
            43.415,
            44.50136,
            67.65,
            43.605,
            42.518,
            49.325,
            51.457,
            69.39,
            68.73,
            48.126,
            56.656,
            55.292,
            60.47,
            62.094,
            55.737,
            48.251,
            45.108,
            39.393,
            43.165,
            47.67,
            54.757,
            45.914,
            65.798,
            62.192,
            50.305,
            65.2,
            56.061,
            45.363,
            48.127,
            35.18
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1962-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             1728137,
             7129864,
             9218400,
             3349000,
             8012946,
             4076557,
             9620282,
             4646899,
             4491443,
             47124000,
             73739117,
             8448233,
             10063000,
             182053,
             2830000,
             50843200,
             474528,
             11805689,
             3638919,
             30329617,
             9019800,
             18680721,
             7616060,
             4237384,
             1582962,
             31158061,
             7561588,
             5666000,
             29788695,
             53292000
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            2312.888958,
            10750.72111,
            10991.20676,
            1709.683679,
            4254.337839,
            5477.890018,
            10136.86713,
            13583.31351,
            9371.842561,
            10560.48553,
            12902.46291,
            6017.190733,
            7550.359877,
            10350.15906,
            6631.597314,
            8243.58234,
            4649.593785,
            12790.84956,
            13450.40151,
            5338.752143,
            4727.954889,
            4734.997586,
            6289.629157,
            7481.107598,
            7402.303395,
            5693.843879,
            12329.44192,
            20431.0927,
            2322.869908,
            12477.17707
           ],
           "xaxis": "x",
           "y": [
            64.82,
            69.54,
            70.25,
            61.93,
            69.51,
            67.13,
            69.9,
            72.35,
            68.75,
            70.51,
            70.3,
            69.51,
            67.96,
            73.68,
            70.29,
            69.24,
            63.728,
            73.23,
            73.47,
            67.64,
            64.39,
            66.8,
            64.531,
            70.33,
            69.15,
            69.69,
            73.37,
            71.32,
            52.098,
            70.76
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1962-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             11000948,
             4826015,
             2151895,
             512764,
             4919632,
             2961915,
             5793633,
             1523478,
             3150417,
             191689,
             17486434,
             1047924,
             3832408,
             89898,
             28173309,
             249220,
             1666618,
             25145372,
             455661,
             374020,
             7355248,
             3140003,
             627820,
             8678557,
             893143,
             1112796,
             1441863,
             5703324,
             3628608,
             4690372,
             1146757,
             701016,
             13056604,
             7788944,
             621392,
             4076008,
             41871351,
             358900,
             3051242,
             65345,
             3430243,
             2467895,
             3080153,
             18356657,
             11183227,
             370006,
             10863958,
             1528098,
             4286552,
             7688797,
             3421000,
             4277736
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            2550.81688,
            4269.276742,
            949.4990641,
            983.6539764,
            722.5120206,
            355.2032273,
            1399.607441,
            1193.068753,
            1389.817618,
            1406.648278,
            896.3146335,
            2464.783157,
            1728.869428,
            3020.989263,
            1693.335853,
            582.8419714,
            380.9958433,
            419.4564161,
            6631.459222,
            599.650276,
            1190.041118,
            686.3736739,
            522.0343725,
            896.9663732,
            411.8006266,
            634.1951625,
            6757.030816,
            1643.38711,
            427.9010856,
            496.1743428,
            1055.896036,
            2529.067487,
            1566.353493,
            556.6863539,
            3173.215595,
            997.7661127,
            1150.927478,
            3173.72334,
            597.4730727,
            1071.551119,
            1654.988723,
            1116.639877,
            1369.488336,
            5768.729717,
            1959.593767,
            1856.182125,
            722.0038073,
            1067.53481,
            1660.30321,
            767.2717398,
            1452.725766,
            527.2721818
           ],
           "xaxis": "x",
           "y": [
            48.303,
            34,
            42.618,
            51.52,
            37.814,
            42.045,
            42.643,
            39.475,
            41.716,
            44.467,
            42.122,
            48.435,
            44.93,
            39.693,
            46.992,
            37.485,
            40.158,
            40.059,
            40.489,
            33.896,
            46.452,
            35.753,
            34.488,
            47.949,
            47.747,
            40.502,
            47.808,
            40.848,
            38.41,
            36.936,
            44.248,
            60.246,
            47.924,
            36.161,
            48.386,
            39.487,
            39.36,
            57.666,
            43,
            51.893,
            41.454,
            32.767,
            36.981,
            49.951,
            40.87,
            44.992,
            44.246,
            43.922,
            49.579,
            45.344,
            46.023,
            52.358
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1962-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             21283783,
             3593918,
             76039390,
             18985849,
             7961258,
             17009885,
             1345187,
             7254373,
             3453434,
             4681707,
             2747687,
             4208858,
             3880130,
             2090162,
             1665128,
             41121485,
             1590597,
             1215725,
             2009813,
             10516500,
             2448046,
             887498,
             186538000,
             2598466,
             8143375
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            7133.166023,
            2180.972546,
            3336.585802,
            13462.48555,
            4519.094331,
            2492.351109,
            3460.937025,
            5180.75591,
            1662.137359,
            4086.114078,
            3776.803627,
            2750.364446,
            1796.589032,
            2291.156835,
            5246.107524,
            4581.609385,
            3634.364406,
            3536.540301,
            2148.027146,
            4957.037982,
            5108.34463,
            4997.523971,
            16173.14586,
            5603.357717,
            8422.974165
           ],
           "xaxis": "x",
           "y": [
            65.142,
            43.428,
            55.665,
            71.3,
            57.924,
            57.863,
            62.842,
            65.246,
            53.459,
            54.64,
            52.307,
            46.954,
            43.59,
            48.041,
            65.61,
            58.299,
            48.632,
            61.817,
            64.361,
            49.096,
            69.62,
            64.9,
            70.21,
            68.253,
            60.77
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1962-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             10794968,
             2488550
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            12217.22686,
            13175.678
           ],
           "xaxis": "x",
           "y": [
            70.93,
            71.24
           ],
           "yaxis": "y"
          }
         ],
         "name": "1962-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1967-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             11537966,
             202182,
             62821884,
             6960067,
             754550000,
             3722800,
             506000000,
             109343000,
             26538000,
             8519282,
             2693585,
             100825279,
             1255058,
             12617009,
             30131000,
             575003,
             2186894,
             10154878,
             1149500,
             25870271,
             11261690,
             714775,
             60641899,
             35356600,
             5618198,
             1977600,
             11737396,
             5680812,
             13648692,
             34024249,
             39463910,
             1142636,
             6740785
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            836.1971382,
            14804.6727,
            721.1860862,
            523.4323142,
            612.7056934,
            6197.962814,
            700.7706107,
            762.4317721,
            5906.731805,
            8931.459811,
            8393.741404,
            9847.788607,
            2741.796252,
            2143.540609,
            2029.228142,
            80894.88326,
            6006.983042,
            2277.742396,
            1226.04113,
            349,
            676.4422254,
            4720.942687,
            942.4082588,
            1814.12743,
            16903.04886,
            4977.41854,
            1135.514326,
            1881.923632,
            2643.858681,
            1295.46066,
            637.1232887,
            2649.715007,
            862.4421463
           ],
           "xaxis": "x",
           "y": [
            34.02,
            59.923,
            43.453,
            45.415,
            58.38112,
            70,
            47.193,
            45.964,
            52.469,
            54.459,
            70.75,
            71.43,
            51.629,
            59.942,
            57.716,
            64.624,
            63.87,
            59.371,
            51.253,
            49.379,
            41.472,
            46.988,
            49.8,
            56.393,
            49.901,
            67.946,
            64.266,
            53.655,
            67.5,
            58.285,
            47.838,
            51.631,
            36.984
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1967-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             1984060,
             7376998,
             9556500,
             3585000,
             8310226,
             4174366,
             9835109,
             4838800,
             4605744,
             49569000,
             76368453,
             8716441,
             10223422,
             198676,
             2900100,
             52667100,
             501035,
             12596822,
             3786019,
             31785378,
             9103000,
             19284814,
             7971222,
             4442238,
             1646912,
             32850275,
             7867931,
             6063000,
             33411317,
             54959000
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            2760.196931,
            12834.6024,
            13149.04119,
            2172.352423,
            5577.0028,
            6960.297861,
            11399.44489,
            15937.21123,
            10921.63626,
            12999.91766,
            14745.62561,
            8513.097016,
            9326.64467,
            13319.89568,
            7655.568963,
            10022.40131,
            5907.850937,
            15363.25136,
            16361.87647,
            6557.152776,
            6361.517993,
            6470.866545,
            7991.707066,
            8412.902397,
            9405.489397,
            7993.512294,
            15258.29697,
            22966.14432,
            2826.356387,
            14142.85089
           ],
           "xaxis": "x",
           "y": [
            66.22,
            70.14,
            70.94,
            64.79,
            70.42,
            68.5,
            70.38,
            72.96,
            69.83,
            71.55,
            70.8,
            71,
            69.5,
            73.73,
            71.08,
            71.06,
            67.178,
            73.82,
            74.08,
            69.61,
            66.6,
            66.8,
            66.914,
            70.98,
            69.18,
            71.44,
            74.16,
            72.77,
            54.336,
            71.36
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1967-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             12760499,
             5247469,
             2427334,
             553541,
             5127935,
             3330989,
             6335506,
             1733638,
             3495967,
             217378,
             19941073,
             1179760,
             4744870,
             127617,
             31681188,
             259864,
             1820319,
             27860297,
             489004,
             439593,
             8490213,
             3451418,
             601287,
             10191512,
             996380,
             1279406,
             1759224,
             6334556,
             4147252,
             5212416,
             1230542,
             789309,
             14770296,
             8680909,
             706640,
             4534062,
             47287752,
             414024,
             3451079,
             70787,
             3965841,
             2662190,
             3428839,
             20997321,
             12716129,
             420690,
             12607312,
             1735550,
             4786986,
             8900294,
             3900000,
             4995432
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            3246.991771,
            5522.776375,
            1035.831411,
            1214.709294,
            794.8265597,
            412.9775136,
            1508.453148,
            1136.056615,
            1196.810565,
            1876.029643,
            861.5932424,
            2677.939642,
            2052.050473,
            3020.050513,
            1814.880728,
            915.5960025,
            468.7949699,
            516.1186438,
            8358.761987,
            734.7829124,
            1125.69716,
            708.7595409,
            715.5806402,
            1056.736457,
            498.6390265,
            713.6036483,
            18772.75169,
            1634.047282,
            495.5147806,
            545.0098873,
            1421.145193,
            2475.387562,
            1711.04477,
            566.6691539,
            3793.694753,
            1054.384891,
            1014.514104,
            4021.175739,
            510.9637142,
            1384.840593,
            1612.404632,
            1206.043465,
            1284.73318,
            7114.477971,
            1687.997641,
            2613.101665,
            848.2186575,
            1477.59676,
            1932.360167,
            908.9185217,
            1777.077318,
            569.7950712
           ],
           "xaxis": "x",
           "y": [
            51.407,
            35.985,
            44.885,
            53.298,
            40.697,
            43.548,
            44.799,
            41.478,
            43.601,
            46.472,
            44.056,
            52.04,
            47.35,
            42.074,
            49.293,
            38.987,
            42.189,
            42.115,
            44.598,
            35.857,
            48.072,
            37.197,
            35.492,
            50.654,
            48.492,
            41.536,
            50.227,
            42.881,
            39.487,
            38.487,
            46.289,
            61.557,
            50.335,
            38.113,
            51.159,
            40.118,
            41.04,
            60.542,
            44.1,
            54.425,
            43.563,
            34.113,
            38.977,
            51.927,
            42.858,
            46.633,
            45.757,
            46.769,
            52.053,
            48.051,
            47.768,
            53.995
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1967-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             22934225,
             4040665,
             88049823,
             20819767,
             8858908,
             19764027,
             1588717,
             8139332,
             4049146,
             5432424,
             3232927,
             4690773,
             4318137,
             2500689,
             1861096,
             47995559,
             1865490,
             1405486,
             2287985,
             12132200,
             2648961,
             960155,
             198712000,
             2748579,
             9709552
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            8052.953021,
            2586.886053,
            3429.864357,
            16076.58803,
            5106.654313,
            2678.729839,
            4161.727834,
            5690.268015,
            1653.723003,
            4579.074215,
            4358.595393,
            3242.531147,
            1452.057666,
            2538.269358,
            6124.703451,
            5754.733883,
            4643.393534,
            4421.009084,
            2299.376311,
            5788.09333,
            6929.277714,
            5621.368472,
            19530.36557,
            5444.61962,
            9541.474188
           ],
           "xaxis": "x",
           "y": [
            65.634,
            45.032,
            57.632,
            72.13,
            60.523,
            59.963,
            65.424,
            68.29,
            56.751,
            56.678,
            55.855,
            50.016,
            46.243,
            50.924,
            67.51,
            60.11,
            51.884,
            64.071,
            64.951,
            51.445,
            71.1,
            65.4,
            70.76,
            68.468,
            63.479
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1967-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             11872264,
             2728150
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            14526.12465,
            14463.91893
           ],
           "xaxis": "x",
           "y": [
            71.1,
            71.52
           ],
           "yaxis": "y"
          }
         ],
         "name": "1967-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1972-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             13079460,
             230800,
             70759295,
             7450606,
             862030000,
             4115700,
             567000000,
             121282000,
             30614000,
             10061506,
             3095893,
             107188273,
             1613551,
             14781241,
             33505000,
             841934,
             2680018,
             11441462,
             1320500,
             28466390,
             12412593,
             829050,
             69325921,
             40850141,
             6472756,
             2152400,
             13016733,
             6701172,
             15226039,
             39276153,
             44655014,
             1089572,
             7407075
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            739.9811058,
            18268.65839,
            630.2336265,
            421.6240257,
            676.9000921,
            8315.928145,
            724.032527,
            1111.107907,
            9613.818607,
            9576.037596,
            12786.93223,
            14778.78636,
            2110.856309,
            3701.621503,
            3030.87665,
            109347.867,
            7486.384341,
            2849.09478,
            1421.741975,
            357,
            674.7881296,
            10618.03855,
            1049.938981,
            1989.37407,
            24837.42865,
            8597.756202,
            1213.39553,
            2571.423014,
            4062.523897,
            1524.358936,
            699.5016441,
            3133.409277,
            1265.047031
           ],
           "xaxis": "x",
           "y": [
            36.088,
            63.3,
            45.252,
            40.317,
            63.11888,
            72,
            50.651,
            49.203,
            55.234,
            56.95,
            71.63,
            73.42,
            56.528,
            63.983,
            62.612,
            67.712,
            65.421,
            63.01,
            53.754,
            53.07,
            43.971,
            52.143,
            51.929,
            58.065,
            53.886,
            69.521,
            65.042,
            57.296,
            69.39,
            60.405,
            50.254,
            56.532,
            39.848
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1972-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             2263554,
             7544201,
             9709100,
             3819000,
             8576200,
             4225310,
             9862158,
             4991596,
             4639657,
             51732000,
             78717088,
             8888628,
             10394091,
             209275,
             3024400,
             54365564,
             527678,
             13329874,
             3933004,
             33039545,
             8970450,
             20662648,
             8313288,
             4593433,
             1694510,
             34513161,
             8122293,
             6401400,
             37492953,
             56079000
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            3313.422188,
            16661.6256,
            16672.14356,
            2860.16975,
            6597.494398,
            9164.090127,
            13108.4536,
            18866.20721,
            14358.8759,
            16107.19171,
            18016.18027,
            12724.82957,
            10168.65611,
            15798.06362,
            9530.772896,
            12269.27378,
            7778.414017,
            18794.74567,
            18965.05551,
            8006.506993,
            9022.247417,
            8011.414402,
            10522.06749,
            9674.167626,
            12383.4862,
            10638.75131,
            17832.02464,
            27195.11304,
            3450.69638,
            15895.11641
           ],
           "xaxis": "x",
           "y": [
            67.69,
            70.63,
            71.44,
            67.45,
            70.9,
            69.61,
            70.29,
            73.47,
            70.87,
            72.38,
            71,
            72.34,
            69.76,
            74.46,
            71.28,
            72.19,
            70.636,
            73.75,
            74.34,
            70.85,
            69.26,
            69.21,
            68.7,
            70.35,
            69.82,
            73.06,
            74.72,
            73.78,
            57.005,
            72.01
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1972-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             14760787,
             5894858,
             2761407,
             619351,
             5433886,
             3529983,
             7021028,
             1927260,
             3899068,
             250027,
             23007669,
             1340458,
             6071696,
             178848,
             34807417,
             277603,
             2260187,
             30770372,
             537977,
             517101,
             9354120,
             3811387,
             625361,
             12044785,
             1116779,
             1482628,
             2183877,
             7082430,
             4730997,
             5828158,
             1332786,
             851334,
             16660670,
             9809596,
             821782,
             5060262,
             53740085,
             461633,
             3992121,
             76595,
             4588696,
             2879013,
             3840161,
             23935810,
             14597019,
             480105,
             14706593,
             2056351,
             5303507,
             10190285,
             4506497,
             5861135
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            4182.663766,
            5473.288005,
            1085.796879,
            2263.611114,
            854.7359763,
            464.0995039,
            1684.146528,
            1070.013275,
            1104.103987,
            1937.577675,
            904.8960685,
            3213.152683,
            2378.201111,
            3694.212352,
            2024.008147,
            672.4122571,
            514.3242082,
            566.2439442,
            11401.94841,
            756.0868363,
            1178.223708,
            741.6662307,
            820.2245876,
            1222.359968,
            496.5815922,
            803.0054535,
            21011.49721,
            1748.562982,
            584.6219709,
            581.3688761,
            1586.851781,
            2575.484158,
            1930.194975,
            724.9178037,
            3746.080948,
            954.2092363,
            1698.388838,
            5047.658563,
            590.5806638,
            1532.985254,
            1597.712056,
            1353.759762,
            1254.576127,
            7765.962636,
            1659.652775,
            3364.836625,
            915.9850592,
            1649.660188,
            2753.285994,
            950.735869,
            1773.498265,
            799.3621758
           ],
           "xaxis": "x",
           "y": [
            54.518,
            37.928,
            47.014,
            56.024,
            43.591,
            44.057,
            47.049,
            43.457,
            45.569,
            48.944,
            45.989,
            54.907,
            49.801,
            44.366,
            51.137,
            40.516,
            44.142,
            43.515,
            48.69,
            38.308,
            49.875,
            38.842,
            36.486,
            53.559,
            49.767,
            42.614,
            52.773,
            44.851,
            41.766,
            39.977,
            48.437,
            62.944,
            52.862,
            40.328,
            53.867,
            40.546,
            42.821,
            64.274,
            44.6,
            56.48,
            45.815,
            35.4,
            40.973,
            53.696,
            45.083,
            49.552,
            47.62,
            49.759,
            55.602,
            51.016,
            50.107,
            55.635
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1972-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             24779799,
             4565872,
             100840058,
             22284500,
             9717524,
             22542890,
             1834796,
             8831348,
             4671329,
             6298651,
             3790903,
             5149581,
             4698301,
             2965146,
             1997616,
             55984294,
             2182908,
             1616384,
             2614104,
             13954700,
             2847132,
             975199,
             209896000,
             2829526,
             11515649
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            9443.038526,
            2980.331339,
            4985.711467,
            18970.57086,
            5494.024437,
            3264.660041,
            5118.146939,
            5305.445256,
            2189.874499,
            5280.99471,
            4520.246008,
            4031.408271,
            1654.456946,
            2529.842345,
            7433.889293,
            6809.40669,
            4688.593267,
            5364.249663,
            2523.337977,
            5937.827283,
            9123.041742,
            6619.551419,
            21806.03594,
            5703.408898,
            10505.25966
           ],
           "xaxis": "x",
           "y": [
            67.065,
            46.714,
            59.504,
            72.88,
            63.441,
            61.623,
            67.849,
            70.723,
            59.631,
            58.796,
            58.207,
            53.738,
            48.042,
            53.884,
            69,
            62.361,
            55.151,
            66.216,
            65.815,
            55.448,
            72.16,
            65.9,
            71.34,
            68.673,
            65.712
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1972-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             13177000,
             2929100
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            16788.62948,
            16046.03728
           ],
           "xaxis": "x",
           "y": [
            71.93,
            71.89
           ],
           "yaxis": "y"
          }
         ],
         "name": "1972-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1977-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             14880372,
             297410,
             80428306,
             6978607,
             943455000,
             4583700,
             634000000,
             136725000,
             35480679,
             11882916,
             3495918,
             113872473,
             1937652,
             16325320,
             36436000,
             1140357,
             3115787,
             12845381,
             1528000,
             31528087,
             13933198,
             1004533,
             78152686,
             46850962,
             8128505,
             2325300,
             14116836,
             7932503,
             16785196,
             44148285,
             50533506,
             1261091,
             8403990
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            786.11336,
            19340.10196,
            659.8772322,
            524.9721832,
            741.2374699,
            11186.14125,
            813.337323,
            1382.702056,
            11888.59508,
            14688.23507,
            13306.61921,
            16610.37701,
            2852.351568,
            4106.301249,
            4657.22102,
            59265.47714,
            8659.696836,
            3827.921571,
            1647.511665,
            371,
            694.1124398,
            11848.34392,
            1175.921193,
            2373.204287,
            34167.7626,
            11210.08948,
            1348.775651,
            3195.484582,
            5596.519826,
            1961.224635,
            713.5371196,
            3682.831494,
            1829.765177
           ],
           "xaxis": "x",
           "y": [
            38.438,
            65.593,
            46.923,
            31.22,
            63.96736,
            73.6,
            54.208,
            52.702,
            57.702,
            60.413,
            73.06,
            75.38,
            61.134,
            67.159,
            64.766,
            69.343,
            66.099,
            65.256,
            55.491,
            56.059,
            46.748,
            57.367,
            54.043,
            60.06,
            58.69,
            70.795,
            65.949,
            61.195,
            70.59,
            62.494,
            55.764,
            60.765,
            44.175
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1977-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             2509048,
             7568430,
             9821800,
             4086000,
             8797022,
             4318673,
             10161915,
             5088419,
             4738902,
             53165019,
             78160773,
             9308479,
             10637171,
             221823,
             3271900,
             56059245,
             560073,
             13852989,
             4043205,
             34621254,
             9662600,
             21658597,
             8686367,
             4827803,
             1746919,
             36439000,
             8251648,
             6316424,
             42404033,
             56179000
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            3533.00391,
            19749.4223,
            19117.97448,
            3528.481305,
            7612.240438,
            11305.38517,
            14800.16062,
            20422.9015,
            15605.42283,
            18292.63514,
            20512.92123,
            14195.52428,
            11674.83737,
            19654.96247,
            11150.98113,
            14255.98475,
            9595.929905,
            21209.0592,
            23311.34939,
            9508.141454,
            10172.48572,
            9356.39724,
            12980.66956,
            10922.66404,
            15277.03017,
            13236.92117,
            18855.72521,
            26982.29052,
            4269.122326,
            17428.74846
           ],
           "xaxis": "x",
           "y": [
            68.93,
            72.17,
            72.8,
            69.86,
            70.81,
            70.64,
            70.71,
            74.69,
            72.52,
            73.83,
            72.5,
            73.68,
            69.95,
            76.11,
            72.03,
            73.48,
            73.066,
            75.24,
            75.37,
            70.67,
            70.41,
            69.46,
            70.3,
            70.45,
            70.97,
            74.39,
            75.44,
            75.39,
            59.507,
            72.76
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1977-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             17152804,
             6162675,
             3168267,
             781472,
             5889574,
             3834415,
             7959865,
             2167533,
             4388260,
             304739,
             26480870,
             1536769,
             7459574,
             228694,
             38783863,
             192675,
             2512642,
             34617799,
             706367,
             608274,
             10538093,
             4227026,
             745228,
             14500404,
             1251524,
             1703617,
             2721783,
             8007166,
             5637246,
             6491649,
             1456688,
             913025,
             18396941,
             11127868,
             977026,
             5682086,
             62209173,
             492095,
             4657072,
             86796,
             5260855,
             3140897,
             4353666,
             27129932,
             17104986,
             551425,
             17129565,
             2308582,
             6005061,
             11457758,
             5216550,
             6642107
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            4910.416756,
            3008.647355,
            1029.161251,
            3214.857818,
            743.3870368,
            556.1032651,
            1783.432873,
            1109.374338,
            1133.98495,
            1172.603047,
            795.757282,
            3259.178978,
            2517.736547,
            3081.761022,
            2785.493582,
            958.5668124,
            505.7538077,
            556.8083834,
            21745.57328,
            884.7552507,
            993.2239571,
            874.6858643,
            764.7259628,
            1267.613204,
            745.3695408,
            640.3224383,
            21951.21176,
            1544.228586,
            663.2236766,
            686.3952693,
            1497.492223,
            3710.982963,
            2370.619976,
            502.3197334,
            3876.485958,
            808.8970728,
            1981.951806,
            4319.804067,
            670.0806011,
            1737.561657,
            1561.769116,
            1348.285159,
            1450.992513,
            8028.651439,
            2202.988423,
            3781.410618,
            962.4922932,
            1532.776998,
            3120.876811,
            843.7331372,
            1588.688299,
            685.5876821
           ],
           "xaxis": "x",
           "y": [
            58.014,
            39.483,
            49.19,
            59.319,
            46.137,
            45.91,
            49.355,
            46.775,
            47.383,
            50.939,
            47.804,
            55.625,
            52.374,
            46.519,
            53.319,
            42.024,
            44.535,
            44.51,
            52.79,
            41.842,
            51.756,
            40.762,
            37.465,
            56.155,
            52.208,
            43.764,
            57.442,
            46.881,
            43.767,
            41.714,
            50.852,
            64.93,
            55.73,
            42.495,
            56.437,
            41.291,
            44.514,
            67.064,
            45,
            58.55,
            48.879,
            36.788,
            41.974,
            55.527,
            47.8,
            52.537,
            49.919,
            52.887,
            59.837,
            50.35,
            51.386,
            57.674
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1977-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             26983828,
             5079716,
             114313951,
             23796400,
             10599793,
             25094412,
             2108457,
             9537988,
             5302800,
             7278866,
             4282586,
             5703430,
             4908554,
             3055235,
             2156814,
             63759976,
             2554598,
             1839782,
             2984494,
             15990099,
             3080828,
             1039009,
             220239000,
             2873520,
             13503563
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            10079.02674,
            3548.097832,
            6660.118654,
            22090.88306,
            4756.763836,
            3815.80787,
            5926.876967,
            6380.494966,
            2681.9889,
            6679.62326,
            5138.922374,
            4879.992748,
            1874.298931,
            3203.208066,
            6650.195573,
            7674.929108,
            5486.371089,
            5351.912144,
            3248.373311,
            6281.290855,
            9770.524921,
            7899.554209,
            24072.63213,
            6504.339663,
            13143.95095
           ],
           "xaxis": "x",
           "y": [
            68.481,
            50.023,
            61.489,
            74.21,
            67.052,
            63.837,
            70.75,
            72.649,
            61.788,
            61.31,
            56.696,
            56.029,
            49.923,
            57.402,
            70.11,
            65.032,
            57.47,
            68.681,
            66.353,
            58.447,
            73.44,
            68.3,
            73.38,
            69.481,
            67.456
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1977-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             14074100,
             3164900
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            18334.19751,
            16233.7177
           ],
           "xaxis": "x",
           "y": [
            73.49,
            72.22
           ],
           "yaxis": "y"
          }
         ],
         "name": "1977-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1982-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             12881816,
             377967,
             93074406,
             7272485,
             1000281000,
             5264500,
             708000000,
             153343000,
             43072751,
             14173318,
             3858421,
             118454974,
             2347031,
             17647518,
             39326000,
             1497494,
             3086876,
             14441916,
             1756032,
             34680442,
             15796314,
             1301048,
             91462088,
             53456774,
             11254672,
             2651869,
             15410151,
             9410494,
             18501390,
             48827160,
             56142181,
             1425876,
             9657618
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            978.0114388,
            19211.14731,
            676.9818656,
            624.4754784,
            962.4213805,
            14560.53051,
            855.7235377,
            1516.872988,
            7608.334602,
            14517.90711,
            15367.0292,
            19384.10571,
            4161.415959,
            4106.525293,
            5622.942464,
            31354.03573,
            7640.519521,
            4920.355951,
            2000.603139,
            424,
            718.3730947,
            12954.79101,
            1443.429832,
            2603.273765,
            33693.17525,
            15169.16112,
            1648.079789,
            3761.837715,
            7426.354774,
            2393.219781,
            707.2357863,
            4336.032082,
            1977.55701
           ],
           "xaxis": "x",
           "y": [
            39.854,
            69.052,
            50.009,
            50.957,
            65.525,
            75.45,
            56.596,
            56.159,
            59.62,
            62.038,
            74.45,
            77.11,
            63.739,
            69.1,
            67.123,
            71.309,
            66.983,
            68,
            57.489,
            58.056,
            49.594,
            62.728,
            56.158,
            62.082,
            63.012,
            71.76,
            68.757,
            64.59,
            72.16,
            64.597,
            58.816,
            64.406,
            49.113
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1982-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             2780097,
             7574613,
             9856303,
             4172693,
             8892098,
             4413368,
             10303704,
             5117810,
             4826933,
             54433565,
             78335266,
             9786480,
             10705535,
             233997,
             3480000,
             56535636,
             562548,
             14310401,
             4114787,
             36227381,
             9859650,
             22356726,
             9032824,
             5048043,
             1861252,
             37983310,
             8325260,
             6468126,
             47328791,
             56339704
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            3630.880722,
            21597.08362,
            20979.84589,
            4126.613157,
            8224.191647,
            13221.82184,
            15377.22855,
            21688.04048,
            18533.15761,
            20293.89746,
            22031.53274,
            15268.42089,
            12545.99066,
            23269.6075,
            12618.32141,
            16537.4835,
            11222.58762,
            21399.46046,
            26298.63531,
            8451.531004,
            11753.84291,
            9605.314053,
            15181.0927,
            11348.54585,
            17866.72175,
            13926.16997,
            20667.38125,
            28397.71512,
            4241.356344,
            18232.42452
           ],
           "xaxis": "x",
           "y": [
            70.42,
            73.18,
            73.93,
            70.69,
            71.08,
            70.46,
            70.96,
            74.63,
            74.55,
            74.89,
            73.8,
            75.24,
            69.39,
            76.99,
            73.1,
            74.98,
            74.101,
            76.05,
            75.97,
            71.32,
            72.77,
            69.66,
            70.162,
            70.8,
            71.063,
            76.3,
            76.42,
            76.21,
            61.036,
            74.04
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1982-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             20033753,
             7016384,
             3641603,
             970347,
             6634596,
             4580410,
             9250831,
             2476971,
             4875118,
             348643,
             30646495,
             1774735,
             9025951,
             305991,
             45681811,
             285483,
             2637297,
             38111756,
             753874,
             715523,
             11400338,
             4710497,
             825987,
             17661452,
             1411807,
             1956875,
             3344074,
             9171477,
             6502825,
             6998256,
             1622136,
             992040,
             20198730,
             12587223,
             1099010,
             6437188,
             73039376,
             517810,
             5507565,
             98593,
             6147783,
             3464522,
             5828892,
             31140029,
             20367053,
             649901,
             19844382,
             2644765,
             6734098,
             12939400,
             6100407,
             7636524
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            5745.160213,
            2756.953672,
            1277.897616,
            4551.14215,
            807.1985855,
            559.603231,
            2367.983282,
            956.7529907,
            797.9081006,
            1267.100083,
            673.7478181,
            4879.507522,
            2602.710169,
            2879.468067,
            3503.729636,
            927.8253427,
            524.8758493,
            577.8607471,
            15113.36194,
            835.8096108,
            876.032569,
            857.2503577,
            838.1239671,
            1348.225791,
            797.2631074,
            572.1995694,
            17364.27538,
            1302.878658,
            632.8039209,
            618.0140641,
            1481.150189,
            3688.037739,
            2702.620356,
            462.2114149,
            4191.100511,
            909.7221354,
            1576.97375,
            5267.219353,
            881.5706467,
            1890.218117,
            1518.479984,
            1465.010784,
            1176.807031,
            8568.266228,
            1895.544073,
            3895.384018,
            874.2426069,
            1344.577953,
            3560.233174,
            682.2662268,
            1408.678565,
            788.8550411
           ],
           "xaxis": "x",
           "y": [
            61.368,
            39.942,
            50.904,
            61.484,
            48.122,
            47.471,
            52.961,
            48.295,
            49.517,
            52.933,
            47.784,
            56.695,
            53.983,
            48.812,
            56.006,
            43.662,
            43.89,
            44.916,
            56.564,
            45.58,
            53.744,
            42.891,
            39.327,
            58.766,
            55.078,
            44.852,
            62.155,
            48.969,
            45.642,
            43.916,
            53.599,
            66.711,
            59.65,
            42.795,
            58.968,
            42.598,
            45.826,
            69.885,
            46.218,
            60.351,
            52.379,
            38.445,
            42.955,
            58.161,
            50.338,
            55.561,
            50.608,
            55.471,
            64.048,
            49.849,
            51.821,
            60.363
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1982-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             29341374,
             5642224,
             128962939,
             25201900,
             11487112,
             27764644,
             2424367,
             9789224,
             5968349,
             8365850,
             4474873,
             6395630,
             5198399,
             3669448,
             2298309,
             71640904,
             2979423,
             2036305,
             3366439,
             18125129,
             3279001,
             1116479,
             232187835,
             2953997,
             15620766
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            8997.897412,
            3156.510452,
            7030.835878,
            22898.79214,
            5095.665738,
            4397.575659,
            5262.734751,
            7316.918107,
            2861.092386,
            7213.791267,
            4098.344175,
            4820.49479,
            2011.159549,
            3121.760794,
            6068.05135,
            9611.147541,
            3470.338156,
            7009.601598,
            4258.503604,
            6434.501797,
            10330.98915,
            9119.528607,
            25009.55914,
            6920.223051,
            11152.41011
           ],
           "xaxis": "x",
           "y": [
            69.942,
            53.859,
            63.336,
            75.76,
            70.565,
            66.653,
            73.45,
            73.717,
            63.727,
            64.342,
            56.604,
            58.137,
            51.461,
            60.909,
            71.21,
            67.405,
            59.298,
            70.472,
            66.874,
            61.406,
            73.75,
            68.832,
            74.65,
            70.805,
            68.557
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1982-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             15184200,
             3210650
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            19477.00928,
            17632.4104
           ],
           "xaxis": "x",
           "y": [
            74.74,
            73.84
           ],
           "yaxis": "y"
          }
         ],
         "name": "1982-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1987-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             13867957,
             454612,
             103764241,
             8371791,
             1084035000,
             5584510,
             788000000,
             169276000,
             51889696,
             16543189,
             4203148,
             122091325,
             2820042,
             19067554,
             41622000,
             1891487,
             3089353,
             16331785,
             2015133,
             38028578,
             17917180,
             1593882,
             105186881,
             60017788,
             14619745,
             2794552,
             16495304,
             11242847,
             19757799,
             52910342,
             62826491,
             1691210,
             11219340
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            852.3959448,
            18524.02406,
            751.9794035,
            683.8955732,
            1378.904018,
            20038.47269,
            976.5126756,
            1748.356961,
            6642.881371,
            11643.57268,
            17122.47986,
            22375.94189,
            4448.679912,
            4106.492315,
            8533.088805,
            28118.42998,
            5377.091329,
            5249.802653,
            2338.008304,
            385,
            775.6324501,
            18115.22313,
            1704.686583,
            2189.634995,
            21198.26136,
            18861.53081,
            1876.766827,
            3116.774285,
            11054.56175,
            2982.653773,
            820.7994449,
            5107.197384,
            1971.741538
           ],
           "xaxis": "x",
           "y": [
            40.822,
            70.75,
            52.819,
            53.914,
            67.274,
            76.2,
            58.553,
            60.137,
            63.04,
            65.044,
            75.6,
            78.67,
            65.869,
            70.647,
            69.81,
            74.174,
            67.926,
            69.5,
            60.222,
            58.339,
            52.537,
            67.734,
            58.245,
            64.151,
            66.295,
            73.56,
            69.011,
            66.974,
            73.4,
            66.084,
            62.82,
            67.046,
            52.922
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1987-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             3075321,
             7578903,
             9870200,
             4338977,
             8971958,
             4484310,
             10311597,
             5127024,
             4931729,
             55630100,
             77718298,
             9974490,
             10612740,
             244676,
             3539900,
             56729703,
             569473,
             14665278,
             4186147,
             37740710,
             9915289,
             22686371,
             9230783,
             5199318,
             1945870,
             38880702,
             8421403,
             6649942,
             52881328,
             56981620
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            3738.932735,
            23687.82607,
            22525.56308,
            4314.114757,
            8239.854824,
            13822.58394,
            16310.4434,
            25116.17581,
            21141.01223,
            22066.44214,
            24639.18566,
            16120.52839,
            12986.47998,
            26923.20628,
            13872.86652,
            19207.23482,
            11732.51017,
            23651.32361,
            31540.9748,
            9082.351172,
            13039.30876,
            9696.273295,
            15870.87851,
            12037.26758,
            18678.53492,
            15764.98313,
            23586.92927,
            30281.70459,
            5089.043686,
            21664.78767
           ],
           "xaxis": "x",
           "y": [
            72,
            74.94,
            75.35,
            71.14,
            71.34,
            71.52,
            71.58,
            74.8,
            74.83,
            76.34,
            74.847,
            76.67,
            69.58,
            77.23,
            74.36,
            76.42,
            74.865,
            76.83,
            75.89,
            70.98,
            74.06,
            69.53,
            71.218,
            71.08,
            72.25,
            76.9,
            77.19,
            77.41,
            63.108,
            75.007
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1987-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             23254956,
             7874230,
             4243788,
             1151184,
             7586551,
             5126023,
             10780667,
             2840009,
             5498955,
             395114,
             35481645,
             2064095,
             10761098,
             311025,
             52799062,
             341244,
             2915959,
             42999530,
             880397,
             848406,
             14168101,
             5650262,
             927524,
             21198082,
             1599200,
             2269414,
             3799845,
             10568642,
             7824747,
             7634008,
             1841240,
             1042663,
             22987397,
             12891952,
             1278184,
             7332638,
             81551520,
             562035,
             6349365,
             110812,
             7171347,
             3868905,
             6921858,
             35933379,
             24725960,
             779348,
             23040630,
             3154264,
             7724976,
             15283050,
             7272406,
             9216418
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            5681.358539,
            2430.208311,
            1225.85601,
            6205.88385,
            912.0631417,
            621.8188189,
            2602.664206,
            844.8763504,
            952.386129,
            1315.980812,
            672.774812,
            4201.194937,
            2156.956069,
            2880.102568,
            3885.46071,
            966.8968149,
            521.1341333,
            573.7413142,
            11864.40844,
            611.6588611,
            847.0061135,
            805.5724718,
            736.4153921,
            1361.936856,
            773.9932141,
            506.1138573,
            11770.5898,
            1155.441948,
            635.5173634,
            684.1715576,
            1421.603576,
            4783.586903,
            2755.046991,
            389.8761846,
            3693.731337,
            668.3000228,
            1385.029563,
            5303.377488,
            847.991217,
            1516.525457,
            1441.72072,
            1294.447788,
            1093.244963,
            7825.823398,
            1507.819159,
            3984.839812,
            831.8220794,
            1202.201361,
            3810.419296,
            617.7244065,
            1213.315116,
            706.1573059
           ],
           "xaxis": "x",
           "y": [
            65.799,
            39.906,
            52.337,
            63.622,
            49.557,
            48.211,
            54.985,
            50.485,
            51.051,
            54.926,
            47.412,
            57.47,
            54.655,
            50.04,
            59.797,
            45.664,
            46.453,
            46.684,
            60.19,
            49.265,
            55.729,
            45.552,
            41.245,
            59.339,
            57.18,
            46.027,
            66.234,
            49.35,
            47.457,
            46.364,
            56.145,
            68.74,
            62.677,
            42.861,
            60.835,
            44.555,
            46.886,
            71.913,
            44.02,
            61.728,
            55.769,
            40.006,
            44.501,
            60.834,
            51.744,
            57.678,
            51.535,
            56.941,
            66.894,
            51.509,
            50.821,
            62.351
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1987-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             31620918,
             6156369,
             142938076,
             26549700,
             12463354,
             30964245,
             2799811,
             10239839,
             6655297,
             9545158,
             4842194,
             7326406,
             5756203,
             4372203,
             2326606,
             80122492,
             3344353,
             2253639,
             3886512,
             20195924,
             3444468,
             1191336,
             242803533,
             3045153,
             17910182
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            9139.671389,
            2753.69149,
            7807.095818,
            26626.51503,
            5547.063754,
            4903.2191,
            5629.915318,
            7532.924763,
            2899.842175,
            6481.776993,
            4140.442097,
            4246.485974,
            1823.015995,
            3023.096699,
            6351.237495,
            8688.156003,
            2955.984375,
            7034.779161,
            3998.875695,
            6360.943444,
            12281.34191,
            7388.597823,
            29884.35041,
            7452.398969,
            9883.584648
           ],
           "xaxis": "x",
           "y": [
            70.774,
            57.251,
            65.205,
            76.86,
            72.492,
            67.768,
            74.752,
            74.174,
            66.046,
            67.231,
            63.154,
            60.782,
            53.636,
            64.492,
            71.77,
            69.498,
            62.008,
            71.523,
            67.378,
            64.134,
            74.63,
            69.582,
            75.02,
            71.918,
            70.19
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1987-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             16257249,
             3317166
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            21888.88903,
            19007.19129
           ],
           "xaxis": "x",
           "y": [
            76.32,
            74.32
           ],
           "yaxis": "y"
          }
         ],
         "name": "1987-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1992-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             16317921,
             529491,
             113704579,
             10150094,
             1164970000,
             5829696,
             872000000,
             184816000,
             60397973,
             17861905,
             4936550,
             124329269,
             3867409,
             20711375,
             43805450,
             1418095,
             3219994,
             18319502,
             2312802,
             40546538,
             20326209,
             1915208,
             120065004,
             67185766,
             16945857,
             3235865,
             17587060,
             13219062,
             20686918,
             56667095,
             69940728,
             2104779,
             13367997
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            649.3413952,
            19035.57917,
            837.8101643,
            682.3031755,
            1655.784158,
            24757.60301,
            1164.406809,
            2383.140898,
            7235.653188,
            3745.640687,
            18051.52254,
            26824.89511,
            3431.593647,
            3726.063507,
            12104.27872,
            34932.91959,
            6890.806854,
            7277.912802,
            1785.402016,
            347,
            897.7403604,
            18616.70691,
            1971.829464,
            2279.324017,
            24841.61777,
            24769.8912,
            2153.739222,
            3340.542768,
            15215.6579,
            4616.896545,
            989.0231487,
            6017.654756,
            1879.496673
           ],
           "xaxis": "x",
           "y": [
            41.674,
            72.601,
            56.018,
            55.803,
            68.69,
            77.601,
            60.223,
            62.681,
            65.742,
            59.461,
            76.93,
            79.36,
            68.015,
            69.978,
            72.244,
            75.19,
            69.292,
            70.693,
            61.271,
            59.32,
            55.727,
            71.197,
            60.838,
            66.458,
            68.768,
            75.788,
            70.379,
            69.249,
            74.26,
            67.298,
            67.662,
            69.718,
            55.599
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1992-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             3326498,
             7914969,
             10045622,
             4256013,
             8658506,
             4494013,
             10315702,
             5171393,
             5041039,
             57374179,
             80597764,
             10325429,
             10348684,
             259012,
             3557761,
             56840847,
             621621,
             15174244,
             4286357,
             38370697,
             9927680,
             22797027,
             9826397,
             5302888,
             1999210,
             39549438,
             8718867,
             6995447,
             58179144,
             57866349
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            2497.437901,
            27042.01868,
            25575.57069,
            2546.781445,
            6302.623438,
            8447.794873,
            14297.02122,
            26406.73985,
            20647.16499,
            24703.79615,
            26505.30317,
            17541.49634,
            10535.62855,
            25144.39201,
            17558.81555,
            22013.64486,
            7003.339037,
            26790.94961,
            33965.66115,
            7738.881247,
            16207.26663,
            6598.409903,
            9325.068238,
            9498.467723,
            14214.71681,
            18603.06452,
            23880.01683,
            31871.5303,
            5678.348271,
            22705.09254
           ],
           "xaxis": "x",
           "y": [
            71.581,
            76.04,
            76.46,
            72.178,
            71.19,
            72.527,
            72.4,
            75.33,
            75.7,
            77.46,
            76.07,
            77.03,
            69.17,
            78.77,
            75.467,
            77.44,
            75.435,
            77.42,
            77.32,
            70.99,
            74.86,
            69.36,
            71.659,
            71.38,
            73.64,
            77.57,
            78.16,
            78.03,
            66.146,
            76.42
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1992-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             26298373,
             8735988,
             4981671,
             1342614,
             8878303,
             5809236,
             12467171,
             3265124,
             6429417,
             454429,
             41672143,
             2409073,
             12772596,
             384156,
             59402198,
             387838,
             3668440,
             52088559,
             985739,
             1025384,
             16278738,
             6990574,
             1050938,
             25020539,
             1803195,
             1912974,
             4364501,
             12210395,
             10014249,
             8416215,
             2119465,
             1096202,
             25798239,
             13160731,
             1554253,
             8392818,
             93364244,
             622191,
             7290203,
             125911,
             8307920,
             4260884,
             6099799,
             39964159,
             28227588,
             962344,
             26605473,
             3747553,
             8523077,
             18252190,
             8381163,
             10704340
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            5023.216647,
            2627.845685,
            1191.207681,
            7954.111645,
            931.7527731,
            631.6998778,
            1793.163278,
            747.9055252,
            1058.0643,
            1246.90737,
            457.7191807,
            4016.239529,
            1648.073791,
            2377.156192,
            3794.755195,
            1132.055034,
            582.8585102,
            421.3534653,
            13522.15752,
            665.6244126,
            925.060154,
            794.3484384,
            745.5398706,
            1341.921721,
            977.4862725,
            636.6229191,
            9640.138501,
            1040.67619,
            563.2000145,
            739.014375,
            1361.369784,
            6058.253846,
            2948.047252,
            410.8968239,
            3804.537999,
            581.182725,
            1619.848217,
            6101.255823,
            737.0685949,
            1428.777814,
            1367.899369,
            1068.696278,
            926.9602964,
            7225.069258,
            1492.197043,
            3553.0224,
            825.682454,
            1034.298904,
            4332.720164,
            644.1707969,
            1210.884633,
            693.4207856
           ],
           "xaxis": "x",
           "y": [
            67.744,
            40.647,
            53.919,
            62.745,
            50.26,
            44.736,
            54.314,
            49.396,
            51.724,
            57.939,
            45.548,
            56.433,
            52.044,
            51.604,
            63.674,
            47.545,
            49.991,
            48.091,
            61.366,
            52.644,
            57.501,
            48.576,
            43.266,
            59.285,
            59.685,
            40.802,
            68.755,
            52.214,
            49.42,
            48.388,
            58.333,
            69.745,
            65.393,
            44.284,
            61.999,
            47.391,
            47.472,
            73.615,
            23.599,
            62.742,
            58.196,
            38.333,
            39.658,
            61.888,
            53.556,
            58.474,
            50.44,
            58.061,
            70.001,
            48.825,
            46.1,
            60.377
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1992-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             33958947,
             6893451,
             155975974,
             28523502,
             13572994,
             34202721,
             3173216,
             10723260,
             7351181,
             10748394,
             5274649,
             8486949,
             6326682,
             5077347,
             2378618,
             88111030,
             4017939,
             2484997,
             4483945,
             22430449,
             3585176,
             1183669,
             256894189,
             3149262,
             20265563
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            9308.41871,
            2961.699694,
            6950.283021,
            26342.88426,
            7596.125964,
            5444.648617,
            6160.416317,
            5592.843963,
            3044.214214,
            7103.702595,
            4444.2317,
            4439.45084,
            1456.309517,
            3081.694603,
            7404.923685,
            9472.384295,
            2170.151724,
            6618.74305,
            4196.411078,
            4446.380924,
            14641.58711,
            7370.990932,
            32003.93224,
            8137.004775,
            10733.92631
           ],
           "xaxis": "x",
           "y": [
            71.868,
            59.957,
            67.057,
            77.95,
            74.126,
            68.421,
            75.713,
            74.414,
            68.457,
            69.613,
            66.798,
            63.373,
            55.089,
            66.399,
            71.766,
            71.455,
            65.843,
            72.462,
            68.225,
            66.458,
            73.911,
            69.862,
            76.09,
            72.752,
            71.15
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1992-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             17481977,
             3437674
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            23424.76683,
            18363.32494
           ],
           "xaxis": "x",
           "y": [
            77.56,
            76.33
           ],
           "yaxis": "y"
          }
         ],
         "name": "1992-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=1997-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             22227415,
             598561,
             123315288,
             11782962,
             1230075000,
             6495918,
             959000000,
             199278000,
             63327987,
             20775703,
             5531387,
             125956499,
             4526235,
             21585105,
             46173816,
             1765345,
             3430388,
             20476091,
             2494803,
             43247867,
             23001113,
             2283635,
             135564834,
             75012988,
             21229759,
             3802309,
             18698655,
             15081016,
             21628605,
             60216677,
             76048996,
             2826046,
             15826497
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            635.341351,
            20292.01679,
            972.7700352,
            734.28517,
            2289.234136,
            28377.63219,
            1458.817442,
            3119.335603,
            8263.590301,
            3076.239795,
            20896.60924,
            28816.58499,
            3645.379572,
            1690.756814,
            15993.52796,
            40300.61996,
            8754.96385,
            10132.90964,
            1902.2521,
            415,
            1010.892138,
            19702.05581,
            2049.350521,
            2536.534925,
            20586.69019,
            33519.4766,
            2664.477257,
            4014.238972,
            20206.82098,
            5852.625497,
            1385.896769,
            7110.667619,
            2117.484526
           ],
           "xaxis": "x",
           "y": [
            41.763,
            73.925,
            59.412,
            56.534,
            70.426,
            80,
            61.765,
            66.041,
            68.042,
            58.811,
            78.269,
            80.69,
            69.772,
            67.727,
            74.647,
            76.156,
            70.265,
            71.938,
            63.625,
            60.328,
            59.426,
            72.499,
            61.818,
            68.564,
            70.533,
            77.158,
            70.457,
            71.527,
            75.25,
            67.521,
            70.672,
            71.096,
            58.02
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=1997-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             3428038,
             8069876,
             10199787,
             3607000,
             8066057,
             4444595,
             10300707,
             5283663,
             5134406,
             58623428,
             82011073,
             10502372,
             10244684,
             271192,
             3667233,
             57479469,
             692651,
             15604464,
             4405672,
             38654957,
             10156415,
             22562458,
             10336594,
             5383010,
             2011612,
             39855442,
             8897619,
             7193761,
             63047647,
             58808266
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            3193.054604,
            29095.92066,
            27561.19663,
            4766.355904,
            5970.38876,
            9875.604515,
            16048.51424,
            29804.34567,
            23723.9502,
            25889.78487,
            27788.88416,
            18747.69814,
            11712.7768,
            28061.09966,
            24521.94713,
            24675.02446,
            6465.613349,
            30246.13063,
            41283.16433,
            10159.58368,
            17641.03156,
            7346.547557,
            7914.320304,
            12126.23065,
            17161.10735,
            20445.29896,
            25266.59499,
            32135.32301,
            6601.429915,
            26074.53136
           ],
           "xaxis": "x",
           "y": [
            72.95,
            77.51,
            77.53,
            73.244,
            70.32,
            73.68,
            74.01,
            76.11,
            77.13,
            78.64,
            77.34,
            77.869,
            71.04,
            78.95,
            76.122,
            78.82,
            75.445,
            78.03,
            78.32,
            72.75,
            75.97,
            69.72,
            72.232,
            72.71,
            75.13,
            78.77,
            79.39,
            79.37,
            68.835,
            77.218
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=1997-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             29072015,
             9875024,
             6066080,
             1536536,
             10352843,
             6121610,
             14195809,
             3696513,
             7562011,
             527982,
             47798986,
             2800947,
             14625967,
             417908,
             66134291,
             439971,
             4058319,
             59861301,
             1126189,
             1235767,
             18418288,
             8048834,
             1193708,
             28263827,
             1982823,
             2200725,
             4759670,
             14165114,
             10419991,
             9384984,
             2444741,
             1149818,
             28529501,
             16603334,
             1774766,
             9666252,
             106207839,
             684810,
             7212583,
             145608,
             9535314,
             4578212,
             6633514,
             42835005,
             32160729,
             1054486,
             30686889,
             4320890,
             9231669,
             21210254,
             9417789,
             11404948
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            4797.295051,
            2277.140884,
            1232.975292,
            8647.142313,
            946.2949618,
            463.1151478,
            1694.337469,
            740.5063317,
            1004.961353,
            1173.618235,
            312.188423,
            3484.164376,
            1786.265407,
            1895.016984,
            4173.181797,
            2814.480755,
            913.47079,
            515.8894013,
            14722.84188,
            653.7301704,
            1005.245812,
            869.4497668,
            796.6644681,
            1360.485021,
            1186.147994,
            609.1739508,
            9467.446056,
            986.2958956,
            692.2758103,
            790.2579846,
            1483.136136,
            7425.705295,
            2982.101858,
            472.3460771,
            3899.52426,
            580.3052092,
            1624.941275,
            6071.941411,
            589.9445051,
            1339.076036,
            1392.368347,
            574.6481576,
            930.5964284,
            7479.188244,
            1632.210764,
            3876.76846,
            789.1862231,
            982.2869243,
            4876.798614,
            816.559081,
            1071.353818,
            792.4499603
           ],
           "xaxis": "x",
           "y": [
            69.152,
            40.963,
            54.777,
            52.556,
            50.324,
            45.326,
            52.199,
            46.066,
            51.573,
            60.66,
            42.587,
            52.962,
            47.991,
            53.157,
            67.217,
            48.245,
            53.378,
            49.402,
            60.461,
            55.861,
            58.556,
            51.455,
            44.873,
            54.407,
            55.558,
            42.221,
            71.555,
            54.978,
            47.495,
            49.903,
            60.43,
            70.736,
            67.66,
            46.344,
            58.909,
            51.313,
            47.464,
            74.772,
            36.087,
            63.306,
            60.187,
            39.897,
            43.795,
            60.236,
            55.373,
            54.289,
            48.466,
            58.39,
            71.973,
            44.578,
            40.238,
            46.809
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=1997-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             36203463,
             7693188,
             168546719,
             30305843,
             14599929,
             37657830,
             3518107,
             10983007,
             7992357,
             11911819,
             5783439,
             9803875,
             6913545,
             5867957,
             2531311,
             95895146,
             4609572,
             2734531,
             5154123,
             24748122,
             3759430,
             1138101,
             272911760,
             3262838,
             22374398
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            10967.28195,
            3326.143191,
            7957.980824,
            28954.92589,
            10118.05318,
            6117.361746,
            6677.045314,
            5431.990415,
            3614.101285,
            7429.455877,
            5154.825496,
            4684.313807,
            1341.726931,
            3160.454906,
            7121.924704,
            9767.29753,
            2253.023004,
            7113.692252,
            4247.400261,
            5838.347657,
            16999.4333,
            8792.573126,
            35767.43303,
            9230.240708,
            10165.49518
           ],
           "xaxis": "x",
           "y": [
            73.275,
            62.05,
            69.388,
            78.61,
            75.816,
            70.313,
            77.26,
            76.151,
            69.957,
            72.312,
            69.535,
            66.322,
            56.671,
            67.659,
            72.262,
            73.67,
            68.426,
            73.738,
            69.4,
            68.386,
            74.917,
            69.465,
            76.81,
            74.223,
            72.146
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=1997-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             18565243,
             3676187
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            26997.93657,
            21050.41377
           ],
           "xaxis": "x",
           "y": [
            78.83,
            77.55
           ],
           "yaxis": "y"
          }
         ],
         "name": "1997-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=2002-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             25268405,
             656397,
             135656790,
             12926707,
             1280400000,
             6762476,
             1034172547,
             211060000,
             66907826,
             24001816,
             6029529,
             127065841,
             5307470,
             22215365,
             47969150,
             2111561,
             3677780,
             22662365,
             2674234,
             45598081,
             25873917,
             2713462,
             153403524,
             82995088,
             24501530,
             4197776,
             19576783,
             17155814,
             22454239,
             62806748,
             80908147,
             3389578,
             18701257
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            726.7340548,
            23403.55927,
            1136.39043,
            896.2260153,
            3119.280896,
            30209.01516,
            1746.769454,
            2873.91287,
            9240.761975,
            4390.717312,
            21905.59514,
            28604.5919,
            3844.917194,
            1646.758151,
            19233.98818,
            35110.10566,
            9313.93883,
            10206.97794,
            2140.739323,
            611,
            1057.206311,
            19774.83687,
            2092.712441,
            2650.921068,
            19014.54118,
            36023.1054,
            3015.378833,
            4090.925331,
            23235.42329,
            5913.187529,
            1764.456677,
            4515.487575,
            2234.820827
           ],
           "xaxis": "x",
           "y": [
            42.129,
            74.795,
            62.013,
            56.752,
            72.028,
            81.495,
            62.879,
            68.588,
            69.451,
            57.046,
            79.696,
            82,
            71.263,
            66.662,
            77.045,
            76.904,
            71.028,
            73.044,
            65.033,
            59.908,
            61.34,
            74.193,
            63.61,
            70.303,
            71.626,
            78.77,
            70.815,
            73.053,
            76.99,
            68.564,
            73.017,
            72.37,
            60.308
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=2002-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             3508512,
             8148312,
             10311970,
             4165416,
             7661799,
             4481020,
             10256295,
             5374693,
             5193039,
             59925035,
             82350671,
             10603863,
             10083313,
             288030,
             3879155,
             57926999,
             720230,
             16122830,
             4535591,
             38625976,
             10433867,
             22404337,
             10111559,
             5410052,
             2011497,
             40152517,
             8954175,
             7361757,
             67308928,
             59912431
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            4604.211737,
            32417.60769,
            30485.88375,
            6018.975239,
            7696.777725,
            11628.38895,
            17596.21022,
            32166.50006,
            28204.59057,
            28926.03234,
            30035.80198,
            22514.2548,
            14843.93556,
            31163.20196,
            34077.04939,
            27968.09817,
            6557.194282,
            33724.75778,
            44683.97525,
            12002.23908,
            19970.90787,
            7885.360081,
            7236.075251,
            13638.77837,
            20660.01936,
            24835.47166,
            29341.63093,
            34480.95771,
            6508.085718,
            29478.99919
           ],
           "xaxis": "x",
           "y": [
            75.651,
            78.98,
            78.32,
            74.09,
            72.14,
            74.876,
            75.51,
            77.18,
            78.37,
            79.59,
            78.67,
            78.256,
            72.59,
            80.5,
            77.783,
            80.24,
            73.981,
            78.53,
            79.05,
            74.67,
            77.29,
            71.322,
            73.213,
            73.8,
            76.66,
            79.78,
            80.04,
            80.62,
            70.845,
            78.471
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=2002-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             31287142,
             10866106,
             7026113,
             1630347,
             12251209,
             7021078,
             15929988,
             4048013,
             8835739,
             614382,
             55379852,
             3328795,
             16252726,
             447416,
             73312559,
             495627,
             4414865,
             67946797,
             1299304,
             1457766,
             20550751,
             8807818,
             1332459,
             31386842,
             2046772,
             2814651,
             5368585,
             16473477,
             11824495,
             10580176,
             2828858,
             1200206,
             31167783,
             18473780,
             1972153,
             11140655,
             119901274,
             743981,
             7852401,
             170372,
             10870037,
             5359092,
             7753310,
             44433622,
             37090298,
             1130269,
             34593779,
             4977378,
             9770575,
             24739869,
             10595811,
             11926563
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            5288.040382,
            2773.287312,
            1372.877931,
            11003.60508,
            1037.645221,
            446.4035126,
            1934.011449,
            738.6906068,
            1156.18186,
            1075.811558,
            241.1658765,
            3484.06197,
            1648.800823,
            1908.260867,
            4754.604414,
            7703.4959,
            765.3500015,
            530.0535319,
            12521.71392,
            660.5855997,
            1111.984578,
            945.5835837,
            575.7047176,
            1287.514732,
            1275.184575,
            531.4823679,
            9534.677467,
            894.6370822,
            665.4231186,
            951.4097518,
            1579.019543,
            9021.815894,
            3258.495584,
            633.6179466,
            4072.324751,
            601.0745012,
            1615.286395,
            6316.1652,
            785.6537648,
            1353.09239,
            1519.635262,
            699.489713,
            882.0818218,
            7710.946444,
            1993.398314,
            4128.116943,
            899.0742111,
            886.2205765,
            5722.895655,
            927.7210018,
            1071.613938,
            672.0386227
           ],
           "xaxis": "x",
           "y": [
            70.994,
            41.003,
            54.406,
            46.634,
            50.65,
            47.36,
            49.856,
            43.308,
            50.525,
            62.974,
            44.966,
            52.97,
            46.832,
            53.373,
            69.806,
            49.348,
            55.24,
            50.725,
            56.761,
            58.041,
            58.453,
            53.676,
            45.504,
            50.992,
            44.593,
            43.753,
            72.737,
            57.286,
            45.009,
            51.818,
            62.247,
            71.954,
            69.615,
            44.026,
            51.479,
            54.496,
            46.608,
            75.744,
            43.413,
            64.337,
            61.6,
            41.012,
            45.936,
            53.365,
            56.369,
            43.869,
            49.651,
            57.561,
            73.042,
            47.813,
            39.193,
            39.989
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=2002-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             38331121,
             8445134,
             179914212,
             31902268,
             15497046,
             41008227,
             3834934,
             11226999,
             8650322,
             12921234,
             6353681,
             11178650,
             7607651,
             6677328,
             2664659,
             102479927,
             5146848,
             2990875,
             5884491,
             26769436,
             3859606,
             1101832,
             287675526,
             3363085,
             24287670
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            8797.640716,
            3413.26269,
            8131.212843,
            33328.96507,
            10778.78385,
            5755.259962,
            7723.447195,
            6340.646683,
            4563.808154,
            5773.044512,
            5351.568666,
            4858.347495,
            1270.364932,
            3099.72866,
            6994.774861,
            10742.44053,
            2474.548819,
            7356.031934,
            3783.674243,
            5909.020073,
            18855.60618,
            11460.60023,
            39097.09955,
            7727.002004,
            8605.047831
           ],
           "xaxis": "x",
           "y": [
            74.34,
            63.883,
            71.006,
            79.77,
            77.86,
            71.682,
            78.123,
            77.158,
            70.847,
            74.173,
            70.734,
            68.978,
            58.137,
            68.565,
            72.047,
            74.902,
            70.836,
            74.712,
            70.755,
            69.906,
            77.778,
            68.976,
            77.31,
            75.307,
            72.766
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=2002-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             19546792,
             3908037
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            30687.75473,
            23189.80135
           ],
           "xaxis": "x",
           "y": [
            80.37,
            79.11
           ],
           "yaxis": "y"
          }
         ],
         "name": "2002-01-01 00:00:00"
        },
        {
         "data": [
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Asia<br>year=2007-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "ids": [
            "Afghanistan",
            "Bahrain",
            "Bangladesh",
            "Cambodia",
            "China",
            "Hong Kong, China",
            "India",
            "Indonesia",
            "Iran",
            "Iraq",
            "Israel",
            "Japan",
            "Jordan",
            "Korea, Dem. Rep.",
            "Korea, Rep.",
            "Kuwait",
            "Lebanon",
            "Malaysia",
            "Mongolia",
            "Myanmar",
            "Nepal",
            "Oman",
            "Pakistan",
            "Philippines",
            "Saudi Arabia",
            "Singapore",
            "Sri Lanka",
            "Syria",
            "Taiwan",
            "Thailand",
            "Vietnam",
            "West Bank and Gaza",
            "Yemen, Rep."
           ],
           "legendgroup": "Asia",
           "marker": {
            "color": "#636efa",
            "size": [
             31889923,
             708573,
             150448339,
             14131858,
             1318683096,
             6980412,
             1110396331,
             223547000,
             69453570,
             27499638,
             6426679,
             127467972,
             6053193,
             23301725,
             49044790,
             2505559,
             3921278,
             24821286,
             2874127,
             47761980,
             28901790,
             3204897,
             169270617,
             91077287,
             27601038,
             4553009,
             20378239,
             19314747,
             23174294,
             65068149,
             85262356,
             4018332,
             22211743
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Asia",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            974.5803384,
            29796.04834,
            1391.253792,
            1713.778686,
            4959.114854,
            39724.97867,
            2452.210407,
            3540.651564,
            11605.71449,
            4471.061906,
            25523.2771,
            31656.06806,
            4519.461171,
            1593.06548,
            23348.13973,
            47306.98978,
            10461.05868,
            12451.6558,
            3095.772271,
            944,
            1091.359778,
            22316.19287,
            2605.94758,
            3190.481016,
            21654.83194,
            47143.17964,
            3970.095407,
            4184.548089,
            28718.27684,
            7458.396327,
            2441.576404,
            3025.349798,
            2280.769906
           ],
           "xaxis": "x",
           "y": [
            43.828,
            75.635,
            64.062,
            59.723,
            72.961,
            82.208,
            64.698,
            70.65,
            70.964,
            59.545,
            80.745,
            82.603,
            72.535,
            67.297,
            78.623,
            77.588,
            71.993,
            74.241,
            66.803,
            62.069,
            63.785,
            75.64,
            65.483,
            71.688,
            72.777,
            79.972,
            72.396,
            74.143,
            78.4,
            70.616,
            74.249,
            73.422,
            62.698
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Europe<br>year=2007-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "ids": [
            "Albania",
            "Austria",
            "Belgium",
            "Bosnia and Herzegovina",
            "Bulgaria",
            "Croatia",
            "Czech Republic",
            "Denmark",
            "Finland",
            "France",
            "Germany",
            "Greece",
            "Hungary",
            "Iceland",
            "Ireland",
            "Italy",
            "Montenegro",
            "Netherlands",
            "Norway",
            "Poland",
            "Portugal",
            "Romania",
            "Serbia",
            "Slovak Republic",
            "Slovenia",
            "Spain",
            "Sweden",
            "Switzerland",
            "Turkey",
            "United Kingdom"
           ],
           "legendgroup": "Europe",
           "marker": {
            "color": "#EF553B",
            "size": [
             3600523,
             8199783,
             10392226,
             4552198,
             7322858,
             4493312,
             10228744,
             5468120,
             5238460,
             61083916,
             82400996,
             10706290,
             9956108,
             301931,
             4109086,
             58147733,
             684736,
             16570613,
             4627926,
             38518241,
             10642836,
             22276056,
             10150265,
             5447502,
             2009245,
             40448191,
             9031088,
             7554661,
             71158647,
             60776238
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Europe",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            5937.029526,
            36126.4927,
            33692.60508,
            7446.298803,
            10680.79282,
            14619.22272,
            22833.30851,
            35278.41874,
            33207.0844,
            30470.0167,
            32170.37442,
            27538.41188,
            18008.94444,
            36180.78919,
            40675.99635,
            28569.7197,
            9253.896111,
            36797.93332,
            49357.19017,
            15389.92468,
            20509.64777,
            10808.47561,
            9786.534714,
            18678.31435,
            25768.25759,
            28821.0637,
            33859.74835,
            37506.41907,
            8458.276384,
            33203.26128
           ],
           "xaxis": "x",
           "y": [
            76.423,
            79.829,
            79.441,
            74.852,
            73.005,
            75.748,
            76.486,
            78.332,
            79.313,
            80.657,
            79.406,
            79.483,
            73.338,
            81.757,
            78.885,
            80.546,
            74.543,
            79.762,
            80.196,
            75.563,
            78.098,
            72.476,
            74.002,
            74.663,
            77.926,
            80.941,
            80.884,
            81.701,
            71.777,
            79.425
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Africa<br>year=2007-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "ids": [
            "Algeria",
            "Angola",
            "Benin",
            "Botswana",
            "Burkina Faso",
            "Burundi",
            "Cameroon",
            "Central African Republic",
            "Chad",
            "Comoros",
            "Congo, Dem. Rep.",
            "Congo, Rep.",
            "Cote d'Ivoire",
            "Djibouti",
            "Egypt",
            "Equatorial Guinea",
            "Eritrea",
            "Ethiopia",
            "Gabon",
            "Gambia",
            "Ghana",
            "Guinea",
            "Guinea-Bissau",
            "Kenya",
            "Lesotho",
            "Liberia",
            "Libya",
            "Madagascar",
            "Malawi",
            "Mali",
            "Mauritania",
            "Mauritius",
            "Morocco",
            "Mozambique",
            "Namibia",
            "Niger",
            "Nigeria",
            "Reunion",
            "Rwanda",
            "Sao Tome and Principe",
            "Senegal",
            "Sierra Leone",
            "Somalia",
            "South Africa",
            "Sudan",
            "Swaziland",
            "Tanzania",
            "Togo",
            "Tunisia",
            "Uganda",
            "Zambia",
            "Zimbabwe"
           ],
           "legendgroup": "Africa",
           "marker": {
            "color": "#00cc96",
            "size": [
             33333216,
             12420476,
             8078314,
             1639131,
             14326203,
             8390505,
             17696293,
             4369038,
             10238807,
             710960,
             64606759,
             3800610,
             18013409,
             496374,
             80264543,
             551201,
             4906585,
             76511887,
             1454867,
             1688359,
             22873338,
             9947814,
             1472041,
             35610177,
             2012649,
             3193942,
             6036914,
             19167654,
             13327079,
             12031795,
             3270065,
             1250882,
             33757175,
             19951656,
             2055080,
             12894865,
             135031164,
             798094,
             8860588,
             199579,
             12267493,
             6144562,
             9118773,
             43997828,
             42292929,
             1133066,
             38139640,
             5701579,
             10276158,
             29170398,
             11746035,
             12311143
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Africa",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            6223.367465,
            4797.231267,
            1441.284873,
            12569.85177,
            1217.032994,
            430.0706916,
            2042.09524,
            706.016537,
            1704.063724,
            986.1478792,
            277.5518587,
            3632.557798,
            1544.750112,
            2082.481567,
            5581.180998,
            12154.08975,
            641.3695236,
            690.8055759,
            13206.48452,
            752.7497265,
            1327.60891,
            942.6542111,
            579.231743,
            1463.249282,
            1569.331442,
            414.5073415,
            12057.49928,
            1044.770126,
            759.3499101,
            1042.581557,
            1803.151496,
            10956.99112,
            3820.17523,
            823.6856205,
            4811.060429,
            619.6768924,
            2013.977305,
            7670.122558,
            863.0884639,
            1598.435089,
            1712.472136,
            862.5407561,
            926.1410683,
            9269.657808,
            2602.394995,
            4513.480643,
            1107.482182,
            882.9699438,
            7092.923025,
            1056.380121,
            1271.211593,
            469.7092981
           ],
           "xaxis": "x",
           "y": [
            72.301,
            42.731,
            56.728,
            50.728,
            52.295,
            49.58,
            50.43,
            44.741,
            50.651,
            65.152,
            46.462,
            55.322,
            48.328,
            54.791,
            71.338,
            51.579,
            58.04,
            52.947,
            56.735,
            59.448,
            60.022,
            56.007,
            46.388,
            54.11,
            42.592,
            45.678,
            73.952,
            59.443,
            48.303,
            54.467,
            64.164,
            72.801,
            71.164,
            42.082,
            52.906,
            56.867,
            46.859,
            76.442,
            46.242,
            65.528,
            63.062,
            42.568,
            48.159,
            49.339,
            58.556,
            39.613,
            52.517,
            58.42,
            73.923,
            51.542,
            42.384,
            43.487
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Americas<br>year=2007-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "ids": [
            "Argentina",
            "Bolivia",
            "Brazil",
            "Canada",
            "Chile",
            "Colombia",
            "Costa Rica",
            "Cuba",
            "Dominican Republic",
            "Ecuador",
            "El Salvador",
            "Guatemala",
            "Haiti",
            "Honduras",
            "Jamaica",
            "Mexico",
            "Nicaragua",
            "Panama",
            "Paraguay",
            "Peru",
            "Puerto Rico",
            "Trinidad and Tobago",
            "United States",
            "Uruguay",
            "Venezuela"
           ],
           "legendgroup": "Americas",
           "marker": {
            "color": "#ab63fa",
            "size": [
             40301927,
             9119152,
             190010647,
             33390141,
             16284741,
             44227550,
             4133884,
             11416987,
             9319622,
             13755680,
             6939688,
             12572928,
             8502814,
             7483763,
             2780132,
             108700891,
             5675356,
             3242173,
             6667147,
             28674757,
             3942491,
             1056608,
             301139947,
             3447496,
             26084662
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Americas",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            12779.37964,
            3822.137084,
            9065.800825,
            36319.23501,
            13171.63885,
            7006.580419,
            9645.06142,
            8948.102923,
            6025.374752,
            6873.262326,
            5728.353514,
            5186.050003,
            1201.637154,
            3548.330846,
            7320.880262,
            11977.57496,
            2749.320965,
            9809.185636,
            4172.838464,
            7408.905561,
            19328.70901,
            18008.50924,
            42951.65309,
            10611.46299,
            11415.80569
           ],
           "xaxis": "x",
           "y": [
            75.32,
            65.554,
            72.39,
            80.653,
            78.553,
            72.889,
            78.782,
            78.273,
            72.235,
            74.994,
            71.878,
            70.259,
            60.916,
            70.198,
            72.567,
            76.195,
            72.899,
            75.537,
            71.752,
            71.421,
            78.746,
            69.819,
            78.242,
            76.384,
            73.747
           ],
           "yaxis": "y"
          },
          {
           "hovertemplate": "<b>%{hovertext}</b><br><br>continent=Oceania<br>year=2007-01-01 00:00:00<br>gdpPercap=%{x}<br>lifeExp=%{y}<br>pop=%{marker.size}<extra></extra>",
           "hovertext": [
            "Australia",
            "New Zealand"
           ],
           "ids": [
            "Australia",
            "New Zealand"
           ],
           "legendgroup": "Oceania",
           "marker": {
            "color": "#FFA15A",
            "size": [
             20434176,
             4115771
            ],
            "sizemode": "area",
            "sizeref": 435928.2961983471,
            "symbol": "circle"
           },
           "mode": "markers",
           "name": "Oceania",
           "orientation": "v",
           "showlegend": true,
           "type": "scatter",
           "x": [
            34435.36744,
            25185.00911
           ],
           "xaxis": "x",
           "y": [
            81.235,
            80.204
           ],
           "yaxis": "y"
          }
         ],
         "name": "2007-01-01 00:00:00"
        }
       ],
       "layout": {
        "legend": {
         "itemsizing": "constant",
         "title": {
          "text": "continent"
         },
         "tracegroupgap": 0
        },
        "margin": {
         "t": 60
        },
        "sliders": [
         {
          "active": 0,
          "currentvalue": {
           "prefix": "year="
          },
          "len": 0.9,
          "pad": {
           "b": 10,
           "t": 60
          },
          "steps": [
           {
            "args": [
             [
              "1952-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1952-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1957-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1957-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1962-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1962-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1967-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1967-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1972-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1972-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1977-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1977-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1982-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1982-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1987-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1987-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1992-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1992-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "1997-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "1997-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "2002-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "2002-01-01 00:00:00",
            "method": "animate"
           },
           {
            "args": [
             [
              "2007-01-01 00:00:00"
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "2007-01-01 00:00:00",
            "method": "animate"
           }
          ],
          "x": 0.1,
          "xanchor": "left",
          "y": 0,
          "yanchor": "top"
         }
        ],
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             },
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "pattern": {
              "fillmode": "overlay",
              "size": 10,
              "solidity": 0.2
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "fillpattern": {
             "fillmode": "overlay",
             "size": 10,
             "solidity": 0.2
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        },
        "updatemenus": [
         {
          "buttons": [
           {
            "args": [
             null,
             {
              "frame": {
               "duration": 500,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 500,
               "easing": "linear"
              }
             }
            ],
            "label": "&#9654;",
            "method": "animate"
           },
           {
            "args": [
             [
              null
             ],
             {
              "frame": {
               "duration": 0,
               "redraw": false
              },
              "fromcurrent": true,
              "mode": "immediate",
              "transition": {
               "duration": 0,
               "easing": "linear"
              }
             }
            ],
            "label": "&#9724;",
            "method": "animate"
           }
          ],
          "direction": "left",
          "pad": {
           "r": 10,
           "t": 70
          },
          "showactive": false,
          "type": "buttons",
          "x": 0.1,
          "xanchor": "right",
          "y": 0,
          "yanchor": "top"
         }
        ],
        "xaxis": {
         "anchor": "y",
         "domain": [
          0,
          1
         ],
         "range": [
          2,
          5
         ],
         "title": {
          "text": "gdpPercap"
         },
         "type": "log"
        },
        "yaxis": {
         "anchor": "x",
         "domain": [
          0,
          1
         ],
         "range": [
          25,
          90
         ],
         "title": {
          "text": "lifeExp"
         }
        }
       }
      }
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# !pip install plotly==5.22.0\n",
    "import plotly.express as px\n",
    "\n",
    "px.scatter(gapminder, \n",
    "           x=\"gdpPercap\", \n",
    "           y=\"lifeExp\", \n",
    "           animation_frame = \"year\",       \n",
    "           animation_group = \"country\",\n",
    "           size = \"pop\", color = \"continent\", \n",
    "           hover_name = \"country\",\n",
    "           log_x = True, \n",
    "           size_max = 55, \n",
    "           range_x = [100,100000], \n",
    "           range_y=[25,90]\n",
    "           )"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.10.13"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
